import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryProvidersResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* AllProvidersAttributes queries all providers
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    allProvidersAttributes = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `akash/audit/v1beta2/audit/attributes/list`;
        return QueryProvidersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ProviderAttributes queries all provider signed attributes
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    providerAttributes = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `akash/audit/v1beta2/audit/attributes/${params.owner}/list`;
        return QueryProvidersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ProviderAuditorAttributes queries provider signed attributes by specific auditor
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    providerAuditorAttributes = async (params) => {
        const endpoint = `akash/audit/v1beta2/audit/attributes/${params.auditor}/${params.owner}`;
        return QueryProvidersResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* AuditorAttributes queries all providers signed by this auditor
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    auditorAttributes = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `akash/provider/v1beta2/auditor/${params.auditor}/list`;
        return QueryProvidersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
