import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryAllProvidersAttributesRequest, QueryProvidersResponse, QueryProviderAttributesRequest, QueryProviderAuditorRequest, QueryAuditorAttributesRequest } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* AllProvidersAttributes queries all providers
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    allProvidersAttributes = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryAllProvidersAttributesRequest.encode(request).finish();
        const promise = this.rpc.request("akash.audit.v1beta2.Query", "AllProvidersAttributes", data);
        return promise.then(data => QueryProvidersResponse.decode(new BinaryReader(data)));
    };
    /* ProviderAttributes queries all provider signed attributes
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    providerAttributes = async (request) => {
        const data = QueryProviderAttributesRequest.encode(request).finish();
        const promise = this.rpc.request("akash.audit.v1beta2.Query", "ProviderAttributes", data);
        return promise.then(data => QueryProvidersResponse.decode(new BinaryReader(data)));
    };
    /* ProviderAuditorAttributes queries provider signed attributes by specific auditor
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    providerAuditorAttributes = async (request) => {
        const data = QueryProviderAuditorRequest.encode(request).finish();
        const promise = this.rpc.request("akash.audit.v1beta2.Query", "ProviderAuditorAttributes", data);
        return promise.then(data => QueryProvidersResponse.decode(new BinaryReader(data)));
    };
    /* AuditorAttributes queries all providers signed by this auditor
     buf:lint:ignore RPC_REQUEST_RESPONSE_UNIQUE
     buf:lint:ignore RPC_RESPONSE_STANDARD_NAME */
    auditorAttributes = async (request) => {
        const data = QueryAuditorAttributesRequest.encode(request).finish();
        const promise = this.rpc.request("akash.audit.v1beta2.Query", "AuditorAttributes", data);
        return promise.then(data => QueryProvidersResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
