import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.base.v1beta2";
/** Attribute represents key value pair */
export interface Attribute {
    key: string;
    value: string;
}
export interface AttributeProtoMsg {
    typeUrl: "/akash.base.v1beta2.Attribute";
    value: Uint8Array;
}
/** Attribute represents key value pair */
export interface AttributeAmino {
    key?: string;
    value?: string;
}
export interface AttributeAminoMsg {
    type: "akash/base/v1beta2/attribute";
    value: AttributeAmino;
}
/** Attribute represents key value pair */
export interface AttributeSDKType {
    key: string;
    value: string;
}
/**
 * SignedBy represents validation accounts that tenant expects signatures for provider attributes
 * AllOf has precedence i.e. if there is at least one entry AnyOf is ignored regardless to how many
 * entries there
 * this behaviour to be discussed
 */
export interface SignedBy {
    /** all_of all keys in this list must have signed attributes */
    allOf: string[];
    /** any_of at least of of the keys from the list must have signed attributes */
    anyOf: string[];
}
export interface SignedByProtoMsg {
    typeUrl: "/akash.base.v1beta2.SignedBy";
    value: Uint8Array;
}
/**
 * SignedBy represents validation accounts that tenant expects signatures for provider attributes
 * AllOf has precedence i.e. if there is at least one entry AnyOf is ignored regardless to how many
 * entries there
 * this behaviour to be discussed
 */
export interface SignedByAmino {
    /** all_of all keys in this list must have signed attributes */
    all_of: string[];
    /** any_of at least of of the keys from the list must have signed attributes */
    any_of: string[];
}
export interface SignedByAminoMsg {
    type: "akash/base/v1beta2/signed-by";
    value: SignedByAmino;
}
/**
 * SignedBy represents validation accounts that tenant expects signatures for provider attributes
 * AllOf has precedence i.e. if there is at least one entry AnyOf is ignored regardless to how many
 * entries there
 * this behaviour to be discussed
 */
export interface SignedBySDKType {
    all_of: string[];
    any_of: string[];
}
/** PlacementRequirements */
export interface PlacementRequirements {
    /** SignedBy list of keys that tenants expect to have signatures from */
    signedBy: SignedBy;
    /** Attribute list of attributes tenant expects from the provider */
    attributes: Attribute[];
}
export interface PlacementRequirementsProtoMsg {
    typeUrl: "/akash.base.v1beta2.PlacementRequirements";
    value: Uint8Array;
}
/** PlacementRequirements */
export interface PlacementRequirementsAmino {
    /** SignedBy list of keys that tenants expect to have signatures from */
    signed_by: SignedByAmino;
    /** Attribute list of attributes tenant expects from the provider */
    attributes: AttributeAmino[];
}
export interface PlacementRequirementsAminoMsg {
    type: "akash/base/v1beta2/placement-requirements";
    value: PlacementRequirementsAmino;
}
/** PlacementRequirements */
export interface PlacementRequirementsSDKType {
    signed_by: SignedBySDKType;
    attributes: AttributeSDKType[];
}
export declare const Attribute: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Attribute;
    isSDK(o: any): o is AttributeSDKType;
    isAmino(o: any): o is AttributeAmino;
    encode(message: Attribute, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Attribute;
    fromJSON(object: any): Attribute;
    toJSON(message: Attribute): JsonSafe<Attribute>;
    fromPartial<I extends Exact<DeepPartial<Attribute>, I>>(object: I): Attribute;
    fromSDK(object: AttributeSDKType): Attribute;
    fromSDKJSON(object: any): AttributeSDKType;
    toSDK(message: Attribute): AttributeSDKType;
    fromAmino(object: AttributeAmino): Attribute;
    toAmino(message: Attribute): AttributeAmino;
    fromAminoMsg(object: AttributeAminoMsg): Attribute;
    toAminoMsg(message: Attribute): AttributeAminoMsg;
    fromProtoMsg(message: AttributeProtoMsg): Attribute;
    toProto(message: Attribute): Uint8Array;
    toProtoMsg(message: Attribute): AttributeProtoMsg;
    registerTypeUrl(): void;
};
export declare const SignedBy: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is SignedBy;
    isSDK(o: any): o is SignedBySDKType;
    isAmino(o: any): o is SignedByAmino;
    encode(message: SignedBy, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignedBy;
    fromJSON(object: any): SignedBy;
    toJSON(message: SignedBy): JsonSafe<SignedBy>;
    fromPartial<I extends Exact<DeepPartial<SignedBy>, I>>(object: I): SignedBy;
    fromSDK(object: SignedBySDKType): SignedBy;
    fromSDKJSON(object: any): SignedBySDKType;
    toSDK(message: SignedBy): SignedBySDKType;
    fromAmino(object: SignedByAmino): SignedBy;
    toAmino(message: SignedBy): SignedByAmino;
    fromAminoMsg(object: SignedByAminoMsg): SignedBy;
    toAminoMsg(message: SignedBy): SignedByAminoMsg;
    fromProtoMsg(message: SignedByProtoMsg): SignedBy;
    toProto(message: SignedBy): Uint8Array;
    toProtoMsg(message: SignedBy): SignedByProtoMsg;
    registerTypeUrl(): void;
};
export declare const PlacementRequirements: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is PlacementRequirements;
    isSDK(o: any): o is PlacementRequirementsSDKType;
    isAmino(o: any): o is PlacementRequirementsAmino;
    encode(message: PlacementRequirements, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): PlacementRequirements;
    fromJSON(object: any): PlacementRequirements;
    toJSON(message: PlacementRequirements): JsonSafe<PlacementRequirements>;
    fromPartial<I extends Exact<DeepPartial<PlacementRequirements>, I>>(object: I): PlacementRequirements;
    fromSDK(object: PlacementRequirementsSDKType): PlacementRequirements;
    fromSDKJSON(object: any): PlacementRequirementsSDKType;
    toSDK(message: PlacementRequirements): PlacementRequirementsSDKType;
    fromAmino(object: PlacementRequirementsAmino): PlacementRequirements;
    toAmino(message: PlacementRequirements): PlacementRequirementsAmino;
    fromAminoMsg(object: PlacementRequirementsAminoMsg): PlacementRequirements;
    toAminoMsg(message: PlacementRequirements): PlacementRequirementsAminoMsg;
    fromProtoMsg(message: PlacementRequirementsProtoMsg): PlacementRequirements;
    toProto(message: PlacementRequirements): Uint8Array;
    toProtoMsg(message: PlacementRequirements): PlacementRequirementsProtoMsg;
    registerTypeUrl(): void;
};
