import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.cert.v1beta2";
/** State is an enum which refers to state of deployment */
export declare enum Certificate_State {
    /** invalid - Prefix should start with 0 in enum. So declaring dummy state */
    invalid = 0,
    /** valid - CertificateValid denotes state for deployment active */
    valid = 1,
    /** revoked - CertificateRevoked denotes state for deployment closed */
    revoked = 2,
    UNRECOGNIZED = -1
}
export declare const Certificate_StateSDKType: typeof Certificate_State;
export declare const Certificate_StateAmino: typeof Certificate_State;
export declare function certificate_StateFromJSON(object: any): Certificate_State;
export declare function certificate_StateToJSON(object: Certificate_State): string;
/** CertificateID stores owner and sequence number */
export interface CertificateID {
    owner: string;
    serial: string;
}
export interface CertificateIDProtoMsg {
    typeUrl: "/akash.cert.v1beta2.CertificateID";
    value: Uint8Array;
}
/** CertificateID stores owner and sequence number */
export interface CertificateIDAmino {
    owner: string;
    serial: string;
}
export interface CertificateIDAminoMsg {
    type: "akash/cert/v1beta2/certificate-i-d";
    value: CertificateIDAmino;
}
/** CertificateID stores owner and sequence number */
export interface CertificateIDSDKType {
    owner: string;
    serial: string;
}
/** Certificate stores state, certificate and it's public key */
export interface Certificate {
    state: Certificate_State;
    cert: Uint8Array;
    pubkey: Uint8Array;
}
export interface CertificateProtoMsg {
    typeUrl: "/akash.cert.v1beta2.Certificate";
    value: Uint8Array;
}
/** Certificate stores state, certificate and it's public key */
export interface CertificateAmino {
    state: Certificate_State;
    cert: string;
    pubkey: string;
}
export interface CertificateAminoMsg {
    type: "akash/cert/v1beta2/certificate";
    value: CertificateAmino;
}
/** Certificate stores state, certificate and it's public key */
export interface CertificateSDKType {
    state: Certificate_State;
    cert: Uint8Array;
    pubkey: Uint8Array;
}
/** CertificateFilter defines filters used to filter certificates */
export interface CertificateFilter {
    owner: string;
    serial: string;
    state: string;
}
export interface CertificateFilterProtoMsg {
    typeUrl: "/akash.cert.v1beta2.CertificateFilter";
    value: Uint8Array;
}
/** CertificateFilter defines filters used to filter certificates */
export interface CertificateFilterAmino {
    owner: string;
    serial: string;
    state: string;
}
export interface CertificateFilterAminoMsg {
    type: "akash/cert/v1beta2/certificate-filter";
    value: CertificateFilterAmino;
}
/** CertificateFilter defines filters used to filter certificates */
export interface CertificateFilterSDKType {
    owner: string;
    serial: string;
    state: string;
}
/** MsgCreateCertificate defines an SDK message for creating certificate */
export interface MsgCreateCertificate {
    owner: string;
    cert: Uint8Array;
    pubkey: Uint8Array;
}
export interface MsgCreateCertificateProtoMsg {
    typeUrl: "/akash.cert.v1beta2.MsgCreateCertificate";
    value: Uint8Array;
}
/** MsgCreateCertificate defines an SDK message for creating certificate */
export interface MsgCreateCertificateAmino {
    owner: string;
    cert: string;
    pubkey: string;
}
export interface MsgCreateCertificateAminoMsg {
    type: "akash/cert/v1beta2/testonly-create-certificate";
    value: MsgCreateCertificateAmino;
}
/** MsgCreateCertificate defines an SDK message for creating certificate */
export interface MsgCreateCertificateSDKType {
    owner: string;
    cert: Uint8Array;
    pubkey: Uint8Array;
}
/** MsgCreateCertificateResponse defines the Msg/CreateCertificate response type. */
export interface MsgCreateCertificateResponse {
}
export interface MsgCreateCertificateResponseProtoMsg {
    typeUrl: "/akash.cert.v1beta2.MsgCreateCertificateResponse";
    value: Uint8Array;
}
/** MsgCreateCertificateResponse defines the Msg/CreateCertificate response type. */
export interface MsgCreateCertificateResponseAmino {
}
export interface MsgCreateCertificateResponseAminoMsg {
    type: "akash/cert/v1beta2/testonly-create-certificate-response";
    value: MsgCreateCertificateResponseAmino;
}
/** MsgCreateCertificateResponse defines the Msg/CreateCertificate response type. */
export interface MsgCreateCertificateResponseSDKType {
}
/** MsgRevokeCertificate defines an SDK message for revoking certificate */
export interface MsgRevokeCertificate {
    id: CertificateID;
}
export interface MsgRevokeCertificateProtoMsg {
    typeUrl: "/akash.cert.v1beta2.MsgRevokeCertificate";
    value: Uint8Array;
}
/** MsgRevokeCertificate defines an SDK message for revoking certificate */
export interface MsgRevokeCertificateAmino {
    id: CertificateIDAmino;
}
export interface MsgRevokeCertificateAminoMsg {
    type: "akash/cert/v1beta2/testonly-revoke-certificate";
    value: MsgRevokeCertificateAmino;
}
/** MsgRevokeCertificate defines an SDK message for revoking certificate */
export interface MsgRevokeCertificateSDKType {
    id: CertificateIDSDKType;
}
/** MsgRevokeCertificateResponse defines the Msg/RevokeCertificate response type. */
export interface MsgRevokeCertificateResponse {
}
export interface MsgRevokeCertificateResponseProtoMsg {
    typeUrl: "/akash.cert.v1beta2.MsgRevokeCertificateResponse";
    value: Uint8Array;
}
/** MsgRevokeCertificateResponse defines the Msg/RevokeCertificate response type. */
export interface MsgRevokeCertificateResponseAmino {
}
export interface MsgRevokeCertificateResponseAminoMsg {
    type: "akash/cert/v1beta2/testonly-revoke-certificate-response";
    value: MsgRevokeCertificateResponseAmino;
}
/** MsgRevokeCertificateResponse defines the Msg/RevokeCertificate response type. */
export interface MsgRevokeCertificateResponseSDKType {
}
export declare const CertificateID: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is CertificateID;
    isSDK(o: any): o is CertificateIDSDKType;
    isAmino(o: any): o is CertificateIDAmino;
    encode(message: CertificateID, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CertificateID;
    fromJSON(object: any): CertificateID;
    toJSON(message: CertificateID): JsonSafe<CertificateID>;
    fromPartial<I extends Exact<DeepPartial<CertificateID>, I>>(object: I): CertificateID;
    fromSDK(object: CertificateIDSDKType): CertificateID;
    fromSDKJSON(object: any): CertificateIDSDKType;
    toSDK(message: CertificateID): CertificateIDSDKType;
    fromAmino(object: CertificateIDAmino): CertificateID;
    toAmino(message: CertificateID): CertificateIDAmino;
    fromAminoMsg(object: CertificateIDAminoMsg): CertificateID;
    toAminoMsg(message: CertificateID): CertificateIDAminoMsg;
    fromProtoMsg(message: CertificateIDProtoMsg): CertificateID;
    toProto(message: CertificateID): Uint8Array;
    toProtoMsg(message: CertificateID): CertificateIDProtoMsg;
    registerTypeUrl(): void;
};
export declare const Certificate: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Certificate;
    isSDK(o: any): o is CertificateSDKType;
    isAmino(o: any): o is CertificateAmino;
    encode(message: Certificate, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Certificate;
    fromJSON(object: any): Certificate;
    toJSON(message: Certificate): JsonSafe<Certificate>;
    fromPartial<I extends Exact<DeepPartial<Certificate>, I>>(object: I): Certificate;
    fromSDK(object: CertificateSDKType): Certificate;
    fromSDKJSON(object: any): CertificateSDKType;
    toSDK(message: Certificate): CertificateSDKType;
    fromAmino(object: CertificateAmino): Certificate;
    toAmino(message: Certificate): CertificateAmino;
    fromAminoMsg(object: CertificateAminoMsg): Certificate;
    toAminoMsg(message: Certificate): CertificateAminoMsg;
    fromProtoMsg(message: CertificateProtoMsg): Certificate;
    toProto(message: Certificate): Uint8Array;
    toProtoMsg(message: Certificate): CertificateProtoMsg;
    registerTypeUrl(): void;
};
export declare const CertificateFilter: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is CertificateFilter;
    isSDK(o: any): o is CertificateFilterSDKType;
    isAmino(o: any): o is CertificateFilterAmino;
    encode(message: CertificateFilter, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CertificateFilter;
    fromJSON(object: any): CertificateFilter;
    toJSON(message: CertificateFilter): JsonSafe<CertificateFilter>;
    fromPartial<I extends Exact<DeepPartial<CertificateFilter>, I>>(object: I): CertificateFilter;
    fromSDK(object: CertificateFilterSDKType): CertificateFilter;
    fromSDKJSON(object: any): CertificateFilterSDKType;
    toSDK(message: CertificateFilter): CertificateFilterSDKType;
    fromAmino(object: CertificateFilterAmino): CertificateFilter;
    toAmino(message: CertificateFilter): CertificateFilterAmino;
    fromAminoMsg(object: CertificateFilterAminoMsg): CertificateFilter;
    toAminoMsg(message: CertificateFilter): CertificateFilterAminoMsg;
    fromProtoMsg(message: CertificateFilterProtoMsg): CertificateFilter;
    toProto(message: CertificateFilter): Uint8Array;
    toProtoMsg(message: CertificateFilter): CertificateFilterProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCreateCertificate: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCreateCertificate;
    isSDK(o: any): o is MsgCreateCertificateSDKType;
    isAmino(o: any): o is MsgCreateCertificateAmino;
    encode(message: MsgCreateCertificate, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCreateCertificate;
    fromJSON(object: any): MsgCreateCertificate;
    toJSON(message: MsgCreateCertificate): JsonSafe<MsgCreateCertificate>;
    fromPartial<I extends Exact<DeepPartial<MsgCreateCertificate>, I>>(object: I): MsgCreateCertificate;
    fromSDK(object: MsgCreateCertificateSDKType): MsgCreateCertificate;
    fromSDKJSON(object: any): MsgCreateCertificateSDKType;
    toSDK(message: MsgCreateCertificate): MsgCreateCertificateSDKType;
    fromAmino(object: MsgCreateCertificateAmino): MsgCreateCertificate;
    toAmino(message: MsgCreateCertificate): MsgCreateCertificateAmino;
    fromAminoMsg(object: MsgCreateCertificateAminoMsg): MsgCreateCertificate;
    toAminoMsg(message: MsgCreateCertificate): MsgCreateCertificateAminoMsg;
    fromProtoMsg(message: MsgCreateCertificateProtoMsg): MsgCreateCertificate;
    toProto(message: MsgCreateCertificate): Uint8Array;
    toProtoMsg(message: MsgCreateCertificate): MsgCreateCertificateProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCreateCertificateResponse: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCreateCertificateResponse;
    isSDK(o: any): o is MsgCreateCertificateResponseSDKType;
    isAmino(o: any): o is MsgCreateCertificateResponseAmino;
    encode(_: MsgCreateCertificateResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCreateCertificateResponse;
    fromJSON(_: any): MsgCreateCertificateResponse;
    toJSON(_: MsgCreateCertificateResponse): JsonSafe<MsgCreateCertificateResponse>;
    fromPartial<I extends Exact<DeepPartial<MsgCreateCertificateResponse>, I>>(_: I): MsgCreateCertificateResponse;
    fromSDK(_: MsgCreateCertificateResponseSDKType): MsgCreateCertificateResponse;
    fromSDKJSON(_: any): MsgCreateCertificateResponseSDKType;
    toSDK(_: MsgCreateCertificateResponse): MsgCreateCertificateResponseSDKType;
    fromAmino(_: MsgCreateCertificateResponseAmino): MsgCreateCertificateResponse;
    toAmino(_: MsgCreateCertificateResponse): MsgCreateCertificateResponseAmino;
    fromAminoMsg(object: MsgCreateCertificateResponseAminoMsg): MsgCreateCertificateResponse;
    toAminoMsg(message: MsgCreateCertificateResponse): MsgCreateCertificateResponseAminoMsg;
    fromProtoMsg(message: MsgCreateCertificateResponseProtoMsg): MsgCreateCertificateResponse;
    toProto(message: MsgCreateCertificateResponse): Uint8Array;
    toProtoMsg(message: MsgCreateCertificateResponse): MsgCreateCertificateResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgRevokeCertificate: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgRevokeCertificate;
    isSDK(o: any): o is MsgRevokeCertificateSDKType;
    isAmino(o: any): o is MsgRevokeCertificateAmino;
    encode(message: MsgRevokeCertificate, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgRevokeCertificate;
    fromJSON(object: any): MsgRevokeCertificate;
    toJSON(message: MsgRevokeCertificate): JsonSafe<MsgRevokeCertificate>;
    fromPartial<I extends Exact<DeepPartial<MsgRevokeCertificate>, I>>(object: I): MsgRevokeCertificate;
    fromSDK(object: MsgRevokeCertificateSDKType): MsgRevokeCertificate;
    fromSDKJSON(object: any): MsgRevokeCertificateSDKType;
    toSDK(message: MsgRevokeCertificate): MsgRevokeCertificateSDKType;
    fromAmino(object: MsgRevokeCertificateAmino): MsgRevokeCertificate;
    toAmino(message: MsgRevokeCertificate): MsgRevokeCertificateAmino;
    fromAminoMsg(object: MsgRevokeCertificateAminoMsg): MsgRevokeCertificate;
    toAminoMsg(message: MsgRevokeCertificate): MsgRevokeCertificateAminoMsg;
    fromProtoMsg(message: MsgRevokeCertificateProtoMsg): MsgRevokeCertificate;
    toProto(message: MsgRevokeCertificate): Uint8Array;
    toProtoMsg(message: MsgRevokeCertificate): MsgRevokeCertificateProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgRevokeCertificateResponse: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgRevokeCertificateResponse;
    isSDK(o: any): o is MsgRevokeCertificateResponseSDKType;
    isAmino(o: any): o is MsgRevokeCertificateResponseAmino;
    encode(_: MsgRevokeCertificateResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgRevokeCertificateResponse;
    fromJSON(_: any): MsgRevokeCertificateResponse;
    toJSON(_: MsgRevokeCertificateResponse): JsonSafe<MsgRevokeCertificateResponse>;
    fromPartial<I extends Exact<DeepPartial<MsgRevokeCertificateResponse>, I>>(_: I): MsgRevokeCertificateResponse;
    fromSDK(_: MsgRevokeCertificateResponseSDKType): MsgRevokeCertificateResponse;
    fromSDKJSON(_: any): MsgRevokeCertificateResponseSDKType;
    toSDK(_: MsgRevokeCertificateResponse): MsgRevokeCertificateResponseSDKType;
    fromAmino(_: MsgRevokeCertificateResponseAmino): MsgRevokeCertificateResponse;
    toAmino(_: MsgRevokeCertificateResponse): MsgRevokeCertificateResponseAmino;
    fromAminoMsg(object: MsgRevokeCertificateResponseAminoMsg): MsgRevokeCertificateResponse;
    toAminoMsg(message: MsgRevokeCertificateResponse): MsgRevokeCertificateResponseAminoMsg;
    fromProtoMsg(message: MsgRevokeCertificateResponseProtoMsg): MsgRevokeCertificateResponse;
    toProto(message: MsgRevokeCertificateResponse): Uint8Array;
    toProtoMsg(message: MsgRevokeCertificateResponse): MsgRevokeCertificateResponseProtoMsg;
    registerTypeUrl(): void;
};
