import { CertificateFilter, Certificate } from "./cert";
import { PageRequest, PageResponse } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.cert.v1beta2";
function createBaseCertificateResponse() {
    return {
        certificate: Certificate.fromPartial({}),
        serial: ""
    };
}
export const CertificateResponse = {
    typeUrl: "/akash.cert.v1beta2.CertificateResponse",
    aminoType: "akash/cert/v1beta2/certificate-response",
    is(o) {
        return o && (o.$typeUrl === CertificateResponse.typeUrl || Certificate.is(o.certificate) && typeof o.serial === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CertificateResponse.typeUrl || Certificate.isSDK(o.certificate) && typeof o.serial === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CertificateResponse.typeUrl || Certificate.isAmino(o.certificate) && typeof o.serial === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.certificate !== undefined) {
            Certificate.encode(message.certificate, writer.uint32(10).fork()).ldelim();
        }
        if (message.serial !== undefined) {
            writer.uint32(18).string(message.serial);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCertificateResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.certificate = Certificate.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.serial = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCertificateResponse();
        if (isSet(object.certificate))
            obj.certificate = Certificate.fromJSON(object.certificate);
        if (isSet(object.serial))
            obj.serial = String(object.serial);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.certificate !== undefined && (obj.certificate = message.certificate ? Certificate.toJSON(message.certificate) : undefined);
        message.serial !== undefined && (obj.serial = message.serial);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCertificateResponse();
        if (object.certificate !== undefined && object.certificate !== null) {
            message.certificate = Certificate.fromPartial(object.certificate);
        }
        message.serial = object.serial ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            certificate: object.certificate ? Certificate.fromSDK(object.certificate) : undefined,
            serial: object?.serial
        };
    },
    fromSDKJSON(object) {
        return {
            certificate: isSet(object.certificate) ? Certificate.fromSDKJSON(object.certificate) : undefined,
            serial: isSet(object.serial) ? String(object.serial) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        message.certificate !== undefined && (obj.certificate = message.certificate ? Certificate.toSDK(message.certificate) : undefined);
        obj.serial = message.serial;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCertificateResponse();
        if (object.certificate !== undefined && object.certificate !== null) {
            message.certificate = Certificate.fromAmino(object.certificate);
        }
        if (object.serial !== undefined && object.serial !== null) {
            message.serial = object.serial;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.certificate = message.certificate ? Certificate.toAmino(message.certificate) : Certificate.toAmino(Certificate.fromPartial({}));
        obj.serial = message.serial ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return CertificateResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/cert/v1beta2/certificate-response",
            value: CertificateResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return CertificateResponse.decode(message.value);
    },
    toProto(message) {
        return CertificateResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.cert.v1beta2.CertificateResponse",
            value: CertificateResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Certificate.registerTypeUrl();
    }
};
function createBaseQueryCertificatesRequest() {
    return {
        filter: CertificateFilter.fromPartial({}),
        pagination: undefined
    };
}
export const QueryCertificatesRequest = {
    typeUrl: "/akash.cert.v1beta2.QueryCertificatesRequest",
    aminoType: "akash/cert/v1beta2/query-certificates-request",
    is(o) {
        return o && (o.$typeUrl === QueryCertificatesRequest.typeUrl || CertificateFilter.is(o.filter));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryCertificatesRequest.typeUrl || CertificateFilter.isSDK(o.filter));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryCertificatesRequest.typeUrl || CertificateFilter.isAmino(o.filter));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.filter !== undefined) {
            CertificateFilter.encode(message.filter, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageRequest.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryCertificatesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.filter = CertificateFilter.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.pagination = PageRequest.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryCertificatesRequest();
        if (isSet(object.filter))
            obj.filter = CertificateFilter.fromJSON(object.filter);
        if (isSet(object.pagination))
            obj.pagination = PageRequest.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.filter !== undefined && (obj.filter = message.filter ? CertificateFilter.toJSON(message.filter) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryCertificatesRequest();
        if (object.filter !== undefined && object.filter !== null) {
            message.filter = CertificateFilter.fromPartial(object.filter);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            filter: object.filter ? CertificateFilter.fromSDK(object.filter) : undefined,
            pagination: object.pagination ? PageRequest.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            filter: isSet(object.filter) ? CertificateFilter.fromSDKJSON(object.filter) : undefined,
            pagination: isSet(object.pagination) ? PageRequest.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.filter !== undefined && (obj.filter = message.filter ? CertificateFilter.toSDK(message.filter) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryCertificatesRequest();
        if (object.filter !== undefined && object.filter !== null) {
            message.filter = CertificateFilter.fromAmino(object.filter);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.filter = message.filter ? CertificateFilter.toAmino(message.filter) : undefined;
        obj.pagination = message.pagination ? PageRequest.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryCertificatesRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/cert/v1beta2/query-certificates-request",
            value: QueryCertificatesRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryCertificatesRequest.decode(message.value);
    },
    toProto(message) {
        return QueryCertificatesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.cert.v1beta2.QueryCertificatesRequest",
            value: QueryCertificatesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        CertificateFilter.registerTypeUrl();
        PageRequest.registerTypeUrl();
    }
};
function createBaseQueryCertificatesResponse() {
    return {
        certificates: [],
        pagination: undefined
    };
}
export const QueryCertificatesResponse = {
    typeUrl: "/akash.cert.v1beta2.QueryCertificatesResponse",
    aminoType: "akash/cert/v1beta2/query-certificates-response",
    is(o) {
        return o && (o.$typeUrl === QueryCertificatesResponse.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || CertificateResponse.is(o.certificates[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryCertificatesResponse.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || CertificateResponse.isSDK(o.certificates[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryCertificatesResponse.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || CertificateResponse.isAmino(o.certificates[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.certificates) {
            CertificateResponse.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageResponse.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryCertificatesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.certificates.push(CertificateResponse.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.pagination = PageResponse.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryCertificatesResponse();
        if (Array.isArray(object?.certificates))
            obj.certificates = object.certificates.map((e) => CertificateResponse.fromJSON(e));
        if (isSet(object.pagination))
            obj.pagination = PageResponse.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? CertificateResponse.toJSON(e) : undefined);
        }
        else {
            obj.certificates = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryCertificatesResponse();
        message.certificates = object.certificates?.map(e => CertificateResponse.fromPartial(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            certificates: Array.isArray(object?.certificates) ? object.certificates.map((e) => CertificateResponse.fromSDK(e)) : [],
            pagination: object.pagination ? PageResponse.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            certificates: Array.isArray(object?.certificates) ? object.certificates.map((e) => CertificateResponse.fromSDKJSON(e)) : [],
            pagination: isSet(object.pagination) ? PageResponse.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? CertificateResponse.toSDK(e) : undefined);
        }
        else {
            obj.certificates = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryCertificatesResponse();
        message.certificates = object.certificates?.map(e => CertificateResponse.fromAmino(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? CertificateResponse.toAmino(e) : undefined);
        }
        else {
            obj.certificates = message.certificates;
        }
        obj.pagination = message.pagination ? PageResponse.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryCertificatesResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/cert/v1beta2/query-certificates-response",
            value: QueryCertificatesResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryCertificatesResponse.decode(message.value);
    },
    toProto(message) {
        return QueryCertificatesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.cert.v1beta2.QueryCertificatesResponse",
            value: QueryCertificatesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        CertificateResponse.registerTypeUrl();
        PageResponse.registerTypeUrl();
    }
};
