import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryCertificatesRequest, QueryCertificatesResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Certificates queries certificates */
    certificates = async (request) => {
        const data = QueryCertificatesRequest.encode(request).finish();
        const promise = this.rpc.request("akash.cert.v1beta2.Query", "Certificates", data);
        return promise.then(data => QueryCertificatesResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useCertificates = ({ request, options }) => {
        return useQuery(["certificatesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.certificates(request);
        }, options);
    };
    return {
        /** Certificates queries certificates */ useCertificates
    };
};
