import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.deployment.v1beta2";
/** State is an enum which refers to state of deployment */
export declare enum Deployment_State {
    /** invalid - Prefix should start with 0 in enum. So declaring dummy state */
    invalid = 0,
    /** active - DeploymentActive denotes state for deployment active */
    active = 1,
    /** closed - DeploymentClosed denotes state for deployment closed */
    closed = 2,
    UNRECOGNIZED = -1
}
export declare const Deployment_StateSDKType: typeof Deployment_State;
export declare const Deployment_StateAmino: typeof Deployment_State;
export declare function deployment_StateFromJSON(object: any): Deployment_State;
export declare function deployment_StateToJSON(object: Deployment_State): string;
/** DeploymentID stores owner and sequence number */
export interface DeploymentID {
    owner: string;
    dseq: bigint;
}
export interface DeploymentIDProtoMsg {
    typeUrl: "/akash.deployment.v1beta2.DeploymentID";
    value: Uint8Array;
}
/** DeploymentID stores owner and sequence number */
export interface DeploymentIDAmino {
    owner: string;
    dseq: string;
}
export interface DeploymentIDAminoMsg {
    type: "akash/deployment/v1beta2/deployment-i-d";
    value: DeploymentIDAmino;
}
/** DeploymentID stores owner and sequence number */
export interface DeploymentIDSDKType {
    owner: string;
    dseq: bigint;
}
/** Deployment stores deploymentID, state and version details */
export interface Deployment {
    deploymentId: DeploymentID;
    state: Deployment_State;
    version: Uint8Array;
    createdAt: bigint;
}
export interface DeploymentProtoMsg {
    typeUrl: "/akash.deployment.v1beta2.Deployment";
    value: Uint8Array;
}
/** Deployment stores deploymentID, state and version details */
export interface DeploymentAmino {
    deployment_id: DeploymentIDAmino;
    state: Deployment_State;
    version: string;
    created_at?: string;
}
export interface DeploymentAminoMsg {
    type: "akash/deployment/v1beta2/deployment";
    value: DeploymentAmino;
}
/** Deployment stores deploymentID, state and version details */
export interface DeploymentSDKType {
    deployment_id: DeploymentIDSDKType;
    state: Deployment_State;
    version: Uint8Array;
    created_at: bigint;
}
/** DeploymentFilters defines filters used to filter deployments */
export interface DeploymentFilters {
    owner: string;
    dseq: bigint;
    state: string;
}
export interface DeploymentFiltersProtoMsg {
    typeUrl: "/akash.deployment.v1beta2.DeploymentFilters";
    value: Uint8Array;
}
/** DeploymentFilters defines filters used to filter deployments */
export interface DeploymentFiltersAmino {
    owner: string;
    dseq: string;
    state: string;
}
export interface DeploymentFiltersAminoMsg {
    type: "akash/deployment/v1beta2/deployment-filters";
    value: DeploymentFiltersAmino;
}
/** DeploymentFilters defines filters used to filter deployments */
export interface DeploymentFiltersSDKType {
    owner: string;
    dseq: bigint;
    state: string;
}
export declare const DeploymentID: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is DeploymentID;
    isSDK(o: any): o is DeploymentIDSDKType;
    isAmino(o: any): o is DeploymentIDAmino;
    encode(message: DeploymentID, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeploymentID;
    fromJSON(object: any): DeploymentID;
    toJSON(message: DeploymentID): JsonSafe<DeploymentID>;
    fromPartial<I extends Exact<DeepPartial<DeploymentID>, I>>(object: I): DeploymentID;
    fromSDK(object: DeploymentIDSDKType): DeploymentID;
    fromSDKJSON(object: any): DeploymentIDSDKType;
    toSDK(message: DeploymentID): DeploymentIDSDKType;
    fromAmino(object: DeploymentIDAmino): DeploymentID;
    toAmino(message: DeploymentID): DeploymentIDAmino;
    fromAminoMsg(object: DeploymentIDAminoMsg): DeploymentID;
    toAminoMsg(message: DeploymentID): DeploymentIDAminoMsg;
    fromProtoMsg(message: DeploymentIDProtoMsg): DeploymentID;
    toProto(message: DeploymentID): Uint8Array;
    toProtoMsg(message: DeploymentID): DeploymentIDProtoMsg;
    registerTypeUrl(): void;
};
export declare const Deployment: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Deployment;
    isSDK(o: any): o is DeploymentSDKType;
    isAmino(o: any): o is DeploymentAmino;
    encode(message: Deployment, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Deployment;
    fromJSON(object: any): Deployment;
    toJSON(message: Deployment): JsonSafe<Deployment>;
    fromPartial<I extends Exact<DeepPartial<Deployment>, I>>(object: I): Deployment;
    fromSDK(object: DeploymentSDKType): Deployment;
    fromSDKJSON(object: any): DeploymentSDKType;
    toSDK(message: Deployment): DeploymentSDKType;
    fromAmino(object: DeploymentAmino): Deployment;
    toAmino(message: Deployment): DeploymentAmino;
    fromAminoMsg(object: DeploymentAminoMsg): Deployment;
    toAminoMsg(message: Deployment): DeploymentAminoMsg;
    fromProtoMsg(message: DeploymentProtoMsg): Deployment;
    toProto(message: Deployment): Uint8Array;
    toProtoMsg(message: Deployment): DeploymentProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeploymentFilters: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is DeploymentFilters;
    isSDK(o: any): o is DeploymentFiltersSDKType;
    isAmino(o: any): o is DeploymentFiltersAmino;
    encode(message: DeploymentFilters, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeploymentFilters;
    fromJSON(object: any): DeploymentFilters;
    toJSON(message: DeploymentFilters): JsonSafe<DeploymentFilters>;
    fromPartial<I extends Exact<DeepPartial<DeploymentFilters>, I>>(object: I): DeploymentFilters;
    fromSDK(object: DeploymentFiltersSDKType): DeploymentFilters;
    fromSDKJSON(object: any): DeploymentFiltersSDKType;
    toSDK(message: DeploymentFilters): DeploymentFiltersSDKType;
    fromAmino(object: DeploymentFiltersAmino): DeploymentFilters;
    toAmino(message: DeploymentFilters): DeploymentFiltersAmino;
    fromAminoMsg(object: DeploymentFiltersAminoMsg): DeploymentFilters;
    toAminoMsg(message: DeploymentFilters): DeploymentFiltersAminoMsg;
    fromProtoMsg(message: DeploymentFiltersProtoMsg): DeploymentFilters;
    toProto(message: DeploymentFilters): Uint8Array;
    toProtoMsg(message: DeploymentFilters): DeploymentFiltersProtoMsg;
    registerTypeUrl(): void;
};
