import { DeploymentID } from "./deployment";
import { GroupSpec } from "./groupspec";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet, bytesFromBase64, base64FromBytes } from "../../../helpers";
export const protobufPackage = "akash.deployment.v1beta2";
function createBaseMsgCreateDeployment() {
    return {
        id: DeploymentID.fromPartial({}),
        groups: [],
        version: new Uint8Array(),
        deposit: Coin.fromPartial({}),
        depositor: ""
    };
}
export const MsgCreateDeployment = {
    typeUrl: "/akash.deployment.v1beta2.MsgCreateDeployment",
    aminoType: "akash/deployment/v1beta2/testonly-create-deployment",
    is(o) {
        return o && (o.$typeUrl === MsgCreateDeployment.typeUrl || DeploymentID.is(o.id) && Array.isArray(o.groups) && (!o.groups.length || GroupSpec.is(o.groups[0])) && (o.version instanceof Uint8Array || typeof o.version === "string") && Coin.is(o.deposit) && typeof o.depositor === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgCreateDeployment.typeUrl || DeploymentID.isSDK(o.id) && Array.isArray(o.groups) && (!o.groups.length || GroupSpec.isSDK(o.groups[0])) && (o.version instanceof Uint8Array || typeof o.version === "string") && Coin.isSDK(o.deposit) && typeof o.depositor === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgCreateDeployment.typeUrl || DeploymentID.isAmino(o.id) && Array.isArray(o.groups) && (!o.groups.length || GroupSpec.isAmino(o.groups[0])) && (o.version instanceof Uint8Array || typeof o.version === "string") && Coin.isAmino(o.deposit) && typeof o.depositor === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            DeploymentID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        for (const v of message.groups) {
            GroupSpec.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.version.length !== 0) {
            writer.uint32(26).bytes(message.version);
        }
        if (message.deposit !== undefined) {
            Coin.encode(message.deposit, writer.uint32(34).fork()).ldelim();
        }
        if (message.depositor !== undefined) {
            writer.uint32(42).string(message.depositor);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCreateDeployment();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = DeploymentID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.groups.push(GroupSpec.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.version = reader.bytes();
                    break;
                case 4:
                    message.deposit = Coin.decode(reader, reader.uint32());
                    break;
                case 5:
                    message.depositor = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgCreateDeployment();
        if (isSet(object.id))
            obj.id = DeploymentID.fromJSON(object.id);
        if (Array.isArray(object?.groups))
            obj.groups = object.groups.map((e) => GroupSpec.fromJSON(e));
        if (isSet(object.version))
            obj.version = bytesFromBase64(object.version);
        if (isSet(object.deposit))
            obj.deposit = Coin.fromJSON(object.deposit);
        if (isSet(object.depositor))
            obj.depositor = String(object.depositor);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toJSON(message.id) : undefined);
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? GroupSpec.toJSON(e) : undefined);
        }
        else {
            obj.groups = [];
        }
        message.version !== undefined && (obj.version = base64FromBytes(message.version !== undefined ? message.version : new Uint8Array()));
        message.deposit !== undefined && (obj.deposit = message.deposit ? Coin.toJSON(message.deposit) : undefined);
        message.depositor !== undefined && (obj.depositor = message.depositor);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgCreateDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromPartial(object.id);
        }
        message.groups = object.groups?.map(e => GroupSpec.fromPartial(e)) || [];
        message.version = object.version ?? new Uint8Array();
        if (object.deposit !== undefined && object.deposit !== null) {
            message.deposit = Coin.fromPartial(object.deposit);
        }
        message.depositor = object.depositor ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? DeploymentID.fromSDK(object.id) : undefined,
            groups: Array.isArray(object?.groups) ? object.groups.map((e) => GroupSpec.fromSDK(e)) : [],
            version: object?.version,
            deposit: object.deposit ? Coin.fromSDK(object.deposit) : undefined,
            depositor: object?.depositor
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? DeploymentID.fromSDKJSON(object.id) : undefined,
            groups: Array.isArray(object?.groups) ? object.groups.map((e) => GroupSpec.fromSDKJSON(e)) : [],
            version: isSet(object.version) ? bytesFromBase64(object.version) : new Uint8Array(),
            deposit: isSet(object.deposit) ? Coin.fromSDKJSON(object.deposit) : undefined,
            depositor: isSet(object.depositor) ? String(object.depositor) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toSDK(message.id) : undefined);
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? GroupSpec.toSDK(e) : undefined);
        }
        else {
            obj.groups = [];
        }
        obj.version = message.version;
        message.deposit !== undefined && (obj.deposit = message.deposit ? Coin.toSDK(message.deposit) : undefined);
        obj.depositor = message.depositor;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgCreateDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromAmino(object.id);
        }
        message.groups = object.groups?.map(e => GroupSpec.fromAmino(e)) || [];
        if (object.version !== undefined && object.version !== null) {
            message.version = bytesFromBase64(object.version);
        }
        if (object.deposit !== undefined && object.deposit !== null) {
            message.deposit = Coin.fromAmino(object.deposit);
        }
        if (object.depositor !== undefined && object.depositor !== null) {
            message.depositor = object.depositor;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? DeploymentID.toAmino(message.id) : DeploymentID.toAmino(DeploymentID.fromPartial({}));
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? GroupSpec.toAmino(e) : undefined);
        }
        else {
            obj.groups = message.groups;
        }
        obj.version = message.version ? base64FromBytes(message.version) : "";
        obj.deposit = message.deposit ? Coin.toAmino(message.deposit) : Coin.toAmino(Coin.fromPartial({}));
        obj.depositor = message.depositor ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCreateDeployment.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-create-deployment",
            value: MsgCreateDeployment.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCreateDeployment.decode(message.value);
    },
    toProto(message) {
        return MsgCreateDeployment.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgCreateDeployment",
            value: MsgCreateDeployment.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentID.registerTypeUrl();
        GroupSpec.registerTypeUrl();
        Coin.registerTypeUrl();
    }
};
function createBaseMsgCreateDeploymentResponse() {
    return {};
}
export const MsgCreateDeploymentResponse = {
    typeUrl: "/akash.deployment.v1beta2.MsgCreateDeploymentResponse",
    aminoType: "akash/deployment/v1beta2/testonly-create-deployment-response",
    is(o) {
        return o && o.$typeUrl === MsgCreateDeploymentResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgCreateDeploymentResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgCreateDeploymentResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCreateDeploymentResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgCreateDeploymentResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgCreateDeploymentResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgCreateDeploymentResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCreateDeploymentResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-create-deployment-response",
            value: MsgCreateDeploymentResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCreateDeploymentResponse.decode(message.value);
    },
    toProto(message) {
        return MsgCreateDeploymentResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgCreateDeploymentResponse",
            value: MsgCreateDeploymentResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseMsgDepositDeployment() {
    return {
        id: DeploymentID.fromPartial({}),
        amount: Coin.fromPartial({}),
        depositor: ""
    };
}
export const MsgDepositDeployment = {
    typeUrl: "/akash.deployment.v1beta2.MsgDepositDeployment",
    aminoType: "akash/deployment/v1beta2/testonly-deposit-deployment",
    is(o) {
        return o && (o.$typeUrl === MsgDepositDeployment.typeUrl || DeploymentID.is(o.id) && Coin.is(o.amount) && typeof o.depositor === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgDepositDeployment.typeUrl || DeploymentID.isSDK(o.id) && Coin.isSDK(o.amount) && typeof o.depositor === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgDepositDeployment.typeUrl || DeploymentID.isAmino(o.id) && Coin.isAmino(o.amount) && typeof o.depositor === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            DeploymentID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        if (message.amount !== undefined) {
            Coin.encode(message.amount, writer.uint32(18).fork()).ldelim();
        }
        if (message.depositor !== undefined) {
            writer.uint32(26).string(message.depositor);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgDepositDeployment();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = DeploymentID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.amount = Coin.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.depositor = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgDepositDeployment();
        if (isSet(object.id))
            obj.id = DeploymentID.fromJSON(object.id);
        if (isSet(object.amount))
            obj.amount = Coin.fromJSON(object.amount);
        if (isSet(object.depositor))
            obj.depositor = String(object.depositor);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toJSON(message.id) : undefined);
        message.amount !== undefined && (obj.amount = message.amount ? Coin.toJSON(message.amount) : undefined);
        message.depositor !== undefined && (obj.depositor = message.depositor);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgDepositDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromPartial(object.id);
        }
        if (object.amount !== undefined && object.amount !== null) {
            message.amount = Coin.fromPartial(object.amount);
        }
        message.depositor = object.depositor ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? DeploymentID.fromSDK(object.id) : undefined,
            amount: object.amount ? Coin.fromSDK(object.amount) : undefined,
            depositor: object?.depositor
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? DeploymentID.fromSDKJSON(object.id) : undefined,
            amount: isSet(object.amount) ? Coin.fromSDKJSON(object.amount) : undefined,
            depositor: isSet(object.depositor) ? String(object.depositor) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toSDK(message.id) : undefined);
        message.amount !== undefined && (obj.amount = message.amount ? Coin.toSDK(message.amount) : undefined);
        obj.depositor = message.depositor;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgDepositDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromAmino(object.id);
        }
        if (object.amount !== undefined && object.amount !== null) {
            message.amount = Coin.fromAmino(object.amount);
        }
        if (object.depositor !== undefined && object.depositor !== null) {
            message.depositor = object.depositor;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? DeploymentID.toAmino(message.id) : DeploymentID.toAmino(DeploymentID.fromPartial({}));
        obj.amount = message.amount ? Coin.toAmino(message.amount) : Coin.toAmino(Coin.fromPartial({}));
        obj.depositor = message.depositor ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return MsgDepositDeployment.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-deposit-deployment",
            value: MsgDepositDeployment.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgDepositDeployment.decode(message.value);
    },
    toProto(message) {
        return MsgDepositDeployment.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgDepositDeployment",
            value: MsgDepositDeployment.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentID.registerTypeUrl();
        Coin.registerTypeUrl();
    }
};
function createBaseMsgDepositDeploymentResponse() {
    return {};
}
export const MsgDepositDeploymentResponse = {
    typeUrl: "/akash.deployment.v1beta2.MsgDepositDeploymentResponse",
    aminoType: "akash/deployment/v1beta2/testonly-deposit-deployment-response",
    is(o) {
        return o && o.$typeUrl === MsgDepositDeploymentResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgDepositDeploymentResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgDepositDeploymentResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgDepositDeploymentResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgDepositDeploymentResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgDepositDeploymentResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgDepositDeploymentResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgDepositDeploymentResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-deposit-deployment-response",
            value: MsgDepositDeploymentResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgDepositDeploymentResponse.decode(message.value);
    },
    toProto(message) {
        return MsgDepositDeploymentResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgDepositDeploymentResponse",
            value: MsgDepositDeploymentResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseMsgUpdateDeployment() {
    return {
        id: DeploymentID.fromPartial({}),
        version: new Uint8Array()
    };
}
export const MsgUpdateDeployment = {
    typeUrl: "/akash.deployment.v1beta2.MsgUpdateDeployment",
    aminoType: "akash/deployment/v1beta2/testonly-update-deployment",
    is(o) {
        return o && (o.$typeUrl === MsgUpdateDeployment.typeUrl || DeploymentID.is(o.id) && (o.version instanceof Uint8Array || typeof o.version === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgUpdateDeployment.typeUrl || DeploymentID.isSDK(o.id) && (o.version instanceof Uint8Array || typeof o.version === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgUpdateDeployment.typeUrl || DeploymentID.isAmino(o.id) && (o.version instanceof Uint8Array || typeof o.version === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            DeploymentID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        if (message.version.length !== 0) {
            writer.uint32(26).bytes(message.version);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgUpdateDeployment();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = DeploymentID.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.version = reader.bytes();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgUpdateDeployment();
        if (isSet(object.id))
            obj.id = DeploymentID.fromJSON(object.id);
        if (isSet(object.version))
            obj.version = bytesFromBase64(object.version);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toJSON(message.id) : undefined);
        message.version !== undefined && (obj.version = base64FromBytes(message.version !== undefined ? message.version : new Uint8Array()));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgUpdateDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromPartial(object.id);
        }
        message.version = object.version ?? new Uint8Array();
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? DeploymentID.fromSDK(object.id) : undefined,
            version: object?.version
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? DeploymentID.fromSDKJSON(object.id) : undefined,
            version: isSet(object.version) ? bytesFromBase64(object.version) : new Uint8Array()
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toSDK(message.id) : undefined);
        obj.version = message.version;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgUpdateDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromAmino(object.id);
        }
        if (object.version !== undefined && object.version !== null) {
            message.version = bytesFromBase64(object.version);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? DeploymentID.toAmino(message.id) : DeploymentID.toAmino(DeploymentID.fromPartial({}));
        obj.version = message.version ? base64FromBytes(message.version) : "";
        return obj;
    },
    fromAminoMsg(object) {
        return MsgUpdateDeployment.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-update-deployment",
            value: MsgUpdateDeployment.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgUpdateDeployment.decode(message.value);
    },
    toProto(message) {
        return MsgUpdateDeployment.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgUpdateDeployment",
            value: MsgUpdateDeployment.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentID.registerTypeUrl();
    }
};
function createBaseMsgUpdateDeploymentResponse() {
    return {};
}
export const MsgUpdateDeploymentResponse = {
    typeUrl: "/akash.deployment.v1beta2.MsgUpdateDeploymentResponse",
    aminoType: "akash/deployment/v1beta2/testonly-update-deployment-response",
    is(o) {
        return o && o.$typeUrl === MsgUpdateDeploymentResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgUpdateDeploymentResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgUpdateDeploymentResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgUpdateDeploymentResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgUpdateDeploymentResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgUpdateDeploymentResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgUpdateDeploymentResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgUpdateDeploymentResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-update-deployment-response",
            value: MsgUpdateDeploymentResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgUpdateDeploymentResponse.decode(message.value);
    },
    toProto(message) {
        return MsgUpdateDeploymentResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgUpdateDeploymentResponse",
            value: MsgUpdateDeploymentResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseMsgCloseDeployment() {
    return {
        id: DeploymentID.fromPartial({})
    };
}
export const MsgCloseDeployment = {
    typeUrl: "/akash.deployment.v1beta2.MsgCloseDeployment",
    aminoType: "akash/deployment/v1beta2/testonly-close-deployment",
    is(o) {
        return o && (o.$typeUrl === MsgCloseDeployment.typeUrl || DeploymentID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgCloseDeployment.typeUrl || DeploymentID.isSDK(o.id));
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgCloseDeployment.typeUrl || DeploymentID.isAmino(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            DeploymentID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCloseDeployment();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = DeploymentID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgCloseDeployment();
        if (isSet(object.id))
            obj.id = DeploymentID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgCloseDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? DeploymentID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? DeploymentID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgCloseDeployment();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? DeploymentID.toAmino(message.id) : DeploymentID.toAmino(DeploymentID.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCloseDeployment.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-close-deployment",
            value: MsgCloseDeployment.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCloseDeployment.decode(message.value);
    },
    toProto(message) {
        return MsgCloseDeployment.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgCloseDeployment",
            value: MsgCloseDeployment.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentID.registerTypeUrl();
    }
};
function createBaseMsgCloseDeploymentResponse() {
    return {};
}
export const MsgCloseDeploymentResponse = {
    typeUrl: "/akash.deployment.v1beta2.MsgCloseDeploymentResponse",
    aminoType: "akash/deployment/v1beta2/testonly-close-deployment-response",
    is(o) {
        return o && o.$typeUrl === MsgCloseDeploymentResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgCloseDeploymentResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgCloseDeploymentResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCloseDeploymentResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgCloseDeploymentResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgCloseDeploymentResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgCloseDeploymentResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCloseDeploymentResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/v1beta2/testonly-close-deployment-response",
            value: MsgCloseDeploymentResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCloseDeploymentResponse.decode(message.value);
    },
    toProto(message) {
        return MsgCloseDeploymentResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta2.MsgCloseDeploymentResponse",
            value: MsgCloseDeploymentResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
