import { TelescopeGeneratedType } from "../../../types";
import { Registry } from "@cosmjs/proto-signing";
import { MsgCreateDeployment, MsgDepositDeployment, MsgUpdateDeployment, MsgCloseDeployment } from "./deploymentmsg";
import { MsgCloseGroup, MsgPauseGroup, MsgStartGroup } from "./groupmsg";
export declare const registry: ReadonlyArray<[string, TelescopeGeneratedType<any, any, any>]>;
export declare const load: (protoRegistry: Registry) => void;
export declare const MessageComposer: {
    encoded: {
        createDeployment(value: MsgCreateDeployment): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        depositDeployment(value: MsgDepositDeployment): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        updateDeployment(value: MsgUpdateDeployment): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        closeDeployment(value: MsgCloseDeployment): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        closeGroup(value: MsgCloseGroup): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        pauseGroup(value: MsgPauseGroup): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        startGroup(value: MsgStartGroup): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
    };
    withTypeUrl: {
        createDeployment(value: MsgCreateDeployment): {
            typeUrl: string;
            value: MsgCreateDeployment;
        };
        depositDeployment(value: MsgDepositDeployment): {
            typeUrl: string;
            value: MsgDepositDeployment;
        };
        updateDeployment(value: MsgUpdateDeployment): {
            typeUrl: string;
            value: MsgUpdateDeployment;
        };
        closeDeployment(value: MsgCloseDeployment): {
            typeUrl: string;
            value: MsgCloseDeployment;
        };
        closeGroup(value: MsgCloseGroup): {
            typeUrl: string;
            value: MsgCloseGroup;
        };
        pauseGroup(value: MsgPauseGroup): {
            typeUrl: string;
            value: MsgPauseGroup;
        };
        startGroup(value: MsgStartGroup): {
            typeUrl: string;
            value: MsgStartGroup;
        };
    };
    toJSON: {
        createDeployment(value: MsgCreateDeployment): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                };
                groups: {
                    name: string;
                    requirements: {
                        signedBy: {
                            allOf: string[];
                            anyOf: string[];
                        };
                        attributes: {
                            key: string;
                            value: string;
                        }[];
                    };
                    resources: {
                        resources: {
                            cpu?: {
                                units: {
                                    val: string;
                                };
                                attributes: {
                                    key: string;
                                    value: string;
                                }[];
                            };
                            memory?: {
                                quantity: {
                                    val: string;
                                };
                                attributes: {
                                    key: string;
                                    value: string;
                                }[];
                            };
                            storage: {
                                name: string;
                                quantity: {
                                    val: string;
                                };
                                attributes: {
                                    key: string;
                                    value: string;
                                }[];
                            }[];
                            endpoints: {
                                kind: import("../../base/v1beta2/endpoint").Endpoint_Kind;
                                sequenceNumber: number;
                            }[];
                        };
                        count: number;
                        price: {
                            denom: string;
                            amount: string;
                        };
                    }[];
                }[];
                version: string;
                deposit: {
                    denom: string;
                    amount: string;
                };
                depositor: string;
            };
        };
        depositDeployment(value: MsgDepositDeployment): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                };
                amount: {
                    denom: string;
                    amount: string;
                };
                depositor: string;
            };
        };
        updateDeployment(value: MsgUpdateDeployment): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                };
                version: string;
            };
        };
        closeDeployment(value: MsgCloseDeployment): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                };
            };
        };
        closeGroup(value: MsgCloseGroup): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                    gseq: number;
                };
            };
        };
        pauseGroup(value: MsgPauseGroup): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                    gseq: number;
                };
            };
        };
        startGroup(value: MsgStartGroup): {
            typeUrl: string;
            value: {
                id: {
                    owner: string;
                    dseq: string;
                    gseq: number;
                };
            };
        };
    };
    fromJSON: {
        createDeployment(value: any): {
            typeUrl: string;
            value: MsgCreateDeployment;
        };
        depositDeployment(value: any): {
            typeUrl: string;
            value: MsgDepositDeployment;
        };
        updateDeployment(value: any): {
            typeUrl: string;
            value: MsgUpdateDeployment;
        };
        closeDeployment(value: any): {
            typeUrl: string;
            value: MsgCloseDeployment;
        };
        closeGroup(value: any): {
            typeUrl: string;
            value: MsgCloseGroup;
        };
        pauseGroup(value: any): {
            typeUrl: string;
            value: MsgPauseGroup;
        };
        startGroup(value: any): {
            typeUrl: string;
            value: MsgStartGroup;
        };
    };
    fromPartial: {
        createDeployment(value: MsgCreateDeployment): {
            typeUrl: string;
            value: MsgCreateDeployment;
        };
        depositDeployment(value: MsgDepositDeployment): {
            typeUrl: string;
            value: MsgDepositDeployment;
        };
        updateDeployment(value: MsgUpdateDeployment): {
            typeUrl: string;
            value: MsgUpdateDeployment;
        };
        closeDeployment(value: MsgCloseDeployment): {
            typeUrl: string;
            value: MsgCloseDeployment;
        };
        closeGroup(value: MsgCloseGroup): {
            typeUrl: string;
            value: MsgCloseGroup;
        };
        pauseGroup(value: MsgPauseGroup): {
            typeUrl: string;
            value: MsgPauseGroup;
        };
        startGroup(value: MsgStartGroup): {
            typeUrl: string;
            value: MsgStartGroup;
        };
    };
};
