import { Coin, CoinAmino, CoinSDKType } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.escrow.v1beta1";
/** State stores state for an escrow account */
export declare enum Account_State {
    /** invalid - AccountStateInvalid is an invalid state */
    invalid = 0,
    /** open - AccountOpen is the state when an account is open */
    open = 1,
    /** closed - AccountClosed is the state when an account is closed */
    closed = 2,
    /** overdrawn - AccountOverdrawn is the state when an account is overdrawn */
    overdrawn = 3,
    UNRECOGNIZED = -1
}
export declare const Account_StateSDKType: typeof Account_State;
export declare const Account_StateAmino: typeof Account_State;
export declare function account_StateFromJSON(object: any): Account_State;
export declare function account_StateToJSON(object: Account_State): string;
/** Payment State */
export declare enum Payment_State {
    /** invalid - PaymentStateInvalid is the state when the payment is invalid */
    invalid = 0,
    /** open - PaymentStateOpen is the state when the payment is open */
    open = 1,
    /** closed - PaymentStateClosed is the state when the payment is closed */
    closed = 2,
    /** overdrawn - PaymentStateOverdrawn is the state when the payment is overdrawn */
    overdrawn = 3,
    UNRECOGNIZED = -1
}
export declare const Payment_StateSDKType: typeof Payment_State;
export declare const Payment_StateAmino: typeof Payment_State;
export declare function payment_StateFromJSON(object: any): Payment_State;
export declare function payment_StateToJSON(object: Payment_State): string;
/** AccountID is the account identifier */
export interface AccountID {
    scope: string;
    xid: string;
}
export interface AccountIDProtoMsg {
    typeUrl: "/akash.escrow.v1beta1.AccountID";
    value: Uint8Array;
}
/** AccountID is the account identifier */
export interface AccountIDAmino {
    scope: string;
    xid: string;
}
export interface AccountIDAminoMsg {
    type: "akash/escrow/account-i-d";
    value: AccountIDAmino;
}
/** AccountID is the account identifier */
export interface AccountIDSDKType {
    scope: string;
    xid: string;
}
/** Account stores state for an escrow account */
export interface Account {
    /** unique identifier for this escrow account */
    id: AccountID;
    /** bech32 encoded account address of the owner of this escrow account */
    owner: string;
    /** current state of this escrow account */
    state: Account_State;
    /** unspent coins received from the owner's wallet */
    balance: Coin;
    /** total coins spent by this account */
    transferred: Coin;
    /** block height at which this account was last settled */
    settledAt: bigint;
}
export interface AccountProtoMsg {
    typeUrl: "/akash.escrow.v1beta1.Account";
    value: Uint8Array;
}
/** Account stores state for an escrow account */
export interface AccountAmino {
    /** unique identifier for this escrow account */
    id: AccountIDAmino;
    /** bech32 encoded account address of the owner of this escrow account */
    owner: string;
    /** current state of this escrow account */
    state: Account_State;
    /** unspent coins received from the owner's wallet */
    balance: CoinAmino;
    /** total coins spent by this account */
    transferred: CoinAmino;
    /** block height at which this account was last settled */
    settled_at: string;
}
export interface AccountAminoMsg {
    type: "akash/escrow/account";
    value: AccountAmino;
}
/** Account stores state for an escrow account */
export interface AccountSDKType {
    id: AccountIDSDKType;
    owner: string;
    state: Account_State;
    balance: CoinSDKType;
    transferred: CoinSDKType;
    settled_at: bigint;
}
/** Payment stores state for a payment */
export interface Payment {
    accountId: AccountID;
    paymentId: string;
    owner: string;
    state: Payment_State;
    rate: Coin;
    balance: Coin;
    withdrawn: Coin;
}
export interface PaymentProtoMsg {
    typeUrl: "/akash.escrow.v1beta1.Payment";
    value: Uint8Array;
}
/** Payment stores state for a payment */
export interface PaymentAmino {
    account_id: AccountIDAmino;
    payment_id: string;
    owner: string;
    state: Payment_State;
    rate: CoinAmino;
    balance: CoinAmino;
    withdrawn: CoinAmino;
}
export interface PaymentAminoMsg {
    type: "akash/escrow/payment";
    value: PaymentAmino;
}
/** Payment stores state for a payment */
export interface PaymentSDKType {
    account_id: AccountIDSDKType;
    payment_id: string;
    owner: string;
    state: Payment_State;
    rate: CoinSDKType;
    balance: CoinSDKType;
    withdrawn: CoinSDKType;
}
export declare const AccountID: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is AccountID;
    isSDK(o: any): o is AccountIDSDKType;
    isAmino(o: any): o is AccountIDAmino;
    encode(message: AccountID, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AccountID;
    fromJSON(object: any): AccountID;
    toJSON(message: AccountID): JsonSafe<AccountID>;
    fromPartial<I extends Exact<DeepPartial<AccountID>, I>>(object: I): AccountID;
    fromSDK(object: AccountIDSDKType): AccountID;
    fromSDKJSON(object: any): AccountIDSDKType;
    toSDK(message: AccountID): AccountIDSDKType;
    fromAmino(object: AccountIDAmino): AccountID;
    toAmino(message: AccountID): AccountIDAmino;
    fromAminoMsg(object: AccountIDAminoMsg): AccountID;
    toAminoMsg(message: AccountID): AccountIDAminoMsg;
    fromProtoMsg(message: AccountIDProtoMsg): AccountID;
    toProto(message: AccountID): Uint8Array;
    toProtoMsg(message: AccountID): AccountIDProtoMsg;
    registerTypeUrl(): void;
};
export declare const Account: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Account;
    isSDK(o: any): o is AccountSDKType;
    isAmino(o: any): o is AccountAmino;
    encode(message: Account, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Account;
    fromJSON(object: any): Account;
    toJSON(message: Account): JsonSafe<Account>;
    fromPartial<I extends Exact<DeepPartial<Account>, I>>(object: I): Account;
    fromSDK(object: AccountSDKType): Account;
    fromSDKJSON(object: any): AccountSDKType;
    toSDK(message: Account): AccountSDKType;
    fromAmino(object: AccountAmino): Account;
    toAmino(message: Account): AccountAmino;
    fromAminoMsg(object: AccountAminoMsg): Account;
    toAminoMsg(message: Account): AccountAminoMsg;
    fromProtoMsg(message: AccountProtoMsg): Account;
    toProto(message: Account): Uint8Array;
    toProtoMsg(message: Account): AccountProtoMsg;
    registerTypeUrl(): void;
};
export declare const Payment: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Payment;
    isSDK(o: any): o is PaymentSDKType;
    isAmino(o: any): o is PaymentAmino;
    encode(message: Payment, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Payment;
    fromJSON(object: any): Payment;
    toJSON(message: Payment): JsonSafe<Payment>;
    fromPartial<I extends Exact<DeepPartial<Payment>, I>>(object: I): Payment;
    fromSDK(object: PaymentSDKType): Payment;
    fromSDKJSON(object: any): PaymentSDKType;
    toSDK(message: Payment): PaymentSDKType;
    fromAmino(object: PaymentAmino): Payment;
    toAmino(message: Payment): PaymentAmino;
    fromAminoMsg(object: PaymentAminoMsg): Payment;
    toAminoMsg(message: Payment): PaymentAminoMsg;
    fromProtoMsg(message: PaymentProtoMsg): Payment;
    toProto(message: Payment): Uint8Array;
    toProtoMsg(message: Payment): PaymentProtoMsg;
    registerTypeUrl(): void;
};
