import { OrderID } from "./order";
import { DecCoin, Coin } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.market.v1beta2";
/** State is an enum which refers to state of bid */
export var Bid_State;
(function (Bid_State) {
    /** invalid - Prefix should start with 0 in enum. So declaring dummy state */
    Bid_State[Bid_State["invalid"] = 0] = "invalid";
    /** open - BidOpen denotes state for bid open */
    Bid_State[Bid_State["open"] = 1] = "open";
    /** active - BidMatched denotes state for bid open */
    Bid_State[Bid_State["active"] = 2] = "active";
    /** lost - BidLost denotes state for bid lost */
    Bid_State[Bid_State["lost"] = 3] = "lost";
    /** closed - BidClosed denotes state for bid closed */
    Bid_State[Bid_State["closed"] = 4] = "closed";
    Bid_State[Bid_State["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Bid_State || (Bid_State = {}));
export const Bid_StateSDKType = Bid_State;
export const Bid_StateAmino = Bid_State;
export function bid_StateFromJSON(object) {
    switch (object) {
        case 0:
        case "invalid":
            return Bid_State.invalid;
        case 1:
        case "open":
            return Bid_State.open;
        case 2:
        case "active":
            return Bid_State.active;
        case 3:
        case "lost":
            return Bid_State.lost;
        case 4:
        case "closed":
            return Bid_State.closed;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Bid_State.UNRECOGNIZED;
    }
}
export function bid_StateToJSON(object) {
    switch (object) {
        case Bid_State.invalid:
            return "invalid";
        case Bid_State.open:
            return "open";
        case Bid_State.active:
            return "active";
        case Bid_State.lost:
            return "lost";
        case Bid_State.closed:
            return "closed";
        case Bid_State.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseMsgCreateBid() {
    return {
        order: OrderID.fromPartial({}),
        provider: "",
        price: DecCoin.fromPartial({}),
        deposit: Coin.fromPartial({})
    };
}
export const MsgCreateBid = {
    typeUrl: "/akash.market.v1beta2.MsgCreateBid",
    aminoType: "akash/market/v1beta2/testonly-create-bid",
    is(o) {
        return o && (o.$typeUrl === MsgCreateBid.typeUrl || OrderID.is(o.order) && typeof o.provider === "string" && DecCoin.is(o.price) && Coin.is(o.deposit));
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgCreateBid.typeUrl || OrderID.isSDK(o.order) && typeof o.provider === "string" && DecCoin.isSDK(o.price) && Coin.isSDK(o.deposit));
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgCreateBid.typeUrl || OrderID.isAmino(o.order) && typeof o.provider === "string" && DecCoin.isAmino(o.price) && Coin.isAmino(o.deposit));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.order !== undefined) {
            OrderID.encode(message.order, writer.uint32(10).fork()).ldelim();
        }
        if (message.provider !== undefined) {
            writer.uint32(18).string(message.provider);
        }
        if (message.price !== undefined) {
            DecCoin.encode(message.price, writer.uint32(26).fork()).ldelim();
        }
        if (message.deposit !== undefined) {
            Coin.encode(message.deposit, writer.uint32(34).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCreateBid();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.order = OrderID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.provider = reader.string();
                    break;
                case 3:
                    message.price = DecCoin.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.deposit = Coin.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgCreateBid();
        if (isSet(object.order))
            obj.order = OrderID.fromJSON(object.order);
        if (isSet(object.provider))
            obj.provider = String(object.provider);
        if (isSet(object.price))
            obj.price = DecCoin.fromJSON(object.price);
        if (isSet(object.deposit))
            obj.deposit = Coin.fromJSON(object.deposit);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.order !== undefined && (obj.order = message.order ? OrderID.toJSON(message.order) : undefined);
        message.provider !== undefined && (obj.provider = message.provider);
        message.price !== undefined && (obj.price = message.price ? DecCoin.toJSON(message.price) : undefined);
        message.deposit !== undefined && (obj.deposit = message.deposit ? Coin.toJSON(message.deposit) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgCreateBid();
        if (object.order !== undefined && object.order !== null) {
            message.order = OrderID.fromPartial(object.order);
        }
        message.provider = object.provider ?? "";
        if (object.price !== undefined && object.price !== null) {
            message.price = DecCoin.fromPartial(object.price);
        }
        if (object.deposit !== undefined && object.deposit !== null) {
            message.deposit = Coin.fromPartial(object.deposit);
        }
        return message;
    },
    fromSDK(object) {
        return {
            order: object.order ? OrderID.fromSDK(object.order) : undefined,
            provider: object?.provider,
            price: object.price ? DecCoin.fromSDK(object.price) : undefined,
            deposit: object.deposit ? Coin.fromSDK(object.deposit) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            order: isSet(object.order) ? OrderID.fromSDKJSON(object.order) : undefined,
            provider: isSet(object.provider) ? String(object.provider) : "",
            price: isSet(object.price) ? DecCoin.fromSDKJSON(object.price) : undefined,
            deposit: isSet(object.deposit) ? Coin.fromSDKJSON(object.deposit) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.order !== undefined && (obj.order = message.order ? OrderID.toSDK(message.order) : undefined);
        obj.provider = message.provider;
        message.price !== undefined && (obj.price = message.price ? DecCoin.toSDK(message.price) : undefined);
        message.deposit !== undefined && (obj.deposit = message.deposit ? Coin.toSDK(message.deposit) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgCreateBid();
        if (object.order !== undefined && object.order !== null) {
            message.order = OrderID.fromAmino(object.order);
        }
        if (object.provider !== undefined && object.provider !== null) {
            message.provider = object.provider;
        }
        if (object.price !== undefined && object.price !== null) {
            message.price = DecCoin.fromAmino(object.price);
        }
        if (object.deposit !== undefined && object.deposit !== null) {
            message.deposit = Coin.fromAmino(object.deposit);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.order = message.order ? OrderID.toAmino(message.order) : OrderID.toAmino(OrderID.fromPartial({}));
        obj.provider = message.provider ?? "";
        obj.price = message.price ? DecCoin.toAmino(message.price) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.deposit = message.deposit ? Coin.toAmino(message.deposit) : Coin.toAmino(Coin.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCreateBid.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/testonly-create-bid",
            value: MsgCreateBid.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCreateBid.decode(message.value);
    },
    toProto(message) {
        return MsgCreateBid.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.MsgCreateBid",
            value: MsgCreateBid.encode(message).finish()
        };
    },
    registerTypeUrl() {
        OrderID.registerTypeUrl();
        DecCoin.registerTypeUrl();
        Coin.registerTypeUrl();
    }
};
function createBaseMsgCreateBidResponse() {
    return {};
}
export const MsgCreateBidResponse = {
    typeUrl: "/akash.market.v1beta2.MsgCreateBidResponse",
    aminoType: "akash/market/v1beta2/testonly-create-bid-response",
    is(o) {
        return o && o.$typeUrl === MsgCreateBidResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgCreateBidResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgCreateBidResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCreateBidResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgCreateBidResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgCreateBidResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgCreateBidResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCreateBidResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/testonly-create-bid-response",
            value: MsgCreateBidResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCreateBidResponse.decode(message.value);
    },
    toProto(message) {
        return MsgCreateBidResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.MsgCreateBidResponse",
            value: MsgCreateBidResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseMsgCloseBid() {
    return {
        bidId: BidID.fromPartial({})
    };
}
export const MsgCloseBid = {
    typeUrl: "/akash.market.v1beta2.MsgCloseBid",
    aminoType: "akash/market/v1beta2/testonly-close-bid",
    is(o) {
        return o && (o.$typeUrl === MsgCloseBid.typeUrl || BidID.is(o.bidId));
    },
    isSDK(o) {
        return o && (o.$typeUrl === MsgCloseBid.typeUrl || BidID.isSDK(o.bid_id));
    },
    isAmino(o) {
        return o && (o.$typeUrl === MsgCloseBid.typeUrl || BidID.isAmino(o.bid_id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.bidId !== undefined) {
            BidID.encode(message.bidId, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCloseBid();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.bidId = BidID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseMsgCloseBid();
        if (isSet(object.bidId))
            obj.bidId = BidID.fromJSON(object.bidId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.bidId !== undefined && (obj.bidId = message.bidId ? BidID.toJSON(message.bidId) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseMsgCloseBid();
        if (object.bidId !== undefined && object.bidId !== null) {
            message.bidId = BidID.fromPartial(object.bidId);
        }
        return message;
    },
    fromSDK(object) {
        return {
            bidId: object.bid_id ? BidID.fromSDK(object.bid_id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            bid_id: isSet(object.bid_id) ? BidID.fromSDKJSON(object.bid_id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.bidId !== undefined && (obj.bid_id = message.bidId ? BidID.toSDK(message.bidId) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseMsgCloseBid();
        if (object.bid_id !== undefined && object.bid_id !== null) {
            message.bidId = BidID.fromAmino(object.bid_id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.bid_id = message.bidId ? BidID.toAmino(message.bidId) : BidID.toAmino(BidID.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCloseBid.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/testonly-close-bid",
            value: MsgCloseBid.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCloseBid.decode(message.value);
    },
    toProto(message) {
        return MsgCloseBid.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.MsgCloseBid",
            value: MsgCloseBid.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BidID.registerTypeUrl();
    }
};
function createBaseMsgCloseBidResponse() {
    return {};
}
export const MsgCloseBidResponse = {
    typeUrl: "/akash.market.v1beta2.MsgCloseBidResponse",
    aminoType: "akash/market/v1beta2/testonly-close-bid-response",
    is(o) {
        return o && o.$typeUrl === MsgCloseBidResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === MsgCloseBidResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === MsgCloseBidResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseMsgCloseBidResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseMsgCloseBidResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseMsgCloseBidResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseMsgCloseBidResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return MsgCloseBidResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/testonly-close-bid-response",
            value: MsgCloseBidResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return MsgCloseBidResponse.decode(message.value);
    },
    toProto(message) {
        return MsgCloseBidResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.MsgCloseBidResponse",
            value: MsgCloseBidResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBidID() {
    return {
        owner: "",
        dseq: BigInt(0),
        gseq: 0,
        oseq: 0,
        provider: ""
    };
}
export const BidID = {
    typeUrl: "/akash.market.v1beta2.BidID",
    aminoType: "akash/market/v1beta2/bid-i-d",
    is(o) {
        return o && (o.$typeUrl === BidID.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BidID.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BidID.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.owner !== undefined) {
            writer.uint32(10).string(message.owner);
        }
        if (message.dseq !== undefined) {
            writer.uint32(16).uint64(message.dseq);
        }
        if (message.gseq !== undefined) {
            writer.uint32(24).uint32(message.gseq);
        }
        if (message.oseq !== undefined) {
            writer.uint32(32).uint32(message.oseq);
        }
        if (message.provider !== undefined) {
            writer.uint32(42).string(message.provider);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBidID();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.owner = reader.string();
                    break;
                case 2:
                    message.dseq = reader.uint64();
                    break;
                case 3:
                    message.gseq = reader.uint32();
                    break;
                case 4:
                    message.oseq = reader.uint32();
                    break;
                case 5:
                    message.provider = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBidID();
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.dseq))
            obj.dseq = BigInt(object.dseq.toString());
        if (isSet(object.gseq))
            obj.gseq = Number(object.gseq);
        if (isSet(object.oseq))
            obj.oseq = Number(object.oseq);
        if (isSet(object.provider))
            obj.provider = String(object.provider);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.owner !== undefined && (obj.owner = message.owner);
        message.dseq !== undefined && (obj.dseq = (message.dseq || BigInt(0)).toString());
        message.gseq !== undefined && (obj.gseq = Math.round(message.gseq));
        message.oseq !== undefined && (obj.oseq = Math.round(message.oseq));
        message.provider !== undefined && (obj.provider = message.provider);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBidID();
        message.owner = object.owner ?? "";
        if (object.dseq !== undefined && object.dseq !== null) {
            message.dseq = BigInt(object.dseq.toString());
        }
        message.gseq = object.gseq ?? 0;
        message.oseq = object.oseq ?? 0;
        message.provider = object.provider ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            owner: object?.owner,
            dseq: object?.dseq,
            gseq: object?.gseq,
            oseq: object?.oseq,
            provider: object?.provider
        };
    },
    fromSDKJSON(object) {
        return {
            owner: isSet(object.owner) ? String(object.owner) : "",
            dseq: isSet(object.dseq) ? BigInt(object.dseq.toString()) : BigInt(0),
            gseq: isSet(object.gseq) ? Number(object.gseq) : 0,
            oseq: isSet(object.oseq) ? Number(object.oseq) : 0,
            provider: isSet(object.provider) ? String(object.provider) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.owner = message.owner;
        obj.dseq = message.dseq;
        obj.gseq = message.gseq;
        obj.oseq = message.oseq;
        obj.provider = message.provider;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBidID();
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.dseq !== undefined && object.dseq !== null) {
            message.dseq = BigInt(object.dseq);
        }
        if (object.gseq !== undefined && object.gseq !== null) {
            message.gseq = object.gseq;
        }
        if (object.oseq !== undefined && object.oseq !== null) {
            message.oseq = object.oseq;
        }
        if (object.provider !== undefined && object.provider !== null) {
            message.provider = object.provider;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.owner = message.owner ?? "";
        obj.dseq = message.dseq ? message.dseq?.toString() : "0";
        obj.gseq = message.gseq ?? 0;
        obj.oseq = message.oseq ?? 0;
        obj.provider = message.provider ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return BidID.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/bid-i-d",
            value: BidID.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return BidID.decode(message.value);
    },
    toProto(message) {
        return BidID.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.BidID",
            value: BidID.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBid() {
    return {
        bidId: BidID.fromPartial({}),
        state: 0,
        price: DecCoin.fromPartial({}),
        createdAt: BigInt(0)
    };
}
export const Bid = {
    typeUrl: "/akash.market.v1beta2.Bid",
    aminoType: "akash/market/v1beta2/bid",
    is(o) {
        return o && (o.$typeUrl === Bid.typeUrl || BidID.is(o.bidId) && isSet(o.state) && DecCoin.is(o.price) && typeof o.createdAt === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Bid.typeUrl || BidID.isSDK(o.bid_id) && isSet(o.state) && DecCoin.isSDK(o.price) && typeof o.created_at === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Bid.typeUrl || BidID.isAmino(o.bid_id) && isSet(o.state) && DecCoin.isAmino(o.price) && typeof o.created_at === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.bidId !== undefined) {
            BidID.encode(message.bidId, writer.uint32(10).fork()).ldelim();
        }
        if (message.state !== 0) {
            writer.uint32(16).int32(message.state);
        }
        if (message.price !== undefined) {
            DecCoin.encode(message.price, writer.uint32(26).fork()).ldelim();
        }
        if (message.createdAt !== undefined) {
            writer.uint32(32).int64(message.createdAt);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBid();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.bidId = BidID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.state = reader.int32();
                    break;
                case 3:
                    message.price = DecCoin.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.createdAt = reader.int64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBid();
        if (isSet(object.bidId))
            obj.bidId = BidID.fromJSON(object.bidId);
        if (isSet(object.state))
            obj.state = bid_StateFromJSON(object.state);
        if (isSet(object.price))
            obj.price = DecCoin.fromJSON(object.price);
        if (isSet(object.createdAt))
            obj.createdAt = BigInt(object.createdAt.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.bidId !== undefined && (obj.bidId = message.bidId ? BidID.toJSON(message.bidId) : undefined);
        message.state !== undefined && (obj.state = bid_StateToJSON(message.state));
        message.price !== undefined && (obj.price = message.price ? DecCoin.toJSON(message.price) : undefined);
        message.createdAt !== undefined && (obj.createdAt = (message.createdAt || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBid();
        if (object.bidId !== undefined && object.bidId !== null) {
            message.bidId = BidID.fromPartial(object.bidId);
        }
        message.state = object.state ?? 0;
        if (object.price !== undefined && object.price !== null) {
            message.price = DecCoin.fromPartial(object.price);
        }
        if (object.createdAt !== undefined && object.createdAt !== null) {
            message.createdAt = BigInt(object.createdAt.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            bidId: object.bid_id ? BidID.fromSDK(object.bid_id) : undefined,
            state: isSet(object.state) ? bid_StateFromJSON(object.state) : -1,
            price: object.price ? DecCoin.fromSDK(object.price) : undefined,
            createdAt: object?.created_at
        };
    },
    fromSDKJSON(object) {
        return {
            bid_id: isSet(object.bid_id) ? BidID.fromSDKJSON(object.bid_id) : undefined,
            state: isSet(object.state) ? bid_StateFromJSON(object.state) : -1,
            price: isSet(object.price) ? DecCoin.fromSDKJSON(object.price) : undefined,
            created_at: isSet(object.created_at) ? BigInt(object.created_at.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        message.bidId !== undefined && (obj.bid_id = message.bidId ? BidID.toSDK(message.bidId) : undefined);
        message.state !== undefined && (obj.state = bid_StateToJSON(message.state));
        message.price !== undefined && (obj.price = message.price ? DecCoin.toSDK(message.price) : undefined);
        obj.created_at = message.createdAt;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBid();
        if (object.bid_id !== undefined && object.bid_id !== null) {
            message.bidId = BidID.fromAmino(object.bid_id);
        }
        if (object.state !== undefined && object.state !== null) {
            message.state = object.state;
        }
        if (object.price !== undefined && object.price !== null) {
            message.price = DecCoin.fromAmino(object.price);
        }
        if (object.created_at !== undefined && object.created_at !== null) {
            message.createdAt = BigInt(object.created_at);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.bid_id = message.bidId ? BidID.toAmino(message.bidId) : BidID.toAmino(BidID.fromPartial({}));
        obj.state = message.state ?? 0;
        obj.price = message.price ? DecCoin.toAmino(message.price) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.created_at = message.createdAt !== BigInt(0) ? message.createdAt?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return Bid.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/bid",
            value: Bid.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Bid.decode(message.value);
    },
    toProto(message) {
        return Bid.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.Bid",
            value: Bid.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BidID.registerTypeUrl();
        DecCoin.registerTypeUrl();
    }
};
function createBaseBidFilters() {
    return {
        owner: "",
        dseq: BigInt(0),
        gseq: 0,
        oseq: 0,
        provider: "",
        state: ""
    };
}
export const BidFilters = {
    typeUrl: "/akash.market.v1beta2.BidFilters",
    aminoType: "akash/market/v1beta2/bid-filters",
    is(o) {
        return o && (o.$typeUrl === BidFilters.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string" && typeof o.state === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BidFilters.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string" && typeof o.state === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BidFilters.typeUrl || typeof o.owner === "string" && typeof o.dseq === "bigint" && typeof o.gseq === "number" && typeof o.oseq === "number" && typeof o.provider === "string" && typeof o.state === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.owner !== undefined) {
            writer.uint32(10).string(message.owner);
        }
        if (message.dseq !== undefined) {
            writer.uint32(16).uint64(message.dseq);
        }
        if (message.gseq !== undefined) {
            writer.uint32(24).uint32(message.gseq);
        }
        if (message.oseq !== undefined) {
            writer.uint32(32).uint32(message.oseq);
        }
        if (message.provider !== undefined) {
            writer.uint32(42).string(message.provider);
        }
        if (message.state !== undefined) {
            writer.uint32(50).string(message.state);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBidFilters();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.owner = reader.string();
                    break;
                case 2:
                    message.dseq = reader.uint64();
                    break;
                case 3:
                    message.gseq = reader.uint32();
                    break;
                case 4:
                    message.oseq = reader.uint32();
                    break;
                case 5:
                    message.provider = reader.string();
                    break;
                case 6:
                    message.state = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBidFilters();
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.dseq))
            obj.dseq = BigInt(object.dseq.toString());
        if (isSet(object.gseq))
            obj.gseq = Number(object.gseq);
        if (isSet(object.oseq))
            obj.oseq = Number(object.oseq);
        if (isSet(object.provider))
            obj.provider = String(object.provider);
        if (isSet(object.state))
            obj.state = String(object.state);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.owner !== undefined && (obj.owner = message.owner);
        message.dseq !== undefined && (obj.dseq = (message.dseq || BigInt(0)).toString());
        message.gseq !== undefined && (obj.gseq = Math.round(message.gseq));
        message.oseq !== undefined && (obj.oseq = Math.round(message.oseq));
        message.provider !== undefined && (obj.provider = message.provider);
        message.state !== undefined && (obj.state = message.state);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBidFilters();
        message.owner = object.owner ?? "";
        if (object.dseq !== undefined && object.dseq !== null) {
            message.dseq = BigInt(object.dseq.toString());
        }
        message.gseq = object.gseq ?? 0;
        message.oseq = object.oseq ?? 0;
        message.provider = object.provider ?? "";
        message.state = object.state ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            owner: object?.owner,
            dseq: object?.dseq,
            gseq: object?.gseq,
            oseq: object?.oseq,
            provider: object?.provider,
            state: object?.state
        };
    },
    fromSDKJSON(object) {
        return {
            owner: isSet(object.owner) ? String(object.owner) : "",
            dseq: isSet(object.dseq) ? BigInt(object.dseq.toString()) : BigInt(0),
            gseq: isSet(object.gseq) ? Number(object.gseq) : 0,
            oseq: isSet(object.oseq) ? Number(object.oseq) : 0,
            provider: isSet(object.provider) ? String(object.provider) : "",
            state: isSet(object.state) ? String(object.state) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.owner = message.owner;
        obj.dseq = message.dseq;
        obj.gseq = message.gseq;
        obj.oseq = message.oseq;
        obj.provider = message.provider;
        obj.state = message.state;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBidFilters();
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.dseq !== undefined && object.dseq !== null) {
            message.dseq = BigInt(object.dseq);
        }
        if (object.gseq !== undefined && object.gseq !== null) {
            message.gseq = object.gseq;
        }
        if (object.oseq !== undefined && object.oseq !== null) {
            message.oseq = object.oseq;
        }
        if (object.provider !== undefined && object.provider !== null) {
            message.provider = object.provider;
        }
        if (object.state !== undefined && object.state !== null) {
            message.state = object.state;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.owner = message.owner ?? "";
        obj.dseq = message.dseq ? message.dseq?.toString() : "0";
        obj.gseq = message.gseq ?? 0;
        obj.oseq = message.oseq ?? 0;
        obj.provider = message.provider ?? "";
        obj.state = message.state ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return BidFilters.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/bid-filters",
            value: BidFilters.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return BidFilters.decode(message.value);
    },
    toProto(message) {
        return BidFilters.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.BidFilters",
            value: BidFilters.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
