import { DecCoin, DecCoinAmino, DecCoinSDKType } from "../../../cosmos/base/v1beta1/coin";
import { BidID, BidIDAmino, BidIDSDKType } from "./bid";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.market.v1beta2";
/** State is an enum which refers to state of lease */
export declare enum Lease_State {
    /** invalid - Prefix should start with 0 in enum. So declaring dummy state */
    invalid = 0,
    /** active - LeaseActive denotes state for lease active */
    active = 1,
    /** insufficient_funds - LeaseInsufficientFunds denotes state for lease insufficient_funds */
    insufficient_funds = 2,
    /** closed - LeaseClosed denotes state for lease closed */
    closed = 3,
    UNRECOGNIZED = -1
}
export declare const Lease_StateSDKType: typeof Lease_State;
export declare const Lease_StateAmino: typeof Lease_State;
export declare function lease_StateFromJSON(object: any): Lease_State;
export declare function lease_StateToJSON(object: Lease_State): string;
/** LeaseID stores bid details of lease */
export interface LeaseID {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    provider: string;
}
export interface LeaseIDProtoMsg {
    typeUrl: "/akash.market.v1beta2.LeaseID";
    value: Uint8Array;
}
/** LeaseID stores bid details of lease */
export interface LeaseIDAmino {
    owner: string;
    dseq: string;
    gseq: number;
    oseq: number;
    provider: string;
}
export interface LeaseIDAminoMsg {
    type: "akash/market/v1beta2/lease-i-d";
    value: LeaseIDAmino;
}
/** LeaseID stores bid details of lease */
export interface LeaseIDSDKType {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    provider: string;
}
/** Lease stores LeaseID, state of lease and price */
export interface Lease {
    leaseId: LeaseID;
    state: Lease_State;
    price: DecCoin;
    createdAt: bigint;
    closedOn: bigint;
}
export interface LeaseProtoMsg {
    typeUrl: "/akash.market.v1beta2.Lease";
    value: Uint8Array;
}
/** Lease stores LeaseID, state of lease and price */
export interface LeaseAmino {
    lease_id: LeaseIDAmino;
    state: Lease_State;
    price: DecCoinAmino;
    created_at?: string;
    closed_on?: string;
}
export interface LeaseAminoMsg {
    type: "akash/market/v1beta2/lease";
    value: LeaseAmino;
}
/** Lease stores LeaseID, state of lease and price */
export interface LeaseSDKType {
    lease_id: LeaseIDSDKType;
    state: Lease_State;
    price: DecCoinSDKType;
    created_at: bigint;
    closed_on: bigint;
}
/** LeaseFilters defines flags for lease list filter */
export interface LeaseFilters {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    provider: string;
    state: string;
}
export interface LeaseFiltersProtoMsg {
    typeUrl: "/akash.market.v1beta2.LeaseFilters";
    value: Uint8Array;
}
/** LeaseFilters defines flags for lease list filter */
export interface LeaseFiltersAmino {
    owner: string;
    dseq: string;
    gseq: number;
    oseq: number;
    provider: string;
    state: string;
}
export interface LeaseFiltersAminoMsg {
    type: "akash/market/v1beta2/lease-filters";
    value: LeaseFiltersAmino;
}
/** LeaseFilters defines flags for lease list filter */
export interface LeaseFiltersSDKType {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    provider: string;
    state: string;
}
/** MsgCreateLease is sent to create a lease */
export interface MsgCreateLease {
    bidId: BidID;
}
export interface MsgCreateLeaseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgCreateLease";
    value: Uint8Array;
}
/** MsgCreateLease is sent to create a lease */
export interface MsgCreateLeaseAmino {
    bid_id: BidIDAmino;
}
export interface MsgCreateLeaseAminoMsg {
    type: "akash/market/v1beta2/testonly-create-lease";
    value: MsgCreateLeaseAmino;
}
/** MsgCreateLease is sent to create a lease */
export interface MsgCreateLeaseSDKType {
    bid_id: BidIDSDKType;
}
/** MsgCreateLeaseResponse is the response from creating a lease */
export interface MsgCreateLeaseResponse {
}
export interface MsgCreateLeaseResponseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgCreateLeaseResponse";
    value: Uint8Array;
}
/** MsgCreateLeaseResponse is the response from creating a lease */
export interface MsgCreateLeaseResponseAmino {
}
export interface MsgCreateLeaseResponseAminoMsg {
    type: "akash/market/v1beta2/testonly-create-lease-response";
    value: MsgCreateLeaseResponseAmino;
}
/** MsgCreateLeaseResponse is the response from creating a lease */
export interface MsgCreateLeaseResponseSDKType {
}
/** MsgWithdrawLease defines an SDK message for closing bid */
export interface MsgWithdrawLease {
    bidId: LeaseID;
}
export interface MsgWithdrawLeaseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgWithdrawLease";
    value: Uint8Array;
}
/** MsgWithdrawLease defines an SDK message for closing bid */
export interface MsgWithdrawLeaseAmino {
    bid_id: LeaseIDAmino;
}
export interface MsgWithdrawLeaseAminoMsg {
    type: "akash/market/v1beta2/testonly-withdraw-lease";
    value: MsgWithdrawLeaseAmino;
}
/** MsgWithdrawLease defines an SDK message for closing bid */
export interface MsgWithdrawLeaseSDKType {
    bid_id: LeaseIDSDKType;
}
/** MsgWithdrawLeaseResponse defines the Msg/WithdrawLease response type. */
export interface MsgWithdrawLeaseResponse {
}
export interface MsgWithdrawLeaseResponseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgWithdrawLeaseResponse";
    value: Uint8Array;
}
/** MsgWithdrawLeaseResponse defines the Msg/WithdrawLease response type. */
export interface MsgWithdrawLeaseResponseAmino {
}
export interface MsgWithdrawLeaseResponseAminoMsg {
    type: "akash/market/v1beta2/testonly-withdraw-lease-response";
    value: MsgWithdrawLeaseResponseAmino;
}
/** MsgWithdrawLeaseResponse defines the Msg/WithdrawLease response type. */
export interface MsgWithdrawLeaseResponseSDKType {
}
/** MsgCloseLease defines an SDK message for closing order */
export interface MsgCloseLease {
    leaseId: LeaseID;
}
export interface MsgCloseLeaseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgCloseLease";
    value: Uint8Array;
}
/** MsgCloseLease defines an SDK message for closing order */
export interface MsgCloseLeaseAmino {
    lease_id: LeaseIDAmino;
}
export interface MsgCloseLeaseAminoMsg {
    type: "akash/market/v1beta2/testonly-close-lease";
    value: MsgCloseLeaseAmino;
}
/** MsgCloseLease defines an SDK message for closing order */
export interface MsgCloseLeaseSDKType {
    lease_id: LeaseIDSDKType;
}
/** MsgCloseLeaseResponse defines the Msg/CloseLease response type. */
export interface MsgCloseLeaseResponse {
}
export interface MsgCloseLeaseResponseProtoMsg {
    typeUrl: "/akash.market.v1beta2.MsgCloseLeaseResponse";
    value: Uint8Array;
}
/** MsgCloseLeaseResponse defines the Msg/CloseLease response type. */
export interface MsgCloseLeaseResponseAmino {
}
export interface MsgCloseLeaseResponseAminoMsg {
    type: "akash/market/v1beta2/testonly-close-lease-response";
    value: MsgCloseLeaseResponseAmino;
}
/** MsgCloseLeaseResponse defines the Msg/CloseLease response type. */
export interface MsgCloseLeaseResponseSDKType {
}
export declare const LeaseID: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is LeaseID;
    isSDK(o: any): o is LeaseIDSDKType;
    isAmino(o: any): o is LeaseIDAmino;
    encode(message: LeaseID, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LeaseID;
    fromJSON(object: any): LeaseID;
    toJSON(message: LeaseID): JsonSafe<LeaseID>;
    fromPartial<I extends Exact<DeepPartial<LeaseID>, I>>(object: I): LeaseID;
    fromSDK(object: LeaseIDSDKType): LeaseID;
    fromSDKJSON(object: any): LeaseIDSDKType;
    toSDK(message: LeaseID): LeaseIDSDKType;
    fromAmino(object: LeaseIDAmino): LeaseID;
    toAmino(message: LeaseID): LeaseIDAmino;
    fromAminoMsg(object: LeaseIDAminoMsg): LeaseID;
    toAminoMsg(message: LeaseID): LeaseIDAminoMsg;
    fromProtoMsg(message: LeaseIDProtoMsg): LeaseID;
    toProto(message: LeaseID): Uint8Array;
    toProtoMsg(message: LeaseID): LeaseIDProtoMsg;
    registerTypeUrl(): void;
};
export declare const Lease: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Lease;
    isSDK(o: any): o is LeaseSDKType;
    isAmino(o: any): o is LeaseAmino;
    encode(message: Lease, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Lease;
    fromJSON(object: any): Lease;
    toJSON(message: Lease): JsonSafe<Lease>;
    fromPartial<I extends Exact<DeepPartial<Lease>, I>>(object: I): Lease;
    fromSDK(object: LeaseSDKType): Lease;
    fromSDKJSON(object: any): LeaseSDKType;
    toSDK(message: Lease): LeaseSDKType;
    fromAmino(object: LeaseAmino): Lease;
    toAmino(message: Lease): LeaseAmino;
    fromAminoMsg(object: LeaseAminoMsg): Lease;
    toAminoMsg(message: Lease): LeaseAminoMsg;
    fromProtoMsg(message: LeaseProtoMsg): Lease;
    toProto(message: Lease): Uint8Array;
    toProtoMsg(message: Lease): LeaseProtoMsg;
    registerTypeUrl(): void;
};
export declare const LeaseFilters: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is LeaseFilters;
    isSDK(o: any): o is LeaseFiltersSDKType;
    isAmino(o: any): o is LeaseFiltersAmino;
    encode(message: LeaseFilters, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LeaseFilters;
    fromJSON(object: any): LeaseFilters;
    toJSON(message: LeaseFilters): JsonSafe<LeaseFilters>;
    fromPartial<I extends Exact<DeepPartial<LeaseFilters>, I>>(object: I): LeaseFilters;
    fromSDK(object: LeaseFiltersSDKType): LeaseFilters;
    fromSDKJSON(object: any): LeaseFiltersSDKType;
    toSDK(message: LeaseFilters): LeaseFiltersSDKType;
    fromAmino(object: LeaseFiltersAmino): LeaseFilters;
    toAmino(message: LeaseFilters): LeaseFiltersAmino;
    fromAminoMsg(object: LeaseFiltersAminoMsg): LeaseFilters;
    toAminoMsg(message: LeaseFilters): LeaseFiltersAminoMsg;
    fromProtoMsg(message: LeaseFiltersProtoMsg): LeaseFilters;
    toProto(message: LeaseFilters): Uint8Array;
    toProtoMsg(message: LeaseFilters): LeaseFiltersProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCreateLease: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCreateLease;
    isSDK(o: any): o is MsgCreateLeaseSDKType;
    isAmino(o: any): o is MsgCreateLeaseAmino;
    encode(message: MsgCreateLease, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCreateLease;
    fromJSON(object: any): MsgCreateLease;
    toJSON(message: MsgCreateLease): JsonSafe<MsgCreateLease>;
    fromPartial<I extends Exact<DeepPartial<MsgCreateLease>, I>>(object: I): MsgCreateLease;
    fromSDK(object: MsgCreateLeaseSDKType): MsgCreateLease;
    fromSDKJSON(object: any): MsgCreateLeaseSDKType;
    toSDK(message: MsgCreateLease): MsgCreateLeaseSDKType;
    fromAmino(object: MsgCreateLeaseAmino): MsgCreateLease;
    toAmino(message: MsgCreateLease): MsgCreateLeaseAmino;
    fromAminoMsg(object: MsgCreateLeaseAminoMsg): MsgCreateLease;
    toAminoMsg(message: MsgCreateLease): MsgCreateLeaseAminoMsg;
    fromProtoMsg(message: MsgCreateLeaseProtoMsg): MsgCreateLease;
    toProto(message: MsgCreateLease): Uint8Array;
    toProtoMsg(message: MsgCreateLease): MsgCreateLeaseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCreateLeaseResponse: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCreateLeaseResponse;
    isSDK(o: any): o is MsgCreateLeaseResponseSDKType;
    isAmino(o: any): o is MsgCreateLeaseResponseAmino;
    encode(_: MsgCreateLeaseResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCreateLeaseResponse;
    fromJSON(_: any): MsgCreateLeaseResponse;
    toJSON(_: MsgCreateLeaseResponse): JsonSafe<MsgCreateLeaseResponse>;
    fromPartial<I extends Exact<DeepPartial<MsgCreateLeaseResponse>, I>>(_: I): MsgCreateLeaseResponse;
    fromSDK(_: MsgCreateLeaseResponseSDKType): MsgCreateLeaseResponse;
    fromSDKJSON(_: any): MsgCreateLeaseResponseSDKType;
    toSDK(_: MsgCreateLeaseResponse): MsgCreateLeaseResponseSDKType;
    fromAmino(_: MsgCreateLeaseResponseAmino): MsgCreateLeaseResponse;
    toAmino(_: MsgCreateLeaseResponse): MsgCreateLeaseResponseAmino;
    fromAminoMsg(object: MsgCreateLeaseResponseAminoMsg): MsgCreateLeaseResponse;
    toAminoMsg(message: MsgCreateLeaseResponse): MsgCreateLeaseResponseAminoMsg;
    fromProtoMsg(message: MsgCreateLeaseResponseProtoMsg): MsgCreateLeaseResponse;
    toProto(message: MsgCreateLeaseResponse): Uint8Array;
    toProtoMsg(message: MsgCreateLeaseResponse): MsgCreateLeaseResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgWithdrawLease: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgWithdrawLease;
    isSDK(o: any): o is MsgWithdrawLeaseSDKType;
    isAmino(o: any): o is MsgWithdrawLeaseAmino;
    encode(message: MsgWithdrawLease, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgWithdrawLease;
    fromJSON(object: any): MsgWithdrawLease;
    toJSON(message: MsgWithdrawLease): JsonSafe<MsgWithdrawLease>;
    fromPartial<I extends Exact<DeepPartial<MsgWithdrawLease>, I>>(object: I): MsgWithdrawLease;
    fromSDK(object: MsgWithdrawLeaseSDKType): MsgWithdrawLease;
    fromSDKJSON(object: any): MsgWithdrawLeaseSDKType;
    toSDK(message: MsgWithdrawLease): MsgWithdrawLeaseSDKType;
    fromAmino(object: MsgWithdrawLeaseAmino): MsgWithdrawLease;
    toAmino(message: MsgWithdrawLease): MsgWithdrawLeaseAmino;
    fromAminoMsg(object: MsgWithdrawLeaseAminoMsg): MsgWithdrawLease;
    toAminoMsg(message: MsgWithdrawLease): MsgWithdrawLeaseAminoMsg;
    fromProtoMsg(message: MsgWithdrawLeaseProtoMsg): MsgWithdrawLease;
    toProto(message: MsgWithdrawLease): Uint8Array;
    toProtoMsg(message: MsgWithdrawLease): MsgWithdrawLeaseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgWithdrawLeaseResponse: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgWithdrawLeaseResponse;
    isSDK(o: any): o is MsgWithdrawLeaseResponseSDKType;
    isAmino(o: any): o is MsgWithdrawLeaseResponseAmino;
    encode(_: MsgWithdrawLeaseResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgWithdrawLeaseResponse;
    fromJSON(_: any): MsgWithdrawLeaseResponse;
    toJSON(_: MsgWithdrawLeaseResponse): JsonSafe<MsgWithdrawLeaseResponse>;
    fromPartial<I extends Exact<DeepPartial<MsgWithdrawLeaseResponse>, I>>(_: I): MsgWithdrawLeaseResponse;
    fromSDK(_: MsgWithdrawLeaseResponseSDKType): MsgWithdrawLeaseResponse;
    fromSDKJSON(_: any): MsgWithdrawLeaseResponseSDKType;
    toSDK(_: MsgWithdrawLeaseResponse): MsgWithdrawLeaseResponseSDKType;
    fromAmino(_: MsgWithdrawLeaseResponseAmino): MsgWithdrawLeaseResponse;
    toAmino(_: MsgWithdrawLeaseResponse): MsgWithdrawLeaseResponseAmino;
    fromAminoMsg(object: MsgWithdrawLeaseResponseAminoMsg): MsgWithdrawLeaseResponse;
    toAminoMsg(message: MsgWithdrawLeaseResponse): MsgWithdrawLeaseResponseAminoMsg;
    fromProtoMsg(message: MsgWithdrawLeaseResponseProtoMsg): MsgWithdrawLeaseResponse;
    toProto(message: MsgWithdrawLeaseResponse): Uint8Array;
    toProtoMsg(message: MsgWithdrawLeaseResponse): MsgWithdrawLeaseResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCloseLease: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCloseLease;
    isSDK(o: any): o is MsgCloseLeaseSDKType;
    isAmino(o: any): o is MsgCloseLeaseAmino;
    encode(message: MsgCloseLease, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCloseLease;
    fromJSON(object: any): MsgCloseLease;
    toJSON(message: MsgCloseLease): JsonSafe<MsgCloseLease>;
    fromPartial<I extends Exact<DeepPartial<MsgCloseLease>, I>>(object: I): MsgCloseLease;
    fromSDK(object: MsgCloseLeaseSDKType): MsgCloseLease;
    fromSDKJSON(object: any): MsgCloseLeaseSDKType;
    toSDK(message: MsgCloseLease): MsgCloseLeaseSDKType;
    fromAmino(object: MsgCloseLeaseAmino): MsgCloseLease;
    toAmino(message: MsgCloseLease): MsgCloseLeaseAmino;
    fromAminoMsg(object: MsgCloseLeaseAminoMsg): MsgCloseLease;
    toAminoMsg(message: MsgCloseLease): MsgCloseLeaseAminoMsg;
    fromProtoMsg(message: MsgCloseLeaseProtoMsg): MsgCloseLease;
    toProto(message: MsgCloseLease): Uint8Array;
    toProtoMsg(message: MsgCloseLease): MsgCloseLeaseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgCloseLeaseResponse: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is MsgCloseLeaseResponse;
    isSDK(o: any): o is MsgCloseLeaseResponseSDKType;
    isAmino(o: any): o is MsgCloseLeaseResponseAmino;
    encode(_: MsgCloseLeaseResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgCloseLeaseResponse;
    fromJSON(_: any): MsgCloseLeaseResponse;
    toJSON(_: MsgCloseLeaseResponse): JsonSafe<MsgCloseLeaseResponse>;
    fromPartial<I extends Exact<DeepPartial<MsgCloseLeaseResponse>, I>>(_: I): MsgCloseLeaseResponse;
    fromSDK(_: MsgCloseLeaseResponseSDKType): MsgCloseLeaseResponse;
    fromSDKJSON(_: any): MsgCloseLeaseResponseSDKType;
    toSDK(_: MsgCloseLeaseResponse): MsgCloseLeaseResponseSDKType;
    fromAmino(_: MsgCloseLeaseResponseAmino): MsgCloseLeaseResponse;
    toAmino(_: MsgCloseLeaseResponse): MsgCloseLeaseResponseAmino;
    fromAminoMsg(object: MsgCloseLeaseResponseAminoMsg): MsgCloseLeaseResponse;
    toAminoMsg(message: MsgCloseLeaseResponse): MsgCloseLeaseResponseAminoMsg;
    fromProtoMsg(message: MsgCloseLeaseResponseProtoMsg): MsgCloseLeaseResponse;
    toProto(message: MsgCloseLeaseResponse): Uint8Array;
    toProtoMsg(message: MsgCloseLeaseResponse): MsgCloseLeaseResponseProtoMsg;
    registerTypeUrl(): void;
};
