import { GroupSpec, GroupSpecAmino, GroupSpecSDKType } from "../../deployment/v1beta2/groupspec";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial, Exact } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "akash.market.v1beta2";
/** State is an enum which refers to state of order */
export declare enum Order_State {
    /** invalid - Prefix should start with 0 in enum. So declaring dummy state */
    invalid = 0,
    /** open - OrderOpen denotes state for order open */
    open = 1,
    /** active - OrderMatched denotes state for order matched */
    active = 2,
    /** closed - OrderClosed denotes state for order lost */
    closed = 3,
    UNRECOGNIZED = -1
}
export declare const Order_StateSDKType: typeof Order_State;
export declare const Order_StateAmino: typeof Order_State;
export declare function order_StateFromJSON(object: any): Order_State;
export declare function order_StateToJSON(object: Order_State): string;
/** OrderID stores owner and all other seq numbers */
export interface OrderID {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
}
export interface OrderIDProtoMsg {
    typeUrl: "/akash.market.v1beta2.OrderID";
    value: Uint8Array;
}
/** OrderID stores owner and all other seq numbers */
export interface OrderIDAmino {
    owner: string;
    dseq: string;
    gseq: number;
    oseq: number;
}
export interface OrderIDAminoMsg {
    type: "akash/market/v1beta2/order-i-d";
    value: OrderIDAmino;
}
/** OrderID stores owner and all other seq numbers */
export interface OrderIDSDKType {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
}
/** Order stores orderID, state of order and other details */
export interface Order {
    orderId: OrderID;
    state: Order_State;
    spec: GroupSpec;
    createdAt: bigint;
}
export interface OrderProtoMsg {
    typeUrl: "/akash.market.v1beta2.Order";
    value: Uint8Array;
}
/** Order stores orderID, state of order and other details */
export interface OrderAmino {
    order_id: OrderIDAmino;
    state: Order_State;
    spec: GroupSpecAmino;
    created_at?: string;
}
export interface OrderAminoMsg {
    type: "akash/market/v1beta2/order";
    value: OrderAmino;
}
/** Order stores orderID, state of order and other details */
export interface OrderSDKType {
    order_id: OrderIDSDKType;
    state: Order_State;
    spec: GroupSpecSDKType;
    created_at: bigint;
}
/** OrderFilters defines flags for order list filter */
export interface OrderFilters {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    state: string;
}
export interface OrderFiltersProtoMsg {
    typeUrl: "/akash.market.v1beta2.OrderFilters";
    value: Uint8Array;
}
/** OrderFilters defines flags for order list filter */
export interface OrderFiltersAmino {
    owner: string;
    dseq: string;
    gseq: number;
    oseq: number;
    state: string;
}
export interface OrderFiltersAminoMsg {
    type: "akash/market/v1beta2/order-filters";
    value: OrderFiltersAmino;
}
/** OrderFilters defines flags for order list filter */
export interface OrderFiltersSDKType {
    owner: string;
    dseq: bigint;
    gseq: number;
    oseq: number;
    state: string;
}
export declare const OrderID: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is OrderID;
    isSDK(o: any): o is OrderIDSDKType;
    isAmino(o: any): o is OrderIDAmino;
    encode(message: OrderID, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OrderID;
    fromJSON(object: any): OrderID;
    toJSON(message: OrderID): JsonSafe<OrderID>;
    fromPartial<I extends Exact<DeepPartial<OrderID>, I>>(object: I): OrderID;
    fromSDK(object: OrderIDSDKType): OrderID;
    fromSDKJSON(object: any): OrderIDSDKType;
    toSDK(message: OrderID): OrderIDSDKType;
    fromAmino(object: OrderIDAmino): OrderID;
    toAmino(message: OrderID): OrderIDAmino;
    fromAminoMsg(object: OrderIDAminoMsg): OrderID;
    toAminoMsg(message: OrderID): OrderIDAminoMsg;
    fromProtoMsg(message: OrderIDProtoMsg): OrderID;
    toProto(message: OrderID): Uint8Array;
    toProtoMsg(message: OrderID): OrderIDProtoMsg;
    registerTypeUrl(): void;
};
export declare const Order: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is Order;
    isSDK(o: any): o is OrderSDKType;
    isAmino(o: any): o is OrderAmino;
    encode(message: Order, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Order;
    fromJSON(object: any): Order;
    toJSON(message: Order): JsonSafe<Order>;
    fromPartial<I extends Exact<DeepPartial<Order>, I>>(object: I): Order;
    fromSDK(object: OrderSDKType): Order;
    fromSDKJSON(object: any): OrderSDKType;
    toSDK(message: Order): OrderSDKType;
    fromAmino(object: OrderAmino): Order;
    toAmino(message: Order): OrderAmino;
    fromAminoMsg(object: OrderAminoMsg): Order;
    toAminoMsg(message: Order): OrderAminoMsg;
    fromProtoMsg(message: OrderProtoMsg): Order;
    toProto(message: Order): Uint8Array;
    toProtoMsg(message: Order): OrderProtoMsg;
    registerTypeUrl(): void;
};
export declare const OrderFilters: {
    typeUrl: string;
    aminoType: string;
    is(o: any): o is OrderFilters;
    isSDK(o: any): o is OrderFiltersSDKType;
    isAmino(o: any): o is OrderFiltersAmino;
    encode(message: OrderFilters, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OrderFilters;
    fromJSON(object: any): OrderFilters;
    toJSON(message: OrderFilters): JsonSafe<OrderFilters>;
    fromPartial<I extends Exact<DeepPartial<OrderFilters>, I>>(object: I): OrderFilters;
    fromSDK(object: OrderFiltersSDKType): OrderFilters;
    fromSDKJSON(object: any): OrderFiltersSDKType;
    toSDK(message: OrderFilters): OrderFiltersSDKType;
    fromAmino(object: OrderFiltersAmino): OrderFilters;
    toAmino(message: OrderFilters): OrderFiltersAmino;
    fromAminoMsg(object: OrderFiltersAminoMsg): OrderFilters;
    toAminoMsg(message: OrderFilters): OrderFiltersAminoMsg;
    fromProtoMsg(message: OrderFiltersProtoMsg): OrderFilters;
    toProto(message: OrderFilters): Uint8Array;
    toProtoMsg(message: OrderFilters): OrderFiltersProtoMsg;
    registerTypeUrl(): void;
};
