import { OrderFilters, OrderID, Order } from "./order";
import { PageRequest, PageResponse } from "../../../cosmos/base/query/v1beta1/pagination";
import { BidFilters, BidID, Bid } from "./bid";
import { LeaseFilters, LeaseID, Lease } from "./lease";
import { Account, FractionalPayment } from "../../escrow/v1beta2/types";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.market.v1beta2";
function createBaseQueryOrdersRequest() {
    return {
        filters: OrderFilters.fromPartial({}),
        pagination: undefined
    };
}
export const QueryOrdersRequest = {
    typeUrl: "/akash.market.v1beta2.QueryOrdersRequest",
    aminoType: "akash/market/v1beta2/query-orders-request",
    is(o) {
        return o && (o.$typeUrl === QueryOrdersRequest.typeUrl || OrderFilters.is(o.filters));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryOrdersRequest.typeUrl || OrderFilters.isSDK(o.filters));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryOrdersRequest.typeUrl || OrderFilters.isAmino(o.filters));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.filters !== undefined) {
            OrderFilters.encode(message.filters, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageRequest.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryOrdersRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.filters = OrderFilters.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.pagination = PageRequest.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryOrdersRequest();
        if (isSet(object.filters))
            obj.filters = OrderFilters.fromJSON(object.filters);
        if (isSet(object.pagination))
            obj.pagination = PageRequest.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? OrderFilters.toJSON(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryOrdersRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = OrderFilters.fromPartial(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            filters: object.filters ? OrderFilters.fromSDK(object.filters) : undefined,
            pagination: object.pagination ? PageRequest.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            filters: isSet(object.filters) ? OrderFilters.fromSDKJSON(object.filters) : undefined,
            pagination: isSet(object.pagination) ? PageRequest.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? OrderFilters.toSDK(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryOrdersRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = OrderFilters.fromAmino(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.filters = message.filters ? OrderFilters.toAmino(message.filters) : undefined;
        obj.pagination = message.pagination ? PageRequest.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryOrdersRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-orders-request",
            value: QueryOrdersRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryOrdersRequest.decode(message.value);
    },
    toProto(message) {
        return QueryOrdersRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryOrdersRequest",
            value: QueryOrdersRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        OrderFilters.registerTypeUrl();
        PageRequest.registerTypeUrl();
    }
};
function createBaseQueryOrdersResponse() {
    return {
        orders: [],
        pagination: undefined
    };
}
export const QueryOrdersResponse = {
    typeUrl: "/akash.market.v1beta2.QueryOrdersResponse",
    aminoType: "akash/market/v1beta2/query-orders-response",
    is(o) {
        return o && (o.$typeUrl === QueryOrdersResponse.typeUrl || Array.isArray(o.orders) && (!o.orders.length || Order.is(o.orders[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryOrdersResponse.typeUrl || Array.isArray(o.orders) && (!o.orders.length || Order.isSDK(o.orders[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryOrdersResponse.typeUrl || Array.isArray(o.orders) && (!o.orders.length || Order.isAmino(o.orders[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.orders) {
            Order.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageResponse.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryOrdersResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.orders.push(Order.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.pagination = PageResponse.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryOrdersResponse();
        if (Array.isArray(object?.orders))
            obj.orders = object.orders.map((e) => Order.fromJSON(e));
        if (isSet(object.pagination))
            obj.pagination = PageResponse.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.orders) {
            obj.orders = message.orders.map(e => e ? Order.toJSON(e) : undefined);
        }
        else {
            obj.orders = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryOrdersResponse();
        message.orders = object.orders?.map(e => Order.fromPartial(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            orders: Array.isArray(object?.orders) ? object.orders.map((e) => Order.fromSDK(e)) : [],
            pagination: object.pagination ? PageResponse.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            orders: Array.isArray(object?.orders) ? object.orders.map((e) => Order.fromSDKJSON(e)) : [],
            pagination: isSet(object.pagination) ? PageResponse.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.orders) {
            obj.orders = message.orders.map(e => e ? Order.toSDK(e) : undefined);
        }
        else {
            obj.orders = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryOrdersResponse();
        message.orders = object.orders?.map(e => Order.fromAmino(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.orders) {
            obj.orders = message.orders.map(e => e ? Order.toAmino(e) : undefined);
        }
        else {
            obj.orders = message.orders;
        }
        obj.pagination = message.pagination ? PageResponse.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryOrdersResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-orders-response",
            value: QueryOrdersResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryOrdersResponse.decode(message.value);
    },
    toProto(message) {
        return QueryOrdersResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryOrdersResponse",
            value: QueryOrdersResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Order.registerTypeUrl();
        PageResponse.registerTypeUrl();
    }
};
function createBaseQueryOrderRequest() {
    return {
        id: OrderID.fromPartial({})
    };
}
export const QueryOrderRequest = {
    typeUrl: "/akash.market.v1beta2.QueryOrderRequest",
    aminoType: "akash/market/v1beta2/query-order-request",
    is(o) {
        return o && (o.$typeUrl === QueryOrderRequest.typeUrl || OrderID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryOrderRequest.typeUrl || OrderID.isSDK(o.id));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryOrderRequest.typeUrl || OrderID.isAmino(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            OrderID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryOrderRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = OrderID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryOrderRequest();
        if (isSet(object.id))
            obj.id = OrderID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? OrderID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryOrderRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = OrderID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? OrderID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? OrderID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? OrderID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryOrderRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = OrderID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? OrderID.toAmino(message.id) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryOrderRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-order-request",
            value: QueryOrderRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryOrderRequest.decode(message.value);
    },
    toProto(message) {
        return QueryOrderRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryOrderRequest",
            value: QueryOrderRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        OrderID.registerTypeUrl();
    }
};
function createBaseQueryOrderResponse() {
    return {
        order: Order.fromPartial({})
    };
}
export const QueryOrderResponse = {
    typeUrl: "/akash.market.v1beta2.QueryOrderResponse",
    aminoType: "akash/market/v1beta2/query-order-response",
    is(o) {
        return o && (o.$typeUrl === QueryOrderResponse.typeUrl || Order.is(o.order));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryOrderResponse.typeUrl || Order.isSDK(o.order));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryOrderResponse.typeUrl || Order.isAmino(o.order));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.order !== undefined) {
            Order.encode(message.order, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryOrderResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.order = Order.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryOrderResponse();
        if (isSet(object.order))
            obj.order = Order.fromJSON(object.order);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.order !== undefined && (obj.order = message.order ? Order.toJSON(message.order) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryOrderResponse();
        if (object.order !== undefined && object.order !== null) {
            message.order = Order.fromPartial(object.order);
        }
        return message;
    },
    fromSDK(object) {
        return {
            order: object.order ? Order.fromSDK(object.order) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            order: isSet(object.order) ? Order.fromSDKJSON(object.order) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.order !== undefined && (obj.order = message.order ? Order.toSDK(message.order) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryOrderResponse();
        if (object.order !== undefined && object.order !== null) {
            message.order = Order.fromAmino(object.order);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.order = message.order ? Order.toAmino(message.order) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryOrderResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-order-response",
            value: QueryOrderResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryOrderResponse.decode(message.value);
    },
    toProto(message) {
        return QueryOrderResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryOrderResponse",
            value: QueryOrderResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Order.registerTypeUrl();
    }
};
function createBaseQueryBidsRequest() {
    return {
        filters: BidFilters.fromPartial({}),
        pagination: undefined
    };
}
export const QueryBidsRequest = {
    typeUrl: "/akash.market.v1beta2.QueryBidsRequest",
    aminoType: "akash/market/v1beta2/query-bids-request",
    is(o) {
        return o && (o.$typeUrl === QueryBidsRequest.typeUrl || BidFilters.is(o.filters));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryBidsRequest.typeUrl || BidFilters.isSDK(o.filters));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryBidsRequest.typeUrl || BidFilters.isAmino(o.filters));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.filters !== undefined) {
            BidFilters.encode(message.filters, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageRequest.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryBidsRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.filters = BidFilters.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.pagination = PageRequest.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryBidsRequest();
        if (isSet(object.filters))
            obj.filters = BidFilters.fromJSON(object.filters);
        if (isSet(object.pagination))
            obj.pagination = PageRequest.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? BidFilters.toJSON(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryBidsRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = BidFilters.fromPartial(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            filters: object.filters ? BidFilters.fromSDK(object.filters) : undefined,
            pagination: object.pagination ? PageRequest.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            filters: isSet(object.filters) ? BidFilters.fromSDKJSON(object.filters) : undefined,
            pagination: isSet(object.pagination) ? PageRequest.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? BidFilters.toSDK(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryBidsRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = BidFilters.fromAmino(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.filters = message.filters ? BidFilters.toAmino(message.filters) : undefined;
        obj.pagination = message.pagination ? PageRequest.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryBidsRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-bids-request",
            value: QueryBidsRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryBidsRequest.decode(message.value);
    },
    toProto(message) {
        return QueryBidsRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryBidsRequest",
            value: QueryBidsRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BidFilters.registerTypeUrl();
        PageRequest.registerTypeUrl();
    }
};
function createBaseQueryBidsResponse() {
    return {
        bids: [],
        pagination: undefined
    };
}
export const QueryBidsResponse = {
    typeUrl: "/akash.market.v1beta2.QueryBidsResponse",
    aminoType: "akash/market/v1beta2/query-bids-response",
    is(o) {
        return o && (o.$typeUrl === QueryBidsResponse.typeUrl || Array.isArray(o.bids) && (!o.bids.length || QueryBidResponse.is(o.bids[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryBidsResponse.typeUrl || Array.isArray(o.bids) && (!o.bids.length || QueryBidResponse.isSDK(o.bids[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryBidsResponse.typeUrl || Array.isArray(o.bids) && (!o.bids.length || QueryBidResponse.isAmino(o.bids[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.bids) {
            QueryBidResponse.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageResponse.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryBidsResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.bids.push(QueryBidResponse.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.pagination = PageResponse.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryBidsResponse();
        if (Array.isArray(object?.bids))
            obj.bids = object.bids.map((e) => QueryBidResponse.fromJSON(e));
        if (isSet(object.pagination))
            obj.pagination = PageResponse.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.bids) {
            obj.bids = message.bids.map(e => e ? QueryBidResponse.toJSON(e) : undefined);
        }
        else {
            obj.bids = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryBidsResponse();
        message.bids = object.bids?.map(e => QueryBidResponse.fromPartial(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            bids: Array.isArray(object?.bids) ? object.bids.map((e) => QueryBidResponse.fromSDK(e)) : [],
            pagination: object.pagination ? PageResponse.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            bids: Array.isArray(object?.bids) ? object.bids.map((e) => QueryBidResponse.fromSDKJSON(e)) : [],
            pagination: isSet(object.pagination) ? PageResponse.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.bids) {
            obj.bids = message.bids.map(e => e ? QueryBidResponse.toSDK(e) : undefined);
        }
        else {
            obj.bids = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryBidsResponse();
        message.bids = object.bids?.map(e => QueryBidResponse.fromAmino(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.bids) {
            obj.bids = message.bids.map(e => e ? QueryBidResponse.toAmino(e) : undefined);
        }
        else {
            obj.bids = message.bids;
        }
        obj.pagination = message.pagination ? PageResponse.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryBidsResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-bids-response",
            value: QueryBidsResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryBidsResponse.decode(message.value);
    },
    toProto(message) {
        return QueryBidsResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryBidsResponse",
            value: QueryBidsResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QueryBidResponse.registerTypeUrl();
        PageResponse.registerTypeUrl();
    }
};
function createBaseQueryBidRequest() {
    return {
        id: BidID.fromPartial({})
    };
}
export const QueryBidRequest = {
    typeUrl: "/akash.market.v1beta2.QueryBidRequest",
    aminoType: "akash/market/v1beta2/query-bid-request",
    is(o) {
        return o && (o.$typeUrl === QueryBidRequest.typeUrl || BidID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryBidRequest.typeUrl || BidID.isSDK(o.id));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryBidRequest.typeUrl || BidID.isAmino(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            BidID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryBidRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = BidID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryBidRequest();
        if (isSet(object.id))
            obj.id = BidID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? BidID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryBidRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = BidID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? BidID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? BidID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? BidID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryBidRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = BidID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? BidID.toAmino(message.id) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryBidRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-bid-request",
            value: QueryBidRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryBidRequest.decode(message.value);
    },
    toProto(message) {
        return QueryBidRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryBidRequest",
            value: QueryBidRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BidID.registerTypeUrl();
    }
};
function createBaseQueryBidResponse() {
    return {
        bid: Bid.fromPartial({}),
        escrowAccount: Account.fromPartial({})
    };
}
export const QueryBidResponse = {
    typeUrl: "/akash.market.v1beta2.QueryBidResponse",
    aminoType: "akash/market/v1beta2/query-bid-response",
    is(o) {
        return o && (o.$typeUrl === QueryBidResponse.typeUrl || Bid.is(o.bid) && Account.is(o.escrowAccount));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryBidResponse.typeUrl || Bid.isSDK(o.bid) && Account.isSDK(o.escrow_account));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryBidResponse.typeUrl || Bid.isAmino(o.bid) && Account.isAmino(o.escrow_account));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.bid !== undefined) {
            Bid.encode(message.bid, writer.uint32(10).fork()).ldelim();
        }
        if (message.escrowAccount !== undefined) {
            Account.encode(message.escrowAccount, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryBidResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.bid = Bid.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.escrowAccount = Account.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryBidResponse();
        if (isSet(object.bid))
            obj.bid = Bid.fromJSON(object.bid);
        if (isSet(object.escrowAccount))
            obj.escrowAccount = Account.fromJSON(object.escrowAccount);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.bid !== undefined && (obj.bid = message.bid ? Bid.toJSON(message.bid) : undefined);
        message.escrowAccount !== undefined && (obj.escrowAccount = message.escrowAccount ? Account.toJSON(message.escrowAccount) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryBidResponse();
        if (object.bid !== undefined && object.bid !== null) {
            message.bid = Bid.fromPartial(object.bid);
        }
        if (object.escrowAccount !== undefined && object.escrowAccount !== null) {
            message.escrowAccount = Account.fromPartial(object.escrowAccount);
        }
        return message;
    },
    fromSDK(object) {
        return {
            bid: object.bid ? Bid.fromSDK(object.bid) : undefined,
            escrowAccount: object.escrow_account ? Account.fromSDK(object.escrow_account) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            bid: isSet(object.bid) ? Bid.fromSDKJSON(object.bid) : undefined,
            escrow_account: isSet(object.escrow_account) ? Account.fromSDKJSON(object.escrow_account) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.bid !== undefined && (obj.bid = message.bid ? Bid.toSDK(message.bid) : undefined);
        message.escrowAccount !== undefined && (obj.escrow_account = message.escrowAccount ? Account.toSDK(message.escrowAccount) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryBidResponse();
        if (object.bid !== undefined && object.bid !== null) {
            message.bid = Bid.fromAmino(object.bid);
        }
        if (object.escrow_account !== undefined && object.escrow_account !== null) {
            message.escrowAccount = Account.fromAmino(object.escrow_account);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.bid = message.bid ? Bid.toAmino(message.bid) : undefined;
        obj.escrow_account = message.escrowAccount ? Account.toAmino(message.escrowAccount) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryBidResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-bid-response",
            value: QueryBidResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryBidResponse.decode(message.value);
    },
    toProto(message) {
        return QueryBidResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryBidResponse",
            value: QueryBidResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Bid.registerTypeUrl();
        Account.registerTypeUrl();
    }
};
function createBaseQueryLeasesRequest() {
    return {
        filters: LeaseFilters.fromPartial({}),
        pagination: undefined
    };
}
export const QueryLeasesRequest = {
    typeUrl: "/akash.market.v1beta2.QueryLeasesRequest",
    aminoType: "akash/market/v1beta2/query-leases-request",
    is(o) {
        return o && (o.$typeUrl === QueryLeasesRequest.typeUrl || LeaseFilters.is(o.filters));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryLeasesRequest.typeUrl || LeaseFilters.isSDK(o.filters));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryLeasesRequest.typeUrl || LeaseFilters.isAmino(o.filters));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.filters !== undefined) {
            LeaseFilters.encode(message.filters, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageRequest.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryLeasesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.filters = LeaseFilters.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.pagination = PageRequest.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryLeasesRequest();
        if (isSet(object.filters))
            obj.filters = LeaseFilters.fromJSON(object.filters);
        if (isSet(object.pagination))
            obj.pagination = PageRequest.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? LeaseFilters.toJSON(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryLeasesRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = LeaseFilters.fromPartial(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            filters: object.filters ? LeaseFilters.fromSDK(object.filters) : undefined,
            pagination: object.pagination ? PageRequest.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            filters: isSet(object.filters) ? LeaseFilters.fromSDKJSON(object.filters) : undefined,
            pagination: isSet(object.pagination) ? PageRequest.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? LeaseFilters.toSDK(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryLeasesRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = LeaseFilters.fromAmino(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.filters = message.filters ? LeaseFilters.toAmino(message.filters) : undefined;
        obj.pagination = message.pagination ? PageRequest.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryLeasesRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-leases-request",
            value: QueryLeasesRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryLeasesRequest.decode(message.value);
    },
    toProto(message) {
        return QueryLeasesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryLeasesRequest",
            value: QueryLeasesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        LeaseFilters.registerTypeUrl();
        PageRequest.registerTypeUrl();
    }
};
function createBaseQueryLeasesResponse() {
    return {
        leases: [],
        pagination: undefined
    };
}
export const QueryLeasesResponse = {
    typeUrl: "/akash.market.v1beta2.QueryLeasesResponse",
    aminoType: "akash/market/v1beta2/query-leases-response",
    is(o) {
        return o && (o.$typeUrl === QueryLeasesResponse.typeUrl || Array.isArray(o.leases) && (!o.leases.length || QueryLeaseResponse.is(o.leases[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryLeasesResponse.typeUrl || Array.isArray(o.leases) && (!o.leases.length || QueryLeaseResponse.isSDK(o.leases[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryLeasesResponse.typeUrl || Array.isArray(o.leases) && (!o.leases.length || QueryLeaseResponse.isAmino(o.leases[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.leases) {
            QueryLeaseResponse.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageResponse.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryLeasesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.leases.push(QueryLeaseResponse.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.pagination = PageResponse.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryLeasesResponse();
        if (Array.isArray(object?.leases))
            obj.leases = object.leases.map((e) => QueryLeaseResponse.fromJSON(e));
        if (isSet(object.pagination))
            obj.pagination = PageResponse.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.leases) {
            obj.leases = message.leases.map(e => e ? QueryLeaseResponse.toJSON(e) : undefined);
        }
        else {
            obj.leases = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryLeasesResponse();
        message.leases = object.leases?.map(e => QueryLeaseResponse.fromPartial(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            leases: Array.isArray(object?.leases) ? object.leases.map((e) => QueryLeaseResponse.fromSDK(e)) : [],
            pagination: object.pagination ? PageResponse.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            leases: Array.isArray(object?.leases) ? object.leases.map((e) => QueryLeaseResponse.fromSDKJSON(e)) : [],
            pagination: isSet(object.pagination) ? PageResponse.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.leases) {
            obj.leases = message.leases.map(e => e ? QueryLeaseResponse.toSDK(e) : undefined);
        }
        else {
            obj.leases = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryLeasesResponse();
        message.leases = object.leases?.map(e => QueryLeaseResponse.fromAmino(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.leases) {
            obj.leases = message.leases.map(e => e ? QueryLeaseResponse.toAmino(e) : undefined);
        }
        else {
            obj.leases = message.leases;
        }
        obj.pagination = message.pagination ? PageResponse.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryLeasesResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-leases-response",
            value: QueryLeasesResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryLeasesResponse.decode(message.value);
    },
    toProto(message) {
        return QueryLeasesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryLeasesResponse",
            value: QueryLeasesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QueryLeaseResponse.registerTypeUrl();
        PageResponse.registerTypeUrl();
    }
};
function createBaseQueryLeaseRequest() {
    return {
        id: LeaseID.fromPartial({})
    };
}
export const QueryLeaseRequest = {
    typeUrl: "/akash.market.v1beta2.QueryLeaseRequest",
    aminoType: "akash/market/v1beta2/query-lease-request",
    is(o) {
        return o && (o.$typeUrl === QueryLeaseRequest.typeUrl || LeaseID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryLeaseRequest.typeUrl || LeaseID.isSDK(o.id));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryLeaseRequest.typeUrl || LeaseID.isAmino(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            LeaseID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryLeaseRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = LeaseID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryLeaseRequest();
        if (isSet(object.id))
            obj.id = LeaseID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? LeaseID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryLeaseRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = LeaseID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? LeaseID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? LeaseID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? LeaseID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryLeaseRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = LeaseID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? LeaseID.toAmino(message.id) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryLeaseRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-lease-request",
            value: QueryLeaseRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryLeaseRequest.decode(message.value);
    },
    toProto(message) {
        return QueryLeaseRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryLeaseRequest",
            value: QueryLeaseRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        LeaseID.registerTypeUrl();
    }
};
function createBaseQueryLeaseResponse() {
    return {
        lease: Lease.fromPartial({}),
        escrowPayment: FractionalPayment.fromPartial({})
    };
}
export const QueryLeaseResponse = {
    typeUrl: "/akash.market.v1beta2.QueryLeaseResponse",
    aminoType: "akash/market/v1beta2/query-lease-response",
    is(o) {
        return o && (o.$typeUrl === QueryLeaseResponse.typeUrl || Lease.is(o.lease) && FractionalPayment.is(o.escrowPayment));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryLeaseResponse.typeUrl || Lease.isSDK(o.lease) && FractionalPayment.isSDK(o.escrow_payment));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QueryLeaseResponse.typeUrl || Lease.isAmino(o.lease) && FractionalPayment.isAmino(o.escrow_payment));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.lease !== undefined) {
            Lease.encode(message.lease, writer.uint32(10).fork()).ldelim();
        }
        if (message.escrowPayment !== undefined) {
            FractionalPayment.encode(message.escrowPayment, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryLeaseResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.lease = Lease.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.escrowPayment = FractionalPayment.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryLeaseResponse();
        if (isSet(object.lease))
            obj.lease = Lease.fromJSON(object.lease);
        if (isSet(object.escrowPayment))
            obj.escrowPayment = FractionalPayment.fromJSON(object.escrowPayment);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.lease !== undefined && (obj.lease = message.lease ? Lease.toJSON(message.lease) : undefined);
        message.escrowPayment !== undefined && (obj.escrowPayment = message.escrowPayment ? FractionalPayment.toJSON(message.escrowPayment) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryLeaseResponse();
        if (object.lease !== undefined && object.lease !== null) {
            message.lease = Lease.fromPartial(object.lease);
        }
        if (object.escrowPayment !== undefined && object.escrowPayment !== null) {
            message.escrowPayment = FractionalPayment.fromPartial(object.escrowPayment);
        }
        return message;
    },
    fromSDK(object) {
        return {
            lease: object.lease ? Lease.fromSDK(object.lease) : undefined,
            escrowPayment: object.escrow_payment ? FractionalPayment.fromSDK(object.escrow_payment) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            lease: isSet(object.lease) ? Lease.fromSDKJSON(object.lease) : undefined,
            escrow_payment: isSet(object.escrow_payment) ? FractionalPayment.fromSDKJSON(object.escrow_payment) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.lease !== undefined && (obj.lease = message.lease ? Lease.toSDK(message.lease) : undefined);
        message.escrowPayment !== undefined && (obj.escrow_payment = message.escrowPayment ? FractionalPayment.toSDK(message.escrowPayment) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryLeaseResponse();
        if (object.lease !== undefined && object.lease !== null) {
            message.lease = Lease.fromAmino(object.lease);
        }
        if (object.escrow_payment !== undefined && object.escrow_payment !== null) {
            message.escrowPayment = FractionalPayment.fromAmino(object.escrow_payment);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.lease = message.lease ? Lease.toAmino(message.lease) : undefined;
        obj.escrow_payment = message.escrowPayment ? FractionalPayment.toAmino(message.escrowPayment) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryLeaseResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/market/v1beta2/query-lease-response",
            value: QueryLeaseResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryLeaseResponse.decode(message.value);
    },
    toProto(message) {
        return QueryLeaseResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.market.v1beta2.QueryLeaseResponse",
            value: QueryLeaseResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Lease.registerTypeUrl();
        FractionalPayment.registerTypeUrl();
    }
};
