import { MsgGrant, MsgExec, MsgRevoke } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Grant grants the provided authorization to the grantee on the granter's
     account with the provided expiration time. If there is already a grant
     for the given (granter, grantee, Authorization) triple, then the grant
     will be overwritten. */
    grant = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgGrant.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Exec attempts to execute the provided messages using
     authorizations granted to the grantee. Each message should have only
     one signer corresponding to the granter of the authorization. */
    exec = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgExec.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Revoke revokes any authorization corresponding to the provided method name on the
     granter's account that has been granted to the grantee. */
    revoke = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgRevoke.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
