import { PageRequest } from "../../base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryBalanceResponse, QueryAllBalancesResponse, QuerySpendableBalancesResponse, QueryTotalSupplyResponse, QuerySupplyOfResponse, QueryParamsResponse, QueryDenomMetadataResponse, QueryDenomsMetadataResponse, QueryDenomOwnersResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Balance queries the balance of a single coin for a single account. */
    balance = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `cosmos/bank/v1beta1/balances/${params.address}/by_denom`;
        return QueryBalanceResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* AllBalances queries the balance of all coins for a single account. */
    allBalances = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/balances/${params.address}`;
        return QueryAllBalancesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* SpendableBalances queries the spenable balance of all coins for a single
     account. */
    spendableBalances = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/spendable_balances/${params.address}`;
        return QuerySpendableBalancesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* TotalSupply queries the total supply of all coins. */
    totalSupply = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/supply`;
        return QueryTotalSupplyResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* SupplyOf queries the supply of a single coin. */
    supplyOf = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `cosmos/bank/v1beta1/supply/by_denom`;
        return QuerySupplyOfResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Params queries the parameters of x/bank module. */
    params = async (_params = {}) => {
        const endpoint = `cosmos/bank/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DenomsMetadata queries the client metadata of a given coin denomination. */
    denomMetadata = async (params) => {
        const endpoint = `cosmos/bank/v1beta1/denoms_metadata/${params.denom}`;
        return QueryDenomMetadataResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DenomsMetadata queries the client metadata for all registered coin
     denominations. */
    denomsMetadata = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/denoms_metadata`;
        return QueryDenomsMetadataResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DenomOwners queries for all account addresses that own a particular token
     denomination. */
    denomOwners = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/denom_owners/${params.denom}`;
        return QueryDenomOwnersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
