import { TxRpc } from "../../../../types";
import { GetAuthnDescriptorRequest, GetAuthnDescriptorResponse, GetChainDescriptorRequest, GetChainDescriptorResponse, GetCodecDescriptorRequest, GetCodecDescriptorResponse, GetConfigurationDescriptorRequest, GetConfigurationDescriptorResponse, GetQueryServicesDescriptorRequest, GetQueryServicesDescriptorResponse, GetTxDescriptorRequest, GetTxDescriptorResponse } from "./reflection";
/** ReflectionService defines a service for application reflection. */
export interface ReflectionService {
    /**
     * GetAuthnDescriptor returns information on how to authenticate transactions in the application
     * NOTE: this RPC is still experimental and might be subject to breaking changes or removal in
     * future releases of the cosmos-sdk.
     */
    getAuthnDescriptor(request?: GetAuthnDescriptorRequest): Promise<GetAuthnDescriptorResponse>;
    /** GetChainDescriptor returns the description of the chain */
    getChainDescriptor(request?: GetChainDescriptorRequest): Promise<GetChainDescriptorResponse>;
    /** GetCodecDescriptor returns the descriptor of the codec of the application */
    getCodecDescriptor(request?: GetCodecDescriptorRequest): Promise<GetCodecDescriptorResponse>;
    /** GetConfigurationDescriptor returns the descriptor for the sdk.Config of the application */
    getConfigurationDescriptor(request?: GetConfigurationDescriptorRequest): Promise<GetConfigurationDescriptorResponse>;
    /** GetQueryServicesDescriptor returns the available gRPC queryable services of the application */
    getQueryServicesDescriptor(request?: GetQueryServicesDescriptorRequest): Promise<GetQueryServicesDescriptorResponse>;
    /** GetTxDescriptor returns information on the used transaction object and available msgs that can be used */
    getTxDescriptor(request?: GetTxDescriptorRequest): Promise<GetTxDescriptorResponse>;
}
export declare class ReflectionServiceClientImpl implements ReflectionService {
    private readonly rpc;
    constructor(rpc: TxRpc);
    getAuthnDescriptor: (request?: GetAuthnDescriptorRequest) => Promise<GetAuthnDescriptorResponse>;
    getChainDescriptor: (request?: GetChainDescriptorRequest) => Promise<GetChainDescriptorResponse>;
    getCodecDescriptor: (request?: GetCodecDescriptorRequest) => Promise<GetCodecDescriptorResponse>;
    getConfigurationDescriptor: (request?: GetConfigurationDescriptorRequest) => Promise<GetConfigurationDescriptorResponse>;
    getQueryServicesDescriptor: (request?: GetQueryServicesDescriptorRequest) => Promise<GetQueryServicesDescriptorResponse>;
    getTxDescriptor: (request?: GetTxDescriptorRequest) => Promise<GetTxDescriptorResponse>;
}
export declare const createClientImpl: (rpc: TxRpc) => ReflectionServiceClientImpl;
