import { PageRequest } from "../../query/v1beta1/pagination";
import { setPaginationParams } from "../../../../helpers";
import { GetNodeInfoResponse, GetSyncingResponse, GetLatestBlockResponse, GetBlockByHeightResponse, GetLatestValidatorSetResponse, GetValidatorSetByHeightResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* GetNodeInfo queries the current node info. */
    getNodeInfo = async (_params = {}) => {
        const endpoint = `cosmos/base/tendermint/v1beta1/node_info`;
        return GetNodeInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetSyncing queries node syncing. */
    getSyncing = async (_params = {}) => {
        const endpoint = `cosmos/base/tendermint/v1beta1/syncing`;
        return GetSyncingResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetLatestBlock returns the latest block. */
    getLatestBlock = async (_params = {}) => {
        const endpoint = `cosmos/base/tendermint/v1beta1/blocks/latest`;
        return GetLatestBlockResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetBlockByHeight queries block for given height. */
    getBlockByHeight = async (params) => {
        const endpoint = `cosmos/base/tendermint/v1beta1/blocks/${params.height}`;
        return GetBlockByHeightResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetLatestValidatorSet queries latest validator-set. */
    getLatestValidatorSet = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/base/tendermint/v1beta1/validatorsets/latest`;
        return GetLatestValidatorSetResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GetValidatorSetByHeight queries validator-set at a given height. */
    getValidatorSetByHeight = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/base/tendermint/v1beta1/validatorsets/${params.height}`;
        return GetValidatorSetByHeightResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
