import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "cosmos.capability.v1beta1";
function createBaseCapability() {
    return {
        index: BigInt(0)
    };
}
export const Capability = {
    typeUrl: "/cosmos.capability.v1beta1.Capability",
    aminoType: "cosmos-sdk/Capability",
    is(o) {
        return o && (o.$typeUrl === Capability.typeUrl || typeof o.index === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Capability.typeUrl || typeof o.index === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Capability.typeUrl || typeof o.index === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.index !== undefined) {
            writer.uint32(8).uint64(message.index);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCapability();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.index = reader.uint64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCapability();
        if (isSet(object.index))
            obj.index = BigInt(object.index.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.index !== undefined && (obj.index = (message.index || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCapability();
        if (object.index !== undefined && object.index !== null) {
            message.index = BigInt(object.index.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            index: object?.index
        };
    },
    fromSDKJSON(object) {
        return {
            index: isSet(object.index) ? BigInt(object.index.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        obj.index = message.index;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCapability();
        if (object.index !== undefined && object.index !== null) {
            message.index = BigInt(object.index);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.index = message.index !== BigInt(0) ? message.index?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return Capability.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "cosmos-sdk/Capability",
            value: Capability.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Capability.decode(message.value);
    },
    toProto(message) {
        return Capability.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/cosmos.capability.v1beta1.Capability",
            value: Capability.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseOwner() {
    return {
        module: "",
        name: ""
    };
}
export const Owner = {
    typeUrl: "/cosmos.capability.v1beta1.Owner",
    aminoType: "cosmos-sdk/Owner",
    is(o) {
        return o && (o.$typeUrl === Owner.typeUrl || typeof o.module === "string" && typeof o.name === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Owner.typeUrl || typeof o.module === "string" && typeof o.name === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Owner.typeUrl || typeof o.module === "string" && typeof o.name === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.module !== undefined) {
            writer.uint32(10).string(message.module);
        }
        if (message.name !== undefined) {
            writer.uint32(18).string(message.name);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseOwner();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.module = reader.string();
                    break;
                case 2:
                    message.name = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseOwner();
        if (isSet(object.module))
            obj.module = String(object.module);
        if (isSet(object.name))
            obj.name = String(object.name);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.module !== undefined && (obj.module = message.module);
        message.name !== undefined && (obj.name = message.name);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseOwner();
        message.module = object.module ?? "";
        message.name = object.name ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            module: object?.module,
            name: object?.name
        };
    },
    fromSDKJSON(object) {
        return {
            module: isSet(object.module) ? String(object.module) : "",
            name: isSet(object.name) ? String(object.name) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.module = message.module;
        obj.name = message.name;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseOwner();
        if (object.module !== undefined && object.module !== null) {
            message.module = object.module;
        }
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.module = message.module === "" ? undefined : message.module;
        obj.name = message.name === "" ? undefined : message.name;
        return obj;
    },
    fromAminoMsg(object) {
        return Owner.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "cosmos-sdk/Owner",
            value: Owner.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Owner.decode(message.value);
    },
    toProto(message) {
        return Owner.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/cosmos.capability.v1beta1.Owner",
            value: Owner.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseCapabilityOwners() {
    return {
        owners: []
    };
}
export const CapabilityOwners = {
    typeUrl: "/cosmos.capability.v1beta1.CapabilityOwners",
    aminoType: "cosmos-sdk/CapabilityOwners",
    is(o) {
        return o && (o.$typeUrl === CapabilityOwners.typeUrl || Array.isArray(o.owners) && (!o.owners.length || Owner.is(o.owners[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === CapabilityOwners.typeUrl || Array.isArray(o.owners) && (!o.owners.length || Owner.isSDK(o.owners[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === CapabilityOwners.typeUrl || Array.isArray(o.owners) && (!o.owners.length || Owner.isAmino(o.owners[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.owners) {
            Owner.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCapabilityOwners();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.owners.push(Owner.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCapabilityOwners();
        if (Array.isArray(object?.owners))
            obj.owners = object.owners.map((e) => Owner.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.owners) {
            obj.owners = message.owners.map(e => e ? Owner.toJSON(e) : undefined);
        }
        else {
            obj.owners = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCapabilityOwners();
        message.owners = object.owners?.map(e => Owner.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            owners: Array.isArray(object?.owners) ? object.owners.map((e) => Owner.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            owners: Array.isArray(object?.owners) ? object.owners.map((e) => Owner.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.owners) {
            obj.owners = message.owners.map(e => e ? Owner.toSDK(e) : undefined);
        }
        else {
            obj.owners = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCapabilityOwners();
        message.owners = object.owners?.map(e => Owner.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.owners) {
            obj.owners = message.owners.map(e => e ? Owner.toAmino(e) : undefined);
        }
        else {
            obj.owners = message.owners;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return CapabilityOwners.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "cosmos-sdk/CapabilityOwners",
            value: CapabilityOwners.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return CapabilityOwners.decode(message.value);
    },
    toProto(message) {
        return CapabilityOwners.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/cosmos.capability.v1beta1.CapabilityOwners",
            value: CapabilityOwners.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Owner.registerTypeUrl();
    }
};
