import { BinaryReader, BinaryWriter } from "../../../../binary";
import { isSet } from "../../../../helpers";
export const protobufPackage = "cosmos.crypto.hd.v1";
function createBaseBIP44Params() {
    return {
        purpose: 0,
        coinType: 0,
        account: 0,
        change: false,
        addressIndex: 0
    };
}
export const BIP44Params = {
    typeUrl: "/cosmos.crypto.hd.v1.BIP44Params",
    aminoType: "cosmos-sdk/BIP44Params",
    is(o) {
        return o && (o.$typeUrl === BIP44Params.typeUrl || typeof o.purpose === "number" && typeof o.coinType === "number" && typeof o.account === "number" && typeof o.change === "boolean" && typeof o.addressIndex === "number");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BIP44Params.typeUrl || typeof o.purpose === "number" && typeof o.coin_type === "number" && typeof o.account === "number" && typeof o.change === "boolean" && typeof o.address_index === "number");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BIP44Params.typeUrl || typeof o.purpose === "number" && typeof o.coin_type === "number" && typeof o.account === "number" && typeof o.change === "boolean" && typeof o.address_index === "number");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.purpose !== undefined) {
            writer.uint32(8).uint32(message.purpose);
        }
        if (message.coinType !== undefined) {
            writer.uint32(16).uint32(message.coinType);
        }
        if (message.account !== undefined) {
            writer.uint32(24).uint32(message.account);
        }
        if (message.change !== undefined) {
            writer.uint32(32).bool(message.change);
        }
        if (message.addressIndex !== undefined) {
            writer.uint32(40).uint32(message.addressIndex);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBIP44Params();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.purpose = reader.uint32();
                    break;
                case 2:
                    message.coinType = reader.uint32();
                    break;
                case 3:
                    message.account = reader.uint32();
                    break;
                case 4:
                    message.change = reader.bool();
                    break;
                case 5:
                    message.addressIndex = reader.uint32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBIP44Params();
        if (isSet(object.purpose))
            obj.purpose = Number(object.purpose);
        if (isSet(object.coinType))
            obj.coinType = Number(object.coinType);
        if (isSet(object.account))
            obj.account = Number(object.account);
        if (isSet(object.change))
            obj.change = Boolean(object.change);
        if (isSet(object.addressIndex))
            obj.addressIndex = Number(object.addressIndex);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.purpose !== undefined && (obj.purpose = Math.round(message.purpose));
        message.coinType !== undefined && (obj.coinType = Math.round(message.coinType));
        message.account !== undefined && (obj.account = Math.round(message.account));
        message.change !== undefined && (obj.change = message.change);
        message.addressIndex !== undefined && (obj.addressIndex = Math.round(message.addressIndex));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBIP44Params();
        message.purpose = object.purpose ?? 0;
        message.coinType = object.coinType ?? 0;
        message.account = object.account ?? 0;
        message.change = object.change ?? false;
        message.addressIndex = object.addressIndex ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            purpose: object?.purpose,
            coinType: object?.coin_type,
            account: object?.account,
            change: object?.change,
            addressIndex: object?.address_index
        };
    },
    fromSDKJSON(object) {
        return {
            purpose: isSet(object.purpose) ? Number(object.purpose) : 0,
            coin_type: isSet(object.coin_type) ? Number(object.coin_type) : 0,
            account: isSet(object.account) ? Number(object.account) : 0,
            change: isSet(object.change) ? Boolean(object.change) : false,
            address_index: isSet(object.address_index) ? Number(object.address_index) : 0
        };
    },
    toSDK(message) {
        const obj = {};
        obj.purpose = message.purpose;
        obj.coin_type = message.coinType;
        obj.account = message.account;
        obj.change = message.change;
        obj.address_index = message.addressIndex;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBIP44Params();
        if (object.purpose !== undefined && object.purpose !== null) {
            message.purpose = object.purpose;
        }
        if (object.coin_type !== undefined && object.coin_type !== null) {
            message.coinType = object.coin_type;
        }
        if (object.account !== undefined && object.account !== null) {
            message.account = object.account;
        }
        if (object.change !== undefined && object.change !== null) {
            message.change = object.change;
        }
        if (object.address_index !== undefined && object.address_index !== null) {
            message.addressIndex = object.address_index;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.purpose = message.purpose === 0 ? undefined : message.purpose;
        obj.coin_type = message.coinType === 0 ? undefined : message.coinType;
        obj.account = message.account === 0 ? undefined : message.account;
        obj.change = message.change === false ? undefined : message.change;
        obj.address_index = message.addressIndex === 0 ? undefined : message.addressIndex;
        return obj;
    },
    fromAminoMsg(object) {
        return BIP44Params.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "cosmos-sdk/BIP44Params",
            value: BIP44Params.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return BIP44Params.decode(message.value);
    },
    toProto(message) {
        return BIP44Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/cosmos.crypto.hd.v1.BIP44Params",
            value: BIP44Params.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
