import { BinaryReader } from "../../../binary";
import { QueryAllowanceRequest, QueryAllowanceResponse, QueryAllowancesRequest, QueryAllowancesResponse, QueryAllowancesByGranterRequest, QueryAllowancesByGranterResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Allowance returns fee granted to the grantee by the granter. */
    allowance = async (request) => {
        const data = QueryAllowanceRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.feegrant.v1beta1.Query", "Allowance", data);
        return promise.then(data => QueryAllowanceResponse.decode(new BinaryReader(data)));
    };
    /* Allowances returns all the grants for address. */
    allowances = async (request) => {
        const data = QueryAllowancesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.feegrant.v1beta1.Query", "Allowances", data);
        return promise.then(data => QueryAllowancesResponse.decode(new BinaryReader(data)));
    };
    /* AllowancesByGranter returns all the grants given by an address
     Since v0.46 */
    allowancesByGranter = async (request) => {
        const data = QueryAllowancesByGranterRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.feegrant.v1beta1.Query", "AllowancesByGranter", data);
        return promise.then(data => QueryAllowancesByGranterResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
