import { VoteOption } from "./gov";
import { TelescopeGeneratedType } from "../../../types";
import { Registry } from "@cosmjs/proto-signing";
import { MsgSubmitProposal, MsgVote, MsgVoteWeighted, MsgDeposit } from "./tx";
export declare const registry: ReadonlyArray<[string, TelescopeGeneratedType<any, any, any>]>;
export declare const load: (protoRegistry: Registry) => void;
export declare const MessageComposer: {
    encoded: {
        submitProposal(value: MsgSubmitProposal): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        vote(value: MsgVote): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        voteWeighted(value: MsgVoteWeighted): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        deposit(value: MsgDeposit): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
    };
    withTypeUrl: {
        submitProposal(value: MsgSubmitProposal): {
            typeUrl: string;
            value: MsgSubmitProposal;
        };
        vote(value: MsgVote): {
            typeUrl: string;
            value: MsgVote;
        };
        voteWeighted(value: MsgVoteWeighted): {
            typeUrl: string;
            value: MsgVoteWeighted;
        };
        deposit(value: MsgDeposit): {
            typeUrl: string;
            value: MsgDeposit;
        };
    };
    toJSON: {
        submitProposal(value: MsgSubmitProposal): {
            typeUrl: string;
            value: {
                content?: {
                    $typeUrl?: "/google.protobuf.Any" | string;
                    typeUrl: string;
                    value: string;
                } | {
                    $typeUrl?: "/evmos.incentives.v1.RegisterIncentiveProposal";
                    title: string;
                    description: string;
                    contract: string;
                    allocations: {
                        denom: string;
                        amount: string;
                    }[];
                    epochs: number;
                } | {
                    $typeUrl?: "/ibc.core.client.v1.ClientUpdateProposal";
                    title: string;
                    description: string;
                    subjectClientId: string;
                    substituteClientId: string;
                } | {
                    $typeUrl?: "/ibc.core.client.v1.UpgradeProposal";
                    title: string;
                    description: string;
                    plan: {
                        name: string;
                        time: string;
                        height: string;
                        info: string;
                        upgradedClientState?: {
                            $typeUrl?: "/google.protobuf.Any" | string;
                            typeUrl: string;
                            value: string;
                        };
                    };
                    upgradedClientState?: {
                        $typeUrl?: "/google.protobuf.Any" | string;
                        typeUrl: string;
                        value: string;
                    };
                } | {
                    $typeUrl?: "/osmosis.poolincentives.v1beta1.ReplacePoolIncentivesProposal";
                    title: string;
                    description: string;
                    records: {
                        gaugeId: string;
                        weight: string;
                    }[];
                } | {
                    $typeUrl?: "/osmosis.poolincentives.v1beta1.UpdatePoolIncentivesProposal";
                    title: string;
                    description: string;
                    records: {
                        gaugeId: string;
                        weight: string;
                    }[];
                } | {
                    $typeUrl?: "/osmosis.superfluid.v1beta1.SetSuperfluidAssetsProposal";
                    title: string;
                    description: string;
                    assets: {
                        denom: string;
                        assetType: import("../../../osmosis/superfluid/superfluid").SuperfluidAssetType;
                    }[];
                } | {
                    $typeUrl?: "/osmosis.superfluid.v1beta1.RemoveSuperfluidAssetsProposal";
                    title: string;
                    description: string;
                    superfluidAssetDenoms: string[];
                } | {
                    $typeUrl?: "/osmosis.superfluid.v1beta1.UpdateUnpoolWhiteListProposal";
                    title: string;
                    description: string;
                    ids: string[];
                    isOverwrite: boolean;
                } | {
                    $typeUrl?: "/osmosis.txfees.v1beta1.UpdateFeeTokenProposal";
                    title: string;
                    description: string;
                    feetoken: {
                        denom: string;
                        poolID: string;
                    };
                } | {
                    $typeUrl?: "/cosmos.gov.v1beta1.TextProposal";
                    title: string;
                    description: string;
                };
                initialDeposit: {
                    denom: string;
                    amount: string;
                }[];
                proposer: string;
            };
        };
        vote(value: MsgVote): {
            typeUrl: string;
            value: {
                proposalId: string;
                voter: string;
                option: VoteOption;
            };
        };
        voteWeighted(value: MsgVoteWeighted): {
            typeUrl: string;
            value: {
                proposalId: string;
                voter: string;
                options: {
                    option: VoteOption;
                    weight: string;
                }[];
            };
        };
        deposit(value: MsgDeposit): {
            typeUrl: string;
            value: {
                proposalId: string;
                depositor: string;
                amount: {
                    denom: string;
                    amount: string;
                }[];
            };
        };
    };
    fromJSON: {
        submitProposal(value: any): {
            typeUrl: string;
            value: MsgSubmitProposal;
        };
        vote(value: any): {
            typeUrl: string;
            value: MsgVote;
        };
        voteWeighted(value: any): {
            typeUrl: string;
            value: MsgVoteWeighted;
        };
        deposit(value: any): {
            typeUrl: string;
            value: MsgDeposit;
        };
    };
    fromPartial: {
        submitProposal(value: MsgSubmitProposal): {
            typeUrl: string;
            value: MsgSubmitProposal;
        };
        vote(value: MsgVote): {
            typeUrl: string;
            value: MsgVote;
        };
        voteWeighted(value: MsgVoteWeighted): {
            typeUrl: string;
            value: MsgVoteWeighted;
        };
        deposit(value: MsgDeposit): {
            typeUrl: string;
            value: MsgDeposit;
        };
    };
};
