import { MsgSubmitProposal, MsgVote, MsgVoteWeighted, MsgDeposit } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* SubmitProposal defines a method to create new proposal given a content. */
    submitProposal = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgSubmitProposal.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Vote defines a method to add a vote on a specific proposal. */
    vote = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgVote.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* VoteWeighted defines a method to add a weighted vote on a specific proposal.
    
     Since: cosmos-sdk 0.43 */
    voteWeighted = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgVoteWeighted.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Deposit defines a method to add deposit on a specific proposal. */
    deposit = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgDeposit.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
