import { PageRequest } from "../../base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryBalanceResponse, QueryOwnerResponse, QuerySupplyResponse, QueryNFTsResponse, QueryNFTResponse, QueryClassResponse, QueryClassesResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721 */
    balance = async (params) => {
        const endpoint = `cosmos/nft/v1beta1/balance/${params.owner}/${params.classId}`;
        return QueryBalanceResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721 */
    owner = async (params) => {
        const endpoint = `cosmos/nft/v1beta1/owner/${params.classId}/${params.id}`;
        return QueryOwnerResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Supply queries the number of NFTs from the given class, same as totalSupply of ERC721. */
    supply = async (params) => {
        const endpoint = `cosmos/nft/v1beta1/supply/${params.classId}`;
        return QuerySupplyResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
     ERC721Enumerable */
    nFTs = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.classId !== "undefined") {
            options.params.class_id = params.classId;
        }
        if (typeof params?.owner !== "undefined") {
            options.params.owner = params.owner;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/nft/v1beta1/nfts`;
        return QueryNFTsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* NFT queries an NFT based on its class and id. */
    nFT = async (params) => {
        const endpoint = `cosmos/nft/v1beta1/nfts/${params.classId}/${params.id}`;
        return QueryNFTResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Class queries an NFT class based on its id */
    class = async (params) => {
        const endpoint = `cosmos/nft/v1beta1/classes/${params.classId}`;
        return QueryClassResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Classes queries all NFT classes */
    classes = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/nft/v1beta1/classes`;
        return QueryClassesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
