import { TxRpc } from "../../../types";
import { ReactQueryParams } from "../../../react-query";
import { ProtobufRpcClient } from "@cosmjs/stargate";
import { QueryBalanceRequest, QueryBalanceResponse, QueryOwnerRequest, QueryOwnerResponse, QuerySupplyRequest, QuerySupplyResponse, QueryNFTsRequest, QueryNFTsResponse, QueryNFTRequest, QueryNFTResponse, QueryClassRequest, QueryClassResponse, QueryClassesRequest, QueryClassesResponse } from "./query";
/** Query defines the gRPC querier service. */
export interface Query {
    /** Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721 */
    balance(request: QueryBalanceRequest): Promise<QueryBalanceResponse>;
    /** Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721 */
    owner(request: QueryOwnerRequest): Promise<QueryOwnerResponse>;
    /** Supply queries the number of NFTs from the given class, same as totalSupply of ERC721. */
    supply(request: QuerySupplyRequest): Promise<QuerySupplyResponse>;
    /**
     * NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
     * ERC721Enumerable
     */
    nFTs(request: QueryNFTsRequest): Promise<QueryNFTsResponse>;
    /** NFT queries an NFT based on its class and id. */
    nFT(request: QueryNFTRequest): Promise<QueryNFTResponse>;
    /** Class queries an NFT class based on its id */
    class(request: QueryClassRequest): Promise<QueryClassResponse>;
    /** Classes queries all NFT classes */
    classes(request?: QueryClassesRequest): Promise<QueryClassesResponse>;
}
export declare class QueryClientImpl implements Query {
    private readonly rpc;
    constructor(rpc: TxRpc);
    balance: (request: QueryBalanceRequest) => Promise<QueryBalanceResponse>;
    owner: (request: QueryOwnerRequest) => Promise<QueryOwnerResponse>;
    supply: (request: QuerySupplyRequest) => Promise<QuerySupplyResponse>;
    nFTs: (request: QueryNFTsRequest) => Promise<QueryNFTsResponse>;
    nFT: (request: QueryNFTRequest) => Promise<QueryNFTResponse>;
    class: (request: QueryClassRequest) => Promise<QueryClassResponse>;
    classes: (request?: QueryClassesRequest) => Promise<QueryClassesResponse>;
}
export declare const createClientImpl: (rpc: TxRpc) => QueryClientImpl;
export interface UseBalanceQuery<TData> extends ReactQueryParams<QueryBalanceResponse, TData> {
    request: QueryBalanceRequest;
}
export interface UseOwnerQuery<TData> extends ReactQueryParams<QueryOwnerResponse, TData> {
    request: QueryOwnerRequest;
}
export interface UseSupplyQuery<TData> extends ReactQueryParams<QuerySupplyResponse, TData> {
    request: QuerySupplyRequest;
}
export interface UseNFTsQuery<TData> extends ReactQueryParams<QueryNFTsResponse, TData> {
    request: QueryNFTsRequest;
}
export interface UseNFTQuery<TData> extends ReactQueryParams<QueryNFTResponse, TData> {
    request: QueryNFTRequest;
}
export interface UseClassQuery<TData> extends ReactQueryParams<QueryClassResponse, TData> {
    request: QueryClassRequest;
}
export interface UseClassesQuery<TData> extends ReactQueryParams<QueryClassesResponse, TData> {
    request?: QueryClassesRequest;
}
export declare const createRpcQueryHooks: (rpc: ProtobufRpcClient | undefined) => {
    /** Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721 */ useBalance: <TData = QueryBalanceResponse>({ request, options }: UseBalanceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721 */ useOwner: <TData = QueryOwnerResponse>({ request, options }: UseOwnerQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Supply queries the number of NFTs from the given class, same as totalSupply of ERC721. */ useSupply: <TData = QuerySupplyResponse>({ request, options }: UseSupplyQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
     * ERC721Enumerable
     */
    useNFTs: <TData = QueryNFTsResponse>({ request, options }: UseNFTsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** NFT queries an NFT based on its class and id. */ useNFT: <TData = QueryNFTResponse>({ request, options }: UseNFTQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Class queries an NFT class based on its id */ useClass: <TData = QueryClassResponse>({ request, options }: UseClassQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Classes queries all NFT classes */ useClasses: <TData = QueryClassesResponse>({ request, options }: UseClassesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
};
