import { setPaginationParams } from "../../../helpers";
import { QueryValidatorsResponse, QueryValidatorResponse, QueryValidatorDelegationsResponse, QueryValidatorUnbondingDelegationsResponse, QueryDelegationResponse, QueryUnbondingDelegationResponse, QueryDelegatorDelegationsResponse, QueryDelegatorUnbondingDelegationsResponse, QueryRedelegationsResponse, QueryDelegatorValidatorsResponse, QueryDelegatorValidatorResponse, QueryHistoricalInfoResponse, QueryPoolResponse, QueryParamsResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Validators queries all validators that match the given status. */
    validators = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.status !== "undefined") {
            options.params.status = params.status;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/validators`;
        return QueryValidatorsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Validator queries validator info for given validator address. */
    validator = async (params) => {
        const endpoint = `cosmos/staking/v1beta1/validators/${params.validatorAddr}`;
        return QueryValidatorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ValidatorDelegations queries delegate info for given validator. */
    validatorDelegations = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/validators/${params.validatorAddr}/delegations`;
        return QueryValidatorDelegationsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ValidatorUnbondingDelegations queries unbonding delegations of a validator. */
    validatorUnbondingDelegations = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/validators/${params.validatorAddr}/unbonding_delegations`;
        return QueryValidatorUnbondingDelegationsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Delegation queries delegate info for given validator delegator pair. */
    delegation = async (params) => {
        const endpoint = `cosmos/staking/v1beta1/validators/${params.validatorAddr}/delegations/${params.delegatorAddr}`;
        return QueryDelegationResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* UnbondingDelegation queries unbonding info for given validator delegator
     pair. */
    unbondingDelegation = async (params) => {
        const endpoint = `cosmos/staking/v1beta1/validators/${params.validatorAddr}/delegations/${params.delegatorAddr}/unbonding_delegation`;
        return QueryUnbondingDelegationResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DelegatorDelegations queries all delegations of a given delegator address. */
    delegatorDelegations = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/delegations/${params.delegatorAddr}`;
        return QueryDelegatorDelegationsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DelegatorUnbondingDelegations queries all unbonding delegations of a given
     delegator address. */
    delegatorUnbondingDelegations = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/delegators/${params.delegatorAddr}/unbonding_delegations`;
        return QueryDelegatorUnbondingDelegationsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Redelegations queries redelegations of given address. */
    redelegations = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.srcValidatorAddr !== "undefined") {
            options.params.src_validator_addr = params.srcValidatorAddr;
        }
        if (typeof params?.dstValidatorAddr !== "undefined") {
            options.params.dst_validator_addr = params.dstValidatorAddr;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/delegators/${params.delegatorAddr}/redelegations`;
        return QueryRedelegationsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DelegatorValidators queries all validators info for given delegator
     address. */
    delegatorValidators = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/staking/v1beta1/delegators/${params.delegatorAddr}/validators`;
        return QueryDelegatorValidatorsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DelegatorValidator queries validator info for given delegator validator
     pair. */
    delegatorValidator = async (params) => {
        const endpoint = `cosmos/staking/v1beta1/delegators/${params.delegatorAddr}/validators/${params.validatorAddr}`;
        return QueryDelegatorValidatorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* HistoricalInfo queries the historical info for given height. */
    historicalInfo = async (params) => {
        const endpoint = `cosmos/staking/v1beta1/historical_info/${params.height}`;
        return QueryHistoricalInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Pool queries the pool info. */
    pool = async (_params = {}) => {
        const endpoint = `cosmos/staking/v1beta1/pool`;
        return QueryPoolResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Parameters queries the staking parameters. */
    params = async (_params = {}) => {
        const endpoint = `cosmos/staking/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
