import { TxRpc } from "../../../types";
import { ReactQueryParams } from "../../../react-query";
import { ProtobufRpcClient } from "@cosmjs/stargate";
import { QueryValidatorsRequest, QueryValidatorsResponse, QueryValidatorRequest, QueryValidatorResponse, QueryValidatorDelegationsRequest, QueryValidatorDelegationsResponse, QueryValidatorUnbondingDelegationsRequest, QueryValidatorUnbondingDelegationsResponse, QueryDelegationRequest, QueryDelegationResponse, QueryUnbondingDelegationRequest, QueryUnbondingDelegationResponse, QueryDelegatorDelegationsRequest, QueryDelegatorDelegationsResponse, QueryDelegatorUnbondingDelegationsRequest, QueryDelegatorUnbondingDelegationsResponse, QueryRedelegationsRequest, QueryRedelegationsResponse, QueryDelegatorValidatorsRequest, QueryDelegatorValidatorsResponse, QueryDelegatorValidatorRequest, QueryDelegatorValidatorResponse, QueryHistoricalInfoRequest, QueryHistoricalInfoResponse, QueryPoolRequest, QueryPoolResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
/** Query defines the gRPC querier service. */
export interface Query {
    /** Validators queries all validators that match the given status. */
    validators(request: QueryValidatorsRequest): Promise<QueryValidatorsResponse>;
    /** Validator queries validator info for given validator address. */
    validator(request: QueryValidatorRequest): Promise<QueryValidatorResponse>;
    /** ValidatorDelegations queries delegate info for given validator. */
    validatorDelegations(request: QueryValidatorDelegationsRequest): Promise<QueryValidatorDelegationsResponse>;
    /** ValidatorUnbondingDelegations queries unbonding delegations of a validator. */
    validatorUnbondingDelegations(request: QueryValidatorUnbondingDelegationsRequest): Promise<QueryValidatorUnbondingDelegationsResponse>;
    /** Delegation queries delegate info for given validator delegator pair. */
    delegation(request: QueryDelegationRequest): Promise<QueryDelegationResponse>;
    /**
     * UnbondingDelegation queries unbonding info for given validator delegator
     * pair.
     */
    unbondingDelegation(request: QueryUnbondingDelegationRequest): Promise<QueryUnbondingDelegationResponse>;
    /** DelegatorDelegations queries all delegations of a given delegator address. */
    delegatorDelegations(request: QueryDelegatorDelegationsRequest): Promise<QueryDelegatorDelegationsResponse>;
    /**
     * DelegatorUnbondingDelegations queries all unbonding delegations of a given
     * delegator address.
     */
    delegatorUnbondingDelegations(request: QueryDelegatorUnbondingDelegationsRequest): Promise<QueryDelegatorUnbondingDelegationsResponse>;
    /** Redelegations queries redelegations of given address. */
    redelegations(request: QueryRedelegationsRequest): Promise<QueryRedelegationsResponse>;
    /**
     * DelegatorValidators queries all validators info for given delegator
     * address.
     */
    delegatorValidators(request: QueryDelegatorValidatorsRequest): Promise<QueryDelegatorValidatorsResponse>;
    /**
     * DelegatorValidator queries validator info for given delegator validator
     * pair.
     */
    delegatorValidator(request: QueryDelegatorValidatorRequest): Promise<QueryDelegatorValidatorResponse>;
    /** HistoricalInfo queries the historical info for given height. */
    historicalInfo(request: QueryHistoricalInfoRequest): Promise<QueryHistoricalInfoResponse>;
    /** Pool queries the pool info. */
    pool(request?: QueryPoolRequest): Promise<QueryPoolResponse>;
    /** Parameters queries the staking parameters. */
    params(request?: QueryParamsRequest): Promise<QueryParamsResponse>;
}
export declare class QueryClientImpl implements Query {
    private readonly rpc;
    constructor(rpc: TxRpc);
    validators: (request: QueryValidatorsRequest) => Promise<QueryValidatorsResponse>;
    validator: (request: QueryValidatorRequest) => Promise<QueryValidatorResponse>;
    validatorDelegations: (request: QueryValidatorDelegationsRequest) => Promise<QueryValidatorDelegationsResponse>;
    validatorUnbondingDelegations: (request: QueryValidatorUnbondingDelegationsRequest) => Promise<QueryValidatorUnbondingDelegationsResponse>;
    delegation: (request: QueryDelegationRequest) => Promise<QueryDelegationResponse>;
    unbondingDelegation: (request: QueryUnbondingDelegationRequest) => Promise<QueryUnbondingDelegationResponse>;
    delegatorDelegations: (request: QueryDelegatorDelegationsRequest) => Promise<QueryDelegatorDelegationsResponse>;
    delegatorUnbondingDelegations: (request: QueryDelegatorUnbondingDelegationsRequest) => Promise<QueryDelegatorUnbondingDelegationsResponse>;
    redelegations: (request: QueryRedelegationsRequest) => Promise<QueryRedelegationsResponse>;
    delegatorValidators: (request: QueryDelegatorValidatorsRequest) => Promise<QueryDelegatorValidatorsResponse>;
    delegatorValidator: (request: QueryDelegatorValidatorRequest) => Promise<QueryDelegatorValidatorResponse>;
    historicalInfo: (request: QueryHistoricalInfoRequest) => Promise<QueryHistoricalInfoResponse>;
    pool: (request?: QueryPoolRequest) => Promise<QueryPoolResponse>;
    params: (request?: QueryParamsRequest) => Promise<QueryParamsResponse>;
}
export declare const createClientImpl: (rpc: TxRpc) => QueryClientImpl;
export interface UseValidatorsQuery<TData> extends ReactQueryParams<QueryValidatorsResponse, TData> {
    request: QueryValidatorsRequest;
}
export interface UseValidatorQuery<TData> extends ReactQueryParams<QueryValidatorResponse, TData> {
    request: QueryValidatorRequest;
}
export interface UseValidatorDelegationsQuery<TData> extends ReactQueryParams<QueryValidatorDelegationsResponse, TData> {
    request: QueryValidatorDelegationsRequest;
}
export interface UseValidatorUnbondingDelegationsQuery<TData> extends ReactQueryParams<QueryValidatorUnbondingDelegationsResponse, TData> {
    request: QueryValidatorUnbondingDelegationsRequest;
}
export interface UseDelegationQuery<TData> extends ReactQueryParams<QueryDelegationResponse, TData> {
    request: QueryDelegationRequest;
}
export interface UseUnbondingDelegationQuery<TData> extends ReactQueryParams<QueryUnbondingDelegationResponse, TData> {
    request: QueryUnbondingDelegationRequest;
}
export interface UseDelegatorDelegationsQuery<TData> extends ReactQueryParams<QueryDelegatorDelegationsResponse, TData> {
    request: QueryDelegatorDelegationsRequest;
}
export interface UseDelegatorUnbondingDelegationsQuery<TData> extends ReactQueryParams<QueryDelegatorUnbondingDelegationsResponse, TData> {
    request: QueryDelegatorUnbondingDelegationsRequest;
}
export interface UseRedelegationsQuery<TData> extends ReactQueryParams<QueryRedelegationsResponse, TData> {
    request: QueryRedelegationsRequest;
}
export interface UseDelegatorValidatorsQuery<TData> extends ReactQueryParams<QueryDelegatorValidatorsResponse, TData> {
    request: QueryDelegatorValidatorsRequest;
}
export interface UseDelegatorValidatorQuery<TData> extends ReactQueryParams<QueryDelegatorValidatorResponse, TData> {
    request: QueryDelegatorValidatorRequest;
}
export interface UseHistoricalInfoQuery<TData> extends ReactQueryParams<QueryHistoricalInfoResponse, TData> {
    request: QueryHistoricalInfoRequest;
}
export interface UsePoolQuery<TData> extends ReactQueryParams<QueryPoolResponse, TData> {
    request?: QueryPoolRequest;
}
export interface UseParamsQuery<TData> extends ReactQueryParams<QueryParamsResponse, TData> {
    request?: QueryParamsRequest;
}
export declare const createRpcQueryHooks: (rpc: ProtobufRpcClient | undefined) => {
    /** Validators queries all validators that match the given status. */ useValidators: <TData = QueryValidatorsResponse>({ request, options }: UseValidatorsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Validator queries validator info for given validator address. */ useValidator: <TData = QueryValidatorResponse>({ request, options }: UseValidatorQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** ValidatorDelegations queries delegate info for given validator. */ useValidatorDelegations: <TData = QueryValidatorDelegationsResponse>({ request, options }: UseValidatorDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** ValidatorUnbondingDelegations queries unbonding delegations of a validator. */ useValidatorUnbondingDelegations: <TData = QueryValidatorUnbondingDelegationsResponse>({ request, options }: UseValidatorUnbondingDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Delegation queries delegate info for given validator delegator pair. */ useDelegation: <TData = QueryDelegationResponse>({ request, options }: UseDelegationQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * UnbondingDelegation queries unbonding info for given validator delegator
     * pair.
     */
    useUnbondingDelegation: <TData = QueryUnbondingDelegationResponse>({ request, options }: UseUnbondingDelegationQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** DelegatorDelegations queries all delegations of a given delegator address. */ useDelegatorDelegations: <TData = QueryDelegatorDelegationsResponse>({ request, options }: UseDelegatorDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * DelegatorUnbondingDelegations queries all unbonding delegations of a given
     * delegator address.
     */
    useDelegatorUnbondingDelegations: <TData = QueryDelegatorUnbondingDelegationsResponse>({ request, options }: UseDelegatorUnbondingDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Redelegations queries redelegations of given address. */ useRedelegations: <TData = QueryRedelegationsResponse>({ request, options }: UseRedelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * DelegatorValidators queries all validators info for given delegator
     * address.
     */
    useDelegatorValidators: <TData = QueryDelegatorValidatorsResponse>({ request, options }: UseDelegatorValidatorsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * DelegatorValidator queries validator info for given delegator validator
     * pair.
     */
    useDelegatorValidator: <TData = QueryDelegatorValidatorResponse>({ request, options }: UseDelegatorValidatorQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** HistoricalInfo queries the historical info for given height. */ useHistoricalInfo: <TData = QueryHistoricalInfoResponse>({ request, options }: UseHistoricalInfoQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Pool queries the pool info. */ usePool: <TData = QueryPoolResponse>({ request, options }: UsePoolQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Parameters queries the staking parameters. */ useParams: <TData = QueryParamsResponse>({ request, options }: UseParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
};
