import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryValidatorsRequest, QueryValidatorsResponse, QueryValidatorRequest, QueryValidatorResponse, QueryValidatorDelegationsRequest, QueryValidatorDelegationsResponse, QueryValidatorUnbondingDelegationsRequest, QueryValidatorUnbondingDelegationsResponse, QueryDelegationRequest, QueryDelegationResponse, QueryUnbondingDelegationRequest, QueryUnbondingDelegationResponse, QueryDelegatorDelegationsRequest, QueryDelegatorDelegationsResponse, QueryDelegatorUnbondingDelegationsRequest, QueryDelegatorUnbondingDelegationsResponse, QueryRedelegationsRequest, QueryRedelegationsResponse, QueryDelegatorValidatorsRequest, QueryDelegatorValidatorsResponse, QueryDelegatorValidatorRequest, QueryDelegatorValidatorResponse, QueryHistoricalInfoRequest, QueryHistoricalInfoResponse, QueryPoolRequest, QueryPoolResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Validators queries all validators that match the given status. */
    validators = async (request) => {
        const data = QueryValidatorsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Validators", data);
        return promise.then(data => QueryValidatorsResponse.decode(new BinaryReader(data)));
    };
    /* Validator queries validator info for given validator address. */
    validator = async (request) => {
        const data = QueryValidatorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Validator", data);
        return promise.then(data => QueryValidatorResponse.decode(new BinaryReader(data)));
    };
    /* ValidatorDelegations queries delegate info for given validator. */
    validatorDelegations = async (request) => {
        const data = QueryValidatorDelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "ValidatorDelegations", data);
        return promise.then(data => QueryValidatorDelegationsResponse.decode(new BinaryReader(data)));
    };
    /* ValidatorUnbondingDelegations queries unbonding delegations of a validator. */
    validatorUnbondingDelegations = async (request) => {
        const data = QueryValidatorUnbondingDelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "ValidatorUnbondingDelegations", data);
        return promise.then(data => QueryValidatorUnbondingDelegationsResponse.decode(new BinaryReader(data)));
    };
    /* Delegation queries delegate info for given validator delegator pair. */
    delegation = async (request) => {
        const data = QueryDelegationRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Delegation", data);
        return promise.then(data => QueryDelegationResponse.decode(new BinaryReader(data)));
    };
    /* UnbondingDelegation queries unbonding info for given validator delegator
     pair. */
    unbondingDelegation = async (request) => {
        const data = QueryUnbondingDelegationRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "UnbondingDelegation", data);
        return promise.then(data => QueryUnbondingDelegationResponse.decode(new BinaryReader(data)));
    };
    /* DelegatorDelegations queries all delegations of a given delegator address. */
    delegatorDelegations = async (request) => {
        const data = QueryDelegatorDelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "DelegatorDelegations", data);
        return promise.then(data => QueryDelegatorDelegationsResponse.decode(new BinaryReader(data)));
    };
    /* DelegatorUnbondingDelegations queries all unbonding delegations of a given
     delegator address. */
    delegatorUnbondingDelegations = async (request) => {
        const data = QueryDelegatorUnbondingDelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "DelegatorUnbondingDelegations", data);
        return promise.then(data => QueryDelegatorUnbondingDelegationsResponse.decode(new BinaryReader(data)));
    };
    /* Redelegations queries redelegations of given address. */
    redelegations = async (request) => {
        const data = QueryRedelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Redelegations", data);
        return promise.then(data => QueryRedelegationsResponse.decode(new BinaryReader(data)));
    };
    /* DelegatorValidators queries all validators info for given delegator
     address. */
    delegatorValidators = async (request) => {
        const data = QueryDelegatorValidatorsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "DelegatorValidators", data);
        return promise.then(data => QueryDelegatorValidatorsResponse.decode(new BinaryReader(data)));
    };
    /* DelegatorValidator queries validator info for given delegator validator
     pair. */
    delegatorValidator = async (request) => {
        const data = QueryDelegatorValidatorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "DelegatorValidator", data);
        return promise.then(data => QueryDelegatorValidatorResponse.decode(new BinaryReader(data)));
    };
    /* HistoricalInfo queries the historical info for given height. */
    historicalInfo = async (request) => {
        const data = QueryHistoricalInfoRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "HistoricalInfo", data);
        return promise.then(data => QueryHistoricalInfoResponse.decode(new BinaryReader(data)));
    };
    /* Pool queries the pool info. */
    pool = async (request = {}) => {
        const data = QueryPoolRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Pool", data);
        return promise.then(data => QueryPoolResponse.decode(new BinaryReader(data)));
    };
    /* Parameters queries the staking parameters. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.staking.v1beta1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useValidators = ({ request, options }) => {
        return useQuery(["validatorsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.validators(request);
        }, options);
    };
    const useValidator = ({ request, options }) => {
        return useQuery(["validatorQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.validator(request);
        }, options);
    };
    const useValidatorDelegations = ({ request, options }) => {
        return useQuery(["validatorDelegationsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.validatorDelegations(request);
        }, options);
    };
    const useValidatorUnbondingDelegations = ({ request, options }) => {
        return useQuery(["validatorUnbondingDelegationsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.validatorUnbondingDelegations(request);
        }, options);
    };
    const useDelegation = ({ request, options }) => {
        return useQuery(["delegationQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.delegation(request);
        }, options);
    };
    const useUnbondingDelegation = ({ request, options }) => {
        return useQuery(["unbondingDelegationQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.unbondingDelegation(request);
        }, options);
    };
    const useDelegatorDelegations = ({ request, options }) => {
        return useQuery(["delegatorDelegationsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.delegatorDelegations(request);
        }, options);
    };
    const useDelegatorUnbondingDelegations = ({ request, options }) => {
        return useQuery(["delegatorUnbondingDelegationsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.delegatorUnbondingDelegations(request);
        }, options);
    };
    const useRedelegations = ({ request, options }) => {
        return useQuery(["redelegationsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.redelegations(request);
        }, options);
    };
    const useDelegatorValidators = ({ request, options }) => {
        return useQuery(["delegatorValidatorsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.delegatorValidators(request);
        }, options);
    };
    const useDelegatorValidator = ({ request, options }) => {
        return useQuery(["delegatorValidatorQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.delegatorValidator(request);
        }, options);
    };
    const useHistoricalInfo = ({ request, options }) => {
        return useQuery(["historicalInfoQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.historicalInfo(request);
        }, options);
    };
    const usePool = ({ request, options }) => {
        return useQuery(["poolQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.pool(request);
        }, options);
    };
    const useParams = ({ request, options }) => {
        return useQuery(["paramsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.params(request);
        }, options);
    };
    return {
        /** Validators queries all validators that match the given status. */ useValidators,
        /** Validator queries validator info for given validator address. */ useValidator,
        /** ValidatorDelegations queries delegate info for given validator. */ useValidatorDelegations,
        /** ValidatorUnbondingDelegations queries unbonding delegations of a validator. */ useValidatorUnbondingDelegations,
        /** Delegation queries delegate info for given validator delegator pair. */ useDelegation,
        /**
         * UnbondingDelegation queries unbonding info for given validator delegator
         * pair.
         */
        useUnbondingDelegation,
        /** DelegatorDelegations queries all delegations of a given delegator address. */ useDelegatorDelegations,
        /**
         * DelegatorUnbondingDelegations queries all unbonding delegations of a given
         * delegator address.
         */
        useDelegatorUnbondingDelegations,
        /** Redelegations queries redelegations of given address. */ useRedelegations,
        /**
         * DelegatorValidators queries all validators info for given delegator
         * address.
         */
        useDelegatorValidators,
        /**
         * DelegatorValidator queries validator info for given delegator validator
         * pair.
         */
        useDelegatorValidator,
        /** HistoricalInfo queries the historical info for given height. */ useHistoricalInfo,
        /** Pool queries the pool info. */ usePool,
        /** Parameters queries the staking parameters. */ useParams
    };
};
