import { TelescopeGeneratedType } from "../../../types";
import { Registry } from "@cosmjs/proto-signing";
import { MsgCreateValidator, MsgEditValidator, MsgDelegate, MsgBeginRedelegate, MsgUndelegate } from "./tx";
export declare const registry: ReadonlyArray<[string, TelescopeGeneratedType<any, any, any>]>;
export declare const load: (protoRegistry: Registry) => void;
export declare const MessageComposer: {
    encoded: {
        createValidator(value: MsgCreateValidator): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        editValidator(value: MsgEditValidator): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        delegate(value: MsgDelegate): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        beginRedelegate(value: MsgBeginRedelegate): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        undelegate(value: MsgUndelegate): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
    };
    withTypeUrl: {
        createValidator(value: MsgCreateValidator): {
            typeUrl: string;
            value: MsgCreateValidator;
        };
        editValidator(value: MsgEditValidator): {
            typeUrl: string;
            value: MsgEditValidator;
        };
        delegate(value: MsgDelegate): {
            typeUrl: string;
            value: MsgDelegate;
        };
        beginRedelegate(value: MsgBeginRedelegate): {
            typeUrl: string;
            value: MsgBeginRedelegate;
        };
        undelegate(value: MsgUndelegate): {
            typeUrl: string;
            value: MsgUndelegate;
        };
    };
    toJSON: {
        createValidator(value: MsgCreateValidator): {
            typeUrl: string;
            value: {
                description: {
                    moniker: string;
                    identity: string;
                    website: string;
                    securityContact: string;
                    details: string;
                };
                commission: {
                    rate: string;
                    maxRate: string;
                    maxChangeRate: string;
                };
                minSelfDelegation: string;
                delegatorAddress: string;
                validatorAddress: string;
                pubkey?: {
                    $typeUrl?: "/google.protobuf.Any" | string;
                    typeUrl: string;
                    value: string;
                };
                value: {
                    denom: string;
                    amount: string;
                };
            };
        };
        editValidator(value: MsgEditValidator): {
            typeUrl: string;
            value: {
                description: {
                    moniker: string;
                    identity: string;
                    website: string;
                    securityContact: string;
                    details: string;
                };
                validatorAddress: string;
                commissionRate: string;
                minSelfDelegation: string;
            };
        };
        delegate(value: MsgDelegate): {
            typeUrl: string;
            value: {
                delegatorAddress: string;
                validatorAddress: string;
                amount: {
                    denom: string;
                    amount: string;
                };
            };
        };
        beginRedelegate(value: MsgBeginRedelegate): {
            typeUrl: string;
            value: {
                delegatorAddress: string;
                validatorSrcAddress: string;
                validatorDstAddress: string;
                amount: {
                    denom: string;
                    amount: string;
                };
            };
        };
        undelegate(value: MsgUndelegate): {
            typeUrl: string;
            value: {
                delegatorAddress: string;
                validatorAddress: string;
                amount: {
                    denom: string;
                    amount: string;
                };
            };
        };
    };
    fromJSON: {
        createValidator(value: any): {
            typeUrl: string;
            value: MsgCreateValidator;
        };
        editValidator(value: any): {
            typeUrl: string;
            value: MsgEditValidator;
        };
        delegate(value: any): {
            typeUrl: string;
            value: MsgDelegate;
        };
        beginRedelegate(value: any): {
            typeUrl: string;
            value: MsgBeginRedelegate;
        };
        undelegate(value: any): {
            typeUrl: string;
            value: MsgUndelegate;
        };
    };
    fromPartial: {
        createValidator(value: MsgCreateValidator): {
            typeUrl: string;
            value: MsgCreateValidator;
        };
        editValidator(value: MsgEditValidator): {
            typeUrl: string;
            value: MsgEditValidator;
        };
        delegate(value: MsgDelegate): {
            typeUrl: string;
            value: MsgDelegate;
        };
        beginRedelegate(value: MsgBeginRedelegate): {
            typeUrl: string;
            value: MsgBeginRedelegate;
        };
        undelegate(value: MsgUndelegate): {
            typeUrl: string;
            value: MsgUndelegate;
        };
    };
};
