import { MsgStoreCode, MsgInstantiateContract, MsgExecuteContract, MsgMigrateContract, MsgUpdateAdmin, MsgClearAdmin } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* StoreCode to submit Wasm code to the system */
    storeCode = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgStoreCode.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Instantiate creates a new smart contract instance for the given code id. */
    instantiateContract = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgInstantiateContract.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Execute submits the given message data to a smart contract */
    executeContract = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgExecuteContract.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Migrate runs a code upgrade/ downgrade for a smart contract */
    migrateContract = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgMigrateContract.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateAdmin sets a new   admin for a smart contract */
    updateAdmin = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateAdmin.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ClearAdmin removes any admin stored for a smart contract */
    clearAdmin = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgClearAdmin.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
