import { Certificate } from "./cert";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.cert.v1beta2";
function createBaseGenesisCertificate() {
    return {
        owner: "",
        certificate: Certificate.fromPartial({})
    };
}
export const GenesisCertificate = {
    typeUrl: "/akash.cert.v1beta2.GenesisCertificate",
    aminoType: "akash/cert/v1beta2/genesis-certificate",
    is(o) {
        return o && (o.$typeUrl === GenesisCertificate.typeUrl || typeof o.owner === "string" && Certificate.is(o.certificate));
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisCertificate.typeUrl || typeof o.owner === "string" && Certificate.isSDK(o.certificate));
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisCertificate.typeUrl || typeof o.owner === "string" && Certificate.isAmino(o.certificate));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.owner !== undefined) {
            writer.uint32(10).string(message.owner);
        }
        if (message.certificate !== undefined) {
            Certificate.encode(message.certificate, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisCertificate();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.owner = reader.string();
                    break;
                case 2:
                    message.certificate = Certificate.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisCertificate();
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.certificate))
            obj.certificate = Certificate.fromJSON(object.certificate);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.owner !== undefined && (obj.owner = message.owner);
        message.certificate !== undefined && (obj.certificate = message.certificate ? Certificate.toJSON(message.certificate) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisCertificate();
        message.owner = object.owner ?? "";
        if (object.certificate !== undefined && object.certificate !== null) {
            message.certificate = Certificate.fromPartial(object.certificate);
        }
        return message;
    },
    fromSDK(object) {
        return {
            owner: object?.owner,
            certificate: object.certificate ? Certificate.fromSDK(object.certificate) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            owner: isSet(object.owner) ? String(object.owner) : "",
            certificate: isSet(object.certificate) ? Certificate.fromSDKJSON(object.certificate) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.owner = message.owner;
        message.certificate !== undefined && (obj.certificate = message.certificate ? Certificate.toSDK(message.certificate) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisCertificate();
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.certificate !== undefined && object.certificate !== null) {
            message.certificate = Certificate.fromAmino(object.certificate);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.owner = message.owner ?? "";
        obj.certificate = message.certificate ? Certificate.toAmino(message.certificate) : Certificate.toAmino(Certificate.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisCertificate.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/cert/v1beta2/genesis-certificate",
            value: GenesisCertificate.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return GenesisCertificate.decode(message.value);
    },
    toProto(message) {
        return GenesisCertificate.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.cert.v1beta2.GenesisCertificate",
            value: GenesisCertificate.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Certificate.registerTypeUrl();
    }
};
function createBaseGenesisState() {
    return {
        certificates: []
    };
}
export const GenesisState = {
    typeUrl: "/akash.cert.v1beta2.GenesisState",
    aminoType: "akash/cert/v1beta2/genesis-state",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || GenesisCertificate.is(o.certificates[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || GenesisCertificate.isSDK(o.certificates[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Array.isArray(o.certificates) && (!o.certificates.length || GenesisCertificate.isAmino(o.certificates[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.certificates) {
            GenesisCertificate.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.certificates.push(GenesisCertificate.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (Array.isArray(object?.certificates))
            obj.certificates = object.certificates.map((e) => GenesisCertificate.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? GenesisCertificate.toJSON(e) : undefined);
        }
        else {
            obj.certificates = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        message.certificates = object.certificates?.map(e => GenesisCertificate.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            certificates: Array.isArray(object?.certificates) ? object.certificates.map((e) => GenesisCertificate.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            certificates: Array.isArray(object?.certificates) ? object.certificates.map((e) => GenesisCertificate.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? GenesisCertificate.toSDK(e) : undefined);
        }
        else {
            obj.certificates = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        message.certificates = object.certificates?.map(e => GenesisCertificate.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.certificates) {
            obj.certificates = message.certificates.map(e => e ? GenesisCertificate.toAmino(e) : undefined);
        }
        else {
            obj.certificates = message.certificates;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/cert/v1beta2/genesis-state",
            value: GenesisState.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.cert.v1beta2.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        GenesisCertificate.registerTypeUrl();
    }
};
