import { DeploymentFilters, DeploymentID, Deployment } from "./deployment";
import { PageRequest, PageResponse } from "../../../cosmos/base/query/v1beta1/pagination";
import { GroupID, Group } from "./group";
import { Account } from "../../escrow/v1beta1/types";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.deployment.v1beta1";
function createBaseQueryDeploymentsRequest() {
    return {
        filters: DeploymentFilters.fromPartial({}),
        pagination: undefined
    };
}
export const QueryDeploymentsRequest = {
    typeUrl: "/akash.deployment.v1beta1.QueryDeploymentsRequest",
    aminoType: "akash/deployment/query-deployments-request",
    is(o) {
        return o && (o.$typeUrl === QueryDeploymentsRequest.typeUrl || DeploymentFilters.is(o.filters));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryDeploymentsRequest.typeUrl || DeploymentFilters.isSDK(o.filters));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.filters !== undefined) {
            DeploymentFilters.encode(message.filters, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageRequest.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryDeploymentsRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.filters = DeploymentFilters.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.pagination = PageRequest.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryDeploymentsRequest();
        if (isSet(object.filters))
            obj.filters = DeploymentFilters.fromJSON(object.filters);
        if (isSet(object.pagination))
            obj.pagination = PageRequest.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? DeploymentFilters.toJSON(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryDeploymentsRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = DeploymentFilters.fromPartial(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            filters: object.filters ? DeploymentFilters.fromSDK(object.filters) : undefined,
            pagination: object.pagination ? PageRequest.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            filters: isSet(object.filters) ? DeploymentFilters.fromSDKJSON(object.filters) : undefined,
            pagination: isSet(object.pagination) ? PageRequest.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.filters !== undefined && (obj.filters = message.filters ? DeploymentFilters.toSDK(message.filters) : undefined);
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageRequest.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryDeploymentsRequest();
        if (object.filters !== undefined && object.filters !== null) {
            message.filters = DeploymentFilters.fromAmino(object.filters);
        }
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageRequest.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.filters = message.filters ? DeploymentFilters.toAmino(message.filters) : undefined;
        obj.pagination = message.pagination ? PageRequest.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryDeploymentsRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-deployments-request",
            value: QueryDeploymentsRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryDeploymentsRequest.decode(message.value);
    },
    toProto(message) {
        return QueryDeploymentsRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryDeploymentsRequest",
            value: QueryDeploymentsRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentFilters.registerTypeUrl();
        PageRequest.registerTypeUrl();
    }
};
function createBaseQueryDeploymentsResponse() {
    return {
        deployments: [],
        pagination: undefined
    };
}
export const QueryDeploymentsResponse = {
    typeUrl: "/akash.deployment.v1beta1.QueryDeploymentsResponse",
    aminoType: "akash/deployment/query-deployments-response",
    is(o) {
        return o && (o.$typeUrl === QueryDeploymentsResponse.typeUrl || Array.isArray(o.deployments) && (!o.deployments.length || QueryDeploymentResponse.is(o.deployments[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryDeploymentsResponse.typeUrl || Array.isArray(o.deployments) && (!o.deployments.length || QueryDeploymentResponse.isSDK(o.deployments[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.deployments) {
            QueryDeploymentResponse.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.pagination !== undefined) {
            PageResponse.encode(message.pagination, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryDeploymentsResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.deployments.push(QueryDeploymentResponse.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.pagination = PageResponse.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryDeploymentsResponse();
        if (Array.isArray(object?.deployments))
            obj.deployments = object.deployments.map((e) => QueryDeploymentResponse.fromJSON(e));
        if (isSet(object.pagination))
            obj.pagination = PageResponse.fromJSON(object.pagination);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.deployments) {
            obj.deployments = message.deployments.map(e => e ? QueryDeploymentResponse.toJSON(e) : undefined);
        }
        else {
            obj.deployments = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toJSON(message.pagination) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryDeploymentsResponse();
        message.deployments = object.deployments?.map(e => QueryDeploymentResponse.fromPartial(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromPartial(object.pagination);
        }
        return message;
    },
    fromSDK(object) {
        return {
            deployments: Array.isArray(object?.deployments) ? object.deployments.map((e) => QueryDeploymentResponse.fromSDK(e)) : [],
            pagination: object.pagination ? PageResponse.fromSDK(object.pagination) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            deployments: Array.isArray(object?.deployments) ? object.deployments.map((e) => QueryDeploymentResponse.fromSDKJSON(e)) : [],
            pagination: isSet(object.pagination) ? PageResponse.fromSDKJSON(object.pagination) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.deployments) {
            obj.deployments = message.deployments.map(e => e ? QueryDeploymentResponse.toSDK(e) : undefined);
        }
        else {
            obj.deployments = [];
        }
        message.pagination !== undefined && (obj.pagination = message.pagination ? PageResponse.toSDK(message.pagination) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryDeploymentsResponse();
        message.deployments = object.deployments?.map(e => QueryDeploymentResponse.fromAmino(e)) || [];
        if (object.pagination !== undefined && object.pagination !== null) {
            message.pagination = PageResponse.fromAmino(object.pagination);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.deployments) {
            obj.deployments = message.deployments.map(e => e ? QueryDeploymentResponse.toAmino(e) : undefined);
        }
        else {
            obj.deployments = message.deployments;
        }
        obj.pagination = message.pagination ? PageResponse.toAmino(message.pagination) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryDeploymentsResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-deployments-response",
            value: QueryDeploymentsResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryDeploymentsResponse.decode(message.value);
    },
    toProto(message) {
        return QueryDeploymentsResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryDeploymentsResponse",
            value: QueryDeploymentsResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QueryDeploymentResponse.registerTypeUrl();
        PageResponse.registerTypeUrl();
    }
};
function createBaseQueryDeploymentRequest() {
    return {
        id: DeploymentID.fromPartial({})
    };
}
export const QueryDeploymentRequest = {
    typeUrl: "/akash.deployment.v1beta1.QueryDeploymentRequest",
    aminoType: "akash/deployment/query-deployment-request",
    is(o) {
        return o && (o.$typeUrl === QueryDeploymentRequest.typeUrl || DeploymentID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryDeploymentRequest.typeUrl || DeploymentID.isSDK(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            DeploymentID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryDeploymentRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = DeploymentID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryDeploymentRequest();
        if (isSet(object.id))
            obj.id = DeploymentID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryDeploymentRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? DeploymentID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? DeploymentID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? DeploymentID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryDeploymentRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = DeploymentID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? DeploymentID.toAmino(message.id) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryDeploymentRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-deployment-request",
            value: QueryDeploymentRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryDeploymentRequest.decode(message.value);
    },
    toProto(message) {
        return QueryDeploymentRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryDeploymentRequest",
            value: QueryDeploymentRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DeploymentID.registerTypeUrl();
    }
};
function createBaseQueryDeploymentResponse() {
    return {
        deployment: Deployment.fromPartial({}),
        groups: [],
        escrowAccount: Account.fromPartial({})
    };
}
export const QueryDeploymentResponse = {
    typeUrl: "/akash.deployment.v1beta1.QueryDeploymentResponse",
    aminoType: "akash/deployment/query-deployment-response",
    is(o) {
        return o && (o.$typeUrl === QueryDeploymentResponse.typeUrl || Deployment.is(o.deployment) && Array.isArray(o.groups) && (!o.groups.length || Group.is(o.groups[0])) && Account.is(o.escrowAccount));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryDeploymentResponse.typeUrl || Deployment.isSDK(o.deployment) && Array.isArray(o.groups) && (!o.groups.length || Group.isSDK(o.groups[0])) && Account.isSDK(o.escrow_account));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.deployment !== undefined) {
            Deployment.encode(message.deployment, writer.uint32(10).fork()).ldelim();
        }
        for (const v of message.groups) {
            Group.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.escrowAccount !== undefined) {
            Account.encode(message.escrowAccount, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryDeploymentResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.deployment = Deployment.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.groups.push(Group.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.escrowAccount = Account.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryDeploymentResponse();
        if (isSet(object.deployment))
            obj.deployment = Deployment.fromJSON(object.deployment);
        if (Array.isArray(object?.groups))
            obj.groups = object.groups.map((e) => Group.fromJSON(e));
        if (isSet(object.escrowAccount))
            obj.escrowAccount = Account.fromJSON(object.escrowAccount);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.deployment !== undefined && (obj.deployment = message.deployment ? Deployment.toJSON(message.deployment) : undefined);
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? Group.toJSON(e) : undefined);
        }
        else {
            obj.groups = [];
        }
        message.escrowAccount !== undefined && (obj.escrowAccount = message.escrowAccount ? Account.toJSON(message.escrowAccount) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryDeploymentResponse();
        if (object.deployment !== undefined && object.deployment !== null) {
            message.deployment = Deployment.fromPartial(object.deployment);
        }
        message.groups = object.groups?.map(e => Group.fromPartial(e)) || [];
        if (object.escrowAccount !== undefined && object.escrowAccount !== null) {
            message.escrowAccount = Account.fromPartial(object.escrowAccount);
        }
        return message;
    },
    fromSDK(object) {
        return {
            deployment: object.deployment ? Deployment.fromSDK(object.deployment) : undefined,
            groups: Array.isArray(object?.groups) ? object.groups.map((e) => Group.fromSDK(e)) : [],
            escrowAccount: object.escrow_account ? Account.fromSDK(object.escrow_account) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            deployment: isSet(object.deployment) ? Deployment.fromSDKJSON(object.deployment) : undefined,
            groups: Array.isArray(object?.groups) ? object.groups.map((e) => Group.fromSDKJSON(e)) : [],
            escrow_account: isSet(object.escrow_account) ? Account.fromSDKJSON(object.escrow_account) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.deployment !== undefined && (obj.deployment = message.deployment ? Deployment.toSDK(message.deployment) : undefined);
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? Group.toSDK(e) : undefined);
        }
        else {
            obj.groups = [];
        }
        message.escrowAccount !== undefined && (obj.escrow_account = message.escrowAccount ? Account.toSDK(message.escrowAccount) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryDeploymentResponse();
        if (object.deployment !== undefined && object.deployment !== null) {
            message.deployment = Deployment.fromAmino(object.deployment);
        }
        message.groups = object.groups?.map(e => Group.fromAmino(e)) || [];
        if (object.escrow_account !== undefined && object.escrow_account !== null) {
            message.escrowAccount = Account.fromAmino(object.escrow_account);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.deployment = message.deployment ? Deployment.toAmino(message.deployment) : Deployment.toAmino(Deployment.fromPartial({}));
        if (message.groups) {
            obj.groups = message.groups.map(e => e ? Group.toAmino(e) : undefined);
        }
        else {
            obj.groups = message.groups;
        }
        obj.escrow_account = message.escrowAccount ? Account.toAmino(message.escrowAccount) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryDeploymentResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-deployment-response",
            value: QueryDeploymentResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryDeploymentResponse.decode(message.value);
    },
    toProto(message) {
        return QueryDeploymentResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryDeploymentResponse",
            value: QueryDeploymentResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Deployment.registerTypeUrl();
        Group.registerTypeUrl();
        Account.registerTypeUrl();
    }
};
function createBaseQueryGroupRequest() {
    return {
        id: GroupID.fromPartial({})
    };
}
export const QueryGroupRequest = {
    typeUrl: "/akash.deployment.v1beta1.QueryGroupRequest",
    aminoType: "akash/deployment/query-group-request",
    is(o) {
        return o && (o.$typeUrl === QueryGroupRequest.typeUrl || GroupID.is(o.id));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryGroupRequest.typeUrl || GroupID.isSDK(o.id));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            GroupID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryGroupRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = GroupID.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryGroupRequest();
        if (isSet(object.id))
            obj.id = GroupID.fromJSON(object.id);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? GroupID.toJSON(message.id) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryGroupRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = GroupID.fromPartial(object.id);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? GroupID.fromSDK(object.id) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? GroupID.fromSDKJSON(object.id) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? GroupID.toSDK(message.id) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryGroupRequest();
        if (object.id !== undefined && object.id !== null) {
            message.id = GroupID.fromAmino(object.id);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? GroupID.toAmino(message.id) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryGroupRequest.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-group-request",
            value: QueryGroupRequest.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryGroupRequest.decode(message.value);
    },
    toProto(message) {
        return QueryGroupRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryGroupRequest",
            value: QueryGroupRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        GroupID.registerTypeUrl();
    }
};
function createBaseQueryGroupResponse() {
    return {
        group: Group.fromPartial({})
    };
}
export const QueryGroupResponse = {
    typeUrl: "/akash.deployment.v1beta1.QueryGroupResponse",
    aminoType: "akash/deployment/query-group-response",
    is(o) {
        return o && (o.$typeUrl === QueryGroupResponse.typeUrl || Group.is(o.group));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QueryGroupResponse.typeUrl || Group.isSDK(o.group));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.group !== undefined) {
            Group.encode(message.group, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQueryGroupResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.group = Group.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQueryGroupResponse();
        if (isSet(object.group))
            obj.group = Group.fromJSON(object.group);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.group !== undefined && (obj.group = message.group ? Group.toJSON(message.group) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQueryGroupResponse();
        if (object.group !== undefined && object.group !== null) {
            message.group = Group.fromPartial(object.group);
        }
        return message;
    },
    fromSDK(object) {
        return {
            group: object.group ? Group.fromSDK(object.group) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            group: isSet(object.group) ? Group.fromSDKJSON(object.group) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.group !== undefined && (obj.group = message.group ? Group.toSDK(message.group) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQueryGroupResponse();
        if (object.group !== undefined && object.group !== null) {
            message.group = Group.fromAmino(object.group);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.group = message.group ? Group.toAmino(message.group) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QueryGroupResponse.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/deployment/query-group-response",
            value: QueryGroupResponse.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return QueryGroupResponse.decode(message.value);
    },
    toProto(message) {
        return QueryGroupResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.deployment.v1beta1.QueryGroupResponse",
            value: QueryGroupResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Group.registerTypeUrl();
    }
};
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Deployments queries deployments */
    deployments = async (request) => {
        const data = QueryDeploymentsRequest.encode(request).finish();
        const promise = this.rpc.request("akash.deployment.v1beta1.Query", "Deployments", data);
        return promise.then(data => QueryDeploymentsResponse.decode(new BinaryReader(data)));
    };
    /* Deployment queries deployment details */
    deployment = async (request) => {
        const data = QueryDeploymentRequest.encode(request).finish();
        const promise = this.rpc.request("akash.deployment.v1beta1.Query", "Deployment", data);
        return promise.then(data => QueryDeploymentResponse.decode(new BinaryReader(data)));
    };
    /* Group queries group details */
    group = async (request) => {
        const data = QueryGroupRequest.encode(request).finish();
        const promise = this.rpc.request("akash.deployment.v1beta1.Query", "Group", data);
        return promise.then(data => QueryGroupResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
