import { DecCoin, Coin } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "akash.escrow.v1beta2";
/** State stores state for an escrow account */
export var Account_State;
(function (Account_State) {
    /** invalid - AccountStateInvalid is an invalid state */
    Account_State[Account_State["invalid"] = 0] = "invalid";
    /** open - AccountOpen is the state when an account is open */
    Account_State[Account_State["open"] = 1] = "open";
    /** closed - AccountClosed is the state when an account is closed */
    Account_State[Account_State["closed"] = 2] = "closed";
    /** overdrawn - AccountOverdrawn is the state when an account is overdrawn */
    Account_State[Account_State["overdrawn"] = 3] = "overdrawn";
    Account_State[Account_State["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Account_State || (Account_State = {}));
export const Account_StateSDKType = Account_State;
export const Account_StateAmino = Account_State;
export function account_StateFromJSON(object) {
    switch (object) {
        case 0:
        case "invalid":
            return Account_State.invalid;
        case 1:
        case "open":
            return Account_State.open;
        case 2:
        case "closed":
            return Account_State.closed;
        case 3:
        case "overdrawn":
            return Account_State.overdrawn;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Account_State.UNRECOGNIZED;
    }
}
export function account_StateToJSON(object) {
    switch (object) {
        case Account_State.invalid:
            return "invalid";
        case Account_State.open:
            return "open";
        case Account_State.closed:
            return "closed";
        case Account_State.overdrawn:
            return "overdrawn";
        case Account_State.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
/** Payment State */
export var FractionalPayment_State;
(function (FractionalPayment_State) {
    /** invalid - PaymentStateInvalid is the state when the payment is invalid */
    FractionalPayment_State[FractionalPayment_State["invalid"] = 0] = "invalid";
    /** open - PaymentStateOpen is the state when the payment is open */
    FractionalPayment_State[FractionalPayment_State["open"] = 1] = "open";
    /** closed - PaymentStateClosed is the state when the payment is closed */
    FractionalPayment_State[FractionalPayment_State["closed"] = 2] = "closed";
    /** overdrawn - PaymentStateOverdrawn is the state when the payment is overdrawn */
    FractionalPayment_State[FractionalPayment_State["overdrawn"] = 3] = "overdrawn";
    FractionalPayment_State[FractionalPayment_State["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(FractionalPayment_State || (FractionalPayment_State = {}));
export const FractionalPayment_StateSDKType = FractionalPayment_State;
export const FractionalPayment_StateAmino = FractionalPayment_State;
export function fractionalPayment_StateFromJSON(object) {
    switch (object) {
        case 0:
        case "invalid":
            return FractionalPayment_State.invalid;
        case 1:
        case "open":
            return FractionalPayment_State.open;
        case 2:
        case "closed":
            return FractionalPayment_State.closed;
        case 3:
        case "overdrawn":
            return FractionalPayment_State.overdrawn;
        case -1:
        case "UNRECOGNIZED":
        default:
            return FractionalPayment_State.UNRECOGNIZED;
    }
}
export function fractionalPayment_StateToJSON(object) {
    switch (object) {
        case FractionalPayment_State.invalid:
            return "invalid";
        case FractionalPayment_State.open:
            return "open";
        case FractionalPayment_State.closed:
            return "closed";
        case FractionalPayment_State.overdrawn:
            return "overdrawn";
        case FractionalPayment_State.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseAccountID() {
    return {
        scope: "",
        xid: ""
    };
}
export const AccountID = {
    typeUrl: "/akash.escrow.v1beta2.AccountID",
    aminoType: "akash/escrow/v1beta2/account-i-d",
    is(o) {
        return o && (o.$typeUrl === AccountID.typeUrl || typeof o.scope === "string" && typeof o.xid === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === AccountID.typeUrl || typeof o.scope === "string" && typeof o.xid === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === AccountID.typeUrl || typeof o.scope === "string" && typeof o.xid === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.scope !== undefined) {
            writer.uint32(10).string(message.scope);
        }
        if (message.xid !== undefined) {
            writer.uint32(18).string(message.xid);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAccountID();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.scope = reader.string();
                    break;
                case 2:
                    message.xid = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAccountID();
        if (isSet(object.scope))
            obj.scope = String(object.scope);
        if (isSet(object.xid))
            obj.xid = String(object.xid);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.scope !== undefined && (obj.scope = message.scope);
        message.xid !== undefined && (obj.xid = message.xid);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAccountID();
        message.scope = object.scope ?? "";
        message.xid = object.xid ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            scope: object?.scope,
            xid: object?.xid
        };
    },
    fromSDKJSON(object) {
        return {
            scope: isSet(object.scope) ? String(object.scope) : "",
            xid: isSet(object.xid) ? String(object.xid) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.scope = message.scope;
        obj.xid = message.xid;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAccountID();
        if (object.scope !== undefined && object.scope !== null) {
            message.scope = object.scope;
        }
        if (object.xid !== undefined && object.xid !== null) {
            message.xid = object.xid;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.scope = message.scope ?? "";
        obj.xid = message.xid ?? "";
        return obj;
    },
    fromAminoMsg(object) {
        return AccountID.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/escrow/v1beta2/account-i-d",
            value: AccountID.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return AccountID.decode(message.value);
    },
    toProto(message) {
        return AccountID.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.escrow.v1beta2.AccountID",
            value: AccountID.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseAccount() {
    return {
        id: AccountID.fromPartial({}),
        owner: "",
        state: 0,
        balance: DecCoin.fromPartial({}),
        transferred: DecCoin.fromPartial({}),
        settledAt: BigInt(0),
        depositor: "",
        funds: DecCoin.fromPartial({})
    };
}
export const Account = {
    typeUrl: "/akash.escrow.v1beta2.Account",
    aminoType: "akash/escrow/v1beta2/account",
    is(o) {
        return o && (o.$typeUrl === Account.typeUrl || AccountID.is(o.id) && typeof o.owner === "string" && isSet(o.state) && DecCoin.is(o.balance) && DecCoin.is(o.transferred) && typeof o.settledAt === "bigint" && typeof o.depositor === "string" && DecCoin.is(o.funds));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Account.typeUrl || AccountID.isSDK(o.id) && typeof o.owner === "string" && isSet(o.state) && DecCoin.isSDK(o.balance) && DecCoin.isSDK(o.transferred) && typeof o.settled_at === "bigint" && typeof o.depositor === "string" && DecCoin.isSDK(o.funds));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Account.typeUrl || AccountID.isAmino(o.id) && typeof o.owner === "string" && isSet(o.state) && DecCoin.isAmino(o.balance) && DecCoin.isAmino(o.transferred) && typeof o.settled_at === "bigint" && typeof o.depositor === "string" && DecCoin.isAmino(o.funds));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            AccountID.encode(message.id, writer.uint32(10).fork()).ldelim();
        }
        if (message.owner !== undefined) {
            writer.uint32(18).string(message.owner);
        }
        if (message.state !== 0) {
            writer.uint32(24).int32(message.state);
        }
        if (message.balance !== undefined) {
            DecCoin.encode(message.balance, writer.uint32(34).fork()).ldelim();
        }
        if (message.transferred !== undefined) {
            DecCoin.encode(message.transferred, writer.uint32(42).fork()).ldelim();
        }
        if (message.settledAt !== undefined) {
            writer.uint32(48).int64(message.settledAt);
        }
        if (message.depositor !== undefined) {
            writer.uint32(58).string(message.depositor);
        }
        if (message.funds !== undefined) {
            DecCoin.encode(message.funds, writer.uint32(66).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAccount();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = AccountID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.owner = reader.string();
                    break;
                case 3:
                    message.state = reader.int32();
                    break;
                case 4:
                    message.balance = DecCoin.decode(reader, reader.uint32());
                    break;
                case 5:
                    message.transferred = DecCoin.decode(reader, reader.uint32());
                    break;
                case 6:
                    message.settledAt = reader.int64();
                    break;
                case 7:
                    message.depositor = reader.string();
                    break;
                case 8:
                    message.funds = DecCoin.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAccount();
        if (isSet(object.id))
            obj.id = AccountID.fromJSON(object.id);
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.state))
            obj.state = account_StateFromJSON(object.state);
        if (isSet(object.balance))
            obj.balance = DecCoin.fromJSON(object.balance);
        if (isSet(object.transferred))
            obj.transferred = DecCoin.fromJSON(object.transferred);
        if (isSet(object.settledAt))
            obj.settledAt = BigInt(object.settledAt.toString());
        if (isSet(object.depositor))
            obj.depositor = String(object.depositor);
        if (isSet(object.funds))
            obj.funds = DecCoin.fromJSON(object.funds);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? AccountID.toJSON(message.id) : undefined);
        message.owner !== undefined && (obj.owner = message.owner);
        message.state !== undefined && (obj.state = account_StateToJSON(message.state));
        message.balance !== undefined && (obj.balance = message.balance ? DecCoin.toJSON(message.balance) : undefined);
        message.transferred !== undefined && (obj.transferred = message.transferred ? DecCoin.toJSON(message.transferred) : undefined);
        message.settledAt !== undefined && (obj.settledAt = (message.settledAt || BigInt(0)).toString());
        message.depositor !== undefined && (obj.depositor = message.depositor);
        message.funds !== undefined && (obj.funds = message.funds ? DecCoin.toJSON(message.funds) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAccount();
        if (object.id !== undefined && object.id !== null) {
            message.id = AccountID.fromPartial(object.id);
        }
        message.owner = object.owner ?? "";
        message.state = object.state ?? 0;
        if (object.balance !== undefined && object.balance !== null) {
            message.balance = DecCoin.fromPartial(object.balance);
        }
        if (object.transferred !== undefined && object.transferred !== null) {
            message.transferred = DecCoin.fromPartial(object.transferred);
        }
        if (object.settledAt !== undefined && object.settledAt !== null) {
            message.settledAt = BigInt(object.settledAt.toString());
        }
        message.depositor = object.depositor ?? "";
        if (object.funds !== undefined && object.funds !== null) {
            message.funds = DecCoin.fromPartial(object.funds);
        }
        return message;
    },
    fromSDK(object) {
        return {
            id: object.id ? AccountID.fromSDK(object.id) : undefined,
            owner: object?.owner,
            state: isSet(object.state) ? account_StateFromJSON(object.state) : -1,
            balance: object.balance ? DecCoin.fromSDK(object.balance) : undefined,
            transferred: object.transferred ? DecCoin.fromSDK(object.transferred) : undefined,
            settledAt: object?.settled_at,
            depositor: object?.depositor,
            funds: object.funds ? DecCoin.fromSDK(object.funds) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? AccountID.fromSDKJSON(object.id) : undefined,
            owner: isSet(object.owner) ? String(object.owner) : "",
            state: isSet(object.state) ? account_StateFromJSON(object.state) : -1,
            balance: isSet(object.balance) ? DecCoin.fromSDKJSON(object.balance) : undefined,
            transferred: isSet(object.transferred) ? DecCoin.fromSDKJSON(object.transferred) : undefined,
            settled_at: isSet(object.settled_at) ? BigInt(object.settled_at.toString()) : BigInt(0),
            depositor: isSet(object.depositor) ? String(object.depositor) : "",
            funds: isSet(object.funds) ? DecCoin.fromSDKJSON(object.funds) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id ? AccountID.toSDK(message.id) : undefined);
        obj.owner = message.owner;
        message.state !== undefined && (obj.state = account_StateToJSON(message.state));
        message.balance !== undefined && (obj.balance = message.balance ? DecCoin.toSDK(message.balance) : undefined);
        message.transferred !== undefined && (obj.transferred = message.transferred ? DecCoin.toSDK(message.transferred) : undefined);
        obj.settled_at = message.settledAt;
        obj.depositor = message.depositor;
        message.funds !== undefined && (obj.funds = message.funds ? DecCoin.toSDK(message.funds) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAccount();
        if (object.id !== undefined && object.id !== null) {
            message.id = AccountID.fromAmino(object.id);
        }
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.state !== undefined && object.state !== null) {
            message.state = object.state;
        }
        if (object.balance !== undefined && object.balance !== null) {
            message.balance = DecCoin.fromAmino(object.balance);
        }
        if (object.transferred !== undefined && object.transferred !== null) {
            message.transferred = DecCoin.fromAmino(object.transferred);
        }
        if (object.settled_at !== undefined && object.settled_at !== null) {
            message.settledAt = BigInt(object.settled_at);
        }
        if (object.depositor !== undefined && object.depositor !== null) {
            message.depositor = object.depositor;
        }
        if (object.funds !== undefined && object.funds !== null) {
            message.funds = DecCoin.fromAmino(object.funds);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id ? AccountID.toAmino(message.id) : AccountID.toAmino(AccountID.fromPartial({}));
        obj.owner = message.owner ?? "";
        obj.state = message.state ?? 0;
        obj.balance = message.balance ? DecCoin.toAmino(message.balance) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.transferred = message.transferred ? DecCoin.toAmino(message.transferred) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.settled_at = message.settledAt ? message.settledAt?.toString() : "0";
        obj.depositor = message.depositor ?? "";
        obj.funds = message.funds ? DecCoin.toAmino(message.funds) : DecCoin.toAmino(DecCoin.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return Account.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/escrow/v1beta2/account",
            value: Account.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Account.decode(message.value);
    },
    toProto(message) {
        return Account.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.escrow.v1beta2.Account",
            value: Account.encode(message).finish()
        };
    },
    registerTypeUrl() {
        AccountID.registerTypeUrl();
        DecCoin.registerTypeUrl();
    }
};
function createBaseFractionalPayment() {
    return {
        accountId: AccountID.fromPartial({}),
        paymentId: "",
        owner: "",
        state: 0,
        rate: DecCoin.fromPartial({}),
        balance: DecCoin.fromPartial({}),
        withdrawn: Coin.fromPartial({})
    };
}
export const FractionalPayment = {
    typeUrl: "/akash.escrow.v1beta2.FractionalPayment",
    aminoType: "akash/escrow/v1beta2/fractional-payment",
    is(o) {
        return o && (o.$typeUrl === FractionalPayment.typeUrl || AccountID.is(o.accountId) && typeof o.paymentId === "string" && typeof o.owner === "string" && isSet(o.state) && DecCoin.is(o.rate) && DecCoin.is(o.balance) && Coin.is(o.withdrawn));
    },
    isSDK(o) {
        return o && (o.$typeUrl === FractionalPayment.typeUrl || AccountID.isSDK(o.account_id) && typeof o.payment_id === "string" && typeof o.owner === "string" && isSet(o.state) && DecCoin.isSDK(o.rate) && DecCoin.isSDK(o.balance) && Coin.isSDK(o.withdrawn));
    },
    isAmino(o) {
        return o && (o.$typeUrl === FractionalPayment.typeUrl || AccountID.isAmino(o.account_id) && typeof o.payment_id === "string" && typeof o.owner === "string" && isSet(o.state) && DecCoin.isAmino(o.rate) && DecCoin.isAmino(o.balance) && Coin.isAmino(o.withdrawn));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.accountId !== undefined) {
            AccountID.encode(message.accountId, writer.uint32(10).fork()).ldelim();
        }
        if (message.paymentId !== undefined) {
            writer.uint32(18).string(message.paymentId);
        }
        if (message.owner !== undefined) {
            writer.uint32(26).string(message.owner);
        }
        if (message.state !== 0) {
            writer.uint32(32).int32(message.state);
        }
        if (message.rate !== undefined) {
            DecCoin.encode(message.rate, writer.uint32(42).fork()).ldelim();
        }
        if (message.balance !== undefined) {
            DecCoin.encode(message.balance, writer.uint32(50).fork()).ldelim();
        }
        if (message.withdrawn !== undefined) {
            Coin.encode(message.withdrawn, writer.uint32(58).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseFractionalPayment();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.accountId = AccountID.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.paymentId = reader.string();
                    break;
                case 3:
                    message.owner = reader.string();
                    break;
                case 4:
                    message.state = reader.int32();
                    break;
                case 5:
                    message.rate = DecCoin.decode(reader, reader.uint32());
                    break;
                case 6:
                    message.balance = DecCoin.decode(reader, reader.uint32());
                    break;
                case 7:
                    message.withdrawn = Coin.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseFractionalPayment();
        if (isSet(object.accountId))
            obj.accountId = AccountID.fromJSON(object.accountId);
        if (isSet(object.paymentId))
            obj.paymentId = String(object.paymentId);
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.state))
            obj.state = fractionalPayment_StateFromJSON(object.state);
        if (isSet(object.rate))
            obj.rate = DecCoin.fromJSON(object.rate);
        if (isSet(object.balance))
            obj.balance = DecCoin.fromJSON(object.balance);
        if (isSet(object.withdrawn))
            obj.withdrawn = Coin.fromJSON(object.withdrawn);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.accountId !== undefined && (obj.accountId = message.accountId ? AccountID.toJSON(message.accountId) : undefined);
        message.paymentId !== undefined && (obj.paymentId = message.paymentId);
        message.owner !== undefined && (obj.owner = message.owner);
        message.state !== undefined && (obj.state = fractionalPayment_StateToJSON(message.state));
        message.rate !== undefined && (obj.rate = message.rate ? DecCoin.toJSON(message.rate) : undefined);
        message.balance !== undefined && (obj.balance = message.balance ? DecCoin.toJSON(message.balance) : undefined);
        message.withdrawn !== undefined && (obj.withdrawn = message.withdrawn ? Coin.toJSON(message.withdrawn) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseFractionalPayment();
        if (object.accountId !== undefined && object.accountId !== null) {
            message.accountId = AccountID.fromPartial(object.accountId);
        }
        message.paymentId = object.paymentId ?? "";
        message.owner = object.owner ?? "";
        message.state = object.state ?? 0;
        if (object.rate !== undefined && object.rate !== null) {
            message.rate = DecCoin.fromPartial(object.rate);
        }
        if (object.balance !== undefined && object.balance !== null) {
            message.balance = DecCoin.fromPartial(object.balance);
        }
        if (object.withdrawn !== undefined && object.withdrawn !== null) {
            message.withdrawn = Coin.fromPartial(object.withdrawn);
        }
        return message;
    },
    fromSDK(object) {
        return {
            accountId: object.account_id ? AccountID.fromSDK(object.account_id) : undefined,
            paymentId: object?.payment_id,
            owner: object?.owner,
            state: isSet(object.state) ? fractionalPayment_StateFromJSON(object.state) : -1,
            rate: object.rate ? DecCoin.fromSDK(object.rate) : undefined,
            balance: object.balance ? DecCoin.fromSDK(object.balance) : undefined,
            withdrawn: object.withdrawn ? Coin.fromSDK(object.withdrawn) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            account_id: isSet(object.account_id) ? AccountID.fromSDKJSON(object.account_id) : undefined,
            payment_id: isSet(object.payment_id) ? String(object.payment_id) : "",
            owner: isSet(object.owner) ? String(object.owner) : "",
            state: isSet(object.state) ? fractionalPayment_StateFromJSON(object.state) : -1,
            rate: isSet(object.rate) ? DecCoin.fromSDKJSON(object.rate) : undefined,
            balance: isSet(object.balance) ? DecCoin.fromSDKJSON(object.balance) : undefined,
            withdrawn: isSet(object.withdrawn) ? Coin.fromSDKJSON(object.withdrawn) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.accountId !== undefined && (obj.account_id = message.accountId ? AccountID.toSDK(message.accountId) : undefined);
        obj.payment_id = message.paymentId;
        obj.owner = message.owner;
        message.state !== undefined && (obj.state = fractionalPayment_StateToJSON(message.state));
        message.rate !== undefined && (obj.rate = message.rate ? DecCoin.toSDK(message.rate) : undefined);
        message.balance !== undefined && (obj.balance = message.balance ? DecCoin.toSDK(message.balance) : undefined);
        message.withdrawn !== undefined && (obj.withdrawn = message.withdrawn ? Coin.toSDK(message.withdrawn) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseFractionalPayment();
        if (object.account_id !== undefined && object.account_id !== null) {
            message.accountId = AccountID.fromAmino(object.account_id);
        }
        if (object.payment_id !== undefined && object.payment_id !== null) {
            message.paymentId = object.payment_id;
        }
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.state !== undefined && object.state !== null) {
            message.state = object.state;
        }
        if (object.rate !== undefined && object.rate !== null) {
            message.rate = DecCoin.fromAmino(object.rate);
        }
        if (object.balance !== undefined && object.balance !== null) {
            message.balance = DecCoin.fromAmino(object.balance);
        }
        if (object.withdrawn !== undefined && object.withdrawn !== null) {
            message.withdrawn = Coin.fromAmino(object.withdrawn);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.account_id = message.accountId ? AccountID.toAmino(message.accountId) : AccountID.toAmino(AccountID.fromPartial({}));
        obj.payment_id = message.paymentId ?? "";
        obj.owner = message.owner ?? "";
        obj.state = message.state ?? 0;
        obj.rate = message.rate ? DecCoin.toAmino(message.rate) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.balance = message.balance ? DecCoin.toAmino(message.balance) : DecCoin.toAmino(DecCoin.fromPartial({}));
        obj.withdrawn = message.withdrawn ? Coin.toAmino(message.withdrawn) : Coin.toAmino(Coin.fromPartial({}));
        return obj;
    },
    fromAminoMsg(object) {
        return FractionalPayment.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "akash/escrow/v1beta2/fractional-payment",
            value: FractionalPayment.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return FractionalPayment.decode(message.value);
    },
    toProto(message) {
        return FractionalPayment.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/akash.escrow.v1beta2.FractionalPayment",
            value: FractionalPayment.encode(message).finish()
        };
    },
    registerTypeUrl() {
        AccountID.registerTypeUrl();
        DecCoin.registerTypeUrl();
        Coin.registerTypeUrl();
    }
};
