import { MsgCreateBid, MsgCloseBid } from "./bid";
import { MsgWithdrawLease, MsgCreateLease, MsgCloseLease } from "./lease";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* CreateBid defines a method to create a bid given proper inputs. */
    createBid = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateBid.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* CloseBid defines a method to close a bid given proper inputs. */
    closeBid = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCloseBid.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* WithdrawLease withdraws accrued funds from the lease payment */
    withdrawLease = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgWithdrawLease.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* CreateLease creates a new lease */
    createLease = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateLease.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* CloseLease defines a method to close an order given proper inputs. */
    closeLease = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCloseLease.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
