import { PageRequest } from "../../base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryAccountsResponse, QueryAccountResponse, QueryParamsResponse, QueryModuleAccountsResponse, Bech32PrefixResponse, AddressBytesToStringResponse, AddressStringToBytesResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Accounts returns all the existing accounts
    
     Since: cosmos-sdk 0.43 */
    accounts = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/auth/v1beta1/accounts`;
        return QueryAccountsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Account returns account details based on address. */
    account = async (params) => {
        const endpoint = `cosmos/auth/v1beta1/accounts/${params.address}`;
        return QueryAccountResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Params queries all parameters. */
    params = async (_params = {}) => {
        const endpoint = `cosmos/auth/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ModuleAccounts returns all the existing module accounts. */
    moduleAccounts = async (_params = {}) => {
        const endpoint = `cosmos/auth/v1beta1/module_accounts`;
        return QueryModuleAccountsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Bech32 queries bech32Prefix */
    bech32Prefix = async (_params = {}) => {
        const endpoint = `cosmos/auth/v1beta1/bech32`;
        return Bech32PrefixResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* AddressBytesToString converts Account Address bytes to string */
    addressBytesToString = async (params) => {
        const endpoint = `cosmos/auth/v1beta1/bech32/${params.addressBytes}`;
        return AddressBytesToStringResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* AddressStringToBytes converts Address string to bytes */
    addressStringToBytes = async (params) => {
        const endpoint = `cosmos/auth/v1beta1/bech32/${params.addressString}`;
        return AddressStringToBytesResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
