import { GetAuthnDescriptorResponse, GetChainDescriptorResponse, GetCodecDescriptorResponse, GetConfigurationDescriptorResponse, GetQueryServicesDescriptorResponse, GetTxDescriptorResponse } from "./reflection";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* GetAuthnDescriptor returns information on how to authenticate transactions in the application
     NOTE: this RPC is still experimental and might be subject to breaking changes or removal in
     future releases of the cosmos-sdk. */
    getAuthnDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/authn`;
        return GetAuthnDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetChainDescriptor returns the description of the chain */
    getChainDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/chain`;
        return GetChainDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetCodecDescriptor returns the descriptor of the codec of the application */
    getCodecDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/codec`;
        return GetCodecDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetConfigurationDescriptor returns the descriptor for the sdk.Config of the application */
    getConfigurationDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/configuration`;
        return GetConfigurationDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetQueryServicesDescriptor returns the available gRPC queryable services of the application */
    getQueryServicesDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/query_services`;
        return GetQueryServicesDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetTxDescriptor returns information on the used transaction object and available msgs that can be used */
    getTxDescriptor = async (_params = {}) => {
        const endpoint = `cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor`;
        return GetTxDescriptorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
