import { BinaryReader } from "../../../../binary";
import { GetAuthnDescriptorRequest, GetAuthnDescriptorResponse, GetChainDescriptorRequest, GetChainDescriptorResponse, GetCodecDescriptorRequest, GetCodecDescriptorResponse, GetConfigurationDescriptorRequest, GetConfigurationDescriptorResponse, GetQueryServicesDescriptorRequest, GetQueryServicesDescriptorResponse, GetTxDescriptorRequest, GetTxDescriptorResponse } from "./reflection";
export class ReflectionServiceClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* GetAuthnDescriptor returns information on how to authenticate transactions in the application
     NOTE: this RPC is still experimental and might be subject to breaking changes or removal in
     future releases of the cosmos-sdk. */
    getAuthnDescriptor = async (request = {}) => {
        const data = GetAuthnDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetAuthnDescriptor", data);
        return promise.then(data => GetAuthnDescriptorResponse.decode(new BinaryReader(data)));
    };
    /* GetChainDescriptor returns the description of the chain */
    getChainDescriptor = async (request = {}) => {
        const data = GetChainDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetChainDescriptor", data);
        return promise.then(data => GetChainDescriptorResponse.decode(new BinaryReader(data)));
    };
    /* GetCodecDescriptor returns the descriptor of the codec of the application */
    getCodecDescriptor = async (request = {}) => {
        const data = GetCodecDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetCodecDescriptor", data);
        return promise.then(data => GetCodecDescriptorResponse.decode(new BinaryReader(data)));
    };
    /* GetConfigurationDescriptor returns the descriptor for the sdk.Config of the application */
    getConfigurationDescriptor = async (request = {}) => {
        const data = GetConfigurationDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetConfigurationDescriptor", data);
        return promise.then(data => GetConfigurationDescriptorResponse.decode(new BinaryReader(data)));
    };
    /* GetQueryServicesDescriptor returns the available gRPC queryable services of the application */
    getQueryServicesDescriptor = async (request = {}) => {
        const data = GetQueryServicesDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetQueryServicesDescriptor", data);
        return promise.then(data => GetQueryServicesDescriptorResponse.decode(new BinaryReader(data)));
    };
    /* GetTxDescriptor returns information on the used transaction object and available msgs that can be used */
    getTxDescriptor = async (request = {}) => {
        const data = GetTxDescriptorRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.reflection.v2alpha1.ReflectionService", "GetTxDescriptor", data);
        return promise.then(data => GetTxDescriptorResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new ReflectionServiceClientImpl(rpc);
};
