import { PageRequest } from "../../query/v1beta1/pagination";
import { BinaryReader } from "../../../../binary";
import { GetNodeInfoRequest, GetNodeInfoResponse, GetSyncingRequest, GetSyncingResponse, GetLatestBlockRequest, GetLatestBlockResponse, GetBlockByHeightRequest, GetBlockByHeightResponse, GetLatestValidatorSetRequest, GetLatestValidatorSetResponse, GetValidatorSetByHeightRequest, GetValidatorSetByHeightResponse } from "./query";
export class ServiceClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* GetNodeInfo queries the current node info. */
    getNodeInfo = async (request = {}) => {
        const data = GetNodeInfoRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetNodeInfo", data);
        return promise.then(data => GetNodeInfoResponse.decode(new BinaryReader(data)));
    };
    /* GetSyncing queries node syncing. */
    getSyncing = async (request = {}) => {
        const data = GetSyncingRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetSyncing", data);
        return promise.then(data => GetSyncingResponse.decode(new BinaryReader(data)));
    };
    /* GetLatestBlock returns the latest block. */
    getLatestBlock = async (request = {}) => {
        const data = GetLatestBlockRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetLatestBlock", data);
        return promise.then(data => GetLatestBlockResponse.decode(new BinaryReader(data)));
    };
    /* GetBlockByHeight queries block for given height. */
    getBlockByHeight = async (request) => {
        const data = GetBlockByHeightRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetBlockByHeight", data);
        return promise.then(data => GetBlockByHeightResponse.decode(new BinaryReader(data)));
    };
    /* GetLatestValidatorSet queries latest validator-set. */
    getLatestValidatorSet = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = GetLatestValidatorSetRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetLatestValidatorSet", data);
        return promise.then(data => GetLatestValidatorSetResponse.decode(new BinaryReader(data)));
    };
    /* GetValidatorSetByHeight queries validator-set at a given height. */
    getValidatorSetByHeight = async (request) => {
        const data = GetValidatorSetByHeightRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.base.tendermint.v1beta1.Service", "GetValidatorSetByHeight", data);
        return promise.then(data => GetValidatorSetByHeightResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new ServiceClientImpl(rpc);
};
