import { MsgSetWithdrawAddress, MsgWithdrawDelegatorReward, MsgWithdrawValidatorCommission, MsgFundCommunityPool } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* SetWithdrawAddress defines a method to change the withdraw address
     for a delegator (or validator self-delegation). */
    setWithdrawAddress = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgSetWithdrawAddress.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* WithdrawDelegatorReward defines a method to withdraw rewards of delegator
     from a single validator. */
    withdrawDelegatorReward = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgWithdrawDelegatorReward.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* WithdrawValidatorCommission defines a method to withdraw the
     full commission to the validator address. */
    withdrawValidatorCommission = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgWithdrawValidatorCommission.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* FundCommunityPool defines a method to allow an account to directly
     fund the community pool. */
    fundCommunityPool = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgFundCommunityPool.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
