import { setPaginationParams } from "../../../helpers";
import { QueryGroupInfoResponse, QueryGroupPolicyInfoResponse, QueryGroupMembersResponse, QueryGroupsByAdminResponse, QueryGroupPoliciesByGroupResponse, QueryGroupPoliciesByAdminResponse, QueryProposalResponse, QueryProposalsByGroupPolicyResponse, QueryVoteByProposalVoterResponse, QueryVotesByProposalResponse, QueryVotesByVoterResponse, QueryGroupsByMemberResponse, QueryTallyResultResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* GroupInfo queries group info based on group id. */
    groupInfo = async (params) => {
        const endpoint = `cosmos/group/v1/group_info/${params.groupId}`;
        return QueryGroupInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GroupPolicyInfo queries group policy info based on account address of group policy. */
    groupPolicyInfo = async (params) => {
        const endpoint = `cosmos/group/v1/group_policy_info/${params.address}`;
        return QueryGroupPolicyInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GroupMembers queries members of a group */
    groupMembers = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_members/${params.groupId}`;
        return QueryGroupMembersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GroupsByAdmin queries groups by admin address. */
    groupsByAdmin = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/groups_by_admin/${params.admin}`;
        return QueryGroupsByAdminResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GroupPoliciesByGroup queries group policies by group id. */
    groupPoliciesByGroup = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_policies_by_group/${params.groupId}`;
        return QueryGroupPoliciesByGroupResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GroupsByAdmin queries group policies by admin address. */
    groupPoliciesByAdmin = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/group_policies_by_admin/${params.admin}`;
        return QueryGroupPoliciesByAdminResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Proposal queries a proposal based on proposal id. */
    proposal = async (params) => {
        const endpoint = `cosmos/group/v1/proposal/${params.proposalId}`;
        return QueryProposalResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ProposalsByGroupPolicy queries proposals based on account address of group policy. */
    proposalsByGroupPolicy = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/proposals_by_group_policy/${params.address}`;
        return QueryProposalsByGroupPolicyResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* VoteByProposalVoter queries a vote by proposal id and voter. */
    voteByProposalVoter = async (params) => {
        const endpoint = `cosmos/group/v1/vote_by_proposal_voter/${params.proposalId}/${params.voter}`;
        return QueryVoteByProposalVoterResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* VotesByProposal queries a vote by proposal. */
    votesByProposal = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/votes_by_proposal/${params.proposalId}`;
        return QueryVotesByProposalResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* VotesByVoter queries a vote by voter. */
    votesByVoter = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/votes_by_voter/${params.voter}`;
        return QueryVotesByVoterResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GroupsByMember queries groups by member address. */
    groupsByMember = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/group/v1/groups_by_member/${params.address}`;
        return QueryGroupsByMemberResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* TallyResult queries the tally of a proposal votes. */
    tallyResult = async (params) => {
        const endpoint = `cosmos/group/v1/proposals/${params.proposalId}/tally`;
        return QueryTallyResultResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
