import { MsgCreateGroup, MsgUpdateGroupMembers, MsgUpdateGroupAdmin, MsgUpdateGroupMetadata, MsgCreateGroupPolicy, MsgCreateGroupWithPolicy, MsgUpdateGroupPolicyAdmin, MsgUpdateGroupPolicyDecisionPolicy, MsgUpdateGroupPolicyMetadata, MsgSubmitProposal, MsgWithdrawProposal, MsgVote, MsgExec, MsgLeaveGroup } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* CreateGroup creates a new group with an admin account address, a list of members and some optional metadata. */
    createGroup = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateGroup.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupMembers updates the group members with given group id and admin address. */
    updateGroupMembers = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupMembers.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupAdmin updates the group admin with given group id and previous admin address. */
    updateGroupAdmin = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupAdmin.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupMetadata updates the group metadata with given group id and admin address. */
    updateGroupMetadata = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupMetadata.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* CreateGroupPolicy creates a new group policy using given DecisionPolicy. */
    createGroupPolicy = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateGroupPolicy.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* CreateGroupWithPolicy creates a new group with policy. */
    createGroupWithPolicy = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateGroupWithPolicy.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupPolicyAdmin updates a group policy admin. */
    updateGroupPolicyAdmin = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupPolicyAdmin.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupPolicyDecisionPolicy allows a group policy's decision policy to be updated. */
    updateGroupPolicyDecisionPolicy = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupPolicyDecisionPolicy.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* UpdateGroupPolicyMetadata updates a group policy metadata. */
    updateGroupPolicyMetadata = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUpdateGroupPolicyMetadata.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* SubmitProposal submits a new proposal. */
    submitProposal = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgSubmitProposal.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* WithdrawProposal aborts a proposal. */
    withdrawProposal = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgWithdrawProposal.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Vote allows a voter to vote on a proposal. */
    vote = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgVote.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Exec executes a proposal. */
    exec = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgExec.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* LeaveGroup allows a group member to leave the group. */
    leaveGroup = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgLeaveGroup.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
