import { MsgCreateValidator, MsgEditValidator, MsgDelegate, MsgBeginRedelegate, MsgUndelegate } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* CreateValidator defines a method for creating a new validator. */
    createValidator = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgCreateValidator.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* EditValidator defines a method for editing an existing validator. */
    editValidator = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgEditValidator.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Delegate defines a method for performing a delegation of coins
     from a delegator to a validator. */
    delegate = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgDelegate.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* BeginRedelegate defines a method for performing a redelegation
     of coins from a delegator and source validator to a destination validator. */
    beginRedelegate = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgBeginRedelegate.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Undelegate defines a method for performing an undelegation from a
     delegate and a validator. */
    undelegate = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgUndelegate.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
