import { setPaginationParams } from "../../../helpers";
import { GetTxResponse, GetTxsEventResponse, GetBlockWithTxsResponse } from "./service";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* GetTx fetches a tx by hash. */
    getTx = async (params) => {
        const endpoint = `cosmos/tx/v1beta1/txs/${params.hash}`;
        return GetTxResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GetTxsEvent fetches txs by event. */
    getTxsEvent = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.events !== "undefined") {
            options.params.events = params.events;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        if (typeof params?.orderBy !== "undefined") {
            options.params.order_by = params.orderBy;
        }
        const endpoint = `cosmos/tx/v1beta1/txs`;
        return GetTxsEventResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GetBlockWithTxs fetches a block with decoded txs.
    
     Since: cosmos-sdk 0.45.2 */
    getBlockWithTxs = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/tx/v1beta1/txs/block/${params.height}`;
        return GetBlockWithTxsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
