import { Registry } from "@cosmjs/proto-signing";
import { defaultRegistryTypes, AminoTypes, SigningStargateClient } from "@cosmjs/stargate";
import { createRpcClient } from "../extern";
import * as cosmwasmWasmV1TxRegistry from "./wasm/v1/tx.registry";
import * as cosmwasmWasmV1TxAmino from "./wasm/v1/tx.amino";
export const cosmwasmAminoConverters = {
    ...cosmwasmWasmV1TxAmino.AminoConverter
};
export const cosmwasmProtoRegistry = [...cosmwasmWasmV1TxRegistry.registry];
export const getSigningCosmwasmClientOptions = ({ defaultTypes = defaultRegistryTypes } = {}) => {
    const registry = new Registry([...defaultTypes, ...cosmwasmProtoRegistry]);
    const aminoTypes = new AminoTypes({
        ...cosmwasmAminoConverters
    });
    return {
        registry,
        aminoTypes
    };
};
export const getSigningCosmwasmClient = async ({ rpcEndpoint, signer, defaultTypes = defaultRegistryTypes }) => {
    const { registry, aminoTypes } = getSigningCosmwasmClientOptions({
        defaultTypes
    });
    const client = await SigningStargateClient.connectWithSigner(rpcEndpoint, signer, {
        registry: registry,
        aminoTypes
    });
    return client;
};
export const getSigningCosmwasmTxRpc = async ({ rpcEndpoint, signer }) => {
    let txRpc = await createRpcClient(rpcEndpoint);
    const signingClient = await getSigningCosmwasmClient({
        rpcEndpoint,
        //@ts-ignore
        signer
    });
    txRpc.signAndBroadcast = (signerAddress, messages, fee, memo) => {
        return signingClient.signAndBroadcast(signerAddress, messages, fee, memo);
    };
    return txRpc;
};
