import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryContractInfoResponse, QueryContractHistoryResponse, QueryContractsByCodeResponse, QueryAllContractStateResponse, QueryRawContractStateResponse, QuerySmartContractStateResponse, QueryCodeResponse, QueryCodesResponse, QueryPinnedCodesResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* ContractInfo gets the contract meta data */
    contractInfo = async (params) => {
        const endpoint = `cosmwasm/wasm/v1/contract/${params.address}`;
        return QueryContractInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ContractHistory gets the contract code history */
    contractHistory = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmwasm/wasm/v1/contract/${params.address}/history`;
        return QueryContractHistoryResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ContractsByCode lists all smart contracts for a code id */
    contractsByCode = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmwasm/wasm/v1/code/${params.codeId}/contracts`;
        return QueryContractsByCodeResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* AllContractState gets all raw store data for a single contract */
    allContractState = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmwasm/wasm/v1/contract/${params.address}/state`;
        return QueryAllContractStateResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* RawContractState gets single key from the raw store data of a contract */
    rawContractState = async (params) => {
        const endpoint = `wasm/v1/contract/${params.address}/raw/${params.queryData}`;
        return QueryRawContractStateResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* SmartContractState get smart query result from the contract */
    smartContractState = async (params) => {
        const endpoint = `wasm/v1/contract/${params.address}/smart/${params.queryData}`;
        return QuerySmartContractStateResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Code gets the binary code and metadata for a singe wasm code */
    code = async (params) => {
        const endpoint = `cosmwasm/wasm/v1/code/${params.codeId}`;
        return QueryCodeResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Codes gets the metadata for all stored wasm codes */
    codes = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmwasm/wasm/v1/code`;
        return QueryCodesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* PinnedCodes gets the pinned code ids */
    pinnedCodes = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmwasm/wasm/v1/codes/pinned`;
        return QueryPinnedCodesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
