import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryContractInfoRequest, QueryContractInfoResponse, QueryContractHistoryRequest, QueryContractHistoryResponse, QueryContractsByCodeRequest, QueryContractsByCodeResponse, QueryAllContractStateRequest, QueryAllContractStateResponse, QueryRawContractStateRequest, QueryRawContractStateResponse, QuerySmartContractStateRequest, QuerySmartContractStateResponse, QueryCodeRequest, QueryCodeResponse, QueryCodesRequest, QueryCodesResponse, QueryPinnedCodesRequest, QueryPinnedCodesResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* ContractInfo gets the contract meta data */
    contractInfo = async (request) => {
        const data = QueryContractInfoRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "ContractInfo", data);
        return promise.then(data => QueryContractInfoResponse.decode(new BinaryReader(data)));
    };
    /* ContractHistory gets the contract code history */
    contractHistory = async (request) => {
        const data = QueryContractHistoryRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "ContractHistory", data);
        return promise.then(data => QueryContractHistoryResponse.decode(new BinaryReader(data)));
    };
    /* ContractsByCode lists all smart contracts for a code id */
    contractsByCode = async (request) => {
        const data = QueryContractsByCodeRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "ContractsByCode", data);
        return promise.then(data => QueryContractsByCodeResponse.decode(new BinaryReader(data)));
    };
    /* AllContractState gets all raw store data for a single contract */
    allContractState = async (request) => {
        const data = QueryAllContractStateRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "AllContractState", data);
        return promise.then(data => QueryAllContractStateResponse.decode(new BinaryReader(data)));
    };
    /* RawContractState gets single key from the raw store data of a contract */
    rawContractState = async (request) => {
        const data = QueryRawContractStateRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "RawContractState", data);
        return promise.then(data => QueryRawContractStateResponse.decode(new BinaryReader(data)));
    };
    /* SmartContractState get smart query result from the contract */
    smartContractState = async (request) => {
        const data = QuerySmartContractStateRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "SmartContractState", data);
        return promise.then(data => QuerySmartContractStateResponse.decode(new BinaryReader(data)));
    };
    /* Code gets the binary code and metadata for a singe wasm code */
    code = async (request) => {
        const data = QueryCodeRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "Code", data);
        return promise.then(data => QueryCodeResponse.decode(new BinaryReader(data)));
    };
    /* Codes gets the metadata for all stored wasm codes */
    codes = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryCodesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "Codes", data);
        return promise.then(data => QueryCodesResponse.decode(new BinaryReader(data)));
    };
    /* PinnedCodes gets the pinned code ids */
    pinnedCodes = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryPinnedCodesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmwasm.wasm.v1.Query", "PinnedCodes", data);
        return promise.then(data => QueryPinnedCodesResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
