import { isSet } from "../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../binary";
export const protobufPackage = "evmos.claims.v1";
/** Action defines the list of available actions to claim the airdrop tokens. */
export var Action;
(function (Action) {
    /** ACTION_UNSPECIFIED - UNSPECIFIED defines an invalid action. */
    Action[Action["ACTION_UNSPECIFIED"] = 0] = "ACTION_UNSPECIFIED";
    /** ACTION_VOTE - VOTE defines a proposal vote. */
    Action[Action["ACTION_VOTE"] = 1] = "ACTION_VOTE";
    /** ACTION_DELEGATE - DELEGATE defines an staking delegation. */
    Action[Action["ACTION_DELEGATE"] = 2] = "ACTION_DELEGATE";
    /** ACTION_EVM - EVM defines an EVM transaction. */
    Action[Action["ACTION_EVM"] = 3] = "ACTION_EVM";
    /** ACTION_IBC_TRANSFER - IBC Transfer defines a fungible token transfer transaction via IBC. */
    Action[Action["ACTION_IBC_TRANSFER"] = 4] = "ACTION_IBC_TRANSFER";
    Action[Action["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Action || (Action = {}));
export const ActionSDKType = Action;
export const ActionAmino = Action;
export function actionFromJSON(object) {
    switch (object) {
        case 0:
        case "ACTION_UNSPECIFIED":
            return Action.ACTION_UNSPECIFIED;
        case 1:
        case "ACTION_VOTE":
            return Action.ACTION_VOTE;
        case 2:
        case "ACTION_DELEGATE":
            return Action.ACTION_DELEGATE;
        case 3:
        case "ACTION_EVM":
            return Action.ACTION_EVM;
        case 4:
        case "ACTION_IBC_TRANSFER":
            return Action.ACTION_IBC_TRANSFER;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Action.UNRECOGNIZED;
    }
}
export function actionToJSON(object) {
    switch (object) {
        case Action.ACTION_UNSPECIFIED:
            return "ACTION_UNSPECIFIED";
        case Action.ACTION_VOTE:
            return "ACTION_VOTE";
        case Action.ACTION_DELEGATE:
            return "ACTION_DELEGATE";
        case Action.ACTION_EVM:
            return "ACTION_EVM";
        case Action.ACTION_IBC_TRANSFER:
            return "ACTION_IBC_TRANSFER";
        case Action.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseClaim() {
    return {
        action: 0,
        completed: false,
        claimableAmount: ""
    };
}
export const Claim = {
    typeUrl: "/evmos.claims.v1.Claim",
    is(o) {
        return o && (o.$typeUrl === Claim.typeUrl || isSet(o.action) && typeof o.completed === "boolean" && typeof o.claimableAmount === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Claim.typeUrl || isSet(o.action) && typeof o.completed === "boolean" && typeof o.claimable_amount === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Claim.typeUrl || isSet(o.action) && typeof o.completed === "boolean" && typeof o.claimable_amount === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.action !== 0) {
            writer.uint32(8).int32(message.action);
        }
        if (message.completed !== undefined) {
            writer.uint32(16).bool(message.completed);
        }
        if (message.claimableAmount !== undefined) {
            writer.uint32(26).string(message.claimableAmount);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseClaim();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.action = reader.int32();
                    break;
                case 2:
                    message.completed = reader.bool();
                    break;
                case 3:
                    message.claimableAmount = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseClaim();
        if (isSet(object.action))
            obj.action = actionFromJSON(object.action);
        if (isSet(object.completed))
            obj.completed = Boolean(object.completed);
        if (isSet(object.claimableAmount))
            obj.claimableAmount = String(object.claimableAmount);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.action !== undefined && (obj.action = actionToJSON(message.action));
        message.completed !== undefined && (obj.completed = message.completed);
        message.claimableAmount !== undefined && (obj.claimableAmount = message.claimableAmount);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseClaim();
        message.action = object.action ?? 0;
        message.completed = object.completed ?? false;
        message.claimableAmount = object.claimableAmount ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            action: isSet(object.action) ? actionFromJSON(object.action) : -1,
            completed: object?.completed,
            claimableAmount: object?.claimable_amount
        };
    },
    fromSDKJSON(object) {
        return {
            action: isSet(object.action) ? actionFromJSON(object.action) : -1,
            completed: isSet(object.completed) ? Boolean(object.completed) : false,
            claimable_amount: isSet(object.claimable_amount) ? String(object.claimable_amount) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        message.action !== undefined && (obj.action = actionToJSON(message.action));
        obj.completed = message.completed;
        obj.claimable_amount = message.claimableAmount;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseClaim();
        if (object.action !== undefined && object.action !== null) {
            message.action = object.action;
        }
        if (object.completed !== undefined && object.completed !== null) {
            message.completed = object.completed;
        }
        if (object.claimable_amount !== undefined && object.claimable_amount !== null) {
            message.claimableAmount = object.claimable_amount;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.action = message.action === 0 ? undefined : message.action;
        obj.completed = message.completed === false ? undefined : message.completed;
        obj.claimable_amount = message.claimableAmount === "" ? undefined : message.claimableAmount;
        return obj;
    },
    fromAminoMsg(object) {
        return Claim.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Claim.decode(message.value);
    },
    toProto(message) {
        return Claim.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.claims.v1.Claim",
            value: Claim.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseClaimsRecordAddress() {
    return {
        address: "",
        initialClaimableAmount: "",
        actionsCompleted: []
    };
}
export const ClaimsRecordAddress = {
    typeUrl: "/evmos.claims.v1.ClaimsRecordAddress",
    is(o) {
        return o && (o.$typeUrl === ClaimsRecordAddress.typeUrl || typeof o.address === "string" && typeof o.initialClaimableAmount === "string" && Array.isArray(o.actionsCompleted) && (!o.actionsCompleted.length || typeof o.actionsCompleted[0] === "boolean"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ClaimsRecordAddress.typeUrl || typeof o.address === "string" && typeof o.initial_claimable_amount === "string" && Array.isArray(o.actions_completed) && (!o.actions_completed.length || typeof o.actions_completed[0] === "boolean"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ClaimsRecordAddress.typeUrl || typeof o.address === "string" && typeof o.initial_claimable_amount === "string" && Array.isArray(o.actions_completed) && (!o.actions_completed.length || typeof o.actions_completed[0] === "boolean"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.address !== undefined) {
            writer.uint32(10).string(message.address);
        }
        if (message.initialClaimableAmount !== undefined) {
            writer.uint32(18).string(message.initialClaimableAmount);
        }
        writer.uint32(26).fork();
        for (const v of message.actionsCompleted) {
            writer.bool(v);
        }
        writer.ldelim();
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseClaimsRecordAddress();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.address = reader.string();
                    break;
                case 2:
                    message.initialClaimableAmount = reader.string();
                    break;
                case 3:
                    if ((tag & 7) === 2) {
                        const end2 = reader.uint32() + reader.pos;
                        while (reader.pos < end2) {
                            message.actionsCompleted.push(reader.bool());
                        }
                    }
                    else {
                        message.actionsCompleted.push(reader.bool());
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseClaimsRecordAddress();
        if (isSet(object.address))
            obj.address = String(object.address);
        if (isSet(object.initialClaimableAmount))
            obj.initialClaimableAmount = String(object.initialClaimableAmount);
        if (Array.isArray(object?.actionsCompleted))
            obj.actionsCompleted = object.actionsCompleted.map((e) => Boolean(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.address !== undefined && (obj.address = message.address);
        message.initialClaimableAmount !== undefined && (obj.initialClaimableAmount = message.initialClaimableAmount);
        if (message.actionsCompleted) {
            obj.actionsCompleted = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actionsCompleted = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseClaimsRecordAddress();
        message.address = object.address ?? "";
        message.initialClaimableAmount = object.initialClaimableAmount ?? "";
        message.actionsCompleted = object.actionsCompleted?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            address: object?.address,
            initialClaimableAmount: object?.initial_claimable_amount,
            actionsCompleted: Array.isArray(object?.actions_completed) ? object.actions_completed.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            address: isSet(object.address) ? String(object.address) : "",
            initial_claimable_amount: isSet(object.initial_claimable_amount) ? String(object.initial_claimable_amount) : "",
            actions_completed: Array.isArray(object?.actions_completed) ? object.actions_completed.map((e) => Boolean(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.address = message.address;
        obj.initial_claimable_amount = message.initialClaimableAmount;
        if (message.actionsCompleted) {
            obj.actions_completed = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actions_completed = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseClaimsRecordAddress();
        if (object.address !== undefined && object.address !== null) {
            message.address = object.address;
        }
        if (object.initial_claimable_amount !== undefined && object.initial_claimable_amount !== null) {
            message.initialClaimableAmount = object.initial_claimable_amount;
        }
        message.actionsCompleted = object.actions_completed?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.address = message.address === "" ? undefined : message.address;
        obj.initial_claimable_amount = message.initialClaimableAmount === "" ? undefined : message.initialClaimableAmount;
        if (message.actionsCompleted) {
            obj.actions_completed = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actions_completed = message.actionsCompleted;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ClaimsRecordAddress.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ClaimsRecordAddress.decode(message.value);
    },
    toProto(message) {
        return ClaimsRecordAddress.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.claims.v1.ClaimsRecordAddress",
            value: ClaimsRecordAddress.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseClaimsRecord() {
    return {
        initialClaimableAmount: "",
        actionsCompleted: []
    };
}
export const ClaimsRecord = {
    typeUrl: "/evmos.claims.v1.ClaimsRecord",
    is(o) {
        return o && (o.$typeUrl === ClaimsRecord.typeUrl || typeof o.initialClaimableAmount === "string" && Array.isArray(o.actionsCompleted) && (!o.actionsCompleted.length || typeof o.actionsCompleted[0] === "boolean"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ClaimsRecord.typeUrl || typeof o.initial_claimable_amount === "string" && Array.isArray(o.actions_completed) && (!o.actions_completed.length || typeof o.actions_completed[0] === "boolean"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ClaimsRecord.typeUrl || typeof o.initial_claimable_amount === "string" && Array.isArray(o.actions_completed) && (!o.actions_completed.length || typeof o.actions_completed[0] === "boolean"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.initialClaimableAmount !== undefined) {
            writer.uint32(10).string(message.initialClaimableAmount);
        }
        writer.uint32(18).fork();
        for (const v of message.actionsCompleted) {
            writer.bool(v);
        }
        writer.ldelim();
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseClaimsRecord();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.initialClaimableAmount = reader.string();
                    break;
                case 2:
                    if ((tag & 7) === 2) {
                        const end2 = reader.uint32() + reader.pos;
                        while (reader.pos < end2) {
                            message.actionsCompleted.push(reader.bool());
                        }
                    }
                    else {
                        message.actionsCompleted.push(reader.bool());
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseClaimsRecord();
        if (isSet(object.initialClaimableAmount))
            obj.initialClaimableAmount = String(object.initialClaimableAmount);
        if (Array.isArray(object?.actionsCompleted))
            obj.actionsCompleted = object.actionsCompleted.map((e) => Boolean(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.initialClaimableAmount !== undefined && (obj.initialClaimableAmount = message.initialClaimableAmount);
        if (message.actionsCompleted) {
            obj.actionsCompleted = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actionsCompleted = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseClaimsRecord();
        message.initialClaimableAmount = object.initialClaimableAmount ?? "";
        message.actionsCompleted = object.actionsCompleted?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            initialClaimableAmount: object?.initial_claimable_amount,
            actionsCompleted: Array.isArray(object?.actions_completed) ? object.actions_completed.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            initial_claimable_amount: isSet(object.initial_claimable_amount) ? String(object.initial_claimable_amount) : "",
            actions_completed: Array.isArray(object?.actions_completed) ? object.actions_completed.map((e) => Boolean(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.initial_claimable_amount = message.initialClaimableAmount;
        if (message.actionsCompleted) {
            obj.actions_completed = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actions_completed = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseClaimsRecord();
        if (object.initial_claimable_amount !== undefined && object.initial_claimable_amount !== null) {
            message.initialClaimableAmount = object.initial_claimable_amount;
        }
        message.actionsCompleted = object.actions_completed?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.initial_claimable_amount = message.initialClaimableAmount === "" ? undefined : message.initialClaimableAmount;
        if (message.actionsCompleted) {
            obj.actions_completed = message.actionsCompleted.map(e => e);
        }
        else {
            obj.actions_completed = message.actionsCompleted;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ClaimsRecord.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ClaimsRecord.decode(message.value);
    },
    toProto(message) {
        return ClaimsRecord.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.claims.v1.ClaimsRecord",
            value: ClaimsRecord.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
