import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryTotalUnclaimedRequest, QueryTotalUnclaimedResponse, QueryParamsRequest, QueryParamsResponse, QueryClaimsRecordsRequest, QueryClaimsRecordsResponse, QueryClaimsRecordRequest, QueryClaimsRecordResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* TotalUnclaimed queries the total unclaimed tokens from the airdrop */
    totalUnclaimed = async (request = {}) => {
        const data = QueryTotalUnclaimedRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.claims.v1.Query", "TotalUnclaimed", data);
        return promise.then(data => QueryTotalUnclaimedResponse.decode(new BinaryReader(data)));
    };
    /* Params returns the claims module parameters */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.claims.v1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* ClaimsRecords returns all claims records */
    claimsRecords = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryClaimsRecordsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.claims.v1.Query", "ClaimsRecords", data);
        return promise.then(data => QueryClaimsRecordsResponse.decode(new BinaryReader(data)));
    };
    /* ClaimsRecord returns the claims record for a given address */
    claimsRecord = async (request) => {
        const data = QueryClaimsRecordRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.claims.v1.Query", "ClaimsRecord", data);
        return promise.then(data => QueryClaimsRecordResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
