import { Metadata } from "../../../cosmos/bank/v1beta1/bank";
import { isSet } from "../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../binary";
export const protobufPackage = "evmos.erc20.v1";
/** Owner enumerates the ownership of a ERC20 contract. */
export var Owner;
(function (Owner) {
    /** OWNER_UNSPECIFIED - OWNER_UNSPECIFIED defines an invalid/undefined owner. */
    Owner[Owner["OWNER_UNSPECIFIED"] = 0] = "OWNER_UNSPECIFIED";
    /** OWNER_MODULE - OWNER_MODULE erc20 is owned by the erc20 module account. */
    Owner[Owner["OWNER_MODULE"] = 1] = "OWNER_MODULE";
    /** OWNER_EXTERNAL - EXTERNAL erc20 is owned by an external account. */
    Owner[Owner["OWNER_EXTERNAL"] = 2] = "OWNER_EXTERNAL";
    Owner[Owner["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Owner || (Owner = {}));
export const OwnerSDKType = Owner;
export const OwnerAmino = Owner;
export function ownerFromJSON(object) {
    switch (object) {
        case 0:
        case "OWNER_UNSPECIFIED":
            return Owner.OWNER_UNSPECIFIED;
        case 1:
        case "OWNER_MODULE":
            return Owner.OWNER_MODULE;
        case 2:
        case "OWNER_EXTERNAL":
            return Owner.OWNER_EXTERNAL;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Owner.UNRECOGNIZED;
    }
}
export function ownerToJSON(object) {
    switch (object) {
        case Owner.OWNER_UNSPECIFIED:
            return "OWNER_UNSPECIFIED";
        case Owner.OWNER_MODULE:
            return "OWNER_MODULE";
        case Owner.OWNER_EXTERNAL:
            return "OWNER_EXTERNAL";
        case Owner.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseTokenPair() {
    return {
        erc20Address: "",
        denom: "",
        enabled: false,
        contractOwner: 0
    };
}
export const TokenPair = {
    typeUrl: "/evmos.erc20.v1.TokenPair",
    is(o) {
        return o && (o.$typeUrl === TokenPair.typeUrl || typeof o.erc20Address === "string" && typeof o.denom === "string" && typeof o.enabled === "boolean" && isSet(o.contractOwner));
    },
    isSDK(o) {
        return o && (o.$typeUrl === TokenPair.typeUrl || typeof o.erc20_address === "string" && typeof o.denom === "string" && typeof o.enabled === "boolean" && isSet(o.contract_owner));
    },
    isAmino(o) {
        return o && (o.$typeUrl === TokenPair.typeUrl || typeof o.erc20_address === "string" && typeof o.denom === "string" && typeof o.enabled === "boolean" && isSet(o.contract_owner));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.erc20Address !== undefined) {
            writer.uint32(10).string(message.erc20Address);
        }
        if (message.denom !== undefined) {
            writer.uint32(18).string(message.denom);
        }
        if (message.enabled !== undefined) {
            writer.uint32(24).bool(message.enabled);
        }
        if (message.contractOwner !== 0) {
            writer.uint32(32).int32(message.contractOwner);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseTokenPair();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.erc20Address = reader.string();
                    break;
                case 2:
                    message.denom = reader.string();
                    break;
                case 3:
                    message.enabled = reader.bool();
                    break;
                case 4:
                    message.contractOwner = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseTokenPair();
        if (isSet(object.erc20Address))
            obj.erc20Address = String(object.erc20Address);
        if (isSet(object.denom))
            obj.denom = String(object.denom);
        if (isSet(object.enabled))
            obj.enabled = Boolean(object.enabled);
        if (isSet(object.contractOwner))
            obj.contractOwner = ownerFromJSON(object.contractOwner);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.erc20Address !== undefined && (obj.erc20Address = message.erc20Address);
        message.denom !== undefined && (obj.denom = message.denom);
        message.enabled !== undefined && (obj.enabled = message.enabled);
        message.contractOwner !== undefined && (obj.contractOwner = ownerToJSON(message.contractOwner));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseTokenPair();
        message.erc20Address = object.erc20Address ?? "";
        message.denom = object.denom ?? "";
        message.enabled = object.enabled ?? false;
        message.contractOwner = object.contractOwner ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            erc20Address: object?.erc20_address,
            denom: object?.denom,
            enabled: object?.enabled,
            contractOwner: isSet(object.contract_owner) ? ownerFromJSON(object.contract_owner) : -1
        };
    },
    fromSDKJSON(object) {
        return {
            erc20_address: isSet(object.erc20_address) ? String(object.erc20_address) : "",
            denom: isSet(object.denom) ? String(object.denom) : "",
            enabled: isSet(object.enabled) ? Boolean(object.enabled) : false,
            contract_owner: isSet(object.contract_owner) ? ownerFromJSON(object.contract_owner) : -1
        };
    },
    toSDK(message) {
        const obj = {};
        obj.erc20_address = message.erc20Address;
        obj.denom = message.denom;
        obj.enabled = message.enabled;
        message.contractOwner !== undefined && (obj.contract_owner = ownerToJSON(message.contractOwner));
        return obj;
    },
    fromAmino(object) {
        const message = createBaseTokenPair();
        if (object.erc20_address !== undefined && object.erc20_address !== null) {
            message.erc20Address = object.erc20_address;
        }
        if (object.denom !== undefined && object.denom !== null) {
            message.denom = object.denom;
        }
        if (object.enabled !== undefined && object.enabled !== null) {
            message.enabled = object.enabled;
        }
        if (object.contract_owner !== undefined && object.contract_owner !== null) {
            message.contractOwner = object.contract_owner;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.erc20_address = message.erc20Address === "" ? undefined : message.erc20Address;
        obj.denom = message.denom === "" ? undefined : message.denom;
        obj.enabled = message.enabled === false ? undefined : message.enabled;
        obj.contract_owner = message.contractOwner === 0 ? undefined : message.contractOwner;
        return obj;
    },
    fromAminoMsg(object) {
        return TokenPair.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return TokenPair.decode(message.value);
    },
    toProto(message) {
        return TokenPair.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.erc20.v1.TokenPair",
            value: TokenPair.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseRegisterCoinProposal() {
    return {
        title: "",
        description: "",
        metadata: Metadata.fromPartial({})
    };
}
export const RegisterCoinProposal = {
    typeUrl: "/evmos.erc20.v1.RegisterCoinProposal",
    is(o) {
        return o && (o.$typeUrl === RegisterCoinProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && Metadata.is(o.metadata));
    },
    isSDK(o) {
        return o && (o.$typeUrl === RegisterCoinProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && Metadata.isSDK(o.metadata));
    },
    isAmino(o) {
        return o && (o.$typeUrl === RegisterCoinProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && Metadata.isAmino(o.metadata));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.title !== undefined) {
            writer.uint32(10).string(message.title);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        if (message.metadata !== undefined) {
            Metadata.encode(message.metadata, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseRegisterCoinProposal();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.title = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                case 3:
                    message.metadata = Metadata.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseRegisterCoinProposal();
        if (isSet(object.title))
            obj.title = String(object.title);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.metadata))
            obj.metadata = Metadata.fromJSON(object.metadata);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.title !== undefined && (obj.title = message.title);
        message.description !== undefined && (obj.description = message.description);
        message.metadata !== undefined && (obj.metadata = message.metadata ? Metadata.toJSON(message.metadata) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseRegisterCoinProposal();
        message.title = object.title ?? "";
        message.description = object.description ?? "";
        if (object.metadata !== undefined && object.metadata !== null) {
            message.metadata = Metadata.fromPartial(object.metadata);
        }
        return message;
    },
    fromSDK(object) {
        return {
            title: object?.title,
            description: object?.description,
            metadata: object.metadata ? Metadata.fromSDK(object.metadata) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            title: isSet(object.title) ? String(object.title) : "",
            description: isSet(object.description) ? String(object.description) : "",
            metadata: isSet(object.metadata) ? Metadata.fromSDKJSON(object.metadata) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.title = message.title;
        obj.description = message.description;
        message.metadata !== undefined && (obj.metadata = message.metadata ? Metadata.toSDK(message.metadata) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseRegisterCoinProposal();
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.metadata !== undefined && object.metadata !== null) {
            message.metadata = Metadata.fromAmino(object.metadata);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.title = message.title === "" ? undefined : message.title;
        obj.description = message.description === "" ? undefined : message.description;
        obj.metadata = message.metadata ? Metadata.toAmino(message.metadata) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return RegisterCoinProposal.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return RegisterCoinProposal.decode(message.value);
    },
    toProto(message) {
        return RegisterCoinProposal.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.erc20.v1.RegisterCoinProposal",
            value: RegisterCoinProposal.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Metadata.registerTypeUrl();
    }
};
function createBaseRegisterERC20Proposal() {
    return {
        title: "",
        description: "",
        erc20address: ""
    };
}
export const RegisterERC20Proposal = {
    typeUrl: "/evmos.erc20.v1.RegisterERC20Proposal",
    is(o) {
        return o && (o.$typeUrl === RegisterERC20Proposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.erc20address === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === RegisterERC20Proposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.erc20address === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === RegisterERC20Proposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.erc20address === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.title !== undefined) {
            writer.uint32(10).string(message.title);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        if (message.erc20address !== undefined) {
            writer.uint32(26).string(message.erc20address);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseRegisterERC20Proposal();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.title = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                case 3:
                    message.erc20address = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseRegisterERC20Proposal();
        if (isSet(object.title))
            obj.title = String(object.title);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.erc20address))
            obj.erc20address = String(object.erc20address);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.title !== undefined && (obj.title = message.title);
        message.description !== undefined && (obj.description = message.description);
        message.erc20address !== undefined && (obj.erc20address = message.erc20address);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseRegisterERC20Proposal();
        message.title = object.title ?? "";
        message.description = object.description ?? "";
        message.erc20address = object.erc20address ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            title: object?.title,
            description: object?.description,
            erc20address: object?.erc20address
        };
    },
    fromSDKJSON(object) {
        return {
            title: isSet(object.title) ? String(object.title) : "",
            description: isSet(object.description) ? String(object.description) : "",
            erc20address: isSet(object.erc20address) ? String(object.erc20address) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.title = message.title;
        obj.description = message.description;
        obj.erc20address = message.erc20address;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseRegisterERC20Proposal();
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.erc20address !== undefined && object.erc20address !== null) {
            message.erc20address = object.erc20address;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.title = message.title === "" ? undefined : message.title;
        obj.description = message.description === "" ? undefined : message.description;
        obj.erc20address = message.erc20address === "" ? undefined : message.erc20address;
        return obj;
    },
    fromAminoMsg(object) {
        return RegisterERC20Proposal.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return RegisterERC20Proposal.decode(message.value);
    },
    toProto(message) {
        return RegisterERC20Proposal.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.erc20.v1.RegisterERC20Proposal",
            value: RegisterERC20Proposal.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseToggleTokenConversionProposal() {
    return {
        title: "",
        description: "",
        token: ""
    };
}
export const ToggleTokenConversionProposal = {
    typeUrl: "/evmos.erc20.v1.ToggleTokenConversionProposal",
    is(o) {
        return o && (o.$typeUrl === ToggleTokenConversionProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.token === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ToggleTokenConversionProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ToggleTokenConversionProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.title !== undefined) {
            writer.uint32(10).string(message.title);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        if (message.token !== undefined) {
            writer.uint32(26).string(message.token);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseToggleTokenConversionProposal();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.title = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                case 3:
                    message.token = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseToggleTokenConversionProposal();
        if (isSet(object.title))
            obj.title = String(object.title);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.token))
            obj.token = String(object.token);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.title !== undefined && (obj.title = message.title);
        message.description !== undefined && (obj.description = message.description);
        message.token !== undefined && (obj.token = message.token);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseToggleTokenConversionProposal();
        message.title = object.title ?? "";
        message.description = object.description ?? "";
        message.token = object.token ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            title: object?.title,
            description: object?.description,
            token: object?.token
        };
    },
    fromSDKJSON(object) {
        return {
            title: isSet(object.title) ? String(object.title) : "",
            description: isSet(object.description) ? String(object.description) : "",
            token: isSet(object.token) ? String(object.token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.title = message.title;
        obj.description = message.description;
        obj.token = message.token;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseToggleTokenConversionProposal();
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.token !== undefined && object.token !== null) {
            message.token = object.token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.title = message.title === "" ? undefined : message.title;
        obj.description = message.description === "" ? undefined : message.description;
        obj.token = message.token === "" ? undefined : message.token;
        return obj;
    },
    fromAminoMsg(object) {
        return ToggleTokenConversionProposal.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ToggleTokenConversionProposal.decode(message.value);
    },
    toProto(message) {
        return ToggleTokenConversionProposal.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.erc20.v1.ToggleTokenConversionProposal",
            value: ToggleTokenConversionProposal.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
