import { DevFeeInfo } from "./fees";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
import { Decimal } from "@cosmjs/math";
export const protobufPackage = "evmos.fees.v1";
function createBaseGenesisState() {
    return {
        params: Params.fromPartial({}),
        devFeeInfos: []
    };
}
export const GenesisState = {
    typeUrl: "/evmos.fees.v1.GenesisState",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.is(o.params) && Array.isArray(o.devFeeInfos) && (!o.devFeeInfos.length || DevFeeInfo.is(o.devFeeInfos[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.isSDK(o.params) && Array.isArray(o.dev_fee_infos) && (!o.dev_fee_infos.length || DevFeeInfo.isSDK(o.dev_fee_infos[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.isAmino(o.params) && Array.isArray(o.dev_fee_infos) && (!o.dev_fee_infos.length || DevFeeInfo.isAmino(o.dev_fee_infos[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.params !== undefined) {
            Params.encode(message.params, writer.uint32(10).fork()).ldelim();
        }
        for (const v of message.devFeeInfos) {
            DevFeeInfo.encode(v, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.params = Params.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.devFeeInfos.push(DevFeeInfo.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (isSet(object.params))
            obj.params = Params.fromJSON(object.params);
        if (Array.isArray(object?.devFeeInfos))
            obj.devFeeInfos = object.devFeeInfos.map((e) => DevFeeInfo.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.params !== undefined && (obj.params = message.params ? Params.toJSON(message.params) : undefined);
        if (message.devFeeInfos) {
            obj.devFeeInfos = message.devFeeInfos.map(e => e ? DevFeeInfo.toJSON(e) : undefined);
        }
        else {
            obj.devFeeInfos = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromPartial(object.params);
        }
        message.devFeeInfos = object.devFeeInfos?.map(e => DevFeeInfo.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            params: object.params ? Params.fromSDK(object.params) : undefined,
            devFeeInfos: Array.isArray(object?.dev_fee_infos) ? object.dev_fee_infos.map((e) => DevFeeInfo.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            params: isSet(object.params) ? Params.fromSDKJSON(object.params) : undefined,
            dev_fee_infos: Array.isArray(object?.dev_fee_infos) ? object.dev_fee_infos.map((e) => DevFeeInfo.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        message.params !== undefined && (obj.params = message.params ? Params.toSDK(message.params) : undefined);
        if (message.devFeeInfos) {
            obj.dev_fee_infos = message.devFeeInfos.map(e => e ? DevFeeInfo.toSDK(e) : undefined);
        }
        else {
            obj.dev_fee_infos = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromAmino(object.params);
        }
        message.devFeeInfos = object.dev_fee_infos?.map(e => DevFeeInfo.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.params = message.params ? Params.toAmino(message.params) : undefined;
        if (message.devFeeInfos) {
            obj.dev_fee_infos = message.devFeeInfos.map(e => e ? DevFeeInfo.toAmino(e) : undefined);
        }
        else {
            obj.dev_fee_infos = message.devFeeInfos;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.fees.v1.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Params.registerTypeUrl();
        DevFeeInfo.registerTypeUrl();
    }
};
function createBaseParams() {
    return {
        enableFees: false,
        developerShares: "",
        validatorShares: "",
        addrDerivationCostCreate: BigInt(0),
        minGasPrice: ""
    };
}
export const Params = {
    typeUrl: "/evmos.fees.v1.Params",
    is(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.enableFees === "boolean" && typeof o.developerShares === "string" && typeof o.validatorShares === "string" && typeof o.addrDerivationCostCreate === "bigint" && typeof o.minGasPrice === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.enable_fees === "boolean" && typeof o.developer_shares === "string" && typeof o.validator_shares === "string" && typeof o.addr_derivation_cost_create === "bigint" && typeof o.min_gas_price === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.enable_fees === "boolean" && typeof o.developer_shares === "string" && typeof o.validator_shares === "string" && typeof o.addr_derivation_cost_create === "bigint" && typeof o.min_gas_price === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.enableFees !== undefined) {
            writer.uint32(8).bool(message.enableFees);
        }
        if (message.developerShares !== undefined) {
            writer.uint32(18).string(Decimal.fromUserInput(message.developerShares, 18).atomics);
        }
        if (message.validatorShares !== undefined) {
            writer.uint32(26).string(Decimal.fromUserInput(message.validatorShares, 18).atomics);
        }
        if (message.addrDerivationCostCreate !== undefined) {
            writer.uint32(32).uint64(message.addrDerivationCostCreate);
        }
        if (message.minGasPrice !== undefined) {
            writer.uint32(42).string(Decimal.fromUserInput(message.minGasPrice, 18).atomics);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseParams();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.enableFees = reader.bool();
                    break;
                case 2:
                    message.developerShares = Decimal.fromAtomics(reader.string(), 18).toString();
                    break;
                case 3:
                    message.validatorShares = Decimal.fromAtomics(reader.string(), 18).toString();
                    break;
                case 4:
                    message.addrDerivationCostCreate = reader.uint64();
                    break;
                case 5:
                    message.minGasPrice = Decimal.fromAtomics(reader.string(), 18).toString();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseParams();
        if (isSet(object.enableFees))
            obj.enableFees = Boolean(object.enableFees);
        if (isSet(object.developerShares))
            obj.developerShares = String(object.developerShares);
        if (isSet(object.validatorShares))
            obj.validatorShares = String(object.validatorShares);
        if (isSet(object.addrDerivationCostCreate))
            obj.addrDerivationCostCreate = BigInt(object.addrDerivationCostCreate.toString());
        if (isSet(object.minGasPrice))
            obj.minGasPrice = String(object.minGasPrice);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.enableFees !== undefined && (obj.enableFees = message.enableFees);
        message.developerShares !== undefined && (obj.developerShares = message.developerShares);
        message.validatorShares !== undefined && (obj.validatorShares = message.validatorShares);
        message.addrDerivationCostCreate !== undefined && (obj.addrDerivationCostCreate = (message.addrDerivationCostCreate || BigInt(0)).toString());
        message.minGasPrice !== undefined && (obj.minGasPrice = message.minGasPrice);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseParams();
        message.enableFees = object.enableFees ?? false;
        message.developerShares = object.developerShares ?? "";
        message.validatorShares = object.validatorShares ?? "";
        if (object.addrDerivationCostCreate !== undefined && object.addrDerivationCostCreate !== null) {
            message.addrDerivationCostCreate = BigInt(object.addrDerivationCostCreate.toString());
        }
        message.minGasPrice = object.minGasPrice ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            enableFees: object?.enable_fees,
            developerShares: object?.developer_shares,
            validatorShares: object?.validator_shares,
            addrDerivationCostCreate: object?.addr_derivation_cost_create,
            minGasPrice: object?.min_gas_price
        };
    },
    fromSDKJSON(object) {
        return {
            enable_fees: isSet(object.enable_fees) ? Boolean(object.enable_fees) : false,
            developer_shares: isSet(object.developer_shares) ? String(object.developer_shares) : "",
            validator_shares: isSet(object.validator_shares) ? String(object.validator_shares) : "",
            addr_derivation_cost_create: isSet(object.addr_derivation_cost_create) ? BigInt(object.addr_derivation_cost_create.toString()) : BigInt(0),
            min_gas_price: isSet(object.min_gas_price) ? String(object.min_gas_price) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.enable_fees = message.enableFees;
        obj.developer_shares = message.developerShares;
        obj.validator_shares = message.validatorShares;
        obj.addr_derivation_cost_create = message.addrDerivationCostCreate;
        obj.min_gas_price = message.minGasPrice;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseParams();
        if (object.enable_fees !== undefined && object.enable_fees !== null) {
            message.enableFees = object.enable_fees;
        }
        if (object.developer_shares !== undefined && object.developer_shares !== null) {
            message.developerShares = object.developer_shares;
        }
        if (object.validator_shares !== undefined && object.validator_shares !== null) {
            message.validatorShares = object.validator_shares;
        }
        if (object.addr_derivation_cost_create !== undefined && object.addr_derivation_cost_create !== null) {
            message.addrDerivationCostCreate = BigInt(object.addr_derivation_cost_create);
        }
        if (object.min_gas_price !== undefined && object.min_gas_price !== null) {
            message.minGasPrice = object.min_gas_price;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.enable_fees = message.enableFees === false ? undefined : message.enableFees;
        obj.developer_shares = message.developerShares === "" ? undefined : message.developerShares;
        obj.validator_shares = message.validatorShares === "" ? undefined : message.validatorShares;
        obj.addr_derivation_cost_create = message.addrDerivationCostCreate !== BigInt(0) ? message.addrDerivationCostCreate?.toString() : undefined;
        obj.min_gas_price = message.minGasPrice === "" ? undefined : message.minGasPrice;
        return obj;
    },
    fromAminoMsg(object) {
        return Params.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Params.decode(message.value);
    },
    toProto(message) {
        return Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.fees.v1.Params",
            value: Params.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
