import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryDevFeeInfosRequest, QueryDevFeeInfosResponse, QueryDevFeeInfoRequest, QueryDevFeeInfoResponse, QueryParamsRequest, QueryParamsResponse, QueryDevFeeInfosPerDeployerRequest, QueryDevFeeInfosPerDeployerResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* DevFeeInfos retrieves all registered contracts for fee distribution */
    devFeeInfos = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryDevFeeInfosRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.fees.v1.Query", "DevFeeInfos", data);
        return promise.then(data => QueryDevFeeInfosResponse.decode(new BinaryReader(data)));
    };
    /* DevFeeInfo retrieves a registered contract for fee distribution */
    devFeeInfo = async (request) => {
        const data = QueryDevFeeInfoRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.fees.v1.Query", "DevFeeInfo", data);
        return promise.then(data => QueryDevFeeInfoResponse.decode(new BinaryReader(data)));
    };
    /* Params retrieves the fees module params */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.fees.v1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* DevFeeInfosPerDeployer retrieves all contracts that a deployer has
     registered for fee distribution */
    devFeeInfosPerDeployer = async (request) => {
        const data = QueryDevFeeInfosPerDeployerRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.fees.v1.Query", "DevFeeInfosPerDeployer", data);
        return promise.then(data => QueryDevFeeInfosPerDeployerResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
