import { DecCoin } from "../../../cosmos/base/v1beta1/coin";
import { Timestamp } from "../../../google/protobuf/timestamp";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { toTimestamp, fromTimestamp, isSet } from "../../../helpers";
import { GlobalDecoderRegistry } from "../../../registry";
export const protobufPackage = "evmos.incentives.v1";
function createBaseIncentive() {
    return {
        contract: "",
        allocations: [],
        epochs: 0,
        startTime: new Date(),
        totalGas: BigInt(0)
    };
}
export const Incentive = {
    typeUrl: "/evmos.incentives.v1.Incentive",
    is(o) {
        return o && (o.$typeUrl === Incentive.typeUrl || typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.is(o.allocations[0])) && typeof o.epochs === "number" && Timestamp.is(o.startTime) && typeof o.totalGas === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Incentive.typeUrl || typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.isSDK(o.allocations[0])) && typeof o.epochs === "number" && Timestamp.isSDK(o.start_time) && typeof o.total_gas === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Incentive.typeUrl || typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.isAmino(o.allocations[0])) && typeof o.epochs === "number" && Timestamp.isAmino(o.start_time) && typeof o.total_gas === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.contract !== undefined) {
            writer.uint32(10).string(message.contract);
        }
        for (const v of message.allocations) {
            DecCoin.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.epochs !== undefined) {
            writer.uint32(24).uint32(message.epochs);
        }
        if (message.startTime !== undefined) {
            Timestamp.encode(toTimestamp(message.startTime), writer.uint32(34).fork()).ldelim();
        }
        if (message.totalGas !== undefined) {
            writer.uint32(40).uint64(message.totalGas);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseIncentive();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.contract = reader.string();
                    break;
                case 2:
                    message.allocations.push(DecCoin.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.epochs = reader.uint32();
                    break;
                case 4:
                    message.startTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.totalGas = reader.uint64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseIncentive();
        if (isSet(object.contract))
            obj.contract = String(object.contract);
        if (Array.isArray(object?.allocations))
            obj.allocations = object.allocations.map((e) => DecCoin.fromJSON(e));
        if (isSet(object.epochs))
            obj.epochs = Number(object.epochs);
        if (isSet(object.startTime))
            obj.startTime = new Date(object.startTime);
        if (isSet(object.totalGas))
            obj.totalGas = BigInt(object.totalGas.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.contract !== undefined && (obj.contract = message.contract);
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toJSON(e) : undefined);
        }
        else {
            obj.allocations = [];
        }
        message.epochs !== undefined && (obj.epochs = Math.round(message.epochs));
        message.startTime !== undefined && (obj.startTime = message.startTime.toISOString());
        message.totalGas !== undefined && (obj.totalGas = (message.totalGas || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseIncentive();
        message.contract = object.contract ?? "";
        message.allocations = object.allocations?.map(e => DecCoin.fromPartial(e)) || [];
        message.epochs = object.epochs ?? 0;
        message.startTime = object.startTime ?? undefined;
        if (object.totalGas !== undefined && object.totalGas !== null) {
            message.totalGas = BigInt(object.totalGas.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            contract: object?.contract,
            allocations: Array.isArray(object?.allocations) ? object.allocations.map((e) => DecCoin.fromSDK(e)) : [],
            epochs: object?.epochs,
            startTime: object.start_time ?? undefined,
            totalGas: object?.total_gas
        };
    },
    fromSDKJSON(object) {
        return {
            contract: isSet(object.contract) ? String(object.contract) : "",
            allocations: Array.isArray(object?.allocations) ? object.allocations.map((e) => DecCoin.fromSDKJSON(e)) : [],
            epochs: isSet(object.epochs) ? Number(object.epochs) : 0,
            start_time: isSet(object.start_time) ? new Date(object.start_time) : undefined,
            total_gas: isSet(object.total_gas) ? BigInt(object.total_gas.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        obj.contract = message.contract;
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toSDK(e) : undefined);
        }
        else {
            obj.allocations = [];
        }
        obj.epochs = message.epochs;
        message.startTime !== undefined && (obj.start_time = message.startTime ?? undefined);
        obj.total_gas = message.totalGas;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseIncentive();
        if (object.contract !== undefined && object.contract !== null) {
            message.contract = object.contract;
        }
        message.allocations = object.allocations?.map(e => DecCoin.fromAmino(e)) || [];
        if (object.epochs !== undefined && object.epochs !== null) {
            message.epochs = object.epochs;
        }
        if (object.start_time !== undefined && object.start_time !== null) {
            message.startTime = fromTimestamp(Timestamp.fromAmino(object.start_time));
        }
        if (object.total_gas !== undefined && object.total_gas !== null) {
            message.totalGas = BigInt(object.total_gas);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.contract = message.contract === "" ? undefined : message.contract;
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toAmino(e) : undefined);
        }
        else {
            obj.allocations = message.allocations;
        }
        obj.epochs = message.epochs === 0 ? undefined : message.epochs;
        obj.start_time = message.startTime ? Timestamp.toAmino(toTimestamp(message.startTime)) : undefined;
        obj.total_gas = message.totalGas !== BigInt(0) ? message.totalGas?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return Incentive.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Incentive.decode(message.value);
    },
    toProto(message) {
        return Incentive.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.incentives.v1.Incentive",
            value: Incentive.encode(message).finish()
        };
    },
    registerTypeUrl() {
        DecCoin.registerTypeUrl();
    }
};
function createBaseGasMeter() {
    return {
        contract: "",
        participant: "",
        cumulativeGas: BigInt(0)
    };
}
export const GasMeter = {
    typeUrl: "/evmos.incentives.v1.GasMeter",
    is(o) {
        return o && (o.$typeUrl === GasMeter.typeUrl || typeof o.contract === "string" && typeof o.participant === "string" && typeof o.cumulativeGas === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === GasMeter.typeUrl || typeof o.contract === "string" && typeof o.participant === "string" && typeof o.cumulative_gas === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === GasMeter.typeUrl || typeof o.contract === "string" && typeof o.participant === "string" && typeof o.cumulative_gas === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.contract !== undefined) {
            writer.uint32(10).string(message.contract);
        }
        if (message.participant !== undefined) {
            writer.uint32(18).string(message.participant);
        }
        if (message.cumulativeGas !== undefined) {
            writer.uint32(24).uint64(message.cumulativeGas);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGasMeter();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.contract = reader.string();
                    break;
                case 2:
                    message.participant = reader.string();
                    break;
                case 3:
                    message.cumulativeGas = reader.uint64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGasMeter();
        if (isSet(object.contract))
            obj.contract = String(object.contract);
        if (isSet(object.participant))
            obj.participant = String(object.participant);
        if (isSet(object.cumulativeGas))
            obj.cumulativeGas = BigInt(object.cumulativeGas.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.contract !== undefined && (obj.contract = message.contract);
        message.participant !== undefined && (obj.participant = message.participant);
        message.cumulativeGas !== undefined && (obj.cumulativeGas = (message.cumulativeGas || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGasMeter();
        message.contract = object.contract ?? "";
        message.participant = object.participant ?? "";
        if (object.cumulativeGas !== undefined && object.cumulativeGas !== null) {
            message.cumulativeGas = BigInt(object.cumulativeGas.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            contract: object?.contract,
            participant: object?.participant,
            cumulativeGas: object?.cumulative_gas
        };
    },
    fromSDKJSON(object) {
        return {
            contract: isSet(object.contract) ? String(object.contract) : "",
            participant: isSet(object.participant) ? String(object.participant) : "",
            cumulative_gas: isSet(object.cumulative_gas) ? BigInt(object.cumulative_gas.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        obj.contract = message.contract;
        obj.participant = message.participant;
        obj.cumulative_gas = message.cumulativeGas;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGasMeter();
        if (object.contract !== undefined && object.contract !== null) {
            message.contract = object.contract;
        }
        if (object.participant !== undefined && object.participant !== null) {
            message.participant = object.participant;
        }
        if (object.cumulative_gas !== undefined && object.cumulative_gas !== null) {
            message.cumulativeGas = BigInt(object.cumulative_gas);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.contract = message.contract === "" ? undefined : message.contract;
        obj.participant = message.participant === "" ? undefined : message.participant;
        obj.cumulative_gas = message.cumulativeGas !== BigInt(0) ? message.cumulativeGas?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return GasMeter.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return GasMeter.decode(message.value);
    },
    toProto(message) {
        return GasMeter.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.incentives.v1.GasMeter",
            value: GasMeter.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseRegisterIncentiveProposal() {
    return {
        $typeUrl: "/evmos.incentives.v1.RegisterIncentiveProposal",
        title: "",
        description: "",
        contract: "",
        allocations: [],
        epochs: 0
    };
}
export const RegisterIncentiveProposal = {
    typeUrl: "/evmos.incentives.v1.RegisterIncentiveProposal",
    is(o) {
        return o && (o.$typeUrl === RegisterIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.is(o.allocations[0])) && typeof o.epochs === "number");
    },
    isSDK(o) {
        return o && (o.$typeUrl === RegisterIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.isSDK(o.allocations[0])) && typeof o.epochs === "number");
    },
    isAmino(o) {
        return o && (o.$typeUrl === RegisterIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string" && Array.isArray(o.allocations) && (!o.allocations.length || DecCoin.isAmino(o.allocations[0])) && typeof o.epochs === "number");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.title !== undefined) {
            writer.uint32(10).string(message.title);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        if (message.contract !== undefined) {
            writer.uint32(26).string(message.contract);
        }
        for (const v of message.allocations) {
            DecCoin.encode(v, writer.uint32(34).fork()).ldelim();
        }
        if (message.epochs !== undefined) {
            writer.uint32(40).uint32(message.epochs);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseRegisterIncentiveProposal();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.title = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                case 3:
                    message.contract = reader.string();
                    break;
                case 4:
                    message.allocations.push(DecCoin.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.epochs = reader.uint32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseRegisterIncentiveProposal();
        if (isSet(object.title))
            obj.title = String(object.title);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.contract))
            obj.contract = String(object.contract);
        if (Array.isArray(object?.allocations))
            obj.allocations = object.allocations.map((e) => DecCoin.fromJSON(e));
        if (isSet(object.epochs))
            obj.epochs = Number(object.epochs);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.title !== undefined && (obj.title = message.title);
        message.description !== undefined && (obj.description = message.description);
        message.contract !== undefined && (obj.contract = message.contract);
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toJSON(e) : undefined);
        }
        else {
            obj.allocations = [];
        }
        message.epochs !== undefined && (obj.epochs = Math.round(message.epochs));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseRegisterIncentiveProposal();
        message.title = object.title ?? "";
        message.description = object.description ?? "";
        message.contract = object.contract ?? "";
        message.allocations = object.allocations?.map(e => DecCoin.fromPartial(e)) || [];
        message.epochs = object.epochs ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            title: object?.title,
            description: object?.description,
            contract: object?.contract,
            allocations: Array.isArray(object?.allocations) ? object.allocations.map((e) => DecCoin.fromSDK(e)) : [],
            epochs: object?.epochs
        };
    },
    fromSDKJSON(object) {
        return {
            title: isSet(object.title) ? String(object.title) : "",
            description: isSet(object.description) ? String(object.description) : "",
            contract: isSet(object.contract) ? String(object.contract) : "",
            allocations: Array.isArray(object?.allocations) ? object.allocations.map((e) => DecCoin.fromSDKJSON(e)) : [],
            epochs: isSet(object.epochs) ? Number(object.epochs) : 0
        };
    },
    toSDK(message) {
        const obj = {};
        obj.title = message.title;
        obj.description = message.description;
        obj.contract = message.contract;
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toSDK(e) : undefined);
        }
        else {
            obj.allocations = [];
        }
        obj.epochs = message.epochs;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseRegisterIncentiveProposal();
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.contract !== undefined && object.contract !== null) {
            message.contract = object.contract;
        }
        message.allocations = object.allocations?.map(e => DecCoin.fromAmino(e)) || [];
        if (object.epochs !== undefined && object.epochs !== null) {
            message.epochs = object.epochs;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.title = message.title === "" ? undefined : message.title;
        obj.description = message.description === "" ? undefined : message.description;
        obj.contract = message.contract === "" ? undefined : message.contract;
        if (message.allocations) {
            obj.allocations = message.allocations.map(e => e ? DecCoin.toAmino(e) : undefined);
        }
        else {
            obj.allocations = message.allocations;
        }
        obj.epochs = message.epochs === 0 ? undefined : message.epochs;
        return obj;
    },
    fromAminoMsg(object) {
        return RegisterIncentiveProposal.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return RegisterIncentiveProposal.decode(message.value);
    },
    toProto(message) {
        return RegisterIncentiveProposal.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.incentives.v1.RegisterIncentiveProposal",
            value: RegisterIncentiveProposal.encode(message).finish()
        };
    },
    registerTypeUrl() {
        GlobalDecoderRegistry.register(RegisterIncentiveProposal.typeUrl, RegisterIncentiveProposal);
        DecCoin.registerTypeUrl();
    }
};
function createBaseCancelIncentiveProposal() {
    return {
        title: "",
        description: "",
        contract: ""
    };
}
export const CancelIncentiveProposal = {
    typeUrl: "/evmos.incentives.v1.CancelIncentiveProposal",
    is(o) {
        return o && (o.$typeUrl === CancelIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CancelIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CancelIncentiveProposal.typeUrl || typeof o.title === "string" && typeof o.description === "string" && typeof o.contract === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.title !== undefined) {
            writer.uint32(10).string(message.title);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        if (message.contract !== undefined) {
            writer.uint32(26).string(message.contract);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCancelIncentiveProposal();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.title = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                case 3:
                    message.contract = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCancelIncentiveProposal();
        if (isSet(object.title))
            obj.title = String(object.title);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.contract))
            obj.contract = String(object.contract);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.title !== undefined && (obj.title = message.title);
        message.description !== undefined && (obj.description = message.description);
        message.contract !== undefined && (obj.contract = message.contract);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCancelIncentiveProposal();
        message.title = object.title ?? "";
        message.description = object.description ?? "";
        message.contract = object.contract ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            title: object?.title,
            description: object?.description,
            contract: object?.contract
        };
    },
    fromSDKJSON(object) {
        return {
            title: isSet(object.title) ? String(object.title) : "",
            description: isSet(object.description) ? String(object.description) : "",
            contract: isSet(object.contract) ? String(object.contract) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.title = message.title;
        obj.description = message.description;
        obj.contract = message.contract;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCancelIncentiveProposal();
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.contract !== undefined && object.contract !== null) {
            message.contract = object.contract;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.title = message.title === "" ? undefined : message.title;
        obj.description = message.description === "" ? undefined : message.description;
        obj.contract = message.contract === "" ? undefined : message.contract;
        return obj;
    },
    fromAminoMsg(object) {
        return CancelIncentiveProposal.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CancelIncentiveProposal.decode(message.value);
    },
    toProto(message) {
        return CancelIncentiveProposal.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.incentives.v1.CancelIncentiveProposal",
            value: CancelIncentiveProposal.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
