import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryIncentivesResponse, QueryIncentiveResponse, QueryGasMetersResponse, QueryGasMeterResponse, QueryAllocationMetersResponse, QueryAllocationMeterResponse, QueryParamsResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Incentives retrieves registered incentives */
    incentives = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `evmos/incentives/v1/incentives`;
        return QueryIncentivesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Incentive retrieves a registered incentive */
    incentive = async (params) => {
        const endpoint = `evmos/incentives/v1/incentives/${params.contract}`;
        return QueryIncentiveResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GasMeters retrieves active gas meters for a given contract */
    gasMeters = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `evmos/incentives/v1/gas_meters/${params.contract}`;
        return QueryGasMetersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* GasMeter Retrieves a active gas meter */
    gasMeter = async (params) => {
        const endpoint = `evmos/incentives/v1/gas_meters/${params.contract}/${params.participant}`;
        return QueryGasMeterResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* AllocationMeters retrieves active allocation meters for a given
     denomination */
    allocationMeters = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `evmos/incentives/v1/allocation_meters`;
        return QueryAllocationMetersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* AllocationMeter Retrieves a active gas meter */
    allocationMeter = async (params) => {
        const endpoint = `evmos/incentives/v1/allocation_meters/${params.denom}`;
        return QueryAllocationMeterResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Params retrieves the incentives module params */
    params = async (_params = {}) => {
        const endpoint = `evmos/incentives/v1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
