import { ExponentialCalculation, InflationDistribution } from "./inflation";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "evmos.inflation.v1";
function createBaseGenesisState() {
    return {
        params: Params.fromPartial({}),
        period: BigInt(0),
        epochIdentifier: "",
        epochsPerPeriod: BigInt(0),
        skippedEpochs: BigInt(0)
    };
}
export const GenesisState = {
    typeUrl: "/evmos.inflation.v1.GenesisState",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.is(o.params) && typeof o.period === "bigint" && typeof o.epochIdentifier === "string" && typeof o.epochsPerPeriod === "bigint" && typeof o.skippedEpochs === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.isSDK(o.params) && typeof o.period === "bigint" && typeof o.epoch_identifier === "string" && typeof o.epochs_per_period === "bigint" && typeof o.skipped_epochs === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Params.isAmino(o.params) && typeof o.period === "bigint" && typeof o.epoch_identifier === "string" && typeof o.epochs_per_period === "bigint" && typeof o.skipped_epochs === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.params !== undefined) {
            Params.encode(message.params, writer.uint32(10).fork()).ldelim();
        }
        if (message.period !== undefined) {
            writer.uint32(16).uint64(message.period);
        }
        if (message.epochIdentifier !== undefined) {
            writer.uint32(26).string(message.epochIdentifier);
        }
        if (message.epochsPerPeriod !== undefined) {
            writer.uint32(32).int64(message.epochsPerPeriod);
        }
        if (message.skippedEpochs !== undefined) {
            writer.uint32(40).uint64(message.skippedEpochs);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.params = Params.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.period = reader.uint64();
                    break;
                case 3:
                    message.epochIdentifier = reader.string();
                    break;
                case 4:
                    message.epochsPerPeriod = reader.int64();
                    break;
                case 5:
                    message.skippedEpochs = reader.uint64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (isSet(object.params))
            obj.params = Params.fromJSON(object.params);
        if (isSet(object.period))
            obj.period = BigInt(object.period.toString());
        if (isSet(object.epochIdentifier))
            obj.epochIdentifier = String(object.epochIdentifier);
        if (isSet(object.epochsPerPeriod))
            obj.epochsPerPeriod = BigInt(object.epochsPerPeriod.toString());
        if (isSet(object.skippedEpochs))
            obj.skippedEpochs = BigInt(object.skippedEpochs.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.params !== undefined && (obj.params = message.params ? Params.toJSON(message.params) : undefined);
        message.period !== undefined && (obj.period = (message.period || BigInt(0)).toString());
        message.epochIdentifier !== undefined && (obj.epochIdentifier = message.epochIdentifier);
        message.epochsPerPeriod !== undefined && (obj.epochsPerPeriod = (message.epochsPerPeriod || BigInt(0)).toString());
        message.skippedEpochs !== undefined && (obj.skippedEpochs = (message.skippedEpochs || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromPartial(object.params);
        }
        if (object.period !== undefined && object.period !== null) {
            message.period = BigInt(object.period.toString());
        }
        message.epochIdentifier = object.epochIdentifier ?? "";
        if (object.epochsPerPeriod !== undefined && object.epochsPerPeriod !== null) {
            message.epochsPerPeriod = BigInt(object.epochsPerPeriod.toString());
        }
        if (object.skippedEpochs !== undefined && object.skippedEpochs !== null) {
            message.skippedEpochs = BigInt(object.skippedEpochs.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            params: object.params ? Params.fromSDK(object.params) : undefined,
            period: object?.period,
            epochIdentifier: object?.epoch_identifier,
            epochsPerPeriod: object?.epochs_per_period,
            skippedEpochs: object?.skipped_epochs
        };
    },
    fromSDKJSON(object) {
        return {
            params: isSet(object.params) ? Params.fromSDKJSON(object.params) : undefined,
            period: isSet(object.period) ? BigInt(object.period.toString()) : BigInt(0),
            epoch_identifier: isSet(object.epoch_identifier) ? String(object.epoch_identifier) : "",
            epochs_per_period: isSet(object.epochs_per_period) ? BigInt(object.epochs_per_period.toString()) : BigInt(0),
            skipped_epochs: isSet(object.skipped_epochs) ? BigInt(object.skipped_epochs.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        message.params !== undefined && (obj.params = message.params ? Params.toSDK(message.params) : undefined);
        obj.period = message.period;
        obj.epoch_identifier = message.epochIdentifier;
        obj.epochs_per_period = message.epochsPerPeriod;
        obj.skipped_epochs = message.skippedEpochs;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromAmino(object.params);
        }
        if (object.period !== undefined && object.period !== null) {
            message.period = BigInt(object.period);
        }
        if (object.epoch_identifier !== undefined && object.epoch_identifier !== null) {
            message.epochIdentifier = object.epoch_identifier;
        }
        if (object.epochs_per_period !== undefined && object.epochs_per_period !== null) {
            message.epochsPerPeriod = BigInt(object.epochs_per_period);
        }
        if (object.skipped_epochs !== undefined && object.skipped_epochs !== null) {
            message.skippedEpochs = BigInt(object.skipped_epochs);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.params = message.params ? Params.toAmino(message.params) : undefined;
        obj.period = message.period !== BigInt(0) ? message.period?.toString() : undefined;
        obj.epoch_identifier = message.epochIdentifier === "" ? undefined : message.epochIdentifier;
        obj.epochs_per_period = message.epochsPerPeriod !== BigInt(0) ? message.epochsPerPeriod?.toString() : undefined;
        obj.skipped_epochs = message.skippedEpochs !== BigInt(0) ? message.skippedEpochs?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.inflation.v1.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Params.registerTypeUrl();
    }
};
function createBaseParams() {
    return {
        mintDenom: "",
        exponentialCalculation: ExponentialCalculation.fromPartial({}),
        inflationDistribution: InflationDistribution.fromPartial({}),
        enableInflation: false
    };
}
export const Params = {
    typeUrl: "/evmos.inflation.v1.Params",
    is(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.mintDenom === "string" && ExponentialCalculation.is(o.exponentialCalculation) && InflationDistribution.is(o.inflationDistribution) && typeof o.enableInflation === "boolean");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.mint_denom === "string" && ExponentialCalculation.isSDK(o.exponential_calculation) && InflationDistribution.isSDK(o.inflation_distribution) && typeof o.enable_inflation === "boolean");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.mint_denom === "string" && ExponentialCalculation.isAmino(o.exponential_calculation) && InflationDistribution.isAmino(o.inflation_distribution) && typeof o.enable_inflation === "boolean");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.mintDenom !== undefined) {
            writer.uint32(10).string(message.mintDenom);
        }
        if (message.exponentialCalculation !== undefined) {
            ExponentialCalculation.encode(message.exponentialCalculation, writer.uint32(18).fork()).ldelim();
        }
        if (message.inflationDistribution !== undefined) {
            InflationDistribution.encode(message.inflationDistribution, writer.uint32(26).fork()).ldelim();
        }
        if (message.enableInflation !== undefined) {
            writer.uint32(32).bool(message.enableInflation);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseParams();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.mintDenom = reader.string();
                    break;
                case 2:
                    message.exponentialCalculation = ExponentialCalculation.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.inflationDistribution = InflationDistribution.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.enableInflation = reader.bool();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseParams();
        if (isSet(object.mintDenom))
            obj.mintDenom = String(object.mintDenom);
        if (isSet(object.exponentialCalculation))
            obj.exponentialCalculation = ExponentialCalculation.fromJSON(object.exponentialCalculation);
        if (isSet(object.inflationDistribution))
            obj.inflationDistribution = InflationDistribution.fromJSON(object.inflationDistribution);
        if (isSet(object.enableInflation))
            obj.enableInflation = Boolean(object.enableInflation);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.mintDenom !== undefined && (obj.mintDenom = message.mintDenom);
        message.exponentialCalculation !== undefined && (obj.exponentialCalculation = message.exponentialCalculation ? ExponentialCalculation.toJSON(message.exponentialCalculation) : undefined);
        message.inflationDistribution !== undefined && (obj.inflationDistribution = message.inflationDistribution ? InflationDistribution.toJSON(message.inflationDistribution) : undefined);
        message.enableInflation !== undefined && (obj.enableInflation = message.enableInflation);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseParams();
        message.mintDenom = object.mintDenom ?? "";
        if (object.exponentialCalculation !== undefined && object.exponentialCalculation !== null) {
            message.exponentialCalculation = ExponentialCalculation.fromPartial(object.exponentialCalculation);
        }
        if (object.inflationDistribution !== undefined && object.inflationDistribution !== null) {
            message.inflationDistribution = InflationDistribution.fromPartial(object.inflationDistribution);
        }
        message.enableInflation = object.enableInflation ?? false;
        return message;
    },
    fromSDK(object) {
        return {
            mintDenom: object?.mint_denom,
            exponentialCalculation: object.exponential_calculation ? ExponentialCalculation.fromSDK(object.exponential_calculation) : undefined,
            inflationDistribution: object.inflation_distribution ? InflationDistribution.fromSDK(object.inflation_distribution) : undefined,
            enableInflation: object?.enable_inflation
        };
    },
    fromSDKJSON(object) {
        return {
            mint_denom: isSet(object.mint_denom) ? String(object.mint_denom) : "",
            exponential_calculation: isSet(object.exponential_calculation) ? ExponentialCalculation.fromSDKJSON(object.exponential_calculation) : undefined,
            inflation_distribution: isSet(object.inflation_distribution) ? InflationDistribution.fromSDKJSON(object.inflation_distribution) : undefined,
            enable_inflation: isSet(object.enable_inflation) ? Boolean(object.enable_inflation) : false
        };
    },
    toSDK(message) {
        const obj = {};
        obj.mint_denom = message.mintDenom;
        message.exponentialCalculation !== undefined && (obj.exponential_calculation = message.exponentialCalculation ? ExponentialCalculation.toSDK(message.exponentialCalculation) : undefined);
        message.inflationDistribution !== undefined && (obj.inflation_distribution = message.inflationDistribution ? InflationDistribution.toSDK(message.inflationDistribution) : undefined);
        obj.enable_inflation = message.enableInflation;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseParams();
        if (object.mint_denom !== undefined && object.mint_denom !== null) {
            message.mintDenom = object.mint_denom;
        }
        if (object.exponential_calculation !== undefined && object.exponential_calculation !== null) {
            message.exponentialCalculation = ExponentialCalculation.fromAmino(object.exponential_calculation);
        }
        if (object.inflation_distribution !== undefined && object.inflation_distribution !== null) {
            message.inflationDistribution = InflationDistribution.fromAmino(object.inflation_distribution);
        }
        if (object.enable_inflation !== undefined && object.enable_inflation !== null) {
            message.enableInflation = object.enable_inflation;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.mint_denom = message.mintDenom === "" ? undefined : message.mintDenom;
        obj.exponential_calculation = message.exponentialCalculation ? ExponentialCalculation.toAmino(message.exponentialCalculation) : undefined;
        obj.inflation_distribution = message.inflationDistribution ? InflationDistribution.toAmino(message.inflationDistribution) : undefined;
        obj.enable_inflation = message.enableInflation === false ? undefined : message.enableInflation;
        return obj;
    },
    fromAminoMsg(object) {
        return Params.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Params.decode(message.value);
    },
    toProto(message) {
        return Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.inflation.v1.Params",
            value: Params.encode(message).finish()
        };
    },
    registerTypeUrl() {
        ExponentialCalculation.registerTypeUrl();
        InflationDistribution.registerTypeUrl();
    }
};
