import { BinaryReader } from "../../../binary";
import { QueryPeriodRequest, QueryPeriodResponse, QueryEpochMintProvisionRequest, QueryEpochMintProvisionResponse, QuerySkippedEpochsRequest, QuerySkippedEpochsResponse, QueryCirculatingSupplyRequest, QueryCirculatingSupplyResponse, QueryInflationRateRequest, QueryInflationRateResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Period retrieves current period. */
    period = async (request = {}) => {
        const data = QueryPeriodRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "Period", data);
        return promise.then(data => QueryPeriodResponse.decode(new BinaryReader(data)));
    };
    /* EpochMintProvision retrieves current minting epoch provision value. */
    epochMintProvision = async (request = {}) => {
        const data = QueryEpochMintProvisionRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "EpochMintProvision", data);
        return promise.then(data => QueryEpochMintProvisionResponse.decode(new BinaryReader(data)));
    };
    /* SkippedEpochs retrieves the total number of skipped epochs. */
    skippedEpochs = async (request = {}) => {
        const data = QuerySkippedEpochsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "SkippedEpochs", data);
        return promise.then(data => QuerySkippedEpochsResponse.decode(new BinaryReader(data)));
    };
    /* CirculatingSupply retrieves the total number of tokens that are in
     circulation (i.e. excluding unvested tokens). */
    circulatingSupply = async (request = {}) => {
        const data = QueryCirculatingSupplyRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "CirculatingSupply", data);
        return promise.then(data => QueryCirculatingSupplyResponse.decode(new BinaryReader(data)));
    };
    /* InflationRate retrieves the inflation rate of the current period. */
    inflationRate = async (request = {}) => {
        const data = QueryInflationRateRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "InflationRate", data);
        return promise.then(data => QueryInflationRateResponse.decode(new BinaryReader(data)));
    };
    /* Params retrieves the total set of minting parameters. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.inflation.v1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
