import { LCDClient } from "@cosmology/lcd";
export const createLCDClient = async ({ restEndpoint }) => {
    const requestClient = new LCDClient({
        restEndpoint
    });
    return {
        cosmos: {
            auth: {
                v1beta1: new (await import("../cosmos/auth/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            authz: {
                v1beta1: new (await import("../cosmos/authz/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            bank: {
                v1beta1: new (await import("../cosmos/bank/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            base: {
                reflection: {
                    v1beta1: new (await import("../cosmos/base/reflection/v1beta1/reflection.lcd")).LCDQueryClient({
                        requestClient
                    }),
                    v2alpha1: new (await import("../cosmos/base/reflection/v2alpha1/reflection.lcd")).LCDQueryClient({
                        requestClient
                    })
                },
                tendermint: {
                    v1beta1: new (await import("../cosmos/base/tendermint/v1beta1/query.lcd")).LCDQueryClient({
                        requestClient
                    })
                }
            },
            distribution: {
                v1beta1: new (await import("../cosmos/distribution/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            evidence: {
                v1beta1: new (await import("../cosmos/evidence/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            feegrant: {
                v1beta1: new (await import("../cosmos/feegrant/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            gov: {
                v1: new (await import("../cosmos/gov/v1/query.lcd")).LCDQueryClient({
                    requestClient
                }),
                v1beta1: new (await import("../cosmos/gov/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            group: {
                v1: new (await import("../cosmos/group/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            mint: {
                v1beta1: new (await import("../cosmos/mint/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            nft: {
                v1beta1: new (await import("../cosmos/nft/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            params: {
                v1beta1: new (await import("../cosmos/params/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            slashing: {
                v1beta1: new (await import("../cosmos/slashing/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            staking: {
                v1beta1: new (await import("../cosmos/staking/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            tx: {
                v1beta1: new (await import("../cosmos/tx/v1beta1/service.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            upgrade: {
                v1beta1: new (await import("../cosmos/upgrade/v1beta1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            }
        },
        evmos: {
            claims: {
                v1: new (await import("./claims/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            epochs: {
                v1: new (await import("./epochs/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            erc20: {
                v1: new (await import("./erc20/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            fees: {
                v1: new (await import("./fees/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            incentives: {
                v1: new (await import("./incentives/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            inflation: {
                v1: new (await import("./inflation/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            recovery: {
                v1: new (await import("./recovery/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            },
            vesting: {
                v1: new (await import("./vesting/v1/query.lcd")).LCDQueryClient({
                    requestClient
                })
            }
        }
    };
};
