import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet } from "../../helpers";
export const protobufPackage = "google.api";
/**
 * Path Translation specifies how to combine the backend address with the
 * request path in order to produce the appropriate forwarding URL for the
 * request.
 *
 * Path Translation is applicable only to HTTP-based backends. Backends which
 * do not accept requests over HTTP/HTTPS should leave `path_translation`
 * unspecified.
 */
export var BackendRule_PathTranslation;
(function (BackendRule_PathTranslation) {
    BackendRule_PathTranslation[BackendRule_PathTranslation["PATH_TRANSLATION_UNSPECIFIED"] = 0] = "PATH_TRANSLATION_UNSPECIFIED";
    /**
     * CONSTANT_ADDRESS - Use the backend address as-is, with no modification to the path. If the
     * URL pattern contains variables, the variable names and values will be
     * appended to the query string. If a query string parameter and a URL
     * pattern variable have the same name, this may result in duplicate keys in
     * the query string.
     *
     * # Examples
     *
     * Given the following operation config:
     *
     *     Method path:        /api/company/{cid}/user/{uid}
     *     Backend address:    https://example.cloudfunctions.net/getUser
     *
     * Requests to the following request paths will call the backend at the
     * translated path:
     *
     *     Request path: /api/company/widgetworks/user/johndoe
     *     Translated:
     *     https://example.cloudfunctions.net/getUser?cid=widgetworks&uid=johndoe
     *
     *     Request path: /api/company/widgetworks/user/johndoe?timezone=EST
     *     Translated:
     *     https://example.cloudfunctions.net/getUser?timezone=EST&cid=widgetworks&uid=johndoe
     */
    BackendRule_PathTranslation[BackendRule_PathTranslation["CONSTANT_ADDRESS"] = 1] = "CONSTANT_ADDRESS";
    /**
     * APPEND_PATH_TO_ADDRESS - The request path will be appended to the backend address.
     *
     * # Examples
     *
     * Given the following operation config:
     *
     *     Method path:        /api/company/{cid}/user/{uid}
     *     Backend address:    https://example.appspot.com
     *
     * Requests to the following request paths will call the backend at the
     * translated path:
     *
     *     Request path: /api/company/widgetworks/user/johndoe
     *     Translated:
     *     https://example.appspot.com/api/company/widgetworks/user/johndoe
     *
     *     Request path: /api/company/widgetworks/user/johndoe?timezone=EST
     *     Translated:
     *     https://example.appspot.com/api/company/widgetworks/user/johndoe?timezone=EST
     */
    BackendRule_PathTranslation[BackendRule_PathTranslation["APPEND_PATH_TO_ADDRESS"] = 2] = "APPEND_PATH_TO_ADDRESS";
    BackendRule_PathTranslation[BackendRule_PathTranslation["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(BackendRule_PathTranslation || (BackendRule_PathTranslation = {}));
export const BackendRule_PathTranslationSDKType = BackendRule_PathTranslation;
export const BackendRule_PathTranslationAmino = BackendRule_PathTranslation;
export function backendRule_PathTranslationFromJSON(object) {
    switch (object) {
        case 0:
        case "PATH_TRANSLATION_UNSPECIFIED":
            return BackendRule_PathTranslation.PATH_TRANSLATION_UNSPECIFIED;
        case 1:
        case "CONSTANT_ADDRESS":
            return BackendRule_PathTranslation.CONSTANT_ADDRESS;
        case 2:
        case "APPEND_PATH_TO_ADDRESS":
            return BackendRule_PathTranslation.APPEND_PATH_TO_ADDRESS;
        case -1:
        case "UNRECOGNIZED":
        default:
            return BackendRule_PathTranslation.UNRECOGNIZED;
    }
}
export function backendRule_PathTranslationToJSON(object) {
    switch (object) {
        case BackendRule_PathTranslation.PATH_TRANSLATION_UNSPECIFIED:
            return "PATH_TRANSLATION_UNSPECIFIED";
        case BackendRule_PathTranslation.CONSTANT_ADDRESS:
            return "CONSTANT_ADDRESS";
        case BackendRule_PathTranslation.APPEND_PATH_TO_ADDRESS:
            return "APPEND_PATH_TO_ADDRESS";
        case BackendRule_PathTranslation.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseBackend() {
    return {
        rules: []
    };
}
export const Backend = {
    typeUrl: "/google.api.Backend",
    is(o) {
        return o && (o.$typeUrl === Backend.typeUrl || Array.isArray(o.rules) && (!o.rules.length || BackendRule.is(o.rules[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Backend.typeUrl || Array.isArray(o.rules) && (!o.rules.length || BackendRule.isSDK(o.rules[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Backend.typeUrl || Array.isArray(o.rules) && (!o.rules.length || BackendRule.isAmino(o.rules[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.rules) {
            BackendRule.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBackend();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.rules.push(BackendRule.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBackend();
        if (Array.isArray(object?.rules))
            obj.rules = object.rules.map((e) => BackendRule.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.rules) {
            obj.rules = message.rules.map(e => e ? BackendRule.toJSON(e) : undefined);
        }
        else {
            obj.rules = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBackend();
        message.rules = object.rules?.map(e => BackendRule.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            rules: Array.isArray(object?.rules) ? object.rules.map((e) => BackendRule.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            rules: Array.isArray(object?.rules) ? object.rules.map((e) => BackendRule.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.rules) {
            obj.rules = message.rules.map(e => e ? BackendRule.toSDK(e) : undefined);
        }
        else {
            obj.rules = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBackend();
        message.rules = object.rules?.map(e => BackendRule.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.rules) {
            obj.rules = message.rules.map(e => e ? BackendRule.toAmino(e) : undefined);
        }
        else {
            obj.rules = message.rules;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return Backend.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Backend.decode(message.value);
    },
    toProto(message) {
        return Backend.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.Backend",
            value: Backend.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BackendRule.registerTypeUrl();
    }
};
function createBaseBackendRule() {
    return {
        selector: "",
        address: "",
        deadline: 0,
        minDeadline: 0,
        operationDeadline: 0,
        pathTranslation: 0,
        jwtAudience: undefined,
        disableAuth: undefined,
        protocol: ""
    };
}
export const BackendRule = {
    typeUrl: "/google.api.BackendRule",
    is(o) {
        return o && (o.$typeUrl === BackendRule.typeUrl || typeof o.selector === "string" && typeof o.address === "string" && typeof o.deadline === "number" && typeof o.minDeadline === "number" && typeof o.operationDeadline === "number" && isSet(o.pathTranslation) && typeof o.protocol === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BackendRule.typeUrl || typeof o.selector === "string" && typeof o.address === "string" && typeof o.deadline === "number" && typeof o.min_deadline === "number" && typeof o.operation_deadline === "number" && isSet(o.path_translation) && typeof o.protocol === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BackendRule.typeUrl || typeof o.selector === "string" && typeof o.address === "string" && typeof o.deadline === "number" && typeof o.min_deadline === "number" && typeof o.operation_deadline === "number" && isSet(o.path_translation) && typeof o.protocol === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.selector !== undefined) {
            writer.uint32(10).string(message.selector);
        }
        if (message.address !== undefined) {
            writer.uint32(18).string(message.address);
        }
        if (message.deadline !== undefined) {
            writer.uint32(25).double(message.deadline);
        }
        if (message.minDeadline !== undefined) {
            writer.uint32(33).double(message.minDeadline);
        }
        if (message.operationDeadline !== undefined) {
            writer.uint32(41).double(message.operationDeadline);
        }
        if (message.pathTranslation !== 0) {
            writer.uint32(48).int32(message.pathTranslation);
        }
        if (message.jwtAudience !== undefined) {
            writer.uint32(58).string(message.jwtAudience);
        }
        if (message.disableAuth !== undefined) {
            writer.uint32(64).bool(message.disableAuth);
        }
        if (message.protocol !== undefined) {
            writer.uint32(74).string(message.protocol);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBackendRule();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.selector = reader.string();
                    break;
                case 2:
                    message.address = reader.string();
                    break;
                case 3:
                    message.deadline = reader.double();
                    break;
                case 4:
                    message.minDeadline = reader.double();
                    break;
                case 5:
                    message.operationDeadline = reader.double();
                    break;
                case 6:
                    message.pathTranslation = reader.int32();
                    break;
                case 7:
                    message.jwtAudience = reader.string();
                    break;
                case 8:
                    message.disableAuth = reader.bool();
                    break;
                case 9:
                    message.protocol = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBackendRule();
        if (isSet(object.selector))
            obj.selector = String(object.selector);
        if (isSet(object.address))
            obj.address = String(object.address);
        if (isSet(object.deadline))
            obj.deadline = Number(object.deadline);
        if (isSet(object.minDeadline))
            obj.minDeadline = Number(object.minDeadline);
        if (isSet(object.operationDeadline))
            obj.operationDeadline = Number(object.operationDeadline);
        if (isSet(object.pathTranslation))
            obj.pathTranslation = backendRule_PathTranslationFromJSON(object.pathTranslation);
        if (isSet(object.jwtAudience))
            obj.jwtAudience = String(object.jwtAudience);
        if (isSet(object.disableAuth))
            obj.disableAuth = Boolean(object.disableAuth);
        if (isSet(object.protocol))
            obj.protocol = String(object.protocol);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.selector !== undefined && (obj.selector = message.selector);
        message.address !== undefined && (obj.address = message.address);
        message.deadline !== undefined && (obj.deadline = message.deadline);
        message.minDeadline !== undefined && (obj.minDeadline = message.minDeadline);
        message.operationDeadline !== undefined && (obj.operationDeadline = message.operationDeadline);
        message.pathTranslation !== undefined && (obj.pathTranslation = backendRule_PathTranslationToJSON(message.pathTranslation));
        message.jwtAudience !== undefined && (obj.jwtAudience = message.jwtAudience);
        message.disableAuth !== undefined && (obj.disableAuth = message.disableAuth);
        message.protocol !== undefined && (obj.protocol = message.protocol);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBackendRule();
        message.selector = object.selector ?? "";
        message.address = object.address ?? "";
        message.deadline = object.deadline ?? 0;
        message.minDeadline = object.minDeadline ?? 0;
        message.operationDeadline = object.operationDeadline ?? 0;
        message.pathTranslation = object.pathTranslation ?? 0;
        message.jwtAudience = object.jwtAudience ?? undefined;
        message.disableAuth = object.disableAuth ?? undefined;
        message.protocol = object.protocol ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            selector: object?.selector,
            address: object?.address,
            deadline: object?.deadline,
            minDeadline: object?.min_deadline,
            operationDeadline: object?.operation_deadline,
            pathTranslation: isSet(object.path_translation) ? backendRule_PathTranslationFromJSON(object.path_translation) : -1,
            jwtAudience: object?.jwt_audience,
            disableAuth: object?.disable_auth,
            protocol: object?.protocol
        };
    },
    fromSDKJSON(object) {
        return {
            selector: isSet(object.selector) ? String(object.selector) : "",
            address: isSet(object.address) ? String(object.address) : "",
            deadline: isSet(object.deadline) ? Number(object.deadline) : 0,
            min_deadline: isSet(object.min_deadline) ? Number(object.min_deadline) : 0,
            operation_deadline: isSet(object.operation_deadline) ? Number(object.operation_deadline) : 0,
            path_translation: isSet(object.path_translation) ? backendRule_PathTranslationFromJSON(object.path_translation) : -1,
            jwt_audience: isSet(object.jwt_audience) ? String(object.jwt_audience) : undefined,
            disable_auth: isSet(object.disable_auth) ? Boolean(object.disable_auth) : undefined,
            protocol: isSet(object.protocol) ? String(object.protocol) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.selector = message.selector;
        obj.address = message.address;
        obj.deadline = message.deadline;
        obj.min_deadline = message.minDeadline;
        obj.operation_deadline = message.operationDeadline;
        message.pathTranslation !== undefined && (obj.path_translation = backendRule_PathTranslationToJSON(message.pathTranslation));
        obj.jwt_audience = message.jwtAudience;
        obj.disable_auth = message.disableAuth;
        obj.protocol = message.protocol;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBackendRule();
        if (object.selector !== undefined && object.selector !== null) {
            message.selector = object.selector;
        }
        if (object.address !== undefined && object.address !== null) {
            message.address = object.address;
        }
        if (object.deadline !== undefined && object.deadline !== null) {
            message.deadline = object.deadline;
        }
        if (object.min_deadline !== undefined && object.min_deadline !== null) {
            message.minDeadline = object.min_deadline;
        }
        if (object.operation_deadline !== undefined && object.operation_deadline !== null) {
            message.operationDeadline = object.operation_deadline;
        }
        if (object.path_translation !== undefined && object.path_translation !== null) {
            message.pathTranslation = object.path_translation;
        }
        if (object.jwt_audience !== undefined && object.jwt_audience !== null) {
            message.jwtAudience = object.jwt_audience;
        }
        if (object.disable_auth !== undefined && object.disable_auth !== null) {
            message.disableAuth = object.disable_auth;
        }
        if (object.protocol !== undefined && object.protocol !== null) {
            message.protocol = object.protocol;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.selector = message.selector === "" ? undefined : message.selector;
        obj.address = message.address === "" ? undefined : message.address;
        obj.deadline = message.deadline === 0 ? undefined : message.deadline;
        obj.min_deadline = message.minDeadline === 0 ? undefined : message.minDeadline;
        obj.operation_deadline = message.operationDeadline === 0 ? undefined : message.operationDeadline;
        obj.path_translation = message.pathTranslation === 0 ? undefined : message.pathTranslation;
        obj.jwt_audience = message.jwtAudience === null ? undefined : message.jwtAudience;
        obj.disable_auth = message.disableAuth === null ? undefined : message.disableAuth;
        obj.protocol = message.protocol === "" ? undefined : message.protocol;
        return obj;
    },
    fromAminoMsg(object) {
        return BackendRule.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BackendRule.decode(message.value);
    },
    toProto(message) {
        return BackendRule.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.BackendRule",
            value: BackendRule.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
