import { isSet } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
export const protobufPackage = "google.api";
/**
 * A description of the historical or future-looking state of the
 * resource pattern.
 */
export var ResourceDescriptor_History;
(function (ResourceDescriptor_History) {
    /** HISTORY_UNSPECIFIED - The "unset" value. */
    ResourceDescriptor_History[ResourceDescriptor_History["HISTORY_UNSPECIFIED"] = 0] = "HISTORY_UNSPECIFIED";
    /**
     * ORIGINALLY_SINGLE_PATTERN - The resource originally had one pattern and launched as such, and
     * additional patterns were added later.
     */
    ResourceDescriptor_History[ResourceDescriptor_History["ORIGINALLY_SINGLE_PATTERN"] = 1] = "ORIGINALLY_SINGLE_PATTERN";
    /**
     * FUTURE_MULTI_PATTERN - The resource has one pattern, but the API owner expects to add more
     * later. (This is the inverse of ORIGINALLY_SINGLE_PATTERN, and prevents
     * that from being necessary once there are multiple patterns.)
     */
    ResourceDescriptor_History[ResourceDescriptor_History["FUTURE_MULTI_PATTERN"] = 2] = "FUTURE_MULTI_PATTERN";
    ResourceDescriptor_History[ResourceDescriptor_History["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(ResourceDescriptor_History || (ResourceDescriptor_History = {}));
export const ResourceDescriptor_HistorySDKType = ResourceDescriptor_History;
export const ResourceDescriptor_HistoryAmino = ResourceDescriptor_History;
export function resourceDescriptor_HistoryFromJSON(object) {
    switch (object) {
        case 0:
        case "HISTORY_UNSPECIFIED":
            return ResourceDescriptor_History.HISTORY_UNSPECIFIED;
        case 1:
        case "ORIGINALLY_SINGLE_PATTERN":
            return ResourceDescriptor_History.ORIGINALLY_SINGLE_PATTERN;
        case 2:
        case "FUTURE_MULTI_PATTERN":
            return ResourceDescriptor_History.FUTURE_MULTI_PATTERN;
        case -1:
        case "UNRECOGNIZED":
        default:
            return ResourceDescriptor_History.UNRECOGNIZED;
    }
}
export function resourceDescriptor_HistoryToJSON(object) {
    switch (object) {
        case ResourceDescriptor_History.HISTORY_UNSPECIFIED:
            return "HISTORY_UNSPECIFIED";
        case ResourceDescriptor_History.ORIGINALLY_SINGLE_PATTERN:
            return "ORIGINALLY_SINGLE_PATTERN";
        case ResourceDescriptor_History.FUTURE_MULTI_PATTERN:
            return "FUTURE_MULTI_PATTERN";
        case ResourceDescriptor_History.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
/** A flag representing a specific style that a resource claims to conform to. */
export var ResourceDescriptor_Style;
(function (ResourceDescriptor_Style) {
    /** STYLE_UNSPECIFIED - The unspecified value. Do not use. */
    ResourceDescriptor_Style[ResourceDescriptor_Style["STYLE_UNSPECIFIED"] = 0] = "STYLE_UNSPECIFIED";
    /**
     * DECLARATIVE_FRIENDLY - This resource is intended to be "declarative-friendly".
     *
     * Declarative-friendly resources must be more strictly consistent, and
     * setting this to true communicates to tools that this resource should
     * adhere to declarative-friendly expectations.
     *
     * Note: This is used by the API linter (linter.aip.dev) to enable
     * additional checks.
     */
    ResourceDescriptor_Style[ResourceDescriptor_Style["DECLARATIVE_FRIENDLY"] = 1] = "DECLARATIVE_FRIENDLY";
    ResourceDescriptor_Style[ResourceDescriptor_Style["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(ResourceDescriptor_Style || (ResourceDescriptor_Style = {}));
export const ResourceDescriptor_StyleSDKType = ResourceDescriptor_Style;
export const ResourceDescriptor_StyleAmino = ResourceDescriptor_Style;
export function resourceDescriptor_StyleFromJSON(object) {
    switch (object) {
        case 0:
        case "STYLE_UNSPECIFIED":
            return ResourceDescriptor_Style.STYLE_UNSPECIFIED;
        case 1:
        case "DECLARATIVE_FRIENDLY":
            return ResourceDescriptor_Style.DECLARATIVE_FRIENDLY;
        case -1:
        case "UNRECOGNIZED":
        default:
            return ResourceDescriptor_Style.UNRECOGNIZED;
    }
}
export function resourceDescriptor_StyleToJSON(object) {
    switch (object) {
        case ResourceDescriptor_Style.STYLE_UNSPECIFIED:
            return "STYLE_UNSPECIFIED";
        case ResourceDescriptor_Style.DECLARATIVE_FRIENDLY:
            return "DECLARATIVE_FRIENDLY";
        case ResourceDescriptor_Style.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseResourceDescriptor() {
    return {
        type: "",
        pattern: [],
        nameField: "",
        history: 0,
        plural: "",
        singular: "",
        style: []
    };
}
export const ResourceDescriptor = {
    typeUrl: "/google.api.ResourceDescriptor",
    is(o) {
        return o && (o.$typeUrl === ResourceDescriptor.typeUrl || typeof o.type === "string" && Array.isArray(o.pattern) && (!o.pattern.length || typeof o.pattern[0] === "string") && typeof o.nameField === "string" && isSet(o.history) && typeof o.plural === "string" && typeof o.singular === "string" && Array.isArray(o.style));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ResourceDescriptor.typeUrl || typeof o.type === "string" && Array.isArray(o.pattern) && (!o.pattern.length || typeof o.pattern[0] === "string") && typeof o.name_field === "string" && isSet(o.history) && typeof o.plural === "string" && typeof o.singular === "string" && Array.isArray(o.style));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ResourceDescriptor.typeUrl || typeof o.type === "string" && Array.isArray(o.pattern) && (!o.pattern.length || typeof o.pattern[0] === "string") && typeof o.name_field === "string" && isSet(o.history) && typeof o.plural === "string" && typeof o.singular === "string" && Array.isArray(o.style));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.type !== undefined) {
            writer.uint32(10).string(message.type);
        }
        for (const v of message.pattern) {
            writer.uint32(18).string(v);
        }
        if (message.nameField !== undefined) {
            writer.uint32(26).string(message.nameField);
        }
        if (message.history !== 0) {
            writer.uint32(32).int32(message.history);
        }
        if (message.plural !== undefined) {
            writer.uint32(42).string(message.plural);
        }
        if (message.singular !== undefined) {
            writer.uint32(50).string(message.singular);
        }
        writer.uint32(82).fork();
        for (const v of message.style) {
            writer.int32(v);
        }
        writer.ldelim();
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseResourceDescriptor();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.type = reader.string();
                    break;
                case 2:
                    message.pattern.push(reader.string());
                    break;
                case 3:
                    message.nameField = reader.string();
                    break;
                case 4:
                    message.history = reader.int32();
                    break;
                case 5:
                    message.plural = reader.string();
                    break;
                case 6:
                    message.singular = reader.string();
                    break;
                case 10:
                    if ((tag & 7) === 2) {
                        const end2 = reader.uint32() + reader.pos;
                        while (reader.pos < end2) {
                            message.style.push(reader.int32());
                        }
                    }
                    else {
                        message.style.push(reader.int32());
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseResourceDescriptor();
        if (isSet(object.type))
            obj.type = String(object.type);
        if (Array.isArray(object?.pattern))
            obj.pattern = object.pattern.map((e) => String(e));
        if (isSet(object.nameField))
            obj.nameField = String(object.nameField);
        if (isSet(object.history))
            obj.history = resourceDescriptor_HistoryFromJSON(object.history);
        if (isSet(object.plural))
            obj.plural = String(object.plural);
        if (isSet(object.singular))
            obj.singular = String(object.singular);
        if (Array.isArray(object?.style))
            obj.style = object.style.map((e) => resourceDescriptor_StyleFromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.type !== undefined && (obj.type = message.type);
        if (message.pattern) {
            obj.pattern = message.pattern.map(e => e);
        }
        else {
            obj.pattern = [];
        }
        message.nameField !== undefined && (obj.nameField = message.nameField);
        message.history !== undefined && (obj.history = resourceDescriptor_HistoryToJSON(message.history));
        message.plural !== undefined && (obj.plural = message.plural);
        message.singular !== undefined && (obj.singular = message.singular);
        if (message.style) {
            obj.style = message.style.map(e => resourceDescriptor_StyleToJSON(e));
        }
        else {
            obj.style = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseResourceDescriptor();
        message.type = object.type ?? "";
        message.pattern = object.pattern?.map(e => e) || [];
        message.nameField = object.nameField ?? "";
        message.history = object.history ?? 0;
        message.plural = object.plural ?? "";
        message.singular = object.singular ?? "";
        message.style = object.style?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            type: object?.type,
            pattern: Array.isArray(object?.pattern) ? object.pattern.map((e) => e) : [],
            nameField: object?.name_field,
            history: isSet(object.history) ? resourceDescriptor_HistoryFromJSON(object.history) : -1,
            plural: object?.plural,
            singular: object?.singular,
            style: Array.isArray(object?.style) ? object.style.map((e) => resourceDescriptor_StyleFromJSON(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            type: isSet(object.type) ? String(object.type) : "",
            pattern: Array.isArray(object?.pattern) ? object.pattern.map((e) => String(e)) : [],
            name_field: isSet(object.name_field) ? String(object.name_field) : "",
            history: isSet(object.history) ? resourceDescriptor_HistoryFromJSON(object.history) : -1,
            plural: isSet(object.plural) ? String(object.plural) : "",
            singular: isSet(object.singular) ? String(object.singular) : "",
            style: Array.isArray(object?.style) ? object.style.map((e) => resourceDescriptor_StyleFromJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.type = message.type;
        if (message.pattern) {
            obj.pattern = message.pattern.map(e => e);
        }
        else {
            obj.pattern = [];
        }
        obj.name_field = message.nameField;
        message.history !== undefined && (obj.history = resourceDescriptor_HistoryToJSON(message.history));
        obj.plural = message.plural;
        obj.singular = message.singular;
        if (message.style) {
            obj.style = message.style.map(e => resourceDescriptor_StyleToJSON(e));
        }
        else {
            obj.style = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseResourceDescriptor();
        if (object.type !== undefined && object.type !== null) {
            message.type = object.type;
        }
        message.pattern = object.pattern?.map(e => e) || [];
        if (object.name_field !== undefined && object.name_field !== null) {
            message.nameField = object.name_field;
        }
        if (object.history !== undefined && object.history !== null) {
            message.history = object.history;
        }
        if (object.plural !== undefined && object.plural !== null) {
            message.plural = object.plural;
        }
        if (object.singular !== undefined && object.singular !== null) {
            message.singular = object.singular;
        }
        message.style = object.style?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.type = message.type === "" ? undefined : message.type;
        if (message.pattern) {
            obj.pattern = message.pattern.map(e => e);
        }
        else {
            obj.pattern = message.pattern;
        }
        obj.name_field = message.nameField === "" ? undefined : message.nameField;
        obj.history = message.history === 0 ? undefined : message.history;
        obj.plural = message.plural === "" ? undefined : message.plural;
        obj.singular = message.singular === "" ? undefined : message.singular;
        if (message.style) {
            obj.style = message.style.map(e => e);
        }
        else {
            obj.style = message.style;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ResourceDescriptor.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ResourceDescriptor.decode(message.value);
    },
    toProto(message) {
        return ResourceDescriptor.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.ResourceDescriptor",
            value: ResourceDescriptor.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseResourceReference() {
    return {
        type: "",
        childType: ""
    };
}
export const ResourceReference = {
    typeUrl: "/google.api.ResourceReference",
    is(o) {
        return o && (o.$typeUrl === ResourceReference.typeUrl || typeof o.type === "string" && typeof o.childType === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ResourceReference.typeUrl || typeof o.type === "string" && typeof o.child_type === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ResourceReference.typeUrl || typeof o.type === "string" && typeof o.child_type === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.type !== undefined) {
            writer.uint32(10).string(message.type);
        }
        if (message.childType !== undefined) {
            writer.uint32(18).string(message.childType);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseResourceReference();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.type = reader.string();
                    break;
                case 2:
                    message.childType = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseResourceReference();
        if (isSet(object.type))
            obj.type = String(object.type);
        if (isSet(object.childType))
            obj.childType = String(object.childType);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.type !== undefined && (obj.type = message.type);
        message.childType !== undefined && (obj.childType = message.childType);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseResourceReference();
        message.type = object.type ?? "";
        message.childType = object.childType ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            type: object?.type,
            childType: object?.child_type
        };
    },
    fromSDKJSON(object) {
        return {
            type: isSet(object.type) ? String(object.type) : "",
            child_type: isSet(object.child_type) ? String(object.child_type) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.type = message.type;
        obj.child_type = message.childType;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseResourceReference();
        if (object.type !== undefined && object.type !== null) {
            message.type = object.type;
        }
        if (object.child_type !== undefined && object.child_type !== null) {
            message.childType = object.child_type;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.type = message.type === "" ? undefined : message.type;
        obj.child_type = message.childType === "" ? undefined : message.childType;
        return obj;
    },
    fromAminoMsg(object) {
        return ResourceReference.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ResourceReference.decode(message.value);
    },
    toProto(message) {
        return ResourceReference.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.ResourceReference",
            value: ResourceReference.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
