import { Timestamp } from "../../../protobuf/timestamp";
import { MetricValueSet } from "./metric_value";
import { LogEntry } from "./log_entry";
import { Any } from "../../../protobuf/any";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { isSet, toTimestamp, fromTimestamp, isObject } from "../../../../helpers";
export const protobufPackage = "google.api.servicecontrol.v1";
/** Defines the importance of the data contained in the operation. */
export var Operation_Importance;
(function (Operation_Importance) {
    /**
     * LOW - Allows data caching, batching, and aggregation. It provides
     * higher performance with higher data loss risk.
     */
    Operation_Importance[Operation_Importance["LOW"] = 0] = "LOW";
    /**
     * HIGH - Disables data aggregation to minimize data loss. It is for operations
     * that contains significant monetary value or audit trail. This feature
     * only applies to the client libraries.
     */
    Operation_Importance[Operation_Importance["HIGH"] = 1] = "HIGH";
    Operation_Importance[Operation_Importance["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Operation_Importance || (Operation_Importance = {}));
export const Operation_ImportanceSDKType = Operation_Importance;
export const Operation_ImportanceAmino = Operation_Importance;
export function operation_ImportanceFromJSON(object) {
    switch (object) {
        case 0:
        case "LOW":
            return Operation_Importance.LOW;
        case 1:
        case "HIGH":
            return Operation_Importance.HIGH;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Operation_Importance.UNRECOGNIZED;
    }
}
export function operation_ImportanceToJSON(object) {
    switch (object) {
        case Operation_Importance.LOW:
            return "LOW";
        case Operation_Importance.HIGH:
            return "HIGH";
        case Operation_Importance.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseOperation_LabelsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const Operation_LabelsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseOperation_LabelsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseOperation_LabelsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseOperation_LabelsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseOperation_LabelsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return Operation_LabelsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Operation_LabelsEntry.decode(message.value);
    },
    toProto(message) {
        return Operation_LabelsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseOperation() {
    return {
        operationId: "",
        operationName: "",
        consumerId: "",
        startTime: undefined,
        endTime: undefined,
        labels: {},
        metricValueSets: [],
        logEntries: [],
        importance: 0,
        extensions: []
    };
}
export const Operation = {
    typeUrl: "/google.api.servicecontrol.v1.Operation",
    is(o) {
        return o && (o.$typeUrl === Operation.typeUrl || typeof o.operationId === "string" && typeof o.operationName === "string" && typeof o.consumerId === "string" && isSet(o.labels) && Array.isArray(o.metricValueSets) && (!o.metricValueSets.length || MetricValueSet.is(o.metricValueSets[0])) && Array.isArray(o.logEntries) && (!o.logEntries.length || LogEntry.is(o.logEntries[0])) && isSet(o.importance) && Array.isArray(o.extensions) && (!o.extensions.length || Any.is(o.extensions[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Operation.typeUrl || typeof o.operation_id === "string" && typeof o.operation_name === "string" && typeof o.consumer_id === "string" && isSet(o.labels) && Array.isArray(o.metric_value_sets) && (!o.metric_value_sets.length || MetricValueSet.isSDK(o.metric_value_sets[0])) && Array.isArray(o.log_entries) && (!o.log_entries.length || LogEntry.isSDK(o.log_entries[0])) && isSet(o.importance) && Array.isArray(o.extensions) && (!o.extensions.length || Any.isSDK(o.extensions[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Operation.typeUrl || typeof o.operation_id === "string" && typeof o.operation_name === "string" && typeof o.consumer_id === "string" && isSet(o.labels) && Array.isArray(o.metric_value_sets) && (!o.metric_value_sets.length || MetricValueSet.isAmino(o.metric_value_sets[0])) && Array.isArray(o.log_entries) && (!o.log_entries.length || LogEntry.isAmino(o.log_entries[0])) && isSet(o.importance) && Array.isArray(o.extensions) && (!o.extensions.length || Any.isAmino(o.extensions[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.operationId !== undefined) {
            writer.uint32(10).string(message.operationId);
        }
        if (message.operationName !== undefined) {
            writer.uint32(18).string(message.operationName);
        }
        if (message.consumerId !== undefined) {
            writer.uint32(26).string(message.consumerId);
        }
        if (message.startTime !== undefined) {
            Timestamp.encode(toTimestamp(message.startTime), writer.uint32(34).fork()).ldelim();
        }
        if (message.endTime !== undefined) {
            Timestamp.encode(toTimestamp(message.endTime), writer.uint32(42).fork()).ldelim();
        }
        Object.entries(message.labels).forEach(([key, value]) => {
            Operation_LabelsEntry.encode({
                key: key,
                value
            }, writer.uint32(50).fork()).ldelim();
        });
        for (const v of message.metricValueSets) {
            MetricValueSet.encode(v, writer.uint32(58).fork()).ldelim();
        }
        for (const v of message.logEntries) {
            LogEntry.encode(v, writer.uint32(66).fork()).ldelim();
        }
        if (message.importance !== 0) {
            writer.uint32(88).int32(message.importance);
        }
        for (const v of message.extensions) {
            Any.encode(v, writer.uint32(130).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseOperation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.operationId = reader.string();
                    break;
                case 2:
                    message.operationName = reader.string();
                    break;
                case 3:
                    message.consumerId = reader.string();
                    break;
                case 4:
                    message.startTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.endTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 6:
                    const entry6 = Operation_LabelsEntry.decode(reader, reader.uint32());
                    if (entry6.value !== undefined) {
                        message.labels[entry6.key] = entry6.value;
                    }
                    break;
                case 7:
                    message.metricValueSets.push(MetricValueSet.decode(reader, reader.uint32()));
                    break;
                case 8:
                    message.logEntries.push(LogEntry.decode(reader, reader.uint32()));
                    break;
                case 11:
                    message.importance = reader.int32();
                    break;
                case 16:
                    message.extensions.push(Any.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseOperation();
        if (isSet(object.operationId))
            obj.operationId = String(object.operationId);
        if (isSet(object.operationName))
            obj.operationName = String(object.operationName);
        if (isSet(object.consumerId))
            obj.consumerId = String(object.consumerId);
        if (isSet(object.startTime))
            obj.startTime = new Date(object.startTime);
        if (isSet(object.endTime))
            obj.endTime = new Date(object.endTime);
        if (isObject(object.labels))
            obj.labels = Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (Array.isArray(object?.metricValueSets))
            obj.metricValueSets = object.metricValueSets.map((e) => MetricValueSet.fromJSON(e));
        if (Array.isArray(object?.logEntries))
            obj.logEntries = object.logEntries.map((e) => LogEntry.fromJSON(e));
        if (isSet(object.importance))
            obj.importance = operation_ImportanceFromJSON(object.importance);
        if (Array.isArray(object?.extensions))
            obj.extensions = object.extensions.map((e) => Any.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.operationId !== undefined && (obj.operationId = message.operationId);
        message.operationName !== undefined && (obj.operationName = message.operationName);
        message.consumerId !== undefined && (obj.consumerId = message.consumerId);
        message.startTime !== undefined && (obj.startTime = message.startTime.toISOString());
        message.endTime !== undefined && (obj.endTime = message.endTime.toISOString());
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.metricValueSets) {
            obj.metricValueSets = message.metricValueSets.map(e => e ? MetricValueSet.toJSON(e) : undefined);
        }
        else {
            obj.metricValueSets = [];
        }
        if (message.logEntries) {
            obj.logEntries = message.logEntries.map(e => e ? LogEntry.toJSON(e) : undefined);
        }
        else {
            obj.logEntries = [];
        }
        message.importance !== undefined && (obj.importance = operation_ImportanceToJSON(message.importance));
        if (message.extensions) {
            obj.extensions = message.extensions.map(e => e ? Any.toJSON(e) : undefined);
        }
        else {
            obj.extensions = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseOperation();
        message.operationId = object.operationId ?? "";
        message.operationName = object.operationName ?? "";
        message.consumerId = object.consumerId ?? "";
        message.startTime = object.startTime ?? undefined;
        message.endTime = object.endTime ?? undefined;
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.metricValueSets = object.metricValueSets?.map(e => MetricValueSet.fromPartial(e)) || [];
        message.logEntries = object.logEntries?.map(e => LogEntry.fromPartial(e)) || [];
        message.importance = object.importance ?? 0;
        message.extensions = object.extensions?.map(e => Any.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            operationId: object?.operation_id,
            operationName: object?.operation_name,
            consumerId: object?.consumer_id,
            startTime: object.start_time ?? undefined,
            endTime: object.end_time ?? undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metricValueSets: Array.isArray(object?.metric_value_sets) ? object.metric_value_sets.map((e) => MetricValueSet.fromSDK(e)) : [],
            logEntries: Array.isArray(object?.log_entries) ? object.log_entries.map((e) => LogEntry.fromSDK(e)) : [],
            importance: isSet(object.importance) ? operation_ImportanceFromJSON(object.importance) : -1,
            extensions: Array.isArray(object?.extensions) ? object.extensions.map((e) => Any.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            operation_id: isSet(object.operation_id) ? String(object.operation_id) : "",
            operation_name: isSet(object.operation_name) ? String(object.operation_name) : "",
            consumer_id: isSet(object.consumer_id) ? String(object.consumer_id) : "",
            start_time: isSet(object.start_time) ? new Date(object.start_time) : undefined,
            end_time: isSet(object.end_time) ? new Date(object.end_time) : undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metric_value_sets: Array.isArray(object?.metric_value_sets) ? object.metric_value_sets.map((e) => MetricValueSet.fromSDKJSON(e)) : [],
            log_entries: Array.isArray(object?.log_entries) ? object.log_entries.map((e) => LogEntry.fromSDKJSON(e)) : [],
            importance: isSet(object.importance) ? operation_ImportanceFromJSON(object.importance) : -1,
            extensions: Array.isArray(object?.extensions) ? object.extensions.map((e) => Any.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.operation_id = message.operationId;
        obj.operation_name = message.operationName;
        obj.consumer_id = message.consumerId;
        message.startTime !== undefined && (obj.start_time = message.startTime ?? undefined);
        message.endTime !== undefined && (obj.end_time = message.endTime ?? undefined);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.metricValueSets) {
            obj.metric_value_sets = message.metricValueSets.map(e => e ? MetricValueSet.toSDK(e) : undefined);
        }
        else {
            obj.metric_value_sets = [];
        }
        if (message.logEntries) {
            obj.log_entries = message.logEntries.map(e => e ? LogEntry.toSDK(e) : undefined);
        }
        else {
            obj.log_entries = [];
        }
        message.importance !== undefined && (obj.importance = operation_ImportanceToJSON(message.importance));
        if (message.extensions) {
            obj.extensions = message.extensions.map(e => e ? Any.toSDK(e) : undefined);
        }
        else {
            obj.extensions = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseOperation();
        if (object.operation_id !== undefined && object.operation_id !== null) {
            message.operationId = object.operation_id;
        }
        if (object.operation_name !== undefined && object.operation_name !== null) {
            message.operationName = object.operation_name;
        }
        if (object.consumer_id !== undefined && object.consumer_id !== null) {
            message.consumerId = object.consumer_id;
        }
        if (object.start_time !== undefined && object.start_time !== null) {
            message.startTime = fromTimestamp(Timestamp.fromAmino(object.start_time));
        }
        if (object.end_time !== undefined && object.end_time !== null) {
            message.endTime = fromTimestamp(Timestamp.fromAmino(object.end_time));
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.metricValueSets = object.metric_value_sets?.map(e => MetricValueSet.fromAmino(e)) || [];
        message.logEntries = object.log_entries?.map(e => LogEntry.fromAmino(e)) || [];
        if (object.importance !== undefined && object.importance !== null) {
            message.importance = object.importance;
        }
        message.extensions = object.extensions?.map(e => Any.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.operation_id = message.operationId === "" ? undefined : message.operationId;
        obj.operation_name = message.operationName === "" ? undefined : message.operationName;
        obj.consumer_id = message.consumerId === "" ? undefined : message.consumerId;
        obj.start_time = message.startTime ? Timestamp.toAmino(toTimestamp(message.startTime)) : undefined;
        obj.end_time = message.endTime ? Timestamp.toAmino(toTimestamp(message.endTime)) : undefined;
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.metricValueSets) {
            obj.metric_value_sets = message.metricValueSets.map(e => e ? MetricValueSet.toAmino(e) : undefined);
        }
        else {
            obj.metric_value_sets = message.metricValueSets;
        }
        if (message.logEntries) {
            obj.log_entries = message.logEntries.map(e => e ? LogEntry.toAmino(e) : undefined);
        }
        else {
            obj.log_entries = message.logEntries;
        }
        obj.importance = message.importance === 0 ? undefined : message.importance;
        if (message.extensions) {
            obj.extensions = message.extensions.map(e => e ? Any.toAmino(e) : undefined);
        }
        else {
            obj.extensions = message.extensions;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return Operation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Operation.decode(message.value);
    },
    toProto(message) {
        return Operation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.Operation",
            value: Operation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
