import { MetricValueSet } from "./metric_value";
import { Status } from "../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { isSet, isObject } from "../../../../helpers";
export const protobufPackage = "google.api.servicecontrol.v1";
/** Supported quota modes. */
export var QuotaOperation_QuotaMode;
(function (QuotaOperation_QuotaMode) {
    /** UNSPECIFIED - Guard against implicit default. Must not be used. */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * NORMAL - For AllocateQuota request, allocates quota for the amount specified in
     * the service configuration or specified using the quota metrics. If the
     * amount is higher than the available quota, allocation error will be
     * returned and no quota will be allocated.
     * If multiple quotas are part of the request, and one fails, none of the
     * quotas are allocated or released.
     */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["NORMAL"] = 1] = "NORMAL";
    /**
     * BEST_EFFORT - The operation allocates quota for the amount specified in the service
     * configuration or specified using the quota metrics. If the amount is
     * higher than the available quota, request does not fail but all available
     * quota will be allocated.
     * For rate quota, BEST_EFFORT will continue to deduct from other groups
     * even if one does not have enough quota. For allocation, it will find the
     * minimum available amount across all groups and deduct that amount from
     * all the affected groups.
     */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["BEST_EFFORT"] = 2] = "BEST_EFFORT";
    /**
     * CHECK_ONLY - For AllocateQuota request, only checks if there is enough quota
     * available and does not change the available quota. No lock is placed on
     * the available quota either.
     */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["CHECK_ONLY"] = 3] = "CHECK_ONLY";
    /**
     * QUERY_ONLY - Unimplemented. When used in AllocateQuotaRequest, this returns the
     * effective quota limit(s) in the response, and no quota check will be
     * performed. Not supported for other requests, and even for
     * AllocateQuotaRequest, this is currently supported only for allowlisted
     * services.
     */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["QUERY_ONLY"] = 4] = "QUERY_ONLY";
    /**
     * ADJUST_ONLY - The operation allocates quota for the amount specified in the service
     * configuration or specified using the quota metrics. If the requested
     * amount is higher than the available quota, request does not fail and
     * remaining quota would become negative (going over the limit).
     * Not supported for Rate Quota.
     */
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["ADJUST_ONLY"] = 5] = "ADJUST_ONLY";
    QuotaOperation_QuotaMode[QuotaOperation_QuotaMode["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(QuotaOperation_QuotaMode || (QuotaOperation_QuotaMode = {}));
export const QuotaOperation_QuotaModeSDKType = QuotaOperation_QuotaMode;
export const QuotaOperation_QuotaModeAmino = QuotaOperation_QuotaMode;
export function quotaOperation_QuotaModeFromJSON(object) {
    switch (object) {
        case 0:
        case "UNSPECIFIED":
            return QuotaOperation_QuotaMode.UNSPECIFIED;
        case 1:
        case "NORMAL":
            return QuotaOperation_QuotaMode.NORMAL;
        case 2:
        case "BEST_EFFORT":
            return QuotaOperation_QuotaMode.BEST_EFFORT;
        case 3:
        case "CHECK_ONLY":
            return QuotaOperation_QuotaMode.CHECK_ONLY;
        case 4:
        case "QUERY_ONLY":
            return QuotaOperation_QuotaMode.QUERY_ONLY;
        case 5:
        case "ADJUST_ONLY":
            return QuotaOperation_QuotaMode.ADJUST_ONLY;
        case -1:
        case "UNRECOGNIZED":
        default:
            return QuotaOperation_QuotaMode.UNRECOGNIZED;
    }
}
export function quotaOperation_QuotaModeToJSON(object) {
    switch (object) {
        case QuotaOperation_QuotaMode.UNSPECIFIED:
            return "UNSPECIFIED";
        case QuotaOperation_QuotaMode.NORMAL:
            return "NORMAL";
        case QuotaOperation_QuotaMode.BEST_EFFORT:
            return "BEST_EFFORT";
        case QuotaOperation_QuotaMode.CHECK_ONLY:
            return "CHECK_ONLY";
        case QuotaOperation_QuotaMode.QUERY_ONLY:
            return "QUERY_ONLY";
        case QuotaOperation_QuotaMode.ADJUST_ONLY:
            return "ADJUST_ONLY";
        case QuotaOperation_QuotaMode.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
/**
 * Error codes related to project config validations are deprecated since the
 * quota controller methods do not perform these validations. Instead services
 * have to call the Check method, without quota_properties field, to perform
 * these validations before calling the quota controller methods. These
 * methods check only for project deletion to be wipe out compliant.
 */
export var QuotaError_Code;
(function (QuotaError_Code) {
    /** UNSPECIFIED - This is never used. */
    QuotaError_Code[QuotaError_Code["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * RESOURCE_EXHAUSTED - Quota allocation failed.
     * Same as [google.rpc.Code.RESOURCE_EXHAUSTED][google.rpc.Code.RESOURCE_EXHAUSTED].
     */
    QuotaError_Code[QuotaError_Code["RESOURCE_EXHAUSTED"] = 8] = "RESOURCE_EXHAUSTED";
    /**
     * BILLING_NOT_ACTIVE - Consumer cannot access the service because the service requires active
     * billing.
     */
    QuotaError_Code[QuotaError_Code["BILLING_NOT_ACTIVE"] = 107] = "BILLING_NOT_ACTIVE";
    /** PROJECT_DELETED - Consumer's project has been marked as deleted (soft deletion). */
    QuotaError_Code[QuotaError_Code["PROJECT_DELETED"] = 108] = "PROJECT_DELETED";
    /** API_KEY_INVALID - Specified API key is invalid. */
    QuotaError_Code[QuotaError_Code["API_KEY_INVALID"] = 105] = "API_KEY_INVALID";
    /** API_KEY_EXPIRED - Specified API Key has expired. */
    QuotaError_Code[QuotaError_Code["API_KEY_EXPIRED"] = 112] = "API_KEY_EXPIRED";
    QuotaError_Code[QuotaError_Code["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(QuotaError_Code || (QuotaError_Code = {}));
export const QuotaError_CodeSDKType = QuotaError_Code;
export const QuotaError_CodeAmino = QuotaError_Code;
export function quotaError_CodeFromJSON(object) {
    switch (object) {
        case 0:
        case "UNSPECIFIED":
            return QuotaError_Code.UNSPECIFIED;
        case 8:
        case "RESOURCE_EXHAUSTED":
            return QuotaError_Code.RESOURCE_EXHAUSTED;
        case 107:
        case "BILLING_NOT_ACTIVE":
            return QuotaError_Code.BILLING_NOT_ACTIVE;
        case 108:
        case "PROJECT_DELETED":
            return QuotaError_Code.PROJECT_DELETED;
        case 105:
        case "API_KEY_INVALID":
            return QuotaError_Code.API_KEY_INVALID;
        case 112:
        case "API_KEY_EXPIRED":
            return QuotaError_Code.API_KEY_EXPIRED;
        case -1:
        case "UNRECOGNIZED":
        default:
            return QuotaError_Code.UNRECOGNIZED;
    }
}
export function quotaError_CodeToJSON(object) {
    switch (object) {
        case QuotaError_Code.UNSPECIFIED:
            return "UNSPECIFIED";
        case QuotaError_Code.RESOURCE_EXHAUSTED:
            return "RESOURCE_EXHAUSTED";
        case QuotaError_Code.BILLING_NOT_ACTIVE:
            return "BILLING_NOT_ACTIVE";
        case QuotaError_Code.PROJECT_DELETED:
            return "PROJECT_DELETED";
        case QuotaError_Code.API_KEY_INVALID:
            return "API_KEY_INVALID";
        case QuotaError_Code.API_KEY_EXPIRED:
            return "API_KEY_EXPIRED";
        case QuotaError_Code.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseAllocateQuotaRequest() {
    return {
        serviceName: "",
        allocateOperation: undefined,
        serviceConfigId: ""
    };
}
export const AllocateQuotaRequest = {
    typeUrl: "/google.api.servicecontrol.v1.AllocateQuotaRequest",
    is(o) {
        return o && (o.$typeUrl === AllocateQuotaRequest.typeUrl || typeof o.serviceName === "string" && typeof o.serviceConfigId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === AllocateQuotaRequest.typeUrl || typeof o.service_name === "string" && typeof o.service_config_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === AllocateQuotaRequest.typeUrl || typeof o.service_name === "string" && typeof o.service_config_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.serviceName !== undefined) {
            writer.uint32(10).string(message.serviceName);
        }
        if (message.allocateOperation !== undefined) {
            QuotaOperation.encode(message.allocateOperation, writer.uint32(18).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(34).string(message.serviceConfigId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAllocateQuotaRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.serviceName = reader.string();
                    break;
                case 2:
                    message.allocateOperation = QuotaOperation.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.serviceConfigId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAllocateQuotaRequest();
        if (isSet(object.serviceName))
            obj.serviceName = String(object.serviceName);
        if (isSet(object.allocateOperation))
            obj.allocateOperation = QuotaOperation.fromJSON(object.allocateOperation);
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.serviceName !== undefined && (obj.serviceName = message.serviceName);
        message.allocateOperation !== undefined && (obj.allocateOperation = message.allocateOperation ? QuotaOperation.toJSON(message.allocateOperation) : undefined);
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAllocateQuotaRequest();
        message.serviceName = object.serviceName ?? "";
        if (object.allocateOperation !== undefined && object.allocateOperation !== null) {
            message.allocateOperation = QuotaOperation.fromPartial(object.allocateOperation);
        }
        message.serviceConfigId = object.serviceConfigId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            serviceName: object?.service_name,
            allocateOperation: object.allocate_operation ? QuotaOperation.fromSDK(object.allocate_operation) : undefined,
            serviceConfigId: object?.service_config_id
        };
    },
    fromSDKJSON(object) {
        return {
            service_name: isSet(object.service_name) ? String(object.service_name) : "",
            allocate_operation: isSet(object.allocate_operation) ? QuotaOperation.fromSDKJSON(object.allocate_operation) : undefined,
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.service_name = message.serviceName;
        message.allocateOperation !== undefined && (obj.allocate_operation = message.allocateOperation ? QuotaOperation.toSDK(message.allocateOperation) : undefined);
        obj.service_config_id = message.serviceConfigId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAllocateQuotaRequest();
        if (object.service_name !== undefined && object.service_name !== null) {
            message.serviceName = object.service_name;
        }
        if (object.allocate_operation !== undefined && object.allocate_operation !== null) {
            message.allocateOperation = QuotaOperation.fromAmino(object.allocate_operation);
        }
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service_name = message.serviceName === "" ? undefined : message.serviceName;
        obj.allocate_operation = message.allocateOperation ? QuotaOperation.toAmino(message.allocateOperation) : undefined;
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        return obj;
    },
    fromAminoMsg(object) {
        return AllocateQuotaRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return AllocateQuotaRequest.decode(message.value);
    },
    toProto(message) {
        return AllocateQuotaRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.AllocateQuotaRequest",
            value: AllocateQuotaRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaOperation.registerTypeUrl();
    }
};
function createBaseQuotaOperation_LabelsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const QuotaOperation_LabelsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaOperation_LabelsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaOperation_LabelsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaOperation_LabelsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaOperation_LabelsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaOperation_LabelsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaOperation_LabelsEntry.decode(message.value);
    },
    toProto(message) {
        return QuotaOperation_LabelsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseQuotaOperation() {
    return {
        operationId: "",
        methodName: "",
        consumerId: "",
        labels: {},
        quotaMetrics: [],
        quotaMode: 0
    };
}
export const QuotaOperation = {
    typeUrl: "/google.api.servicecontrol.v1.QuotaOperation",
    is(o) {
        return o && (o.$typeUrl === QuotaOperation.typeUrl || typeof o.operationId === "string" && typeof o.methodName === "string" && typeof o.consumerId === "string" && isSet(o.labels) && Array.isArray(o.quotaMetrics) && (!o.quotaMetrics.length || MetricValueSet.is(o.quotaMetrics[0])) && isSet(o.quotaMode));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaOperation.typeUrl || typeof o.operation_id === "string" && typeof o.method_name === "string" && typeof o.consumer_id === "string" && isSet(o.labels) && Array.isArray(o.quota_metrics) && (!o.quota_metrics.length || MetricValueSet.isSDK(o.quota_metrics[0])) && isSet(o.quota_mode));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaOperation.typeUrl || typeof o.operation_id === "string" && typeof o.method_name === "string" && typeof o.consumer_id === "string" && isSet(o.labels) && Array.isArray(o.quota_metrics) && (!o.quota_metrics.length || MetricValueSet.isAmino(o.quota_metrics[0])) && isSet(o.quota_mode));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.operationId !== undefined) {
            writer.uint32(10).string(message.operationId);
        }
        if (message.methodName !== undefined) {
            writer.uint32(18).string(message.methodName);
        }
        if (message.consumerId !== undefined) {
            writer.uint32(26).string(message.consumerId);
        }
        Object.entries(message.labels).forEach(([key, value]) => {
            QuotaOperation_LabelsEntry.encode({
                key: key,
                value
            }, writer.uint32(34).fork()).ldelim();
        });
        for (const v of message.quotaMetrics) {
            MetricValueSet.encode(v, writer.uint32(42).fork()).ldelim();
        }
        if (message.quotaMode !== 0) {
            writer.uint32(48).int32(message.quotaMode);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaOperation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.operationId = reader.string();
                    break;
                case 2:
                    message.methodName = reader.string();
                    break;
                case 3:
                    message.consumerId = reader.string();
                    break;
                case 4:
                    const entry4 = QuotaOperation_LabelsEntry.decode(reader, reader.uint32());
                    if (entry4.value !== undefined) {
                        message.labels[entry4.key] = entry4.value;
                    }
                    break;
                case 5:
                    message.quotaMetrics.push(MetricValueSet.decode(reader, reader.uint32()));
                    break;
                case 6:
                    message.quotaMode = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaOperation();
        if (isSet(object.operationId))
            obj.operationId = String(object.operationId);
        if (isSet(object.methodName))
            obj.methodName = String(object.methodName);
        if (isSet(object.consumerId))
            obj.consumerId = String(object.consumerId);
        if (isObject(object.labels))
            obj.labels = Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (Array.isArray(object?.quotaMetrics))
            obj.quotaMetrics = object.quotaMetrics.map((e) => MetricValueSet.fromJSON(e));
        if (isSet(object.quotaMode))
            obj.quotaMode = quotaOperation_QuotaModeFromJSON(object.quotaMode);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.operationId !== undefined && (obj.operationId = message.operationId);
        message.methodName !== undefined && (obj.methodName = message.methodName);
        message.consumerId !== undefined && (obj.consumerId = message.consumerId);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.quotaMetrics) {
            obj.quotaMetrics = message.quotaMetrics.map(e => e ? MetricValueSet.toJSON(e) : undefined);
        }
        else {
            obj.quotaMetrics = [];
        }
        message.quotaMode !== undefined && (obj.quotaMode = quotaOperation_QuotaModeToJSON(message.quotaMode));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaOperation();
        message.operationId = object.operationId ?? "";
        message.methodName = object.methodName ?? "";
        message.consumerId = object.consumerId ?? "";
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.quotaMetrics = object.quotaMetrics?.map(e => MetricValueSet.fromPartial(e)) || [];
        message.quotaMode = object.quotaMode ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            operationId: object?.operation_id,
            methodName: object?.method_name,
            consumerId: object?.consumer_id,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            quotaMetrics: Array.isArray(object?.quota_metrics) ? object.quota_metrics.map((e) => MetricValueSet.fromSDK(e)) : [],
            quotaMode: isSet(object.quota_mode) ? quotaOperation_QuotaModeFromJSON(object.quota_mode) : -1
        };
    },
    fromSDKJSON(object) {
        return {
            operation_id: isSet(object.operation_id) ? String(object.operation_id) : "",
            method_name: isSet(object.method_name) ? String(object.method_name) : "",
            consumer_id: isSet(object.consumer_id) ? String(object.consumer_id) : "",
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            quota_metrics: Array.isArray(object?.quota_metrics) ? object.quota_metrics.map((e) => MetricValueSet.fromSDKJSON(e)) : [],
            quota_mode: isSet(object.quota_mode) ? quotaOperation_QuotaModeFromJSON(object.quota_mode) : -1
        };
    },
    toSDK(message) {
        const obj = {};
        obj.operation_id = message.operationId;
        obj.method_name = message.methodName;
        obj.consumer_id = message.consumerId;
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.quotaMetrics) {
            obj.quota_metrics = message.quotaMetrics.map(e => e ? MetricValueSet.toSDK(e) : undefined);
        }
        else {
            obj.quota_metrics = [];
        }
        message.quotaMode !== undefined && (obj.quota_mode = quotaOperation_QuotaModeToJSON(message.quotaMode));
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaOperation();
        if (object.operation_id !== undefined && object.operation_id !== null) {
            message.operationId = object.operation_id;
        }
        if (object.method_name !== undefined && object.method_name !== null) {
            message.methodName = object.method_name;
        }
        if (object.consumer_id !== undefined && object.consumer_id !== null) {
            message.consumerId = object.consumer_id;
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.quotaMetrics = object.quota_metrics?.map(e => MetricValueSet.fromAmino(e)) || [];
        if (object.quota_mode !== undefined && object.quota_mode !== null) {
            message.quotaMode = object.quota_mode;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.operation_id = message.operationId === "" ? undefined : message.operationId;
        obj.method_name = message.methodName === "" ? undefined : message.methodName;
        obj.consumer_id = message.consumerId === "" ? undefined : message.consumerId;
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.quotaMetrics) {
            obj.quota_metrics = message.quotaMetrics.map(e => e ? MetricValueSet.toAmino(e) : undefined);
        }
        else {
            obj.quota_metrics = message.quotaMetrics;
        }
        obj.quota_mode = message.quotaMode === 0 ? undefined : message.quotaMode;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaOperation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaOperation.decode(message.value);
    },
    toProto(message) {
        return QuotaOperation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.QuotaOperation",
            value: QuotaOperation.encode(message).finish()
        };
    },
    registerTypeUrl() {
        MetricValueSet.registerTypeUrl();
    }
};
function createBaseAllocateQuotaResponse() {
    return {
        operationId: "",
        allocateErrors: [],
        quotaMetrics: [],
        serviceConfigId: ""
    };
}
export const AllocateQuotaResponse = {
    typeUrl: "/google.api.servicecontrol.v1.AllocateQuotaResponse",
    is(o) {
        return o && (o.$typeUrl === AllocateQuotaResponse.typeUrl || typeof o.operationId === "string" && Array.isArray(o.allocateErrors) && (!o.allocateErrors.length || QuotaError.is(o.allocateErrors[0])) && Array.isArray(o.quotaMetrics) && (!o.quotaMetrics.length || MetricValueSet.is(o.quotaMetrics[0])) && typeof o.serviceConfigId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === AllocateQuotaResponse.typeUrl || typeof o.operation_id === "string" && Array.isArray(o.allocate_errors) && (!o.allocate_errors.length || QuotaError.isSDK(o.allocate_errors[0])) && Array.isArray(o.quota_metrics) && (!o.quota_metrics.length || MetricValueSet.isSDK(o.quota_metrics[0])) && typeof o.service_config_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === AllocateQuotaResponse.typeUrl || typeof o.operation_id === "string" && Array.isArray(o.allocate_errors) && (!o.allocate_errors.length || QuotaError.isAmino(o.allocate_errors[0])) && Array.isArray(o.quota_metrics) && (!o.quota_metrics.length || MetricValueSet.isAmino(o.quota_metrics[0])) && typeof o.service_config_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.operationId !== undefined) {
            writer.uint32(10).string(message.operationId);
        }
        for (const v of message.allocateErrors) {
            QuotaError.encode(v, writer.uint32(18).fork()).ldelim();
        }
        for (const v of message.quotaMetrics) {
            MetricValueSet.encode(v, writer.uint32(26).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(34).string(message.serviceConfigId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAllocateQuotaResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.operationId = reader.string();
                    break;
                case 2:
                    message.allocateErrors.push(QuotaError.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.quotaMetrics.push(MetricValueSet.decode(reader, reader.uint32()));
                    break;
                case 4:
                    message.serviceConfigId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAllocateQuotaResponse();
        if (isSet(object.operationId))
            obj.operationId = String(object.operationId);
        if (Array.isArray(object?.allocateErrors))
            obj.allocateErrors = object.allocateErrors.map((e) => QuotaError.fromJSON(e));
        if (Array.isArray(object?.quotaMetrics))
            obj.quotaMetrics = object.quotaMetrics.map((e) => MetricValueSet.fromJSON(e));
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.operationId !== undefined && (obj.operationId = message.operationId);
        if (message.allocateErrors) {
            obj.allocateErrors = message.allocateErrors.map(e => e ? QuotaError.toJSON(e) : undefined);
        }
        else {
            obj.allocateErrors = [];
        }
        if (message.quotaMetrics) {
            obj.quotaMetrics = message.quotaMetrics.map(e => e ? MetricValueSet.toJSON(e) : undefined);
        }
        else {
            obj.quotaMetrics = [];
        }
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAllocateQuotaResponse();
        message.operationId = object.operationId ?? "";
        message.allocateErrors = object.allocateErrors?.map(e => QuotaError.fromPartial(e)) || [];
        message.quotaMetrics = object.quotaMetrics?.map(e => MetricValueSet.fromPartial(e)) || [];
        message.serviceConfigId = object.serviceConfigId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            operationId: object?.operation_id,
            allocateErrors: Array.isArray(object?.allocate_errors) ? object.allocate_errors.map((e) => QuotaError.fromSDK(e)) : [],
            quotaMetrics: Array.isArray(object?.quota_metrics) ? object.quota_metrics.map((e) => MetricValueSet.fromSDK(e)) : [],
            serviceConfigId: object?.service_config_id
        };
    },
    fromSDKJSON(object) {
        return {
            operation_id: isSet(object.operation_id) ? String(object.operation_id) : "",
            allocate_errors: Array.isArray(object?.allocate_errors) ? object.allocate_errors.map((e) => QuotaError.fromSDKJSON(e)) : [],
            quota_metrics: Array.isArray(object?.quota_metrics) ? object.quota_metrics.map((e) => MetricValueSet.fromSDKJSON(e)) : [],
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.operation_id = message.operationId;
        if (message.allocateErrors) {
            obj.allocate_errors = message.allocateErrors.map(e => e ? QuotaError.toSDK(e) : undefined);
        }
        else {
            obj.allocate_errors = [];
        }
        if (message.quotaMetrics) {
            obj.quota_metrics = message.quotaMetrics.map(e => e ? MetricValueSet.toSDK(e) : undefined);
        }
        else {
            obj.quota_metrics = [];
        }
        obj.service_config_id = message.serviceConfigId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAllocateQuotaResponse();
        if (object.operation_id !== undefined && object.operation_id !== null) {
            message.operationId = object.operation_id;
        }
        message.allocateErrors = object.allocate_errors?.map(e => QuotaError.fromAmino(e)) || [];
        message.quotaMetrics = object.quota_metrics?.map(e => MetricValueSet.fromAmino(e)) || [];
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.operation_id = message.operationId === "" ? undefined : message.operationId;
        if (message.allocateErrors) {
            obj.allocate_errors = message.allocateErrors.map(e => e ? QuotaError.toAmino(e) : undefined);
        }
        else {
            obj.allocate_errors = message.allocateErrors;
        }
        if (message.quotaMetrics) {
            obj.quota_metrics = message.quotaMetrics.map(e => e ? MetricValueSet.toAmino(e) : undefined);
        }
        else {
            obj.quota_metrics = message.quotaMetrics;
        }
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        return obj;
    },
    fromAminoMsg(object) {
        return AllocateQuotaResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return AllocateQuotaResponse.decode(message.value);
    },
    toProto(message) {
        return AllocateQuotaResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.AllocateQuotaResponse",
            value: AllocateQuotaResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaError.registerTypeUrl();
        MetricValueSet.registerTypeUrl();
    }
};
function createBaseQuotaError() {
    return {
        code: 0,
        subject: "",
        description: "",
        status: undefined
    };
}
export const QuotaError = {
    typeUrl: "/google.api.servicecontrol.v1.QuotaError",
    is(o) {
        return o && (o.$typeUrl === QuotaError.typeUrl || isSet(o.code) && typeof o.subject === "string" && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaError.typeUrl || isSet(o.code) && typeof o.subject === "string" && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaError.typeUrl || isSet(o.code) && typeof o.subject === "string" && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.code !== 0) {
            writer.uint32(8).int32(message.code);
        }
        if (message.subject !== undefined) {
            writer.uint32(18).string(message.subject);
        }
        if (message.description !== undefined) {
            writer.uint32(26).string(message.description);
        }
        if (message.status !== undefined) {
            Status.encode(message.status, writer.uint32(34).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaError();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.code = reader.int32();
                    break;
                case 2:
                    message.subject = reader.string();
                    break;
                case 3:
                    message.description = reader.string();
                    break;
                case 4:
                    message.status = Status.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaError();
        if (isSet(object.code))
            obj.code = quotaError_CodeFromJSON(object.code);
        if (isSet(object.subject))
            obj.subject = String(object.subject);
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.status))
            obj.status = Status.fromJSON(object.status);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.code !== undefined && (obj.code = quotaError_CodeToJSON(message.code));
        message.subject !== undefined && (obj.subject = message.subject);
        message.description !== undefined && (obj.description = message.description);
        message.status !== undefined && (obj.status = message.status ? Status.toJSON(message.status) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaError();
        message.code = object.code ?? 0;
        message.subject = object.subject ?? "";
        message.description = object.description ?? "";
        if (object.status !== undefined && object.status !== null) {
            message.status = Status.fromPartial(object.status);
        }
        return message;
    },
    fromSDK(object) {
        return {
            code: isSet(object.code) ? quotaError_CodeFromJSON(object.code) : -1,
            subject: object?.subject,
            description: object?.description,
            status: object.status ? Status.fromSDK(object.status) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            code: isSet(object.code) ? quotaError_CodeFromJSON(object.code) : -1,
            subject: isSet(object.subject) ? String(object.subject) : "",
            description: isSet(object.description) ? String(object.description) : "",
            status: isSet(object.status) ? Status.fromSDKJSON(object.status) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.code !== undefined && (obj.code = quotaError_CodeToJSON(message.code));
        obj.subject = message.subject;
        obj.description = message.description;
        message.status !== undefined && (obj.status = message.status ? Status.toSDK(message.status) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaError();
        if (object.code !== undefined && object.code !== null) {
            message.code = object.code;
        }
        if (object.subject !== undefined && object.subject !== null) {
            message.subject = object.subject;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.status !== undefined && object.status !== null) {
            message.status = Status.fromAmino(object.status);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.code = message.code === 0 ? undefined : message.code;
        obj.subject = message.subject === "" ? undefined : message.subject;
        obj.description = message.description === "" ? undefined : message.description;
        obj.status = message.status ? Status.toAmino(message.status) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaError.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaError.decode(message.value);
    },
    toProto(message) {
        return QuotaError.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.QuotaError",
            value: QuotaError.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Status.registerTypeUrl();
    }
};
