import { Operation } from "./operation";
import { CheckError } from "./check_error";
import { Status } from "../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { isSet } from "../../../../helpers";
export const protobufPackage = "google.api.servicecontrol.v1";
/**
 * The type of the consumer as defined in
 * [Google Resource Manager](https://cloud.google.com/resource-manager/).
 */
export var CheckResponse_ConsumerInfo_ConsumerType;
(function (CheckResponse_ConsumerInfo_ConsumerType) {
    /** CONSUMER_TYPE_UNSPECIFIED - This is never used. */
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["CONSUMER_TYPE_UNSPECIFIED"] = 0] = "CONSUMER_TYPE_UNSPECIFIED";
    /** PROJECT - The consumer is a Google Cloud Project. */
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["PROJECT"] = 1] = "PROJECT";
    /** FOLDER - The consumer is a Google Cloud Folder. */
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["FOLDER"] = 2] = "FOLDER";
    /** ORGANIZATION - The consumer is a Google Cloud Organization. */
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["ORGANIZATION"] = 3] = "ORGANIZATION";
    /**
     * SERVICE_SPECIFIC - Service-specific resource container which is defined by the service
     * producer to offer their users the ability to manage service control
     * functionalities at a finer level of granularity than the PROJECT.
     */
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["SERVICE_SPECIFIC"] = 4] = "SERVICE_SPECIFIC";
    CheckResponse_ConsumerInfo_ConsumerType[CheckResponse_ConsumerInfo_ConsumerType["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(CheckResponse_ConsumerInfo_ConsumerType || (CheckResponse_ConsumerInfo_ConsumerType = {}));
export const CheckResponse_ConsumerInfo_ConsumerTypeSDKType = CheckResponse_ConsumerInfo_ConsumerType;
export const CheckResponse_ConsumerInfo_ConsumerTypeAmino = CheckResponse_ConsumerInfo_ConsumerType;
export function checkResponse_ConsumerInfo_ConsumerTypeFromJSON(object) {
    switch (object) {
        case 0:
        case "CONSUMER_TYPE_UNSPECIFIED":
            return CheckResponse_ConsumerInfo_ConsumerType.CONSUMER_TYPE_UNSPECIFIED;
        case 1:
        case "PROJECT":
            return CheckResponse_ConsumerInfo_ConsumerType.PROJECT;
        case 2:
        case "FOLDER":
            return CheckResponse_ConsumerInfo_ConsumerType.FOLDER;
        case 3:
        case "ORGANIZATION":
            return CheckResponse_ConsumerInfo_ConsumerType.ORGANIZATION;
        case 4:
        case "SERVICE_SPECIFIC":
            return CheckResponse_ConsumerInfo_ConsumerType.SERVICE_SPECIFIC;
        case -1:
        case "UNRECOGNIZED":
        default:
            return CheckResponse_ConsumerInfo_ConsumerType.UNRECOGNIZED;
    }
}
export function checkResponse_ConsumerInfo_ConsumerTypeToJSON(object) {
    switch (object) {
        case CheckResponse_ConsumerInfo_ConsumerType.CONSUMER_TYPE_UNSPECIFIED:
            return "CONSUMER_TYPE_UNSPECIFIED";
        case CheckResponse_ConsumerInfo_ConsumerType.PROJECT:
            return "PROJECT";
        case CheckResponse_ConsumerInfo_ConsumerType.FOLDER:
            return "FOLDER";
        case CheckResponse_ConsumerInfo_ConsumerType.ORGANIZATION:
            return "ORGANIZATION";
        case CheckResponse_ConsumerInfo_ConsumerType.SERVICE_SPECIFIC:
            return "SERVICE_SPECIFIC";
        case CheckResponse_ConsumerInfo_ConsumerType.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseCheckRequest() {
    return {
        serviceName: "",
        operation: undefined,
        serviceConfigId: ""
    };
}
export const CheckRequest = {
    typeUrl: "/google.api.servicecontrol.v1.CheckRequest",
    is(o) {
        return o && (o.$typeUrl === CheckRequest.typeUrl || typeof o.serviceName === "string" && typeof o.serviceConfigId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CheckRequest.typeUrl || typeof o.service_name === "string" && typeof o.service_config_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CheckRequest.typeUrl || typeof o.service_name === "string" && typeof o.service_config_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.serviceName !== undefined) {
            writer.uint32(10).string(message.serviceName);
        }
        if (message.operation !== undefined) {
            Operation.encode(message.operation, writer.uint32(18).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(34).string(message.serviceConfigId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCheckRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.serviceName = reader.string();
                    break;
                case 2:
                    message.operation = Operation.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.serviceConfigId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCheckRequest();
        if (isSet(object.serviceName))
            obj.serviceName = String(object.serviceName);
        if (isSet(object.operation))
            obj.operation = Operation.fromJSON(object.operation);
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.serviceName !== undefined && (obj.serviceName = message.serviceName);
        message.operation !== undefined && (obj.operation = message.operation ? Operation.toJSON(message.operation) : undefined);
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCheckRequest();
        message.serviceName = object.serviceName ?? "";
        if (object.operation !== undefined && object.operation !== null) {
            message.operation = Operation.fromPartial(object.operation);
        }
        message.serviceConfigId = object.serviceConfigId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            serviceName: object?.service_name,
            operation: object.operation ? Operation.fromSDK(object.operation) : undefined,
            serviceConfigId: object?.service_config_id
        };
    },
    fromSDKJSON(object) {
        return {
            service_name: isSet(object.service_name) ? String(object.service_name) : "",
            operation: isSet(object.operation) ? Operation.fromSDKJSON(object.operation) : undefined,
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.service_name = message.serviceName;
        message.operation !== undefined && (obj.operation = message.operation ? Operation.toSDK(message.operation) : undefined);
        obj.service_config_id = message.serviceConfigId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCheckRequest();
        if (object.service_name !== undefined && object.service_name !== null) {
            message.serviceName = object.service_name;
        }
        if (object.operation !== undefined && object.operation !== null) {
            message.operation = Operation.fromAmino(object.operation);
        }
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service_name = message.serviceName === "" ? undefined : message.serviceName;
        obj.operation = message.operation ? Operation.toAmino(message.operation) : undefined;
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        return obj;
    },
    fromAminoMsg(object) {
        return CheckRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CheckRequest.decode(message.value);
    },
    toProto(message) {
        return CheckRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.CheckRequest",
            value: CheckRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Operation.registerTypeUrl();
    }
};
function createBaseCheckResponse() {
    return {
        operationId: "",
        checkErrors: [],
        serviceConfigId: "",
        serviceRolloutId: "",
        checkInfo: undefined
    };
}
export const CheckResponse = {
    typeUrl: "/google.api.servicecontrol.v1.CheckResponse",
    is(o) {
        return o && (o.$typeUrl === CheckResponse.typeUrl || typeof o.operationId === "string" && Array.isArray(o.checkErrors) && (!o.checkErrors.length || CheckError.is(o.checkErrors[0])) && typeof o.serviceConfigId === "string" && typeof o.serviceRolloutId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CheckResponse.typeUrl || typeof o.operation_id === "string" && Array.isArray(o.check_errors) && (!o.check_errors.length || CheckError.isSDK(o.check_errors[0])) && typeof o.service_config_id === "string" && typeof o.service_rollout_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CheckResponse.typeUrl || typeof o.operation_id === "string" && Array.isArray(o.check_errors) && (!o.check_errors.length || CheckError.isAmino(o.check_errors[0])) && typeof o.service_config_id === "string" && typeof o.service_rollout_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.operationId !== undefined) {
            writer.uint32(10).string(message.operationId);
        }
        for (const v of message.checkErrors) {
            CheckError.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(42).string(message.serviceConfigId);
        }
        if (message.serviceRolloutId !== undefined) {
            writer.uint32(90).string(message.serviceRolloutId);
        }
        if (message.checkInfo !== undefined) {
            CheckResponse_CheckInfo.encode(message.checkInfo, writer.uint32(50).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCheckResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.operationId = reader.string();
                    break;
                case 2:
                    message.checkErrors.push(CheckError.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.serviceConfigId = reader.string();
                    break;
                case 11:
                    message.serviceRolloutId = reader.string();
                    break;
                case 6:
                    message.checkInfo = CheckResponse_CheckInfo.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCheckResponse();
        if (isSet(object.operationId))
            obj.operationId = String(object.operationId);
        if (Array.isArray(object?.checkErrors))
            obj.checkErrors = object.checkErrors.map((e) => CheckError.fromJSON(e));
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        if (isSet(object.serviceRolloutId))
            obj.serviceRolloutId = String(object.serviceRolloutId);
        if (isSet(object.checkInfo))
            obj.checkInfo = CheckResponse_CheckInfo.fromJSON(object.checkInfo);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.operationId !== undefined && (obj.operationId = message.operationId);
        if (message.checkErrors) {
            obj.checkErrors = message.checkErrors.map(e => e ? CheckError.toJSON(e) : undefined);
        }
        else {
            obj.checkErrors = [];
        }
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        message.serviceRolloutId !== undefined && (obj.serviceRolloutId = message.serviceRolloutId);
        message.checkInfo !== undefined && (obj.checkInfo = message.checkInfo ? CheckResponse_CheckInfo.toJSON(message.checkInfo) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCheckResponse();
        message.operationId = object.operationId ?? "";
        message.checkErrors = object.checkErrors?.map(e => CheckError.fromPartial(e)) || [];
        message.serviceConfigId = object.serviceConfigId ?? "";
        message.serviceRolloutId = object.serviceRolloutId ?? "";
        if (object.checkInfo !== undefined && object.checkInfo !== null) {
            message.checkInfo = CheckResponse_CheckInfo.fromPartial(object.checkInfo);
        }
        return message;
    },
    fromSDK(object) {
        return {
            operationId: object?.operation_id,
            checkErrors: Array.isArray(object?.check_errors) ? object.check_errors.map((e) => CheckError.fromSDK(e)) : [],
            serviceConfigId: object?.service_config_id,
            serviceRolloutId: object?.service_rollout_id,
            checkInfo: object.check_info ? CheckResponse_CheckInfo.fromSDK(object.check_info) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            operation_id: isSet(object.operation_id) ? String(object.operation_id) : "",
            check_errors: Array.isArray(object?.check_errors) ? object.check_errors.map((e) => CheckError.fromSDKJSON(e)) : [],
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : "",
            service_rollout_id: isSet(object.service_rollout_id) ? String(object.service_rollout_id) : "",
            check_info: isSet(object.check_info) ? CheckResponse_CheckInfo.fromSDKJSON(object.check_info) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.operation_id = message.operationId;
        if (message.checkErrors) {
            obj.check_errors = message.checkErrors.map(e => e ? CheckError.toSDK(e) : undefined);
        }
        else {
            obj.check_errors = [];
        }
        obj.service_config_id = message.serviceConfigId;
        obj.service_rollout_id = message.serviceRolloutId;
        message.checkInfo !== undefined && (obj.check_info = message.checkInfo ? CheckResponse_CheckInfo.toSDK(message.checkInfo) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCheckResponse();
        if (object.operation_id !== undefined && object.operation_id !== null) {
            message.operationId = object.operation_id;
        }
        message.checkErrors = object.check_errors?.map(e => CheckError.fromAmino(e)) || [];
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        if (object.service_rollout_id !== undefined && object.service_rollout_id !== null) {
            message.serviceRolloutId = object.service_rollout_id;
        }
        if (object.check_info !== undefined && object.check_info !== null) {
            message.checkInfo = CheckResponse_CheckInfo.fromAmino(object.check_info);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.operation_id = message.operationId === "" ? undefined : message.operationId;
        if (message.checkErrors) {
            obj.check_errors = message.checkErrors.map(e => e ? CheckError.toAmino(e) : undefined);
        }
        else {
            obj.check_errors = message.checkErrors;
        }
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        obj.service_rollout_id = message.serviceRolloutId === "" ? undefined : message.serviceRolloutId;
        obj.check_info = message.checkInfo ? CheckResponse_CheckInfo.toAmino(message.checkInfo) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return CheckResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CheckResponse.decode(message.value);
    },
    toProto(message) {
        return CheckResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.CheckResponse",
            value: CheckResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        CheckError.registerTypeUrl();
        CheckResponse_CheckInfo.registerTypeUrl();
    }
};
function createBaseCheckResponse_CheckInfo() {
    return {
        unusedArguments: [],
        consumerInfo: undefined
    };
}
export const CheckResponse_CheckInfo = {
    typeUrl: "/google.api.servicecontrol.v1.CheckInfo",
    is(o) {
        return o && (o.$typeUrl === CheckResponse_CheckInfo.typeUrl || Array.isArray(o.unusedArguments) && (!o.unusedArguments.length || typeof o.unusedArguments[0] === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === CheckResponse_CheckInfo.typeUrl || Array.isArray(o.unused_arguments) && (!o.unused_arguments.length || typeof o.unused_arguments[0] === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === CheckResponse_CheckInfo.typeUrl || Array.isArray(o.unused_arguments) && (!o.unused_arguments.length || typeof o.unused_arguments[0] === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.unusedArguments) {
            writer.uint32(10).string(v);
        }
        if (message.consumerInfo !== undefined) {
            CheckResponse_ConsumerInfo.encode(message.consumerInfo, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCheckResponse_CheckInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.unusedArguments.push(reader.string());
                    break;
                case 2:
                    message.consumerInfo = CheckResponse_ConsumerInfo.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCheckResponse_CheckInfo();
        if (Array.isArray(object?.unusedArguments))
            obj.unusedArguments = object.unusedArguments.map((e) => String(e));
        if (isSet(object.consumerInfo))
            obj.consumerInfo = CheckResponse_ConsumerInfo.fromJSON(object.consumerInfo);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.unusedArguments) {
            obj.unusedArguments = message.unusedArguments.map(e => e);
        }
        else {
            obj.unusedArguments = [];
        }
        message.consumerInfo !== undefined && (obj.consumerInfo = message.consumerInfo ? CheckResponse_ConsumerInfo.toJSON(message.consumerInfo) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCheckResponse_CheckInfo();
        message.unusedArguments = object.unusedArguments?.map(e => e) || [];
        if (object.consumerInfo !== undefined && object.consumerInfo !== null) {
            message.consumerInfo = CheckResponse_ConsumerInfo.fromPartial(object.consumerInfo);
        }
        return message;
    },
    fromSDK(object) {
        return {
            unusedArguments: Array.isArray(object?.unused_arguments) ? object.unused_arguments.map((e) => e) : [],
            consumerInfo: object.consumer_info ? CheckResponse_ConsumerInfo.fromSDK(object.consumer_info) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            unused_arguments: Array.isArray(object?.unused_arguments) ? object.unused_arguments.map((e) => String(e)) : [],
            consumer_info: isSet(object.consumer_info) ? CheckResponse_ConsumerInfo.fromSDKJSON(object.consumer_info) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.unusedArguments) {
            obj.unused_arguments = message.unusedArguments.map(e => e);
        }
        else {
            obj.unused_arguments = [];
        }
        message.consumerInfo !== undefined && (obj.consumer_info = message.consumerInfo ? CheckResponse_ConsumerInfo.toSDK(message.consumerInfo) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCheckResponse_CheckInfo();
        message.unusedArguments = object.unused_arguments?.map(e => e) || [];
        if (object.consumer_info !== undefined && object.consumer_info !== null) {
            message.consumerInfo = CheckResponse_ConsumerInfo.fromAmino(object.consumer_info);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.unusedArguments) {
            obj.unused_arguments = message.unusedArguments.map(e => e);
        }
        else {
            obj.unused_arguments = message.unusedArguments;
        }
        obj.consumer_info = message.consumerInfo ? CheckResponse_ConsumerInfo.toAmino(message.consumerInfo) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return CheckResponse_CheckInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CheckResponse_CheckInfo.decode(message.value);
    },
    toProto(message) {
        return CheckResponse_CheckInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.CheckInfo",
            value: CheckResponse_CheckInfo.encode(message).finish()
        };
    },
    registerTypeUrl() {
        CheckResponse_ConsumerInfo.registerTypeUrl();
    }
};
function createBaseCheckResponse_ConsumerInfo() {
    return {
        projectNumber: BigInt(0),
        type: 0,
        consumerNumber: BigInt(0)
    };
}
export const CheckResponse_ConsumerInfo = {
    typeUrl: "/google.api.servicecontrol.v1.ConsumerInfo",
    is(o) {
        return o && (o.$typeUrl === CheckResponse_ConsumerInfo.typeUrl || typeof o.projectNumber === "bigint" && isSet(o.type) && typeof o.consumerNumber === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CheckResponse_ConsumerInfo.typeUrl || typeof o.project_number === "bigint" && isSet(o.type) && typeof o.consumer_number === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CheckResponse_ConsumerInfo.typeUrl || typeof o.project_number === "bigint" && isSet(o.type) && typeof o.consumer_number === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.projectNumber !== undefined) {
            writer.uint32(8).int64(message.projectNumber);
        }
        if (message.type !== 0) {
            writer.uint32(16).int32(message.type);
        }
        if (message.consumerNumber !== undefined) {
            writer.uint32(24).int64(message.consumerNumber);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCheckResponse_ConsumerInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.projectNumber = reader.int64();
                    break;
                case 2:
                    message.type = reader.int32();
                    break;
                case 3:
                    message.consumerNumber = reader.int64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCheckResponse_ConsumerInfo();
        if (isSet(object.projectNumber))
            obj.projectNumber = BigInt(object.projectNumber.toString());
        if (isSet(object.type))
            obj.type = checkResponse_ConsumerInfo_ConsumerTypeFromJSON(object.type);
        if (isSet(object.consumerNumber))
            obj.consumerNumber = BigInt(object.consumerNumber.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.projectNumber !== undefined && (obj.projectNumber = (message.projectNumber || BigInt(0)).toString());
        message.type !== undefined && (obj.type = checkResponse_ConsumerInfo_ConsumerTypeToJSON(message.type));
        message.consumerNumber !== undefined && (obj.consumerNumber = (message.consumerNumber || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCheckResponse_ConsumerInfo();
        if (object.projectNumber !== undefined && object.projectNumber !== null) {
            message.projectNumber = BigInt(object.projectNumber.toString());
        }
        message.type = object.type ?? 0;
        if (object.consumerNumber !== undefined && object.consumerNumber !== null) {
            message.consumerNumber = BigInt(object.consumerNumber.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            projectNumber: object?.project_number,
            type: isSet(object.type) ? checkResponse_ConsumerInfo_ConsumerTypeFromJSON(object.type) : -1,
            consumerNumber: object?.consumer_number
        };
    },
    fromSDKJSON(object) {
        return {
            project_number: isSet(object.project_number) ? BigInt(object.project_number.toString()) : BigInt(0),
            type: isSet(object.type) ? checkResponse_ConsumerInfo_ConsumerTypeFromJSON(object.type) : -1,
            consumer_number: isSet(object.consumer_number) ? BigInt(object.consumer_number.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        obj.project_number = message.projectNumber;
        message.type !== undefined && (obj.type = checkResponse_ConsumerInfo_ConsumerTypeToJSON(message.type));
        obj.consumer_number = message.consumerNumber;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCheckResponse_ConsumerInfo();
        if (object.project_number !== undefined && object.project_number !== null) {
            message.projectNumber = BigInt(object.project_number);
        }
        if (object.type !== undefined && object.type !== null) {
            message.type = object.type;
        }
        if (object.consumer_number !== undefined && object.consumer_number !== null) {
            message.consumerNumber = BigInt(object.consumer_number);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.project_number = message.projectNumber !== BigInt(0) ? message.projectNumber?.toString() : undefined;
        obj.type = message.type === 0 ? undefined : message.type;
        obj.consumer_number = message.consumerNumber !== BigInt(0) ? message.consumerNumber?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return CheckResponse_ConsumerInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CheckResponse_ConsumerInfo.decode(message.value);
    },
    toProto(message) {
        return CheckResponse_ConsumerInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.ConsumerInfo",
            value: CheckResponse_ConsumerInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseReportRequest() {
    return {
        serviceName: "",
        operations: [],
        serviceConfigId: ""
    };
}
export const ReportRequest = {
    typeUrl: "/google.api.servicecontrol.v1.ReportRequest",
    is(o) {
        return o && (o.$typeUrl === ReportRequest.typeUrl || typeof o.serviceName === "string" && Array.isArray(o.operations) && (!o.operations.length || Operation.is(o.operations[0])) && typeof o.serviceConfigId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ReportRequest.typeUrl || typeof o.service_name === "string" && Array.isArray(o.operations) && (!o.operations.length || Operation.isSDK(o.operations[0])) && typeof o.service_config_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ReportRequest.typeUrl || typeof o.service_name === "string" && Array.isArray(o.operations) && (!o.operations.length || Operation.isAmino(o.operations[0])) && typeof o.service_config_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.serviceName !== undefined) {
            writer.uint32(10).string(message.serviceName);
        }
        for (const v of message.operations) {
            Operation.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(26).string(message.serviceConfigId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseReportRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.serviceName = reader.string();
                    break;
                case 2:
                    message.operations.push(Operation.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.serviceConfigId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseReportRequest();
        if (isSet(object.serviceName))
            obj.serviceName = String(object.serviceName);
        if (Array.isArray(object?.operations))
            obj.operations = object.operations.map((e) => Operation.fromJSON(e));
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.serviceName !== undefined && (obj.serviceName = message.serviceName);
        if (message.operations) {
            obj.operations = message.operations.map(e => e ? Operation.toJSON(e) : undefined);
        }
        else {
            obj.operations = [];
        }
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseReportRequest();
        message.serviceName = object.serviceName ?? "";
        message.operations = object.operations?.map(e => Operation.fromPartial(e)) || [];
        message.serviceConfigId = object.serviceConfigId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            serviceName: object?.service_name,
            operations: Array.isArray(object?.operations) ? object.operations.map((e) => Operation.fromSDK(e)) : [],
            serviceConfigId: object?.service_config_id
        };
    },
    fromSDKJSON(object) {
        return {
            service_name: isSet(object.service_name) ? String(object.service_name) : "",
            operations: Array.isArray(object?.operations) ? object.operations.map((e) => Operation.fromSDKJSON(e)) : [],
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.service_name = message.serviceName;
        if (message.operations) {
            obj.operations = message.operations.map(e => e ? Operation.toSDK(e) : undefined);
        }
        else {
            obj.operations = [];
        }
        obj.service_config_id = message.serviceConfigId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseReportRequest();
        if (object.service_name !== undefined && object.service_name !== null) {
            message.serviceName = object.service_name;
        }
        message.operations = object.operations?.map(e => Operation.fromAmino(e)) || [];
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service_name = message.serviceName === "" ? undefined : message.serviceName;
        if (message.operations) {
            obj.operations = message.operations.map(e => e ? Operation.toAmino(e) : undefined);
        }
        else {
            obj.operations = message.operations;
        }
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        return obj;
    },
    fromAminoMsg(object) {
        return ReportRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ReportRequest.decode(message.value);
    },
    toProto(message) {
        return ReportRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.ReportRequest",
            value: ReportRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Operation.registerTypeUrl();
    }
};
function createBaseReportResponse() {
    return {
        reportErrors: [],
        serviceConfigId: "",
        serviceRolloutId: ""
    };
}
export const ReportResponse = {
    typeUrl: "/google.api.servicecontrol.v1.ReportResponse",
    is(o) {
        return o && (o.$typeUrl === ReportResponse.typeUrl || Array.isArray(o.reportErrors) && (!o.reportErrors.length || ReportResponse_ReportError.is(o.reportErrors[0])) && typeof o.serviceConfigId === "string" && typeof o.serviceRolloutId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ReportResponse.typeUrl || Array.isArray(o.report_errors) && (!o.report_errors.length || ReportResponse_ReportError.isSDK(o.report_errors[0])) && typeof o.service_config_id === "string" && typeof o.service_rollout_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ReportResponse.typeUrl || Array.isArray(o.report_errors) && (!o.report_errors.length || ReportResponse_ReportError.isAmino(o.report_errors[0])) && typeof o.service_config_id === "string" && typeof o.service_rollout_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.reportErrors) {
            ReportResponse_ReportError.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.serviceConfigId !== undefined) {
            writer.uint32(18).string(message.serviceConfigId);
        }
        if (message.serviceRolloutId !== undefined) {
            writer.uint32(34).string(message.serviceRolloutId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseReportResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.reportErrors.push(ReportResponse_ReportError.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.serviceConfigId = reader.string();
                    break;
                case 4:
                    message.serviceRolloutId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseReportResponse();
        if (Array.isArray(object?.reportErrors))
            obj.reportErrors = object.reportErrors.map((e) => ReportResponse_ReportError.fromJSON(e));
        if (isSet(object.serviceConfigId))
            obj.serviceConfigId = String(object.serviceConfigId);
        if (isSet(object.serviceRolloutId))
            obj.serviceRolloutId = String(object.serviceRolloutId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.reportErrors) {
            obj.reportErrors = message.reportErrors.map(e => e ? ReportResponse_ReportError.toJSON(e) : undefined);
        }
        else {
            obj.reportErrors = [];
        }
        message.serviceConfigId !== undefined && (obj.serviceConfigId = message.serviceConfigId);
        message.serviceRolloutId !== undefined && (obj.serviceRolloutId = message.serviceRolloutId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseReportResponse();
        message.reportErrors = object.reportErrors?.map(e => ReportResponse_ReportError.fromPartial(e)) || [];
        message.serviceConfigId = object.serviceConfigId ?? "";
        message.serviceRolloutId = object.serviceRolloutId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            reportErrors: Array.isArray(object?.report_errors) ? object.report_errors.map((e) => ReportResponse_ReportError.fromSDK(e)) : [],
            serviceConfigId: object?.service_config_id,
            serviceRolloutId: object?.service_rollout_id
        };
    },
    fromSDKJSON(object) {
        return {
            report_errors: Array.isArray(object?.report_errors) ? object.report_errors.map((e) => ReportResponse_ReportError.fromSDKJSON(e)) : [],
            service_config_id: isSet(object.service_config_id) ? String(object.service_config_id) : "",
            service_rollout_id: isSet(object.service_rollout_id) ? String(object.service_rollout_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.reportErrors) {
            obj.report_errors = message.reportErrors.map(e => e ? ReportResponse_ReportError.toSDK(e) : undefined);
        }
        else {
            obj.report_errors = [];
        }
        obj.service_config_id = message.serviceConfigId;
        obj.service_rollout_id = message.serviceRolloutId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseReportResponse();
        message.reportErrors = object.report_errors?.map(e => ReportResponse_ReportError.fromAmino(e)) || [];
        if (object.service_config_id !== undefined && object.service_config_id !== null) {
            message.serviceConfigId = object.service_config_id;
        }
        if (object.service_rollout_id !== undefined && object.service_rollout_id !== null) {
            message.serviceRolloutId = object.service_rollout_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.reportErrors) {
            obj.report_errors = message.reportErrors.map(e => e ? ReportResponse_ReportError.toAmino(e) : undefined);
        }
        else {
            obj.report_errors = message.reportErrors;
        }
        obj.service_config_id = message.serviceConfigId === "" ? undefined : message.serviceConfigId;
        obj.service_rollout_id = message.serviceRolloutId === "" ? undefined : message.serviceRolloutId;
        return obj;
    },
    fromAminoMsg(object) {
        return ReportResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ReportResponse.decode(message.value);
    },
    toProto(message) {
        return ReportResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.ReportResponse",
            value: ReportResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        ReportResponse_ReportError.registerTypeUrl();
    }
};
function createBaseReportResponse_ReportError() {
    return {
        operationId: "",
        status: undefined
    };
}
export const ReportResponse_ReportError = {
    typeUrl: "/google.api.servicecontrol.v1.ReportError",
    is(o) {
        return o && (o.$typeUrl === ReportResponse_ReportError.typeUrl || typeof o.operationId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ReportResponse_ReportError.typeUrl || typeof o.operation_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ReportResponse_ReportError.typeUrl || typeof o.operation_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.operationId !== undefined) {
            writer.uint32(10).string(message.operationId);
        }
        if (message.status !== undefined) {
            Status.encode(message.status, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseReportResponse_ReportError();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.operationId = reader.string();
                    break;
                case 2:
                    message.status = Status.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseReportResponse_ReportError();
        if (isSet(object.operationId))
            obj.operationId = String(object.operationId);
        if (isSet(object.status))
            obj.status = Status.fromJSON(object.status);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.operationId !== undefined && (obj.operationId = message.operationId);
        message.status !== undefined && (obj.status = message.status ? Status.toJSON(message.status) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseReportResponse_ReportError();
        message.operationId = object.operationId ?? "";
        if (object.status !== undefined && object.status !== null) {
            message.status = Status.fromPartial(object.status);
        }
        return message;
    },
    fromSDK(object) {
        return {
            operationId: object?.operation_id,
            status: object.status ? Status.fromSDK(object.status) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            operation_id: isSet(object.operation_id) ? String(object.operation_id) : "",
            status: isSet(object.status) ? Status.fromSDKJSON(object.status) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.operation_id = message.operationId;
        message.status !== undefined && (obj.status = message.status ? Status.toSDK(message.status) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseReportResponse_ReportError();
        if (object.operation_id !== undefined && object.operation_id !== null) {
            message.operationId = object.operation_id;
        }
        if (object.status !== undefined && object.status !== null) {
            message.status = Status.fromAmino(object.status);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.operation_id = message.operationId === "" ? undefined : message.operationId;
        obj.status = message.status ? Status.toAmino(message.status) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return ReportResponse_ReportError.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ReportResponse_ReportError.decode(message.value);
    },
    toProto(message) {
        return ReportResponse_ReportError.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.servicecontrol.v1.ReportError",
            value: ReportResponse_ReportError.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Status.registerTypeUrl();
    }
};
