import { Service } from "./resources";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { isSet } from "../../../../helpers";
export const protobufPackage = "google.api.serviceusage.v1";
/**
 * Enum to determine if service usage should be checked when disabling a
 * service.
 */
export var DisableServiceRequest_CheckIfServiceHasUsage;
(function (DisableServiceRequest_CheckIfServiceHasUsage) {
    /** CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED - When unset, the default behavior is used, which is SKIP. */
    DisableServiceRequest_CheckIfServiceHasUsage[DisableServiceRequest_CheckIfServiceHasUsage["CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED"] = 0] = "CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED";
    /** SKIP - If set, skip checking service usage when disabling a service. */
    DisableServiceRequest_CheckIfServiceHasUsage[DisableServiceRequest_CheckIfServiceHasUsage["SKIP"] = 1] = "SKIP";
    /**
     * CHECK - If set, service usage is checked when disabling the service. If a
     * service, or its dependents, has usage in the last 30 days, the request
     * returns a FAILED_PRECONDITION error.
     */
    DisableServiceRequest_CheckIfServiceHasUsage[DisableServiceRequest_CheckIfServiceHasUsage["CHECK"] = 2] = "CHECK";
    DisableServiceRequest_CheckIfServiceHasUsage[DisableServiceRequest_CheckIfServiceHasUsage["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(DisableServiceRequest_CheckIfServiceHasUsage || (DisableServiceRequest_CheckIfServiceHasUsage = {}));
export const DisableServiceRequest_CheckIfServiceHasUsageSDKType = DisableServiceRequest_CheckIfServiceHasUsage;
export const DisableServiceRequest_CheckIfServiceHasUsageAmino = DisableServiceRequest_CheckIfServiceHasUsage;
export function disableServiceRequest_CheckIfServiceHasUsageFromJSON(object) {
    switch (object) {
        case 0:
        case "CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED":
            return DisableServiceRequest_CheckIfServiceHasUsage.CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED;
        case 1:
        case "SKIP":
            return DisableServiceRequest_CheckIfServiceHasUsage.SKIP;
        case 2:
        case "CHECK":
            return DisableServiceRequest_CheckIfServiceHasUsage.CHECK;
        case -1:
        case "UNRECOGNIZED":
        default:
            return DisableServiceRequest_CheckIfServiceHasUsage.UNRECOGNIZED;
    }
}
export function disableServiceRequest_CheckIfServiceHasUsageToJSON(object) {
    switch (object) {
        case DisableServiceRequest_CheckIfServiceHasUsage.CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED:
            return "CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED";
        case DisableServiceRequest_CheckIfServiceHasUsage.SKIP:
            return "SKIP";
        case DisableServiceRequest_CheckIfServiceHasUsage.CHECK:
            return "CHECK";
        case DisableServiceRequest_CheckIfServiceHasUsage.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseEnableServiceRequest() {
    return {
        name: ""
    };
}
export const EnableServiceRequest = {
    typeUrl: "/google.api.serviceusage.v1.EnableServiceRequest",
    is(o) {
        return o && (o.$typeUrl === EnableServiceRequest.typeUrl || typeof o.name === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === EnableServiceRequest.typeUrl || typeof o.name === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === EnableServiceRequest.typeUrl || typeof o.name === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseEnableServiceRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseEnableServiceRequest();
        if (isSet(object.name))
            obj.name = String(object.name);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseEnableServiceRequest();
        message.name = object.name ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseEnableServiceRequest();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        return obj;
    },
    fromAminoMsg(object) {
        return EnableServiceRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return EnableServiceRequest.decode(message.value);
    },
    toProto(message) {
        return EnableServiceRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.EnableServiceRequest",
            value: EnableServiceRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseEnableServiceResponse() {
    return {
        service: undefined
    };
}
export const EnableServiceResponse = {
    typeUrl: "/google.api.serviceusage.v1.EnableServiceResponse",
    is(o) {
        return o && o.$typeUrl === EnableServiceResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === EnableServiceResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === EnableServiceResponse.typeUrl;
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.service !== undefined) {
            Service.encode(message.service, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseEnableServiceResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.service = Service.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseEnableServiceResponse();
        if (isSet(object.service))
            obj.service = Service.fromJSON(object.service);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.service !== undefined && (obj.service = message.service ? Service.toJSON(message.service) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseEnableServiceResponse();
        if (object.service !== undefined && object.service !== null) {
            message.service = Service.fromPartial(object.service);
        }
        return message;
    },
    fromSDK(object) {
        return {
            service: object.service ? Service.fromSDK(object.service) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            service: isSet(object.service) ? Service.fromSDKJSON(object.service) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.service !== undefined && (obj.service = message.service ? Service.toSDK(message.service) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseEnableServiceResponse();
        if (object.service !== undefined && object.service !== null) {
            message.service = Service.fromAmino(object.service);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service = message.service ? Service.toAmino(message.service) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return EnableServiceResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return EnableServiceResponse.decode(message.value);
    },
    toProto(message) {
        return EnableServiceResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.EnableServiceResponse",
            value: EnableServiceResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Service.registerTypeUrl();
    }
};
function createBaseDisableServiceRequest() {
    return {
        name: "",
        disableDependentServices: false,
        checkIfServiceHasUsage: 0
    };
}
export const DisableServiceRequest = {
    typeUrl: "/google.api.serviceusage.v1.DisableServiceRequest",
    is(o) {
        return o && (o.$typeUrl === DisableServiceRequest.typeUrl || typeof o.name === "string" && typeof o.disableDependentServices === "boolean" && isSet(o.checkIfServiceHasUsage));
    },
    isSDK(o) {
        return o && (o.$typeUrl === DisableServiceRequest.typeUrl || typeof o.name === "string" && typeof o.disable_dependent_services === "boolean" && isSet(o.check_if_service_has_usage));
    },
    isAmino(o) {
        return o && (o.$typeUrl === DisableServiceRequest.typeUrl || typeof o.name === "string" && typeof o.disable_dependent_services === "boolean" && isSet(o.check_if_service_has_usage));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.disableDependentServices !== undefined) {
            writer.uint32(16).bool(message.disableDependentServices);
        }
        if (message.checkIfServiceHasUsage !== 0) {
            writer.uint32(24).int32(message.checkIfServiceHasUsage);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseDisableServiceRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.disableDependentServices = reader.bool();
                    break;
                case 3:
                    message.checkIfServiceHasUsage = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseDisableServiceRequest();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.disableDependentServices))
            obj.disableDependentServices = Boolean(object.disableDependentServices);
        if (isSet(object.checkIfServiceHasUsage))
            obj.checkIfServiceHasUsage = disableServiceRequest_CheckIfServiceHasUsageFromJSON(object.checkIfServiceHasUsage);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.disableDependentServices !== undefined && (obj.disableDependentServices = message.disableDependentServices);
        message.checkIfServiceHasUsage !== undefined && (obj.checkIfServiceHasUsage = disableServiceRequest_CheckIfServiceHasUsageToJSON(message.checkIfServiceHasUsage));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseDisableServiceRequest();
        message.name = object.name ?? "";
        message.disableDependentServices = object.disableDependentServices ?? false;
        message.checkIfServiceHasUsage = object.checkIfServiceHasUsage ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            disableDependentServices: object?.disable_dependent_services,
            checkIfServiceHasUsage: isSet(object.check_if_service_has_usage) ? disableServiceRequest_CheckIfServiceHasUsageFromJSON(object.check_if_service_has_usage) : -1
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            disable_dependent_services: isSet(object.disable_dependent_services) ? Boolean(object.disable_dependent_services) : false,
            check_if_service_has_usage: isSet(object.check_if_service_has_usage) ? disableServiceRequest_CheckIfServiceHasUsageFromJSON(object.check_if_service_has_usage) : -1
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.disable_dependent_services = message.disableDependentServices;
        message.checkIfServiceHasUsage !== undefined && (obj.check_if_service_has_usage = disableServiceRequest_CheckIfServiceHasUsageToJSON(message.checkIfServiceHasUsage));
        return obj;
    },
    fromAmino(object) {
        const message = createBaseDisableServiceRequest();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.disable_dependent_services !== undefined && object.disable_dependent_services !== null) {
            message.disableDependentServices = object.disable_dependent_services;
        }
        if (object.check_if_service_has_usage !== undefined && object.check_if_service_has_usage !== null) {
            message.checkIfServiceHasUsage = object.check_if_service_has_usage;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.disable_dependent_services = message.disableDependentServices === false ? undefined : message.disableDependentServices;
        obj.check_if_service_has_usage = message.checkIfServiceHasUsage === 0 ? undefined : message.checkIfServiceHasUsage;
        return obj;
    },
    fromAminoMsg(object) {
        return DisableServiceRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return DisableServiceRequest.decode(message.value);
    },
    toProto(message) {
        return DisableServiceRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.DisableServiceRequest",
            value: DisableServiceRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseDisableServiceResponse() {
    return {
        service: undefined
    };
}
export const DisableServiceResponse = {
    typeUrl: "/google.api.serviceusage.v1.DisableServiceResponse",
    is(o) {
        return o && o.$typeUrl === DisableServiceResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === DisableServiceResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === DisableServiceResponse.typeUrl;
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.service !== undefined) {
            Service.encode(message.service, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseDisableServiceResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.service = Service.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseDisableServiceResponse();
        if (isSet(object.service))
            obj.service = Service.fromJSON(object.service);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.service !== undefined && (obj.service = message.service ? Service.toJSON(message.service) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseDisableServiceResponse();
        if (object.service !== undefined && object.service !== null) {
            message.service = Service.fromPartial(object.service);
        }
        return message;
    },
    fromSDK(object) {
        return {
            service: object.service ? Service.fromSDK(object.service) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            service: isSet(object.service) ? Service.fromSDKJSON(object.service) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.service !== undefined && (obj.service = message.service ? Service.toSDK(message.service) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseDisableServiceResponse();
        if (object.service !== undefined && object.service !== null) {
            message.service = Service.fromAmino(object.service);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service = message.service ? Service.toAmino(message.service) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return DisableServiceResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return DisableServiceResponse.decode(message.value);
    },
    toProto(message) {
        return DisableServiceResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.DisableServiceResponse",
            value: DisableServiceResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Service.registerTypeUrl();
    }
};
function createBaseGetServiceRequest() {
    return {
        name: ""
    };
}
export const GetServiceRequest = {
    typeUrl: "/google.api.serviceusage.v1.GetServiceRequest",
    is(o) {
        return o && (o.$typeUrl === GetServiceRequest.typeUrl || typeof o.name === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === GetServiceRequest.typeUrl || typeof o.name === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === GetServiceRequest.typeUrl || typeof o.name === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGetServiceRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGetServiceRequest();
        if (isSet(object.name))
            obj.name = String(object.name);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGetServiceRequest();
        message.name = object.name ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGetServiceRequest();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        return obj;
    },
    fromAminoMsg(object) {
        return GetServiceRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return GetServiceRequest.decode(message.value);
    },
    toProto(message) {
        return GetServiceRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.GetServiceRequest",
            value: GetServiceRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseListServicesRequest() {
    return {
        parent: "",
        pageSize: 0,
        pageToken: "",
        filter: ""
    };
}
export const ListServicesRequest = {
    typeUrl: "/google.api.serviceusage.v1.ListServicesRequest",
    is(o) {
        return o && (o.$typeUrl === ListServicesRequest.typeUrl || typeof o.parent === "string" && typeof o.pageSize === "number" && typeof o.pageToken === "string" && typeof o.filter === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListServicesRequest.typeUrl || typeof o.parent === "string" && typeof o.page_size === "number" && typeof o.page_token === "string" && typeof o.filter === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListServicesRequest.typeUrl || typeof o.parent === "string" && typeof o.page_size === "number" && typeof o.page_token === "string" && typeof o.filter === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.parent !== undefined) {
            writer.uint32(10).string(message.parent);
        }
        if (message.pageSize !== undefined) {
            writer.uint32(16).int32(message.pageSize);
        }
        if (message.pageToken !== undefined) {
            writer.uint32(26).string(message.pageToken);
        }
        if (message.filter !== undefined) {
            writer.uint32(34).string(message.filter);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListServicesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.parent = reader.string();
                    break;
                case 2:
                    message.pageSize = reader.int32();
                    break;
                case 3:
                    message.pageToken = reader.string();
                    break;
                case 4:
                    message.filter = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListServicesRequest();
        if (isSet(object.parent))
            obj.parent = String(object.parent);
        if (isSet(object.pageSize))
            obj.pageSize = Number(object.pageSize);
        if (isSet(object.pageToken))
            obj.pageToken = String(object.pageToken);
        if (isSet(object.filter))
            obj.filter = String(object.filter);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.parent !== undefined && (obj.parent = message.parent);
        message.pageSize !== undefined && (obj.pageSize = Math.round(message.pageSize));
        message.pageToken !== undefined && (obj.pageToken = message.pageToken);
        message.filter !== undefined && (obj.filter = message.filter);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListServicesRequest();
        message.parent = object.parent ?? "";
        message.pageSize = object.pageSize ?? 0;
        message.pageToken = object.pageToken ?? "";
        message.filter = object.filter ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            parent: object?.parent,
            pageSize: object?.page_size,
            pageToken: object?.page_token,
            filter: object?.filter
        };
    },
    fromSDKJSON(object) {
        return {
            parent: isSet(object.parent) ? String(object.parent) : "",
            page_size: isSet(object.page_size) ? Number(object.page_size) : 0,
            page_token: isSet(object.page_token) ? String(object.page_token) : "",
            filter: isSet(object.filter) ? String(object.filter) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.parent = message.parent;
        obj.page_size = message.pageSize;
        obj.page_token = message.pageToken;
        obj.filter = message.filter;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListServicesRequest();
        if (object.parent !== undefined && object.parent !== null) {
            message.parent = object.parent;
        }
        if (object.page_size !== undefined && object.page_size !== null) {
            message.pageSize = object.page_size;
        }
        if (object.page_token !== undefined && object.page_token !== null) {
            message.pageToken = object.page_token;
        }
        if (object.filter !== undefined && object.filter !== null) {
            message.filter = object.filter;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.parent = message.parent === "" ? undefined : message.parent;
        obj.page_size = message.pageSize === 0 ? undefined : message.pageSize;
        obj.page_token = message.pageToken === "" ? undefined : message.pageToken;
        obj.filter = message.filter === "" ? undefined : message.filter;
        return obj;
    },
    fromAminoMsg(object) {
        return ListServicesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListServicesRequest.decode(message.value);
    },
    toProto(message) {
        return ListServicesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.ListServicesRequest",
            value: ListServicesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseListServicesResponse() {
    return {
        services: [],
        nextPageToken: ""
    };
}
export const ListServicesResponse = {
    typeUrl: "/google.api.serviceusage.v1.ListServicesResponse",
    is(o) {
        return o && (o.$typeUrl === ListServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.is(o.services[0])) && typeof o.nextPageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isSDK(o.services[0])) && typeof o.next_page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isAmino(o.services[0])) && typeof o.next_page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.services) {
            Service.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.nextPageToken !== undefined) {
            writer.uint32(18).string(message.nextPageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListServicesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.services.push(Service.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.nextPageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListServicesResponse();
        if (Array.isArray(object?.services))
            obj.services = object.services.map((e) => Service.fromJSON(e));
        if (isSet(object.nextPageToken))
            obj.nextPageToken = String(object.nextPageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toJSON(e) : undefined);
        }
        else {
            obj.services = [];
        }
        message.nextPageToken !== undefined && (obj.nextPageToken = message.nextPageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListServicesResponse();
        message.services = object.services?.map(e => Service.fromPartial(e)) || [];
        message.nextPageToken = object.nextPageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDK(e)) : [],
            nextPageToken: object?.next_page_token
        };
    },
    fromSDKJSON(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDKJSON(e)) : [],
            next_page_token: isSet(object.next_page_token) ? String(object.next_page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toSDK(e) : undefined);
        }
        else {
            obj.services = [];
        }
        obj.next_page_token = message.nextPageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListServicesResponse();
        message.services = object.services?.map(e => Service.fromAmino(e)) || [];
        if (object.next_page_token !== undefined && object.next_page_token !== null) {
            message.nextPageToken = object.next_page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toAmino(e) : undefined);
        }
        else {
            obj.services = message.services;
        }
        obj.next_page_token = message.nextPageToken === "" ? undefined : message.nextPageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListServicesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListServicesResponse.decode(message.value);
    },
    toProto(message) {
        return ListServicesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.ListServicesResponse",
            value: ListServicesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Service.registerTypeUrl();
    }
};
function createBaseBatchEnableServicesRequest() {
    return {
        parent: "",
        serviceIds: []
    };
}
export const BatchEnableServicesRequest = {
    typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesRequest",
    is(o) {
        return o && (o.$typeUrl === BatchEnableServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.serviceIds) && (!o.serviceIds.length || typeof o.serviceIds[0] === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === BatchEnableServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.service_ids) && (!o.service_ids.length || typeof o.service_ids[0] === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === BatchEnableServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.service_ids) && (!o.service_ids.length || typeof o.service_ids[0] === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.parent !== undefined) {
            writer.uint32(10).string(message.parent);
        }
        for (const v of message.serviceIds) {
            writer.uint32(18).string(v);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBatchEnableServicesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.parent = reader.string();
                    break;
                case 2:
                    message.serviceIds.push(reader.string());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBatchEnableServicesRequest();
        if (isSet(object.parent))
            obj.parent = String(object.parent);
        if (Array.isArray(object?.serviceIds))
            obj.serviceIds = object.serviceIds.map((e) => String(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.parent !== undefined && (obj.parent = message.parent);
        if (message.serviceIds) {
            obj.serviceIds = message.serviceIds.map(e => e);
        }
        else {
            obj.serviceIds = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBatchEnableServicesRequest();
        message.parent = object.parent ?? "";
        message.serviceIds = object.serviceIds?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            parent: object?.parent,
            serviceIds: Array.isArray(object?.service_ids) ? object.service_ids.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            parent: isSet(object.parent) ? String(object.parent) : "",
            service_ids: Array.isArray(object?.service_ids) ? object.service_ids.map((e) => String(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.parent = message.parent;
        if (message.serviceIds) {
            obj.service_ids = message.serviceIds.map(e => e);
        }
        else {
            obj.service_ids = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBatchEnableServicesRequest();
        if (object.parent !== undefined && object.parent !== null) {
            message.parent = object.parent;
        }
        message.serviceIds = object.service_ids?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.parent = message.parent === "" ? undefined : message.parent;
        if (message.serviceIds) {
            obj.service_ids = message.serviceIds.map(e => e);
        }
        else {
            obj.service_ids = message.serviceIds;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return BatchEnableServicesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BatchEnableServicesRequest.decode(message.value);
    },
    toProto(message) {
        return BatchEnableServicesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesRequest",
            value: BatchEnableServicesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBatchEnableServicesResponse() {
    return {
        services: [],
        failures: []
    };
}
export const BatchEnableServicesResponse = {
    typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesResponse",
    is(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.is(o.services[0])) && Array.isArray(o.failures) && (!o.failures.length || BatchEnableServicesResponse_EnableFailure.is(o.failures[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isSDK(o.services[0])) && Array.isArray(o.failures) && (!o.failures.length || BatchEnableServicesResponse_EnableFailure.isSDK(o.failures[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isAmino(o.services[0])) && Array.isArray(o.failures) && (!o.failures.length || BatchEnableServicesResponse_EnableFailure.isAmino(o.failures[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.services) {
            Service.encode(v, writer.uint32(10).fork()).ldelim();
        }
        for (const v of message.failures) {
            BatchEnableServicesResponse_EnableFailure.encode(v, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBatchEnableServicesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.services.push(Service.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.failures.push(BatchEnableServicesResponse_EnableFailure.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBatchEnableServicesResponse();
        if (Array.isArray(object?.services))
            obj.services = object.services.map((e) => Service.fromJSON(e));
        if (Array.isArray(object?.failures))
            obj.failures = object.failures.map((e) => BatchEnableServicesResponse_EnableFailure.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toJSON(e) : undefined);
        }
        else {
            obj.services = [];
        }
        if (message.failures) {
            obj.failures = message.failures.map(e => e ? BatchEnableServicesResponse_EnableFailure.toJSON(e) : undefined);
        }
        else {
            obj.failures = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBatchEnableServicesResponse();
        message.services = object.services?.map(e => Service.fromPartial(e)) || [];
        message.failures = object.failures?.map(e => BatchEnableServicesResponse_EnableFailure.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDK(e)) : [],
            failures: Array.isArray(object?.failures) ? object.failures.map((e) => BatchEnableServicesResponse_EnableFailure.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDKJSON(e)) : [],
            failures: Array.isArray(object?.failures) ? object.failures.map((e) => BatchEnableServicesResponse_EnableFailure.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toSDK(e) : undefined);
        }
        else {
            obj.services = [];
        }
        if (message.failures) {
            obj.failures = message.failures.map(e => e ? BatchEnableServicesResponse_EnableFailure.toSDK(e) : undefined);
        }
        else {
            obj.failures = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBatchEnableServicesResponse();
        message.services = object.services?.map(e => Service.fromAmino(e)) || [];
        message.failures = object.failures?.map(e => BatchEnableServicesResponse_EnableFailure.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toAmino(e) : undefined);
        }
        else {
            obj.services = message.services;
        }
        if (message.failures) {
            obj.failures = message.failures.map(e => e ? BatchEnableServicesResponse_EnableFailure.toAmino(e) : undefined);
        }
        else {
            obj.failures = message.failures;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return BatchEnableServicesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BatchEnableServicesResponse.decode(message.value);
    },
    toProto(message) {
        return BatchEnableServicesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesResponse",
            value: BatchEnableServicesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Service.registerTypeUrl();
        BatchEnableServicesResponse_EnableFailure.registerTypeUrl();
    }
};
function createBaseBatchEnableServicesResponse_EnableFailure() {
    return {
        serviceId: "",
        errorMessage: ""
    };
}
export const BatchEnableServicesResponse_EnableFailure = {
    typeUrl: "/google.api.serviceusage.v1.EnableFailure",
    is(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse_EnableFailure.typeUrl || typeof o.serviceId === "string" && typeof o.errorMessage === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse_EnableFailure.typeUrl || typeof o.service_id === "string" && typeof o.error_message === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BatchEnableServicesResponse_EnableFailure.typeUrl || typeof o.service_id === "string" && typeof o.error_message === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.serviceId !== undefined) {
            writer.uint32(10).string(message.serviceId);
        }
        if (message.errorMessage !== undefined) {
            writer.uint32(18).string(message.errorMessage);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBatchEnableServicesResponse_EnableFailure();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.serviceId = reader.string();
                    break;
                case 2:
                    message.errorMessage = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBatchEnableServicesResponse_EnableFailure();
        if (isSet(object.serviceId))
            obj.serviceId = String(object.serviceId);
        if (isSet(object.errorMessage))
            obj.errorMessage = String(object.errorMessage);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.serviceId !== undefined && (obj.serviceId = message.serviceId);
        message.errorMessage !== undefined && (obj.errorMessage = message.errorMessage);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBatchEnableServicesResponse_EnableFailure();
        message.serviceId = object.serviceId ?? "";
        message.errorMessage = object.errorMessage ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            serviceId: object?.service_id,
            errorMessage: object?.error_message
        };
    },
    fromSDKJSON(object) {
        return {
            service_id: isSet(object.service_id) ? String(object.service_id) : "",
            error_message: isSet(object.error_message) ? String(object.error_message) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.service_id = message.serviceId;
        obj.error_message = message.errorMessage;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBatchEnableServicesResponse_EnableFailure();
        if (object.service_id !== undefined && object.service_id !== null) {
            message.serviceId = object.service_id;
        }
        if (object.error_message !== undefined && object.error_message !== null) {
            message.errorMessage = object.error_message;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.service_id = message.serviceId === "" ? undefined : message.serviceId;
        obj.error_message = message.errorMessage === "" ? undefined : message.errorMessage;
        return obj;
    },
    fromAminoMsg(object) {
        return BatchEnableServicesResponse_EnableFailure.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BatchEnableServicesResponse_EnableFailure.decode(message.value);
    },
    toProto(message) {
        return BatchEnableServicesResponse_EnableFailure.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.EnableFailure",
            value: BatchEnableServicesResponse_EnableFailure.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBatchGetServicesRequest() {
    return {
        parent: "",
        names: []
    };
}
export const BatchGetServicesRequest = {
    typeUrl: "/google.api.serviceusage.v1.BatchGetServicesRequest",
    is(o) {
        return o && (o.$typeUrl === BatchGetServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.names) && (!o.names.length || typeof o.names[0] === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === BatchGetServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.names) && (!o.names.length || typeof o.names[0] === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === BatchGetServicesRequest.typeUrl || typeof o.parent === "string" && Array.isArray(o.names) && (!o.names.length || typeof o.names[0] === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.parent !== undefined) {
            writer.uint32(10).string(message.parent);
        }
        for (const v of message.names) {
            writer.uint32(18).string(v);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBatchGetServicesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.parent = reader.string();
                    break;
                case 2:
                    message.names.push(reader.string());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBatchGetServicesRequest();
        if (isSet(object.parent))
            obj.parent = String(object.parent);
        if (Array.isArray(object?.names))
            obj.names = object.names.map((e) => String(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.parent !== undefined && (obj.parent = message.parent);
        if (message.names) {
            obj.names = message.names.map(e => e);
        }
        else {
            obj.names = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBatchGetServicesRequest();
        message.parent = object.parent ?? "";
        message.names = object.names?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            parent: object?.parent,
            names: Array.isArray(object?.names) ? object.names.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            parent: isSet(object.parent) ? String(object.parent) : "",
            names: Array.isArray(object?.names) ? object.names.map((e) => String(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.parent = message.parent;
        if (message.names) {
            obj.names = message.names.map(e => e);
        }
        else {
            obj.names = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBatchGetServicesRequest();
        if (object.parent !== undefined && object.parent !== null) {
            message.parent = object.parent;
        }
        message.names = object.names?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.parent = message.parent === "" ? undefined : message.parent;
        if (message.names) {
            obj.names = message.names.map(e => e);
        }
        else {
            obj.names = message.names;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return BatchGetServicesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BatchGetServicesRequest.decode(message.value);
    },
    toProto(message) {
        return BatchGetServicesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.BatchGetServicesRequest",
            value: BatchGetServicesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBatchGetServicesResponse() {
    return {
        services: []
    };
}
export const BatchGetServicesResponse = {
    typeUrl: "/google.api.serviceusage.v1.BatchGetServicesResponse",
    is(o) {
        return o && (o.$typeUrl === BatchGetServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.is(o.services[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === BatchGetServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isSDK(o.services[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === BatchGetServicesResponse.typeUrl || Array.isArray(o.services) && (!o.services.length || Service.isAmino(o.services[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.services) {
            Service.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBatchGetServicesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.services.push(Service.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBatchGetServicesResponse();
        if (Array.isArray(object?.services))
            obj.services = object.services.map((e) => Service.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toJSON(e) : undefined);
        }
        else {
            obj.services = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBatchGetServicesResponse();
        message.services = object.services?.map(e => Service.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            services: Array.isArray(object?.services) ? object.services.map((e) => Service.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toSDK(e) : undefined);
        }
        else {
            obj.services = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBatchGetServicesResponse();
        message.services = object.services?.map(e => Service.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.services) {
            obj.services = message.services.map(e => e ? Service.toAmino(e) : undefined);
        }
        else {
            obj.services = message.services;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return BatchGetServicesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BatchGetServicesResponse.decode(message.value);
    },
    toProto(message) {
        return BatchGetServicesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1.BatchGetServicesResponse",
            value: BatchGetServicesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Service.registerTypeUrl();
    }
};
