import { Api } from "../../../protobuf/api";
import { Documentation } from "../../documentation";
import { Quota } from "../../quota";
import { Authentication } from "../../auth";
import { Usage } from "../../usage";
import { Endpoint } from "../../endpoint";
import { MonitoredResourceDescriptor } from "../../monitored_resource";
import { Monitoring } from "../../monitoring";
import { isSet, isObject } from "../../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../../binary";
export const protobufPackage = "google.api.serviceusage.v1beta1";
/** Whether or not a service has been enabled for use by a consumer. */
export var State;
(function (State) {
    /**
     * STATE_UNSPECIFIED - The default value, which indicates that the enabled state of the service
     * is unspecified or not meaningful. Currently, all consumers other than
     * projects (such as folders and organizations) are always in this state.
     */
    State[State["STATE_UNSPECIFIED"] = 0] = "STATE_UNSPECIFIED";
    /**
     * DISABLED - The service cannot be used by this consumer. It has either been explicitly
     * disabled, or has never been enabled.
     */
    State[State["DISABLED"] = 1] = "DISABLED";
    /** ENABLED - The service has been explicitly enabled for use by this consumer. */
    State[State["ENABLED"] = 2] = "ENABLED";
    State[State["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(State || (State = {}));
export const StateSDKType = State;
export const StateAmino = State;
export function stateFromJSON(object) {
    switch (object) {
        case 0:
        case "STATE_UNSPECIFIED":
            return State.STATE_UNSPECIFIED;
        case 1:
        case "DISABLED":
            return State.DISABLED;
        case 2:
        case "ENABLED":
            return State.ENABLED;
        case -1:
        case "UNRECOGNIZED":
        default:
            return State.UNRECOGNIZED;
    }
}
export function stateToJSON(object) {
    switch (object) {
        case State.STATE_UNSPECIFIED:
            return "STATE_UNSPECIFIED";
        case State.DISABLED:
            return "DISABLED";
        case State.ENABLED:
            return "ENABLED";
        case State.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
/**
 * Selected view of quota. Can be used to request more detailed quota
 * information when retrieving quota metrics and limits.
 */
export var QuotaView;
(function (QuotaView) {
    /**
     * QUOTA_VIEW_UNSPECIFIED - No quota view specified. Requests that do not specify a quota view will
     * typically default to the BASIC view.
     */
    QuotaView[QuotaView["QUOTA_VIEW_UNSPECIFIED"] = 0] = "QUOTA_VIEW_UNSPECIFIED";
    /** BASIC - Only buckets with overrides are shown in the response. */
    QuotaView[QuotaView["BASIC"] = 1] = "BASIC";
    /**
     * FULL - Include per-location buckets even if they do not have overrides.
     * When the view is FULL, and a limit has regional or zonal quota, the limit
     * will include buckets for all regions or zones that could support
     * overrides, even if none are currently present. In some cases this will
     * cause the response to become very large; callers that do not need this
     * extra information should use the BASIC view instead.
     */
    QuotaView[QuotaView["FULL"] = 2] = "FULL";
    QuotaView[QuotaView["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(QuotaView || (QuotaView = {}));
export const QuotaViewSDKType = QuotaView;
export const QuotaViewAmino = QuotaView;
export function quotaViewFromJSON(object) {
    switch (object) {
        case 0:
        case "QUOTA_VIEW_UNSPECIFIED":
            return QuotaView.QUOTA_VIEW_UNSPECIFIED;
        case 1:
        case "BASIC":
            return QuotaView.BASIC;
        case 2:
        case "FULL":
            return QuotaView.FULL;
        case -1:
        case "UNRECOGNIZED":
        default:
            return QuotaView.UNRECOGNIZED;
    }
}
export function quotaViewToJSON(object) {
    switch (object) {
        case QuotaView.QUOTA_VIEW_UNSPECIFIED:
            return "QUOTA_VIEW_UNSPECIFIED";
        case QuotaView.BASIC:
            return "BASIC";
        case QuotaView.FULL:
            return "FULL";
        case QuotaView.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
/** Enumerations of quota safety checks. */
export var QuotaSafetyCheck;
(function (QuotaSafetyCheck) {
    /** QUOTA_SAFETY_CHECK_UNSPECIFIED - Unspecified quota safety check. */
    QuotaSafetyCheck[QuotaSafetyCheck["QUOTA_SAFETY_CHECK_UNSPECIFIED"] = 0] = "QUOTA_SAFETY_CHECK_UNSPECIFIED";
    /**
     * LIMIT_DECREASE_BELOW_USAGE - Validates that a quota mutation would not cause the consumer's effective
     * limit to be lower than the consumer's quota usage.
     */
    QuotaSafetyCheck[QuotaSafetyCheck["LIMIT_DECREASE_BELOW_USAGE"] = 1] = "LIMIT_DECREASE_BELOW_USAGE";
    /**
     * LIMIT_DECREASE_PERCENTAGE_TOO_HIGH - Validates that a quota mutation would not cause the consumer's effective
     * limit to decrease by more than 10 percent.
     */
    QuotaSafetyCheck[QuotaSafetyCheck["LIMIT_DECREASE_PERCENTAGE_TOO_HIGH"] = 2] = "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH";
    QuotaSafetyCheck[QuotaSafetyCheck["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(QuotaSafetyCheck || (QuotaSafetyCheck = {}));
export const QuotaSafetyCheckSDKType = QuotaSafetyCheck;
export const QuotaSafetyCheckAmino = QuotaSafetyCheck;
export function quotaSafetyCheckFromJSON(object) {
    switch (object) {
        case 0:
        case "QUOTA_SAFETY_CHECK_UNSPECIFIED":
            return QuotaSafetyCheck.QUOTA_SAFETY_CHECK_UNSPECIFIED;
        case 1:
        case "LIMIT_DECREASE_BELOW_USAGE":
            return QuotaSafetyCheck.LIMIT_DECREASE_BELOW_USAGE;
        case 2:
        case "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH":
            return QuotaSafetyCheck.LIMIT_DECREASE_PERCENTAGE_TOO_HIGH;
        case -1:
        case "UNRECOGNIZED":
        default:
            return QuotaSafetyCheck.UNRECOGNIZED;
    }
}
export function quotaSafetyCheckToJSON(object) {
    switch (object) {
        case QuotaSafetyCheck.QUOTA_SAFETY_CHECK_UNSPECIFIED:
            return "QUOTA_SAFETY_CHECK_UNSPECIFIED";
        case QuotaSafetyCheck.LIMIT_DECREASE_BELOW_USAGE:
            return "LIMIT_DECREASE_BELOW_USAGE";
        case QuotaSafetyCheck.LIMIT_DECREASE_PERCENTAGE_TOO_HIGH:
            return "LIMIT_DECREASE_PERCENTAGE_TOO_HIGH";
        case QuotaSafetyCheck.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseService() {
    return {
        name: "",
        parent: "",
        config: undefined,
        state: 0
    };
}
export const Service = {
    typeUrl: "/google.api.serviceusage.v1beta1.Service",
    is(o) {
        return o && (o.$typeUrl === Service.typeUrl || typeof o.name === "string" && typeof o.parent === "string" && isSet(o.state));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Service.typeUrl || typeof o.name === "string" && typeof o.parent === "string" && isSet(o.state));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Service.typeUrl || typeof o.name === "string" && typeof o.parent === "string" && isSet(o.state));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.parent !== undefined) {
            writer.uint32(42).string(message.parent);
        }
        if (message.config !== undefined) {
            ServiceConfig.encode(message.config, writer.uint32(18).fork()).ldelim();
        }
        if (message.state !== 0) {
            writer.uint32(32).int32(message.state);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseService();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 5:
                    message.parent = reader.string();
                    break;
                case 2:
                    message.config = ServiceConfig.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.state = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseService();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.parent))
            obj.parent = String(object.parent);
        if (isSet(object.config))
            obj.config = ServiceConfig.fromJSON(object.config);
        if (isSet(object.state))
            obj.state = stateFromJSON(object.state);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.parent !== undefined && (obj.parent = message.parent);
        message.config !== undefined && (obj.config = message.config ? ServiceConfig.toJSON(message.config) : undefined);
        message.state !== undefined && (obj.state = stateToJSON(message.state));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseService();
        message.name = object.name ?? "";
        message.parent = object.parent ?? "";
        if (object.config !== undefined && object.config !== null) {
            message.config = ServiceConfig.fromPartial(object.config);
        }
        message.state = object.state ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            parent: object?.parent,
            config: object.config ? ServiceConfig.fromSDK(object.config) : undefined,
            state: isSet(object.state) ? stateFromJSON(object.state) : -1
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            parent: isSet(object.parent) ? String(object.parent) : "",
            config: isSet(object.config) ? ServiceConfig.fromSDKJSON(object.config) : undefined,
            state: isSet(object.state) ? stateFromJSON(object.state) : -1
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.parent = message.parent;
        message.config !== undefined && (obj.config = message.config ? ServiceConfig.toSDK(message.config) : undefined);
        message.state !== undefined && (obj.state = stateToJSON(message.state));
        return obj;
    },
    fromAmino(object) {
        const message = createBaseService();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.parent !== undefined && object.parent !== null) {
            message.parent = object.parent;
        }
        if (object.config !== undefined && object.config !== null) {
            message.config = ServiceConfig.fromAmino(object.config);
        }
        if (object.state !== undefined && object.state !== null) {
            message.state = object.state;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.parent = message.parent === "" ? undefined : message.parent;
        obj.config = message.config ? ServiceConfig.toAmino(message.config) : undefined;
        obj.state = message.state === 0 ? undefined : message.state;
        return obj;
    },
    fromAminoMsg(object) {
        return Service.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Service.decode(message.value);
    },
    toProto(message) {
        return Service.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.Service",
            value: Service.encode(message).finish()
        };
    },
    registerTypeUrl() {
        ServiceConfig.registerTypeUrl();
    }
};
function createBaseServiceConfig() {
    return {
        name: "",
        title: "",
        apis: [],
        documentation: undefined,
        quota: undefined,
        authentication: undefined,
        usage: undefined,
        endpoints: [],
        monitoredResources: [],
        monitoring: undefined
    };
}
export const ServiceConfig = {
    typeUrl: "/google.api.serviceusage.v1beta1.ServiceConfig",
    is(o) {
        return o && (o.$typeUrl === ServiceConfig.typeUrl || typeof o.name === "string" && typeof o.title === "string" && Array.isArray(o.apis) && (!o.apis.length || Api.is(o.apis[0])) && Array.isArray(o.endpoints) && (!o.endpoints.length || Endpoint.is(o.endpoints[0])) && Array.isArray(o.monitoredResources) && (!o.monitoredResources.length || MonitoredResourceDescriptor.is(o.monitoredResources[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ServiceConfig.typeUrl || typeof o.name === "string" && typeof o.title === "string" && Array.isArray(o.apis) && (!o.apis.length || Api.isSDK(o.apis[0])) && Array.isArray(o.endpoints) && (!o.endpoints.length || Endpoint.isSDK(o.endpoints[0])) && Array.isArray(o.monitored_resources) && (!o.monitored_resources.length || MonitoredResourceDescriptor.isSDK(o.monitored_resources[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ServiceConfig.typeUrl || typeof o.name === "string" && typeof o.title === "string" && Array.isArray(o.apis) && (!o.apis.length || Api.isAmino(o.apis[0])) && Array.isArray(o.endpoints) && (!o.endpoints.length || Endpoint.isAmino(o.endpoints[0])) && Array.isArray(o.monitored_resources) && (!o.monitored_resources.length || MonitoredResourceDescriptor.isAmino(o.monitored_resources[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.title !== undefined) {
            writer.uint32(18).string(message.title);
        }
        for (const v of message.apis) {
            Api.encode(v, writer.uint32(26).fork()).ldelim();
        }
        if (message.documentation !== undefined) {
            Documentation.encode(message.documentation, writer.uint32(50).fork()).ldelim();
        }
        if (message.quota !== undefined) {
            Quota.encode(message.quota, writer.uint32(82).fork()).ldelim();
        }
        if (message.authentication !== undefined) {
            Authentication.encode(message.authentication, writer.uint32(90).fork()).ldelim();
        }
        if (message.usage !== undefined) {
            Usage.encode(message.usage, writer.uint32(122).fork()).ldelim();
        }
        for (const v of message.endpoints) {
            Endpoint.encode(v, writer.uint32(146).fork()).ldelim();
        }
        for (const v of message.monitoredResources) {
            MonitoredResourceDescriptor.encode(v, writer.uint32(202).fork()).ldelim();
        }
        if (message.monitoring !== undefined) {
            Monitoring.encode(message.monitoring, writer.uint32(226).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseServiceConfig();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.title = reader.string();
                    break;
                case 3:
                    message.apis.push(Api.decode(reader, reader.uint32()));
                    break;
                case 6:
                    message.documentation = Documentation.decode(reader, reader.uint32());
                    break;
                case 10:
                    message.quota = Quota.decode(reader, reader.uint32());
                    break;
                case 11:
                    message.authentication = Authentication.decode(reader, reader.uint32());
                    break;
                case 15:
                    message.usage = Usage.decode(reader, reader.uint32());
                    break;
                case 18:
                    message.endpoints.push(Endpoint.decode(reader, reader.uint32()));
                    break;
                case 25:
                    message.monitoredResources.push(MonitoredResourceDescriptor.decode(reader, reader.uint32()));
                    break;
                case 28:
                    message.monitoring = Monitoring.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseServiceConfig();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.title))
            obj.title = String(object.title);
        if (Array.isArray(object?.apis))
            obj.apis = object.apis.map((e) => Api.fromJSON(e));
        if (isSet(object.documentation))
            obj.documentation = Documentation.fromJSON(object.documentation);
        if (isSet(object.quota))
            obj.quota = Quota.fromJSON(object.quota);
        if (isSet(object.authentication))
            obj.authentication = Authentication.fromJSON(object.authentication);
        if (isSet(object.usage))
            obj.usage = Usage.fromJSON(object.usage);
        if (Array.isArray(object?.endpoints))
            obj.endpoints = object.endpoints.map((e) => Endpoint.fromJSON(e));
        if (Array.isArray(object?.monitoredResources))
            obj.monitoredResources = object.monitoredResources.map((e) => MonitoredResourceDescriptor.fromJSON(e));
        if (isSet(object.monitoring))
            obj.monitoring = Monitoring.fromJSON(object.monitoring);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.title !== undefined && (obj.title = message.title);
        if (message.apis) {
            obj.apis = message.apis.map(e => e ? Api.toJSON(e) : undefined);
        }
        else {
            obj.apis = [];
        }
        message.documentation !== undefined && (obj.documentation = message.documentation ? Documentation.toJSON(message.documentation) : undefined);
        message.quota !== undefined && (obj.quota = message.quota ? Quota.toJSON(message.quota) : undefined);
        message.authentication !== undefined && (obj.authentication = message.authentication ? Authentication.toJSON(message.authentication) : undefined);
        message.usage !== undefined && (obj.usage = message.usage ? Usage.toJSON(message.usage) : undefined);
        if (message.endpoints) {
            obj.endpoints = message.endpoints.map(e => e ? Endpoint.toJSON(e) : undefined);
        }
        else {
            obj.endpoints = [];
        }
        if (message.monitoredResources) {
            obj.monitoredResources = message.monitoredResources.map(e => e ? MonitoredResourceDescriptor.toJSON(e) : undefined);
        }
        else {
            obj.monitoredResources = [];
        }
        message.monitoring !== undefined && (obj.monitoring = message.monitoring ? Monitoring.toJSON(message.monitoring) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseServiceConfig();
        message.name = object.name ?? "";
        message.title = object.title ?? "";
        message.apis = object.apis?.map(e => Api.fromPartial(e)) || [];
        if (object.documentation !== undefined && object.documentation !== null) {
            message.documentation = Documentation.fromPartial(object.documentation);
        }
        if (object.quota !== undefined && object.quota !== null) {
            message.quota = Quota.fromPartial(object.quota);
        }
        if (object.authentication !== undefined && object.authentication !== null) {
            message.authentication = Authentication.fromPartial(object.authentication);
        }
        if (object.usage !== undefined && object.usage !== null) {
            message.usage = Usage.fromPartial(object.usage);
        }
        message.endpoints = object.endpoints?.map(e => Endpoint.fromPartial(e)) || [];
        message.monitoredResources = object.monitoredResources?.map(e => MonitoredResourceDescriptor.fromPartial(e)) || [];
        if (object.monitoring !== undefined && object.monitoring !== null) {
            message.monitoring = Monitoring.fromPartial(object.monitoring);
        }
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            title: object?.title,
            apis: Array.isArray(object?.apis) ? object.apis.map((e) => Api.fromSDK(e)) : [],
            documentation: object.documentation ? Documentation.fromSDK(object.documentation) : undefined,
            quota: object.quota ? Quota.fromSDK(object.quota) : undefined,
            authentication: object.authentication ? Authentication.fromSDK(object.authentication) : undefined,
            usage: object.usage ? Usage.fromSDK(object.usage) : undefined,
            endpoints: Array.isArray(object?.endpoints) ? object.endpoints.map((e) => Endpoint.fromSDK(e)) : [],
            monitoredResources: Array.isArray(object?.monitored_resources) ? object.monitored_resources.map((e) => MonitoredResourceDescriptor.fromSDK(e)) : [],
            monitoring: object.monitoring ? Monitoring.fromSDK(object.monitoring) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            title: isSet(object.title) ? String(object.title) : "",
            apis: Array.isArray(object?.apis) ? object.apis.map((e) => Api.fromSDKJSON(e)) : [],
            documentation: isSet(object.documentation) ? Documentation.fromSDKJSON(object.documentation) : undefined,
            quota: isSet(object.quota) ? Quota.fromSDKJSON(object.quota) : undefined,
            authentication: isSet(object.authentication) ? Authentication.fromSDKJSON(object.authentication) : undefined,
            usage: isSet(object.usage) ? Usage.fromSDKJSON(object.usage) : undefined,
            endpoints: Array.isArray(object?.endpoints) ? object.endpoints.map((e) => Endpoint.fromSDKJSON(e)) : [],
            monitored_resources: Array.isArray(object?.monitored_resources) ? object.monitored_resources.map((e) => MonitoredResourceDescriptor.fromSDKJSON(e)) : [],
            monitoring: isSet(object.monitoring) ? Monitoring.fromSDKJSON(object.monitoring) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.title = message.title;
        if (message.apis) {
            obj.apis = message.apis.map(e => e ? Api.toSDK(e) : undefined);
        }
        else {
            obj.apis = [];
        }
        message.documentation !== undefined && (obj.documentation = message.documentation ? Documentation.toSDK(message.documentation) : undefined);
        message.quota !== undefined && (obj.quota = message.quota ? Quota.toSDK(message.quota) : undefined);
        message.authentication !== undefined && (obj.authentication = message.authentication ? Authentication.toSDK(message.authentication) : undefined);
        message.usage !== undefined && (obj.usage = message.usage ? Usage.toSDK(message.usage) : undefined);
        if (message.endpoints) {
            obj.endpoints = message.endpoints.map(e => e ? Endpoint.toSDK(e) : undefined);
        }
        else {
            obj.endpoints = [];
        }
        if (message.monitoredResources) {
            obj.monitored_resources = message.monitoredResources.map(e => e ? MonitoredResourceDescriptor.toSDK(e) : undefined);
        }
        else {
            obj.monitored_resources = [];
        }
        message.monitoring !== undefined && (obj.monitoring = message.monitoring ? Monitoring.toSDK(message.monitoring) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseServiceConfig();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.title !== undefined && object.title !== null) {
            message.title = object.title;
        }
        message.apis = object.apis?.map(e => Api.fromAmino(e)) || [];
        if (object.documentation !== undefined && object.documentation !== null) {
            message.documentation = Documentation.fromAmino(object.documentation);
        }
        if (object.quota !== undefined && object.quota !== null) {
            message.quota = Quota.fromAmino(object.quota);
        }
        if (object.authentication !== undefined && object.authentication !== null) {
            message.authentication = Authentication.fromAmino(object.authentication);
        }
        if (object.usage !== undefined && object.usage !== null) {
            message.usage = Usage.fromAmino(object.usage);
        }
        message.endpoints = object.endpoints?.map(e => Endpoint.fromAmino(e)) || [];
        message.monitoredResources = object.monitored_resources?.map(e => MonitoredResourceDescriptor.fromAmino(e)) || [];
        if (object.monitoring !== undefined && object.monitoring !== null) {
            message.monitoring = Monitoring.fromAmino(object.monitoring);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.title = message.title === "" ? undefined : message.title;
        if (message.apis) {
            obj.apis = message.apis.map(e => e ? Api.toAmino(e) : undefined);
        }
        else {
            obj.apis = message.apis;
        }
        obj.documentation = message.documentation ? Documentation.toAmino(message.documentation) : undefined;
        obj.quota = message.quota ? Quota.toAmino(message.quota) : undefined;
        obj.authentication = message.authentication ? Authentication.toAmino(message.authentication) : undefined;
        obj.usage = message.usage ? Usage.toAmino(message.usage) : undefined;
        if (message.endpoints) {
            obj.endpoints = message.endpoints.map(e => e ? Endpoint.toAmino(e) : undefined);
        }
        else {
            obj.endpoints = message.endpoints;
        }
        if (message.monitoredResources) {
            obj.monitored_resources = message.monitoredResources.map(e => e ? MonitoredResourceDescriptor.toAmino(e) : undefined);
        }
        else {
            obj.monitored_resources = message.monitoredResources;
        }
        obj.monitoring = message.monitoring ? Monitoring.toAmino(message.monitoring) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return ServiceConfig.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ServiceConfig.decode(message.value);
    },
    toProto(message) {
        return ServiceConfig.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.ServiceConfig",
            value: ServiceConfig.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Api.registerTypeUrl();
        Documentation.registerTypeUrl();
        Quota.registerTypeUrl();
        Authentication.registerTypeUrl();
        Usage.registerTypeUrl();
        Endpoint.registerTypeUrl();
        MonitoredResourceDescriptor.registerTypeUrl();
        Monitoring.registerTypeUrl();
    }
};
function createBaseOperationMetadata() {
    return {
        resourceNames: []
    };
}
export const OperationMetadata = {
    typeUrl: "/google.api.serviceusage.v1beta1.OperationMetadata",
    is(o) {
        return o && (o.$typeUrl === OperationMetadata.typeUrl || Array.isArray(o.resourceNames) && (!o.resourceNames.length || typeof o.resourceNames[0] === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === OperationMetadata.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === OperationMetadata.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.resourceNames) {
            writer.uint32(18).string(v);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseOperationMetadata();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 2:
                    message.resourceNames.push(reader.string());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseOperationMetadata();
        if (Array.isArray(object?.resourceNames))
            obj.resourceNames = object.resourceNames.map((e) => String(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resourceNames = message.resourceNames.map(e => e);
        }
        else {
            obj.resourceNames = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseOperationMetadata();
        message.resourceNames = object.resourceNames?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            resourceNames: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            resource_names: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => String(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseOperationMetadata();
        message.resourceNames = object.resource_names?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = message.resourceNames;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return OperationMetadata.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return OperationMetadata.decode(message.value);
    },
    toProto(message) {
        return OperationMetadata.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.OperationMetadata",
            value: OperationMetadata.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseConsumerQuotaMetric() {
    return {
        name: "",
        metric: "",
        displayName: "",
        consumerQuotaLimits: [],
        descendantConsumerQuotaLimits: [],
        unit: ""
    };
}
export const ConsumerQuotaMetric = {
    typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaMetric",
    is(o) {
        return o && (o.$typeUrl === ConsumerQuotaMetric.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.displayName === "string" && Array.isArray(o.consumerQuotaLimits) && (!o.consumerQuotaLimits.length || ConsumerQuotaLimit.is(o.consumerQuotaLimits[0])) && Array.isArray(o.descendantConsumerQuotaLimits) && (!o.descendantConsumerQuotaLimits.length || ConsumerQuotaLimit.is(o.descendantConsumerQuotaLimits[0])) && typeof o.unit === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ConsumerQuotaMetric.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.display_name === "string" && Array.isArray(o.consumer_quota_limits) && (!o.consumer_quota_limits.length || ConsumerQuotaLimit.isSDK(o.consumer_quota_limits[0])) && Array.isArray(o.descendant_consumer_quota_limits) && (!o.descendant_consumer_quota_limits.length || ConsumerQuotaLimit.isSDK(o.descendant_consumer_quota_limits[0])) && typeof o.unit === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ConsumerQuotaMetric.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.display_name === "string" && Array.isArray(o.consumer_quota_limits) && (!o.consumer_quota_limits.length || ConsumerQuotaLimit.isAmino(o.consumer_quota_limits[0])) && Array.isArray(o.descendant_consumer_quota_limits) && (!o.descendant_consumer_quota_limits.length || ConsumerQuotaLimit.isAmino(o.descendant_consumer_quota_limits[0])) && typeof o.unit === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.metric !== undefined) {
            writer.uint32(34).string(message.metric);
        }
        if (message.displayName !== undefined) {
            writer.uint32(18).string(message.displayName);
        }
        for (const v of message.consumerQuotaLimits) {
            ConsumerQuotaLimit.encode(v, writer.uint32(26).fork()).ldelim();
        }
        for (const v of message.descendantConsumerQuotaLimits) {
            ConsumerQuotaLimit.encode(v, writer.uint32(50).fork()).ldelim();
        }
        if (message.unit !== undefined) {
            writer.uint32(42).string(message.unit);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseConsumerQuotaMetric();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 4:
                    message.metric = reader.string();
                    break;
                case 2:
                    message.displayName = reader.string();
                    break;
                case 3:
                    message.consumerQuotaLimits.push(ConsumerQuotaLimit.decode(reader, reader.uint32()));
                    break;
                case 6:
                    message.descendantConsumerQuotaLimits.push(ConsumerQuotaLimit.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.unit = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseConsumerQuotaMetric();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.metric))
            obj.metric = String(object.metric);
        if (isSet(object.displayName))
            obj.displayName = String(object.displayName);
        if (Array.isArray(object?.consumerQuotaLimits))
            obj.consumerQuotaLimits = object.consumerQuotaLimits.map((e) => ConsumerQuotaLimit.fromJSON(e));
        if (Array.isArray(object?.descendantConsumerQuotaLimits))
            obj.descendantConsumerQuotaLimits = object.descendantConsumerQuotaLimits.map((e) => ConsumerQuotaLimit.fromJSON(e));
        if (isSet(object.unit))
            obj.unit = String(object.unit);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.metric !== undefined && (obj.metric = message.metric);
        message.displayName !== undefined && (obj.displayName = message.displayName);
        if (message.consumerQuotaLimits) {
            obj.consumerQuotaLimits = message.consumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toJSON(e) : undefined);
        }
        else {
            obj.consumerQuotaLimits = [];
        }
        if (message.descendantConsumerQuotaLimits) {
            obj.descendantConsumerQuotaLimits = message.descendantConsumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toJSON(e) : undefined);
        }
        else {
            obj.descendantConsumerQuotaLimits = [];
        }
        message.unit !== undefined && (obj.unit = message.unit);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseConsumerQuotaMetric();
        message.name = object.name ?? "";
        message.metric = object.metric ?? "";
        message.displayName = object.displayName ?? "";
        message.consumerQuotaLimits = object.consumerQuotaLimits?.map(e => ConsumerQuotaLimit.fromPartial(e)) || [];
        message.descendantConsumerQuotaLimits = object.descendantConsumerQuotaLimits?.map(e => ConsumerQuotaLimit.fromPartial(e)) || [];
        message.unit = object.unit ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            metric: object?.metric,
            displayName: object?.display_name,
            consumerQuotaLimits: Array.isArray(object?.consumer_quota_limits) ? object.consumer_quota_limits.map((e) => ConsumerQuotaLimit.fromSDK(e)) : [],
            descendantConsumerQuotaLimits: Array.isArray(object?.descendant_consumer_quota_limits) ? object.descendant_consumer_quota_limits.map((e) => ConsumerQuotaLimit.fromSDK(e)) : [],
            unit: object?.unit
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            metric: isSet(object.metric) ? String(object.metric) : "",
            display_name: isSet(object.display_name) ? String(object.display_name) : "",
            consumer_quota_limits: Array.isArray(object?.consumer_quota_limits) ? object.consumer_quota_limits.map((e) => ConsumerQuotaLimit.fromSDKJSON(e)) : [],
            descendant_consumer_quota_limits: Array.isArray(object?.descendant_consumer_quota_limits) ? object.descendant_consumer_quota_limits.map((e) => ConsumerQuotaLimit.fromSDKJSON(e)) : [],
            unit: isSet(object.unit) ? String(object.unit) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.metric = message.metric;
        obj.display_name = message.displayName;
        if (message.consumerQuotaLimits) {
            obj.consumer_quota_limits = message.consumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toSDK(e) : undefined);
        }
        else {
            obj.consumer_quota_limits = [];
        }
        if (message.descendantConsumerQuotaLimits) {
            obj.descendant_consumer_quota_limits = message.descendantConsumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toSDK(e) : undefined);
        }
        else {
            obj.descendant_consumer_quota_limits = [];
        }
        obj.unit = message.unit;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseConsumerQuotaMetric();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.metric !== undefined && object.metric !== null) {
            message.metric = object.metric;
        }
        if (object.display_name !== undefined && object.display_name !== null) {
            message.displayName = object.display_name;
        }
        message.consumerQuotaLimits = object.consumer_quota_limits?.map(e => ConsumerQuotaLimit.fromAmino(e)) || [];
        message.descendantConsumerQuotaLimits = object.descendant_consumer_quota_limits?.map(e => ConsumerQuotaLimit.fromAmino(e)) || [];
        if (object.unit !== undefined && object.unit !== null) {
            message.unit = object.unit;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.metric = message.metric === "" ? undefined : message.metric;
        obj.display_name = message.displayName === "" ? undefined : message.displayName;
        if (message.consumerQuotaLimits) {
            obj.consumer_quota_limits = message.consumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toAmino(e) : undefined);
        }
        else {
            obj.consumer_quota_limits = message.consumerQuotaLimits;
        }
        if (message.descendantConsumerQuotaLimits) {
            obj.descendant_consumer_quota_limits = message.descendantConsumerQuotaLimits.map(e => e ? ConsumerQuotaLimit.toAmino(e) : undefined);
        }
        else {
            obj.descendant_consumer_quota_limits = message.descendantConsumerQuotaLimits;
        }
        obj.unit = message.unit === "" ? undefined : message.unit;
        return obj;
    },
    fromAminoMsg(object) {
        return ConsumerQuotaMetric.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ConsumerQuotaMetric.decode(message.value);
    },
    toProto(message) {
        return ConsumerQuotaMetric.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaMetric",
            value: ConsumerQuotaMetric.encode(message).finish()
        };
    },
    registerTypeUrl() {
        ConsumerQuotaLimit.registerTypeUrl();
    }
};
function createBaseConsumerQuotaLimit() {
    return {
        name: "",
        metric: "",
        unit: "",
        isPrecise: false,
        allowsAdminOverrides: false,
        quotaBuckets: []
    };
}
export const ConsumerQuotaLimit = {
    typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaLimit",
    is(o) {
        return o && (o.$typeUrl === ConsumerQuotaLimit.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.isPrecise === "boolean" && typeof o.allowsAdminOverrides === "boolean" && Array.isArray(o.quotaBuckets) && (!o.quotaBuckets.length || QuotaBucket.is(o.quotaBuckets[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ConsumerQuotaLimit.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.is_precise === "boolean" && typeof o.allows_admin_overrides === "boolean" && Array.isArray(o.quota_buckets) && (!o.quota_buckets.length || QuotaBucket.isSDK(o.quota_buckets[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ConsumerQuotaLimit.typeUrl || typeof o.name === "string" && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.is_precise === "boolean" && typeof o.allows_admin_overrides === "boolean" && Array.isArray(o.quota_buckets) && (!o.quota_buckets.length || QuotaBucket.isAmino(o.quota_buckets[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.metric !== undefined) {
            writer.uint32(66).string(message.metric);
        }
        if (message.unit !== undefined) {
            writer.uint32(18).string(message.unit);
        }
        if (message.isPrecise !== undefined) {
            writer.uint32(24).bool(message.isPrecise);
        }
        if (message.allowsAdminOverrides !== undefined) {
            writer.uint32(56).bool(message.allowsAdminOverrides);
        }
        for (const v of message.quotaBuckets) {
            QuotaBucket.encode(v, writer.uint32(74).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseConsumerQuotaLimit();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 8:
                    message.metric = reader.string();
                    break;
                case 2:
                    message.unit = reader.string();
                    break;
                case 3:
                    message.isPrecise = reader.bool();
                    break;
                case 7:
                    message.allowsAdminOverrides = reader.bool();
                    break;
                case 9:
                    message.quotaBuckets.push(QuotaBucket.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseConsumerQuotaLimit();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.metric))
            obj.metric = String(object.metric);
        if (isSet(object.unit))
            obj.unit = String(object.unit);
        if (isSet(object.isPrecise))
            obj.isPrecise = Boolean(object.isPrecise);
        if (isSet(object.allowsAdminOverrides))
            obj.allowsAdminOverrides = Boolean(object.allowsAdminOverrides);
        if (Array.isArray(object?.quotaBuckets))
            obj.quotaBuckets = object.quotaBuckets.map((e) => QuotaBucket.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.metric !== undefined && (obj.metric = message.metric);
        message.unit !== undefined && (obj.unit = message.unit);
        message.isPrecise !== undefined && (obj.isPrecise = message.isPrecise);
        message.allowsAdminOverrides !== undefined && (obj.allowsAdminOverrides = message.allowsAdminOverrides);
        if (message.quotaBuckets) {
            obj.quotaBuckets = message.quotaBuckets.map(e => e ? QuotaBucket.toJSON(e) : undefined);
        }
        else {
            obj.quotaBuckets = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseConsumerQuotaLimit();
        message.name = object.name ?? "";
        message.metric = object.metric ?? "";
        message.unit = object.unit ?? "";
        message.isPrecise = object.isPrecise ?? false;
        message.allowsAdminOverrides = object.allowsAdminOverrides ?? false;
        message.quotaBuckets = object.quotaBuckets?.map(e => QuotaBucket.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            metric: object?.metric,
            unit: object?.unit,
            isPrecise: object?.is_precise,
            allowsAdminOverrides: object?.allows_admin_overrides,
            quotaBuckets: Array.isArray(object?.quota_buckets) ? object.quota_buckets.map((e) => QuotaBucket.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            metric: isSet(object.metric) ? String(object.metric) : "",
            unit: isSet(object.unit) ? String(object.unit) : "",
            is_precise: isSet(object.is_precise) ? Boolean(object.is_precise) : false,
            allows_admin_overrides: isSet(object.allows_admin_overrides) ? Boolean(object.allows_admin_overrides) : false,
            quota_buckets: Array.isArray(object?.quota_buckets) ? object.quota_buckets.map((e) => QuotaBucket.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.metric = message.metric;
        obj.unit = message.unit;
        obj.is_precise = message.isPrecise;
        obj.allows_admin_overrides = message.allowsAdminOverrides;
        if (message.quotaBuckets) {
            obj.quota_buckets = message.quotaBuckets.map(e => e ? QuotaBucket.toSDK(e) : undefined);
        }
        else {
            obj.quota_buckets = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseConsumerQuotaLimit();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.metric !== undefined && object.metric !== null) {
            message.metric = object.metric;
        }
        if (object.unit !== undefined && object.unit !== null) {
            message.unit = object.unit;
        }
        if (object.is_precise !== undefined && object.is_precise !== null) {
            message.isPrecise = object.is_precise;
        }
        if (object.allows_admin_overrides !== undefined && object.allows_admin_overrides !== null) {
            message.allowsAdminOverrides = object.allows_admin_overrides;
        }
        message.quotaBuckets = object.quota_buckets?.map(e => QuotaBucket.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.metric = message.metric === "" ? undefined : message.metric;
        obj.unit = message.unit === "" ? undefined : message.unit;
        obj.is_precise = message.isPrecise === false ? undefined : message.isPrecise;
        obj.allows_admin_overrides = message.allowsAdminOverrides === false ? undefined : message.allowsAdminOverrides;
        if (message.quotaBuckets) {
            obj.quota_buckets = message.quotaBuckets.map(e => e ? QuotaBucket.toAmino(e) : undefined);
        }
        else {
            obj.quota_buckets = message.quotaBuckets;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ConsumerQuotaLimit.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ConsumerQuotaLimit.decode(message.value);
    },
    toProto(message) {
        return ConsumerQuotaLimit.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaLimit",
            value: ConsumerQuotaLimit.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaBucket.registerTypeUrl();
    }
};
function createBaseQuotaBucket_DimensionsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const QuotaBucket_DimensionsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaBucket_DimensionsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaBucket_DimensionsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaBucket_DimensionsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaBucket_DimensionsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaBucket_DimensionsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaBucket_DimensionsEntry.decode(message.value);
    },
    toProto(message) {
        return QuotaBucket_DimensionsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseQuotaBucket() {
    return {
        effectiveLimit: BigInt(0),
        defaultLimit: BigInt(0),
        producerOverride: undefined,
        consumerOverride: undefined,
        adminOverride: undefined,
        dimensions: {}
    };
}
export const QuotaBucket = {
    typeUrl: "/google.api.serviceusage.v1beta1.QuotaBucket",
    is(o) {
        return o && (o.$typeUrl === QuotaBucket.typeUrl || typeof o.effectiveLimit === "bigint" && typeof o.defaultLimit === "bigint" && isSet(o.dimensions));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaBucket.typeUrl || typeof o.effective_limit === "bigint" && typeof o.default_limit === "bigint" && isSet(o.dimensions));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaBucket.typeUrl || typeof o.effective_limit === "bigint" && typeof o.default_limit === "bigint" && isSet(o.dimensions));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.effectiveLimit !== undefined) {
            writer.uint32(8).int64(message.effectiveLimit);
        }
        if (message.defaultLimit !== undefined) {
            writer.uint32(16).int64(message.defaultLimit);
        }
        if (message.producerOverride !== undefined) {
            QuotaOverride.encode(message.producerOverride, writer.uint32(26).fork()).ldelim();
        }
        if (message.consumerOverride !== undefined) {
            QuotaOverride.encode(message.consumerOverride, writer.uint32(34).fork()).ldelim();
        }
        if (message.adminOverride !== undefined) {
            QuotaOverride.encode(message.adminOverride, writer.uint32(42).fork()).ldelim();
        }
        Object.entries(message.dimensions).forEach(([key, value]) => {
            QuotaBucket_DimensionsEntry.encode({
                key: key,
                value
            }, writer.uint32(50).fork()).ldelim();
        });
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaBucket();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.effectiveLimit = reader.int64();
                    break;
                case 2:
                    message.defaultLimit = reader.int64();
                    break;
                case 3:
                    message.producerOverride = QuotaOverride.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.consumerOverride = QuotaOverride.decode(reader, reader.uint32());
                    break;
                case 5:
                    message.adminOverride = QuotaOverride.decode(reader, reader.uint32());
                    break;
                case 6:
                    const entry6 = QuotaBucket_DimensionsEntry.decode(reader, reader.uint32());
                    if (entry6.value !== undefined) {
                        message.dimensions[entry6.key] = entry6.value;
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaBucket();
        if (isSet(object.effectiveLimit))
            obj.effectiveLimit = BigInt(object.effectiveLimit.toString());
        if (isSet(object.defaultLimit))
            obj.defaultLimit = BigInt(object.defaultLimit.toString());
        if (isSet(object.producerOverride))
            obj.producerOverride = QuotaOverride.fromJSON(object.producerOverride);
        if (isSet(object.consumerOverride))
            obj.consumerOverride = QuotaOverride.fromJSON(object.consumerOverride);
        if (isSet(object.adminOverride))
            obj.adminOverride = QuotaOverride.fromJSON(object.adminOverride);
        if (isObject(object.dimensions))
            obj.dimensions = Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.effectiveLimit !== undefined && (obj.effectiveLimit = (message.effectiveLimit || BigInt(0)).toString());
        message.defaultLimit !== undefined && (obj.defaultLimit = (message.defaultLimit || BigInt(0)).toString());
        message.producerOverride !== undefined && (obj.producerOverride = message.producerOverride ? QuotaOverride.toJSON(message.producerOverride) : undefined);
        message.consumerOverride !== undefined && (obj.consumerOverride = message.consumerOverride ? QuotaOverride.toJSON(message.consumerOverride) : undefined);
        message.adminOverride !== undefined && (obj.adminOverride = message.adminOverride ? QuotaOverride.toJSON(message.adminOverride) : undefined);
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaBucket();
        if (object.effectiveLimit !== undefined && object.effectiveLimit !== null) {
            message.effectiveLimit = BigInt(object.effectiveLimit.toString());
        }
        if (object.defaultLimit !== undefined && object.defaultLimit !== null) {
            message.defaultLimit = BigInt(object.defaultLimit.toString());
        }
        if (object.producerOverride !== undefined && object.producerOverride !== null) {
            message.producerOverride = QuotaOverride.fromPartial(object.producerOverride);
        }
        if (object.consumerOverride !== undefined && object.consumerOverride !== null) {
            message.consumerOverride = QuotaOverride.fromPartial(object.consumerOverride);
        }
        if (object.adminOverride !== undefined && object.adminOverride !== null) {
            message.adminOverride = QuotaOverride.fromPartial(object.adminOverride);
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        return message;
    },
    fromSDK(object) {
        return {
            effectiveLimit: object?.effective_limit,
            defaultLimit: object?.default_limit,
            producerOverride: object.producer_override ? QuotaOverride.fromSDK(object.producer_override) : undefined,
            consumerOverride: object.consumer_override ? QuotaOverride.fromSDK(object.consumer_override) : undefined,
            adminOverride: object.admin_override ? QuotaOverride.fromSDK(object.admin_override) : undefined,
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {}
        };
    },
    fromSDKJSON(object) {
        return {
            effective_limit: isSet(object.effective_limit) ? BigInt(object.effective_limit.toString()) : BigInt(0),
            default_limit: isSet(object.default_limit) ? BigInt(object.default_limit.toString()) : BigInt(0),
            producer_override: isSet(object.producer_override) ? QuotaOverride.fromSDKJSON(object.producer_override) : undefined,
            consumer_override: isSet(object.consumer_override) ? QuotaOverride.fromSDKJSON(object.consumer_override) : undefined,
            admin_override: isSet(object.admin_override) ? QuotaOverride.fromSDKJSON(object.admin_override) : undefined,
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {}
        };
    },
    toSDK(message) {
        const obj = {};
        obj.effective_limit = message.effectiveLimit;
        obj.default_limit = message.defaultLimit;
        message.producerOverride !== undefined && (obj.producer_override = message.producerOverride ? QuotaOverride.toSDK(message.producerOverride) : undefined);
        message.consumerOverride !== undefined && (obj.consumer_override = message.consumerOverride ? QuotaOverride.toSDK(message.consumerOverride) : undefined);
        message.adminOverride !== undefined && (obj.admin_override = message.adminOverride ? QuotaOverride.toSDK(message.adminOverride) : undefined);
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaBucket();
        if (object.effective_limit !== undefined && object.effective_limit !== null) {
            message.effectiveLimit = BigInt(object.effective_limit);
        }
        if (object.default_limit !== undefined && object.default_limit !== null) {
            message.defaultLimit = BigInt(object.default_limit);
        }
        if (object.producer_override !== undefined && object.producer_override !== null) {
            message.producerOverride = QuotaOverride.fromAmino(object.producer_override);
        }
        if (object.consumer_override !== undefined && object.consumer_override !== null) {
            message.consumerOverride = QuotaOverride.fromAmino(object.consumer_override);
        }
        if (object.admin_override !== undefined && object.admin_override !== null) {
            message.adminOverride = QuotaOverride.fromAmino(object.admin_override);
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.effective_limit = message.effectiveLimit !== BigInt(0) ? message.effectiveLimit?.toString() : undefined;
        obj.default_limit = message.defaultLimit !== BigInt(0) ? message.defaultLimit?.toString() : undefined;
        obj.producer_override = message.producerOverride ? QuotaOverride.toAmino(message.producerOverride) : undefined;
        obj.consumer_override = message.consumerOverride ? QuotaOverride.toAmino(message.consumerOverride) : undefined;
        obj.admin_override = message.adminOverride ? QuotaOverride.toAmino(message.adminOverride) : undefined;
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaBucket.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaBucket.decode(message.value);
    },
    toProto(message) {
        return QuotaBucket.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.QuotaBucket",
            value: QuotaBucket.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaOverride.registerTypeUrl();
    }
};
function createBaseQuotaOverride_DimensionsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const QuotaOverride_DimensionsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaOverride_DimensionsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaOverride_DimensionsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaOverride_DimensionsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaOverride_DimensionsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaOverride_DimensionsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaOverride_DimensionsEntry.decode(message.value);
    },
    toProto(message) {
        return QuotaOverride_DimensionsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseQuotaOverride() {
    return {
        name: "",
        overrideValue: BigInt(0),
        dimensions: {},
        metric: "",
        unit: "",
        adminOverrideAncestor: ""
    };
}
export const QuotaOverride = {
    typeUrl: "/google.api.serviceusage.v1beta1.QuotaOverride",
    is(o) {
        return o && (o.$typeUrl === QuotaOverride.typeUrl || typeof o.name === "string" && typeof o.overrideValue === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.adminOverrideAncestor === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaOverride.typeUrl || typeof o.name === "string" && typeof o.override_value === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.admin_override_ancestor === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaOverride.typeUrl || typeof o.name === "string" && typeof o.override_value === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.admin_override_ancestor === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.overrideValue !== undefined) {
            writer.uint32(16).int64(message.overrideValue);
        }
        Object.entries(message.dimensions).forEach(([key, value]) => {
            QuotaOverride_DimensionsEntry.encode({
                key: key,
                value
            }, writer.uint32(26).fork()).ldelim();
        });
        if (message.metric !== undefined) {
            writer.uint32(34).string(message.metric);
        }
        if (message.unit !== undefined) {
            writer.uint32(42).string(message.unit);
        }
        if (message.adminOverrideAncestor !== undefined) {
            writer.uint32(50).string(message.adminOverrideAncestor);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaOverride();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.overrideValue = reader.int64();
                    break;
                case 3:
                    const entry3 = QuotaOverride_DimensionsEntry.decode(reader, reader.uint32());
                    if (entry3.value !== undefined) {
                        message.dimensions[entry3.key] = entry3.value;
                    }
                    break;
                case 4:
                    message.metric = reader.string();
                    break;
                case 5:
                    message.unit = reader.string();
                    break;
                case 6:
                    message.adminOverrideAncestor = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaOverride();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.overrideValue))
            obj.overrideValue = BigInt(object.overrideValue.toString());
        if (isObject(object.dimensions))
            obj.dimensions = Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (isSet(object.metric))
            obj.metric = String(object.metric);
        if (isSet(object.unit))
            obj.unit = String(object.unit);
        if (isSet(object.adminOverrideAncestor))
            obj.adminOverrideAncestor = String(object.adminOverrideAncestor);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.overrideValue !== undefined && (obj.overrideValue = (message.overrideValue || BigInt(0)).toString());
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        message.metric !== undefined && (obj.metric = message.metric);
        message.unit !== undefined && (obj.unit = message.unit);
        message.adminOverrideAncestor !== undefined && (obj.adminOverrideAncestor = message.adminOverrideAncestor);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaOverride();
        message.name = object.name ?? "";
        if (object.overrideValue !== undefined && object.overrideValue !== null) {
            message.overrideValue = BigInt(object.overrideValue.toString());
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.metric = object.metric ?? "";
        message.unit = object.unit ?? "";
        message.adminOverrideAncestor = object.adminOverrideAncestor ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            overrideValue: object?.override_value,
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metric: object?.metric,
            unit: object?.unit,
            adminOverrideAncestor: object?.admin_override_ancestor
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            override_value: isSet(object.override_value) ? BigInt(object.override_value.toString()) : BigInt(0),
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metric: isSet(object.metric) ? String(object.metric) : "",
            unit: isSet(object.unit) ? String(object.unit) : "",
            admin_override_ancestor: isSet(object.admin_override_ancestor) ? String(object.admin_override_ancestor) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.override_value = message.overrideValue;
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        obj.metric = message.metric;
        obj.unit = message.unit;
        obj.admin_override_ancestor = message.adminOverrideAncestor;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaOverride();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.override_value !== undefined && object.override_value !== null) {
            message.overrideValue = BigInt(object.override_value);
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        if (object.metric !== undefined && object.metric !== null) {
            message.metric = object.metric;
        }
        if (object.unit !== undefined && object.unit !== null) {
            message.unit = object.unit;
        }
        if (object.admin_override_ancestor !== undefined && object.admin_override_ancestor !== null) {
            message.adminOverrideAncestor = object.admin_override_ancestor;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.override_value = message.overrideValue !== BigInt(0) ? message.overrideValue?.toString() : undefined;
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        obj.metric = message.metric === "" ? undefined : message.metric;
        obj.unit = message.unit === "" ? undefined : message.unit;
        obj.admin_override_ancestor = message.adminOverrideAncestor === "" ? undefined : message.adminOverrideAncestor;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaOverride.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaOverride.decode(message.value);
    },
    toProto(message) {
        return QuotaOverride.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.QuotaOverride",
            value: QuotaOverride.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseOverrideInlineSource() {
    return {
        overrides: []
    };
}
export const OverrideInlineSource = {
    typeUrl: "/google.api.serviceusage.v1beta1.OverrideInlineSource",
    is(o) {
        return o && (o.$typeUrl === OverrideInlineSource.typeUrl || Array.isArray(o.overrides) && (!o.overrides.length || QuotaOverride.is(o.overrides[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === OverrideInlineSource.typeUrl || Array.isArray(o.overrides) && (!o.overrides.length || QuotaOverride.isSDK(o.overrides[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === OverrideInlineSource.typeUrl || Array.isArray(o.overrides) && (!o.overrides.length || QuotaOverride.isAmino(o.overrides[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.overrides) {
            QuotaOverride.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseOverrideInlineSource();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.overrides.push(QuotaOverride.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseOverrideInlineSource();
        if (Array.isArray(object?.overrides))
            obj.overrides = object.overrides.map((e) => QuotaOverride.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.overrides) {
            obj.overrides = message.overrides.map(e => e ? QuotaOverride.toJSON(e) : undefined);
        }
        else {
            obj.overrides = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseOverrideInlineSource();
        message.overrides = object.overrides?.map(e => QuotaOverride.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            overrides: Array.isArray(object?.overrides) ? object.overrides.map((e) => QuotaOverride.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            overrides: Array.isArray(object?.overrides) ? object.overrides.map((e) => QuotaOverride.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.overrides) {
            obj.overrides = message.overrides.map(e => e ? QuotaOverride.toSDK(e) : undefined);
        }
        else {
            obj.overrides = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseOverrideInlineSource();
        message.overrides = object.overrides?.map(e => QuotaOverride.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.overrides) {
            obj.overrides = message.overrides.map(e => e ? QuotaOverride.toAmino(e) : undefined);
        }
        else {
            obj.overrides = message.overrides;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return OverrideInlineSource.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return OverrideInlineSource.decode(message.value);
    },
    toProto(message) {
        return OverrideInlineSource.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.OverrideInlineSource",
            value: OverrideInlineSource.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaOverride.registerTypeUrl();
    }
};
function createBaseAdminQuotaPolicy_DimensionsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const AdminQuotaPolicy_DimensionsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAdminQuotaPolicy_DimensionsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAdminQuotaPolicy_DimensionsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAdminQuotaPolicy_DimensionsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAdminQuotaPolicy_DimensionsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return AdminQuotaPolicy_DimensionsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return AdminQuotaPolicy_DimensionsEntry.decode(message.value);
    },
    toProto(message) {
        return AdminQuotaPolicy_DimensionsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseAdminQuotaPolicy() {
    return {
        name: "",
        policyValue: BigInt(0),
        dimensions: {},
        metric: "",
        unit: "",
        container: ""
    };
}
export const AdminQuotaPolicy = {
    typeUrl: "/google.api.serviceusage.v1beta1.AdminQuotaPolicy",
    is(o) {
        return o && (o.$typeUrl === AdminQuotaPolicy.typeUrl || typeof o.name === "string" && typeof o.policyValue === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.container === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === AdminQuotaPolicy.typeUrl || typeof o.name === "string" && typeof o.policy_value === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.container === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === AdminQuotaPolicy.typeUrl || typeof o.name === "string" && typeof o.policy_value === "bigint" && isSet(o.dimensions) && typeof o.metric === "string" && typeof o.unit === "string" && typeof o.container === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.policyValue !== undefined) {
            writer.uint32(16).int64(message.policyValue);
        }
        Object.entries(message.dimensions).forEach(([key, value]) => {
            AdminQuotaPolicy_DimensionsEntry.encode({
                key: key,
                value
            }, writer.uint32(26).fork()).ldelim();
        });
        if (message.metric !== undefined) {
            writer.uint32(34).string(message.metric);
        }
        if (message.unit !== undefined) {
            writer.uint32(42).string(message.unit);
        }
        if (message.container !== undefined) {
            writer.uint32(50).string(message.container);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAdminQuotaPolicy();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.policyValue = reader.int64();
                    break;
                case 3:
                    const entry3 = AdminQuotaPolicy_DimensionsEntry.decode(reader, reader.uint32());
                    if (entry3.value !== undefined) {
                        message.dimensions[entry3.key] = entry3.value;
                    }
                    break;
                case 4:
                    message.metric = reader.string();
                    break;
                case 5:
                    message.unit = reader.string();
                    break;
                case 6:
                    message.container = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAdminQuotaPolicy();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.policyValue))
            obj.policyValue = BigInt(object.policyValue.toString());
        if (isObject(object.dimensions))
            obj.dimensions = Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (isSet(object.metric))
            obj.metric = String(object.metric);
        if (isSet(object.unit))
            obj.unit = String(object.unit);
        if (isSet(object.container))
            obj.container = String(object.container);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.policyValue !== undefined && (obj.policyValue = (message.policyValue || BigInt(0)).toString());
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        message.metric !== undefined && (obj.metric = message.metric);
        message.unit !== undefined && (obj.unit = message.unit);
        message.container !== undefined && (obj.container = message.container);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAdminQuotaPolicy();
        message.name = object.name ?? "";
        if (object.policyValue !== undefined && object.policyValue !== null) {
            message.policyValue = BigInt(object.policyValue.toString());
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.metric = object.metric ?? "";
        message.unit = object.unit ?? "";
        message.container = object.container ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            policyValue: object?.policy_value,
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metric: object?.metric,
            unit: object?.unit,
            container: object?.container
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            policy_value: isSet(object.policy_value) ? BigInt(object.policy_value.toString()) : BigInt(0),
            dimensions: isObject(object.dimensions) ? Object.entries(object.dimensions).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            metric: isSet(object.metric) ? String(object.metric) : "",
            unit: isSet(object.unit) ? String(object.unit) : "",
            container: isSet(object.container) ? String(object.container) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.policy_value = message.policyValue;
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        obj.metric = message.metric;
        obj.unit = message.unit;
        obj.container = message.container;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAdminQuotaPolicy();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.policy_value !== undefined && object.policy_value !== null) {
            message.policyValue = BigInt(object.policy_value);
        }
        message.dimensions = Object.entries(object.dimensions ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        if (object.metric !== undefined && object.metric !== null) {
            message.metric = object.metric;
        }
        if (object.unit !== undefined && object.unit !== null) {
            message.unit = object.unit;
        }
        if (object.container !== undefined && object.container !== null) {
            message.container = object.container;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.policy_value = message.policyValue !== BigInt(0) ? message.policyValue?.toString() : undefined;
        obj.dimensions = {};
        if (message.dimensions) {
            Object.entries(message.dimensions).forEach(([k, v]) => {
                obj.dimensions[k] = v;
            });
        }
        obj.metric = message.metric === "" ? undefined : message.metric;
        obj.unit = message.unit === "" ? undefined : message.unit;
        obj.container = message.container === "" ? undefined : message.container;
        return obj;
    },
    fromAminoMsg(object) {
        return AdminQuotaPolicy.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return AdminQuotaPolicy.decode(message.value);
    },
    toProto(message) {
        return AdminQuotaPolicy.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.AdminQuotaPolicy",
            value: AdminQuotaPolicy.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseServiceIdentity() {
    return {
        email: "",
        uniqueId: ""
    };
}
export const ServiceIdentity = {
    typeUrl: "/google.api.serviceusage.v1beta1.ServiceIdentity",
    is(o) {
        return o && (o.$typeUrl === ServiceIdentity.typeUrl || typeof o.email === "string" && typeof o.uniqueId === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ServiceIdentity.typeUrl || typeof o.email === "string" && typeof o.unique_id === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ServiceIdentity.typeUrl || typeof o.email === "string" && typeof o.unique_id === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.email !== undefined) {
            writer.uint32(10).string(message.email);
        }
        if (message.uniqueId !== undefined) {
            writer.uint32(18).string(message.uniqueId);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseServiceIdentity();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.email = reader.string();
                    break;
                case 2:
                    message.uniqueId = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseServiceIdentity();
        if (isSet(object.email))
            obj.email = String(object.email);
        if (isSet(object.uniqueId))
            obj.uniqueId = String(object.uniqueId);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.email !== undefined && (obj.email = message.email);
        message.uniqueId !== undefined && (obj.uniqueId = message.uniqueId);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseServiceIdentity();
        message.email = object.email ?? "";
        message.uniqueId = object.uniqueId ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            email: object?.email,
            uniqueId: object?.unique_id
        };
    },
    fromSDKJSON(object) {
        return {
            email: isSet(object.email) ? String(object.email) : "",
            unique_id: isSet(object.unique_id) ? String(object.unique_id) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.email = message.email;
        obj.unique_id = message.uniqueId;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseServiceIdentity();
        if (object.email !== undefined && object.email !== null) {
            message.email = object.email;
        }
        if (object.unique_id !== undefined && object.unique_id !== null) {
            message.uniqueId = object.unique_id;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.email = message.email === "" ? undefined : message.email;
        obj.unique_id = message.uniqueId === "" ? undefined : message.uniqueId;
        return obj;
    },
    fromAminoMsg(object) {
        return ServiceIdentity.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ServiceIdentity.decode(message.value);
    },
    toProto(message) {
        return ServiceIdentity.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.serviceusage.v1beta1.ServiceIdentity",
            value: ServiceIdentity.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
