import { MonitoredResource } from "../../api/monitored_resource";
import { Any } from "../../protobuf/any";
import { Struct } from "../../protobuf/struct";
import { Timestamp } from "../../protobuf/timestamp";
import { logSeverityFromJSON, logSeverityToJSON } from "../type/log_severity";
import { HttpRequest } from "../type/http_request";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet, toTimestamp, fromTimestamp, isObject } from "../../../helpers";
export const protobufPackage = "google.logging.v2";
function createBaseLogEntry_LabelsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const LogEntry_LabelsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLogEntry_LabelsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLogEntry_LabelsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLogEntry_LabelsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLogEntry_LabelsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return LogEntry_LabelsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LogEntry_LabelsEntry.decode(message.value);
    },
    toProto(message) {
        return LogEntry_LabelsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseLogEntry() {
    return {
        logName: "",
        resource: undefined,
        protoPayload: undefined,
        textPayload: undefined,
        jsonPayload: undefined,
        timestamp: undefined,
        receiveTimestamp: undefined,
        severity: 0,
        insertId: "",
        httpRequest: undefined,
        labels: {},
        operation: undefined,
        trace: "",
        spanId: "",
        traceSampled: false,
        sourceLocation: undefined,
        split: undefined
    };
}
export const LogEntry = {
    typeUrl: "/google.logging.v2.LogEntry",
    is(o) {
        return o && (o.$typeUrl === LogEntry.typeUrl || typeof o.logName === "string" && isSet(o.severity) && typeof o.insertId === "string" && isSet(o.labels) && typeof o.trace === "string" && typeof o.spanId === "string" && typeof o.traceSampled === "boolean");
    },
    isSDK(o) {
        return o && (o.$typeUrl === LogEntry.typeUrl || typeof o.log_name === "string" && isSet(o.severity) && typeof o.insert_id === "string" && isSet(o.labels) && typeof o.trace === "string" && typeof o.span_id === "string" && typeof o.trace_sampled === "boolean");
    },
    isAmino(o) {
        return o && (o.$typeUrl === LogEntry.typeUrl || typeof o.log_name === "string" && isSet(o.severity) && typeof o.insert_id === "string" && isSet(o.labels) && typeof o.trace === "string" && typeof o.span_id === "string" && typeof o.trace_sampled === "boolean");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.logName !== undefined) {
            writer.uint32(98).string(message.logName);
        }
        if (message.resource !== undefined) {
            MonitoredResource.encode(message.resource, writer.uint32(66).fork()).ldelim();
        }
        if (message.protoPayload !== undefined) {
            Any.encode(message.protoPayload, writer.uint32(18).fork()).ldelim();
        }
        if (message.textPayload !== undefined) {
            writer.uint32(26).string(message.textPayload);
        }
        if (message.jsonPayload !== undefined) {
            Struct.encode(message.jsonPayload, writer.uint32(50).fork()).ldelim();
        }
        if (message.timestamp !== undefined) {
            Timestamp.encode(toTimestamp(message.timestamp), writer.uint32(74).fork()).ldelim();
        }
        if (message.receiveTimestamp !== undefined) {
            Timestamp.encode(toTimestamp(message.receiveTimestamp), writer.uint32(194).fork()).ldelim();
        }
        if (message.severity !== 0) {
            writer.uint32(80).int32(message.severity);
        }
        if (message.insertId !== undefined) {
            writer.uint32(34).string(message.insertId);
        }
        if (message.httpRequest !== undefined) {
            HttpRequest.encode(message.httpRequest, writer.uint32(58).fork()).ldelim();
        }
        Object.entries(message.labels).forEach(([key, value]) => {
            LogEntry_LabelsEntry.encode({
                key: key,
                value
            }, writer.uint32(90).fork()).ldelim();
        });
        if (message.operation !== undefined) {
            LogEntryOperation.encode(message.operation, writer.uint32(122).fork()).ldelim();
        }
        if (message.trace !== undefined) {
            writer.uint32(178).string(message.trace);
        }
        if (message.spanId !== undefined) {
            writer.uint32(218).string(message.spanId);
        }
        if (message.traceSampled !== undefined) {
            writer.uint32(240).bool(message.traceSampled);
        }
        if (message.sourceLocation !== undefined) {
            LogEntrySourceLocation.encode(message.sourceLocation, writer.uint32(186).fork()).ldelim();
        }
        if (message.split !== undefined) {
            LogSplit.encode(message.split, writer.uint32(282).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLogEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 12:
                    message.logName = reader.string();
                    break;
                case 8:
                    message.resource = MonitoredResource.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.protoPayload = Any.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.textPayload = reader.string();
                    break;
                case 6:
                    message.jsonPayload = Struct.decode(reader, reader.uint32());
                    break;
                case 9:
                    message.timestamp = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 24:
                    message.receiveTimestamp = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 10:
                    message.severity = reader.int32();
                    break;
                case 4:
                    message.insertId = reader.string();
                    break;
                case 7:
                    message.httpRequest = HttpRequest.decode(reader, reader.uint32());
                    break;
                case 11:
                    const entry11 = LogEntry_LabelsEntry.decode(reader, reader.uint32());
                    if (entry11.value !== undefined) {
                        message.labels[entry11.key] = entry11.value;
                    }
                    break;
                case 15:
                    message.operation = LogEntryOperation.decode(reader, reader.uint32());
                    break;
                case 22:
                    message.trace = reader.string();
                    break;
                case 27:
                    message.spanId = reader.string();
                    break;
                case 30:
                    message.traceSampled = reader.bool();
                    break;
                case 23:
                    message.sourceLocation = LogEntrySourceLocation.decode(reader, reader.uint32());
                    break;
                case 35:
                    message.split = LogSplit.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLogEntry();
        if (isSet(object.logName))
            obj.logName = String(object.logName);
        if (isSet(object.resource))
            obj.resource = MonitoredResource.fromJSON(object.resource);
        if (isSet(object.protoPayload))
            obj.protoPayload = Any.fromJSON(object.protoPayload);
        if (isSet(object.textPayload))
            obj.textPayload = String(object.textPayload);
        if (isSet(object.jsonPayload))
            obj.jsonPayload = Struct.fromJSON(object.jsonPayload);
        if (isSet(object.timestamp))
            obj.timestamp = new Date(object.timestamp);
        if (isSet(object.receiveTimestamp))
            obj.receiveTimestamp = new Date(object.receiveTimestamp);
        if (isSet(object.severity))
            obj.severity = logSeverityFromJSON(object.severity);
        if (isSet(object.insertId))
            obj.insertId = String(object.insertId);
        if (isSet(object.httpRequest))
            obj.httpRequest = HttpRequest.fromJSON(object.httpRequest);
        if (isObject(object.labels))
            obj.labels = Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (isSet(object.operation))
            obj.operation = LogEntryOperation.fromJSON(object.operation);
        if (isSet(object.trace))
            obj.trace = String(object.trace);
        if (isSet(object.spanId))
            obj.spanId = String(object.spanId);
        if (isSet(object.traceSampled))
            obj.traceSampled = Boolean(object.traceSampled);
        if (isSet(object.sourceLocation))
            obj.sourceLocation = LogEntrySourceLocation.fromJSON(object.sourceLocation);
        if (isSet(object.split))
            obj.split = LogSplit.fromJSON(object.split);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.logName !== undefined && (obj.logName = message.logName);
        message.resource !== undefined && (obj.resource = message.resource ? MonitoredResource.toJSON(message.resource) : undefined);
        message.protoPayload !== undefined && (obj.protoPayload = message.protoPayload ? Any.toJSON(message.protoPayload) : undefined);
        message.textPayload !== undefined && (obj.textPayload = message.textPayload);
        message.jsonPayload !== undefined && (obj.jsonPayload = message.jsonPayload ? Struct.toJSON(message.jsonPayload) : undefined);
        message.timestamp !== undefined && (obj.timestamp = message.timestamp.toISOString());
        message.receiveTimestamp !== undefined && (obj.receiveTimestamp = message.receiveTimestamp.toISOString());
        message.severity !== undefined && (obj.severity = logSeverityToJSON(message.severity));
        message.insertId !== undefined && (obj.insertId = message.insertId);
        message.httpRequest !== undefined && (obj.httpRequest = message.httpRequest ? HttpRequest.toJSON(message.httpRequest) : undefined);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        message.operation !== undefined && (obj.operation = message.operation ? LogEntryOperation.toJSON(message.operation) : undefined);
        message.trace !== undefined && (obj.trace = message.trace);
        message.spanId !== undefined && (obj.spanId = message.spanId);
        message.traceSampled !== undefined && (obj.traceSampled = message.traceSampled);
        message.sourceLocation !== undefined && (obj.sourceLocation = message.sourceLocation ? LogEntrySourceLocation.toJSON(message.sourceLocation) : undefined);
        message.split !== undefined && (obj.split = message.split ? LogSplit.toJSON(message.split) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLogEntry();
        message.logName = object.logName ?? "";
        if (object.resource !== undefined && object.resource !== null) {
            message.resource = MonitoredResource.fromPartial(object.resource);
        }
        if (object.protoPayload !== undefined && object.protoPayload !== null) {
            message.protoPayload = Any.fromPartial(object.protoPayload);
        }
        message.textPayload = object.textPayload ?? undefined;
        if (object.jsonPayload !== undefined && object.jsonPayload !== null) {
            message.jsonPayload = Struct.fromPartial(object.jsonPayload);
        }
        message.timestamp = object.timestamp ?? undefined;
        message.receiveTimestamp = object.receiveTimestamp ?? undefined;
        message.severity = object.severity ?? 0;
        message.insertId = object.insertId ?? "";
        if (object.httpRequest !== undefined && object.httpRequest !== null) {
            message.httpRequest = HttpRequest.fromPartial(object.httpRequest);
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        if (object.operation !== undefined && object.operation !== null) {
            message.operation = LogEntryOperation.fromPartial(object.operation);
        }
        message.trace = object.trace ?? "";
        message.spanId = object.spanId ?? "";
        message.traceSampled = object.traceSampled ?? false;
        if (object.sourceLocation !== undefined && object.sourceLocation !== null) {
            message.sourceLocation = LogEntrySourceLocation.fromPartial(object.sourceLocation);
        }
        if (object.split !== undefined && object.split !== null) {
            message.split = LogSplit.fromPartial(object.split);
        }
        return message;
    },
    fromSDK(object) {
        return {
            logName: object?.log_name,
            resource: object.resource ? MonitoredResource.fromSDK(object.resource) : undefined,
            protoPayload: object.proto_payload ? Any.fromSDK(object.proto_payload) : undefined,
            textPayload: object?.text_payload,
            jsonPayload: object.json_payload ? Struct.fromSDK(object.json_payload) : undefined,
            timestamp: object.timestamp ?? undefined,
            receiveTimestamp: object.receive_timestamp ?? undefined,
            severity: isSet(object.severity) ? logSeverityFromJSON(object.severity) : -1,
            insertId: object?.insert_id,
            httpRequest: object.http_request ? HttpRequest.fromSDK(object.http_request) : undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            operation: object.operation ? LogEntryOperation.fromSDK(object.operation) : undefined,
            trace: object?.trace,
            spanId: object?.span_id,
            traceSampled: object?.trace_sampled,
            sourceLocation: object.source_location ? LogEntrySourceLocation.fromSDK(object.source_location) : undefined,
            split: object.split ? LogSplit.fromSDK(object.split) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            log_name: isSet(object.log_name) ? String(object.log_name) : "",
            resource: isSet(object.resource) ? MonitoredResource.fromSDKJSON(object.resource) : undefined,
            proto_payload: isSet(object.proto_payload) ? Any.fromSDKJSON(object.proto_payload) : undefined,
            text_payload: isSet(object.text_payload) ? String(object.text_payload) : undefined,
            json_payload: isSet(object.json_payload) ? Struct.fromSDKJSON(object.json_payload) : undefined,
            timestamp: isSet(object.timestamp) ? new Date(object.timestamp) : undefined,
            receive_timestamp: isSet(object.receive_timestamp) ? new Date(object.receive_timestamp) : undefined,
            severity: isSet(object.severity) ? logSeverityFromJSON(object.severity) : -1,
            insert_id: isSet(object.insert_id) ? String(object.insert_id) : "",
            http_request: isSet(object.http_request) ? HttpRequest.fromSDKJSON(object.http_request) : undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            operation: isSet(object.operation) ? LogEntryOperation.fromSDKJSON(object.operation) : undefined,
            trace: isSet(object.trace) ? String(object.trace) : "",
            span_id: isSet(object.span_id) ? String(object.span_id) : "",
            trace_sampled: isSet(object.trace_sampled) ? Boolean(object.trace_sampled) : false,
            source_location: isSet(object.source_location) ? LogEntrySourceLocation.fromSDKJSON(object.source_location) : undefined,
            split: isSet(object.split) ? LogSplit.fromSDKJSON(object.split) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.log_name = message.logName;
        message.resource !== undefined && (obj.resource = message.resource ? MonitoredResource.toSDK(message.resource) : undefined);
        message.protoPayload !== undefined && (obj.proto_payload = message.protoPayload ? Any.toSDK(message.protoPayload) : undefined);
        obj.text_payload = message.textPayload;
        message.jsonPayload !== undefined && (obj.json_payload = message.jsonPayload ? Struct.toSDK(message.jsonPayload) : undefined);
        message.timestamp !== undefined && (obj.timestamp = message.timestamp ?? undefined);
        message.receiveTimestamp !== undefined && (obj.receive_timestamp = message.receiveTimestamp ?? undefined);
        message.severity !== undefined && (obj.severity = logSeverityToJSON(message.severity));
        obj.insert_id = message.insertId;
        message.httpRequest !== undefined && (obj.http_request = message.httpRequest ? HttpRequest.toSDK(message.httpRequest) : undefined);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        message.operation !== undefined && (obj.operation = message.operation ? LogEntryOperation.toSDK(message.operation) : undefined);
        obj.trace = message.trace;
        obj.span_id = message.spanId;
        obj.trace_sampled = message.traceSampled;
        message.sourceLocation !== undefined && (obj.source_location = message.sourceLocation ? LogEntrySourceLocation.toSDK(message.sourceLocation) : undefined);
        message.split !== undefined && (obj.split = message.split ? LogSplit.toSDK(message.split) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLogEntry();
        if (object.log_name !== undefined && object.log_name !== null) {
            message.logName = object.log_name;
        }
        if (object.resource !== undefined && object.resource !== null) {
            message.resource = MonitoredResource.fromAmino(object.resource);
        }
        if (object.proto_payload !== undefined && object.proto_payload !== null) {
            message.protoPayload = Any.fromAmino(object.proto_payload);
        }
        if (object.text_payload !== undefined && object.text_payload !== null) {
            message.textPayload = object.text_payload;
        }
        if (object.json_payload !== undefined && object.json_payload !== null) {
            message.jsonPayload = Struct.fromAmino(object.json_payload);
        }
        if (object.timestamp !== undefined && object.timestamp !== null) {
            message.timestamp = fromTimestamp(Timestamp.fromAmino(object.timestamp));
        }
        if (object.receive_timestamp !== undefined && object.receive_timestamp !== null) {
            message.receiveTimestamp = fromTimestamp(Timestamp.fromAmino(object.receive_timestamp));
        }
        if (object.severity !== undefined && object.severity !== null) {
            message.severity = object.severity;
        }
        if (object.insert_id !== undefined && object.insert_id !== null) {
            message.insertId = object.insert_id;
        }
        if (object.http_request !== undefined && object.http_request !== null) {
            message.httpRequest = HttpRequest.fromAmino(object.http_request);
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        if (object.operation !== undefined && object.operation !== null) {
            message.operation = LogEntryOperation.fromAmino(object.operation);
        }
        if (object.trace !== undefined && object.trace !== null) {
            message.trace = object.trace;
        }
        if (object.span_id !== undefined && object.span_id !== null) {
            message.spanId = object.span_id;
        }
        if (object.trace_sampled !== undefined && object.trace_sampled !== null) {
            message.traceSampled = object.trace_sampled;
        }
        if (object.source_location !== undefined && object.source_location !== null) {
            message.sourceLocation = LogEntrySourceLocation.fromAmino(object.source_location);
        }
        if (object.split !== undefined && object.split !== null) {
            message.split = LogSplit.fromAmino(object.split);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.log_name = message.logName === "" ? undefined : message.logName;
        obj.resource = message.resource ? MonitoredResource.toAmino(message.resource) : undefined;
        obj.proto_payload = message.protoPayload ? Any.toAmino(message.protoPayload) : undefined;
        obj.text_payload = message.textPayload === null ? undefined : message.textPayload;
        obj.json_payload = message.jsonPayload ? Struct.toAmino(message.jsonPayload) : undefined;
        obj.timestamp = message.timestamp ? Timestamp.toAmino(toTimestamp(message.timestamp)) : undefined;
        obj.receive_timestamp = message.receiveTimestamp ? Timestamp.toAmino(toTimestamp(message.receiveTimestamp)) : undefined;
        obj.severity = message.severity === 0 ? undefined : message.severity;
        obj.insert_id = message.insertId === "" ? undefined : message.insertId;
        obj.http_request = message.httpRequest ? HttpRequest.toAmino(message.httpRequest) : undefined;
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        obj.operation = message.operation ? LogEntryOperation.toAmino(message.operation) : undefined;
        obj.trace = message.trace === "" ? undefined : message.trace;
        obj.span_id = message.spanId === "" ? undefined : message.spanId;
        obj.trace_sampled = message.traceSampled === false ? undefined : message.traceSampled;
        obj.source_location = message.sourceLocation ? LogEntrySourceLocation.toAmino(message.sourceLocation) : undefined;
        obj.split = message.split ? LogSplit.toAmino(message.split) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return LogEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LogEntry.decode(message.value);
    },
    toProto(message) {
        return LogEntry.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.LogEntry",
            value: LogEntry.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Struct.registerTypeUrl();
        HttpRequest.registerTypeUrl();
        LogEntryOperation.registerTypeUrl();
        LogEntrySourceLocation.registerTypeUrl();
        LogSplit.registerTypeUrl();
    }
};
function createBaseLogEntryOperation() {
    return {
        id: "",
        producer: "",
        first: false,
        last: false
    };
}
export const LogEntryOperation = {
    typeUrl: "/google.logging.v2.LogEntryOperation",
    is(o) {
        return o && (o.$typeUrl === LogEntryOperation.typeUrl || typeof o.id === "string" && typeof o.producer === "string" && typeof o.first === "boolean" && typeof o.last === "boolean");
    },
    isSDK(o) {
        return o && (o.$typeUrl === LogEntryOperation.typeUrl || typeof o.id === "string" && typeof o.producer === "string" && typeof o.first === "boolean" && typeof o.last === "boolean");
    },
    isAmino(o) {
        return o && (o.$typeUrl === LogEntryOperation.typeUrl || typeof o.id === "string" && typeof o.producer === "string" && typeof o.first === "boolean" && typeof o.last === "boolean");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            writer.uint32(10).string(message.id);
        }
        if (message.producer !== undefined) {
            writer.uint32(18).string(message.producer);
        }
        if (message.first !== undefined) {
            writer.uint32(24).bool(message.first);
        }
        if (message.last !== undefined) {
            writer.uint32(32).bool(message.last);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLogEntryOperation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = reader.string();
                    break;
                case 2:
                    message.producer = reader.string();
                    break;
                case 3:
                    message.first = reader.bool();
                    break;
                case 4:
                    message.last = reader.bool();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLogEntryOperation();
        if (isSet(object.id))
            obj.id = String(object.id);
        if (isSet(object.producer))
            obj.producer = String(object.producer);
        if (isSet(object.first))
            obj.first = Boolean(object.first);
        if (isSet(object.last))
            obj.last = Boolean(object.last);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id);
        message.producer !== undefined && (obj.producer = message.producer);
        message.first !== undefined && (obj.first = message.first);
        message.last !== undefined && (obj.last = message.last);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLogEntryOperation();
        message.id = object.id ?? "";
        message.producer = object.producer ?? "";
        message.first = object.first ?? false;
        message.last = object.last ?? false;
        return message;
    },
    fromSDK(object) {
        return {
            id: object?.id,
            producer: object?.producer,
            first: object?.first,
            last: object?.last
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? String(object.id) : "",
            producer: isSet(object.producer) ? String(object.producer) : "",
            first: isSet(object.first) ? Boolean(object.first) : false,
            last: isSet(object.last) ? Boolean(object.last) : false
        };
    },
    toSDK(message) {
        const obj = {};
        obj.id = message.id;
        obj.producer = message.producer;
        obj.first = message.first;
        obj.last = message.last;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLogEntryOperation();
        if (object.id !== undefined && object.id !== null) {
            message.id = object.id;
        }
        if (object.producer !== undefined && object.producer !== null) {
            message.producer = object.producer;
        }
        if (object.first !== undefined && object.first !== null) {
            message.first = object.first;
        }
        if (object.last !== undefined && object.last !== null) {
            message.last = object.last;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id === "" ? undefined : message.id;
        obj.producer = message.producer === "" ? undefined : message.producer;
        obj.first = message.first === false ? undefined : message.first;
        obj.last = message.last === false ? undefined : message.last;
        return obj;
    },
    fromAminoMsg(object) {
        return LogEntryOperation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LogEntryOperation.decode(message.value);
    },
    toProto(message) {
        return LogEntryOperation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.LogEntryOperation",
            value: LogEntryOperation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseLogEntrySourceLocation() {
    return {
        file: "",
        line: BigInt(0),
        function: ""
    };
}
export const LogEntrySourceLocation = {
    typeUrl: "/google.logging.v2.LogEntrySourceLocation",
    is(o) {
        return o && (o.$typeUrl === LogEntrySourceLocation.typeUrl || typeof o.file === "string" && typeof o.line === "bigint" && typeof o.function === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === LogEntrySourceLocation.typeUrl || typeof o.file === "string" && typeof o.line === "bigint" && typeof o.function === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === LogEntrySourceLocation.typeUrl || typeof o.file === "string" && typeof o.line === "bigint" && typeof o.function === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.file !== undefined) {
            writer.uint32(10).string(message.file);
        }
        if (message.line !== undefined) {
            writer.uint32(16).int64(message.line);
        }
        if (message.function !== undefined) {
            writer.uint32(26).string(message.function);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLogEntrySourceLocation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.file = reader.string();
                    break;
                case 2:
                    message.line = reader.int64();
                    break;
                case 3:
                    message.function = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLogEntrySourceLocation();
        if (isSet(object.file))
            obj.file = String(object.file);
        if (isSet(object.line))
            obj.line = BigInt(object.line.toString());
        if (isSet(object.function))
            obj.function = String(object.function);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.file !== undefined && (obj.file = message.file);
        message.line !== undefined && (obj.line = (message.line || BigInt(0)).toString());
        message.function !== undefined && (obj.function = message.function);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLogEntrySourceLocation();
        message.file = object.file ?? "";
        if (object.line !== undefined && object.line !== null) {
            message.line = BigInt(object.line.toString());
        }
        message.function = object.function ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            file: object?.file,
            line: object?.line,
            function: object?.function
        };
    },
    fromSDKJSON(object) {
        return {
            file: isSet(object.file) ? String(object.file) : "",
            line: isSet(object.line) ? BigInt(object.line.toString()) : BigInt(0),
            function: isSet(object.function) ? String(object.function) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.file = message.file;
        obj.line = message.line;
        obj.function = message.function;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLogEntrySourceLocation();
        if (object.file !== undefined && object.file !== null) {
            message.file = object.file;
        }
        if (object.line !== undefined && object.line !== null) {
            message.line = BigInt(object.line);
        }
        if (object.function !== undefined && object.function !== null) {
            message.function = object.function;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.file = message.file === "" ? undefined : message.file;
        obj.line = message.line !== BigInt(0) ? message.line?.toString() : undefined;
        obj.function = message.function === "" ? undefined : message.function;
        return obj;
    },
    fromAminoMsg(object) {
        return LogEntrySourceLocation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LogEntrySourceLocation.decode(message.value);
    },
    toProto(message) {
        return LogEntrySourceLocation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.LogEntrySourceLocation",
            value: LogEntrySourceLocation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseLogSplit() {
    return {
        uid: "",
        index: 0,
        totalSplits: 0
    };
}
export const LogSplit = {
    typeUrl: "/google.logging.v2.LogSplit",
    is(o) {
        return o && (o.$typeUrl === LogSplit.typeUrl || typeof o.uid === "string" && typeof o.index === "number" && typeof o.totalSplits === "number");
    },
    isSDK(o) {
        return o && (o.$typeUrl === LogSplit.typeUrl || typeof o.uid === "string" && typeof o.index === "number" && typeof o.total_splits === "number");
    },
    isAmino(o) {
        return o && (o.$typeUrl === LogSplit.typeUrl || typeof o.uid === "string" && typeof o.index === "number" && typeof o.total_splits === "number");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.uid !== undefined) {
            writer.uint32(10).string(message.uid);
        }
        if (message.index !== undefined) {
            writer.uint32(16).int32(message.index);
        }
        if (message.totalSplits !== undefined) {
            writer.uint32(24).int32(message.totalSplits);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLogSplit();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.uid = reader.string();
                    break;
                case 2:
                    message.index = reader.int32();
                    break;
                case 3:
                    message.totalSplits = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLogSplit();
        if (isSet(object.uid))
            obj.uid = String(object.uid);
        if (isSet(object.index))
            obj.index = Number(object.index);
        if (isSet(object.totalSplits))
            obj.totalSplits = Number(object.totalSplits);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.uid !== undefined && (obj.uid = message.uid);
        message.index !== undefined && (obj.index = Math.round(message.index));
        message.totalSplits !== undefined && (obj.totalSplits = Math.round(message.totalSplits));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLogSplit();
        message.uid = object.uid ?? "";
        message.index = object.index ?? 0;
        message.totalSplits = object.totalSplits ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            uid: object?.uid,
            index: object?.index,
            totalSplits: object?.total_splits
        };
    },
    fromSDKJSON(object) {
        return {
            uid: isSet(object.uid) ? String(object.uid) : "",
            index: isSet(object.index) ? Number(object.index) : 0,
            total_splits: isSet(object.total_splits) ? Number(object.total_splits) : 0
        };
    },
    toSDK(message) {
        const obj = {};
        obj.uid = message.uid;
        obj.index = message.index;
        obj.total_splits = message.totalSplits;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLogSplit();
        if (object.uid !== undefined && object.uid !== null) {
            message.uid = object.uid;
        }
        if (object.index !== undefined && object.index !== null) {
            message.index = object.index;
        }
        if (object.total_splits !== undefined && object.total_splits !== null) {
            message.totalSplits = object.total_splits;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.uid = message.uid === "" ? undefined : message.uid;
        obj.index = message.index === 0 ? undefined : message.index;
        obj.total_splits = message.totalSplits === 0 ? undefined : message.totalSplits;
        return obj;
    },
    fromAminoMsg(object) {
        return LogSplit.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LogSplit.decode(message.value);
    },
    toProto(message) {
        return LogSplit.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.LogSplit",
            value: LogSplit.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
