import { MonitoredResource, MonitoredResourceDescriptor } from "../../api/monitored_resource";
import { LogEntry } from "./log_entry";
import { Duration } from "../../protobuf/duration";
import { Status } from "../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet, isObject } from "../../../helpers";
export const protobufPackage = "google.logging.v2";
/** An indicator of why entries were omitted. */
export var TailLogEntriesResponse_SuppressionInfo_Reason;
(function (TailLogEntriesResponse_SuppressionInfo_Reason) {
    /** REASON_UNSPECIFIED - Unexpected default. */
    TailLogEntriesResponse_SuppressionInfo_Reason[TailLogEntriesResponse_SuppressionInfo_Reason["REASON_UNSPECIFIED"] = 0] = "REASON_UNSPECIFIED";
    /**
     * RATE_LIMIT - Indicates suppression occurred due to relevant entries being
     * received in excess of rate limits. For quotas and limits, see
     * [Logging API quotas and
     * limits](https://cloud.google.com/logging/quotas#api-limits).
     */
    TailLogEntriesResponse_SuppressionInfo_Reason[TailLogEntriesResponse_SuppressionInfo_Reason["RATE_LIMIT"] = 1] = "RATE_LIMIT";
    /**
     * NOT_CONSUMED - Indicates suppression occurred due to the client not consuming
     * responses quickly enough.
     */
    TailLogEntriesResponse_SuppressionInfo_Reason[TailLogEntriesResponse_SuppressionInfo_Reason["NOT_CONSUMED"] = 2] = "NOT_CONSUMED";
    TailLogEntriesResponse_SuppressionInfo_Reason[TailLogEntriesResponse_SuppressionInfo_Reason["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(TailLogEntriesResponse_SuppressionInfo_Reason || (TailLogEntriesResponse_SuppressionInfo_Reason = {}));
export const TailLogEntriesResponse_SuppressionInfo_ReasonSDKType = TailLogEntriesResponse_SuppressionInfo_Reason;
export const TailLogEntriesResponse_SuppressionInfo_ReasonAmino = TailLogEntriesResponse_SuppressionInfo_Reason;
export function tailLogEntriesResponse_SuppressionInfo_ReasonFromJSON(object) {
    switch (object) {
        case 0:
        case "REASON_UNSPECIFIED":
            return TailLogEntriesResponse_SuppressionInfo_Reason.REASON_UNSPECIFIED;
        case 1:
        case "RATE_LIMIT":
            return TailLogEntriesResponse_SuppressionInfo_Reason.RATE_LIMIT;
        case 2:
        case "NOT_CONSUMED":
            return TailLogEntriesResponse_SuppressionInfo_Reason.NOT_CONSUMED;
        case -1:
        case "UNRECOGNIZED":
        default:
            return TailLogEntriesResponse_SuppressionInfo_Reason.UNRECOGNIZED;
    }
}
export function tailLogEntriesResponse_SuppressionInfo_ReasonToJSON(object) {
    switch (object) {
        case TailLogEntriesResponse_SuppressionInfo_Reason.REASON_UNSPECIFIED:
            return "REASON_UNSPECIFIED";
        case TailLogEntriesResponse_SuppressionInfo_Reason.RATE_LIMIT:
            return "RATE_LIMIT";
        case TailLogEntriesResponse_SuppressionInfo_Reason.NOT_CONSUMED:
            return "NOT_CONSUMED";
        case TailLogEntriesResponse_SuppressionInfo_Reason.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseDeleteLogRequest() {
    return {
        logName: ""
    };
}
export const DeleteLogRequest = {
    typeUrl: "/google.logging.v2.DeleteLogRequest",
    is(o) {
        return o && (o.$typeUrl === DeleteLogRequest.typeUrl || typeof o.logName === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === DeleteLogRequest.typeUrl || typeof o.log_name === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === DeleteLogRequest.typeUrl || typeof o.log_name === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.logName !== undefined) {
            writer.uint32(10).string(message.logName);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseDeleteLogRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.logName = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseDeleteLogRequest();
        if (isSet(object.logName))
            obj.logName = String(object.logName);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.logName !== undefined && (obj.logName = message.logName);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseDeleteLogRequest();
        message.logName = object.logName ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            logName: object?.log_name
        };
    },
    fromSDKJSON(object) {
        return {
            log_name: isSet(object.log_name) ? String(object.log_name) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.log_name = message.logName;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseDeleteLogRequest();
        if (object.log_name !== undefined && object.log_name !== null) {
            message.logName = object.log_name;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.log_name = message.logName === "" ? undefined : message.logName;
        return obj;
    },
    fromAminoMsg(object) {
        return DeleteLogRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return DeleteLogRequest.decode(message.value);
    },
    toProto(message) {
        return DeleteLogRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.DeleteLogRequest",
            value: DeleteLogRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseWriteLogEntriesRequest_LabelsEntry() {
    return {
        key: "",
        value: ""
    };
}
export const WriteLogEntriesRequest_LabelsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseWriteLogEntriesRequest_LabelsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseWriteLogEntriesRequest_LabelsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseWriteLogEntriesRequest_LabelsEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseWriteLogEntriesRequest_LabelsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return WriteLogEntriesRequest_LabelsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return WriteLogEntriesRequest_LabelsEntry.decode(message.value);
    },
    toProto(message) {
        return WriteLogEntriesRequest_LabelsEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseWriteLogEntriesRequest() {
    return {
        logName: "",
        resource: undefined,
        labels: {},
        entries: [],
        partialSuccess: false,
        dryRun: false
    };
}
export const WriteLogEntriesRequest = {
    typeUrl: "/google.logging.v2.WriteLogEntriesRequest",
    is(o) {
        return o && (o.$typeUrl === WriteLogEntriesRequest.typeUrl || typeof o.logName === "string" && isSet(o.labels) && Array.isArray(o.entries) && (!o.entries.length || LogEntry.is(o.entries[0])) && typeof o.partialSuccess === "boolean" && typeof o.dryRun === "boolean");
    },
    isSDK(o) {
        return o && (o.$typeUrl === WriteLogEntriesRequest.typeUrl || typeof o.log_name === "string" && isSet(o.labels) && Array.isArray(o.entries) && (!o.entries.length || LogEntry.isSDK(o.entries[0])) && typeof o.partial_success === "boolean" && typeof o.dry_run === "boolean");
    },
    isAmino(o) {
        return o && (o.$typeUrl === WriteLogEntriesRequest.typeUrl || typeof o.log_name === "string" && isSet(o.labels) && Array.isArray(o.entries) && (!o.entries.length || LogEntry.isAmino(o.entries[0])) && typeof o.partial_success === "boolean" && typeof o.dry_run === "boolean");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.logName !== undefined) {
            writer.uint32(10).string(message.logName);
        }
        if (message.resource !== undefined) {
            MonitoredResource.encode(message.resource, writer.uint32(18).fork()).ldelim();
        }
        Object.entries(message.labels).forEach(([key, value]) => {
            WriteLogEntriesRequest_LabelsEntry.encode({
                key: key,
                value
            }, writer.uint32(26).fork()).ldelim();
        });
        for (const v of message.entries) {
            LogEntry.encode(v, writer.uint32(34).fork()).ldelim();
        }
        if (message.partialSuccess !== undefined) {
            writer.uint32(40).bool(message.partialSuccess);
        }
        if (message.dryRun !== undefined) {
            writer.uint32(48).bool(message.dryRun);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseWriteLogEntriesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.logName = reader.string();
                    break;
                case 2:
                    message.resource = MonitoredResource.decode(reader, reader.uint32());
                    break;
                case 3:
                    const entry3 = WriteLogEntriesRequest_LabelsEntry.decode(reader, reader.uint32());
                    if (entry3.value !== undefined) {
                        message.labels[entry3.key] = entry3.value;
                    }
                    break;
                case 4:
                    message.entries.push(LogEntry.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.partialSuccess = reader.bool();
                    break;
                case 6:
                    message.dryRun = reader.bool();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseWriteLogEntriesRequest();
        if (isSet(object.logName))
            obj.logName = String(object.logName);
        if (isSet(object.resource))
            obj.resource = MonitoredResource.fromJSON(object.resource);
        if (isObject(object.labels))
            obj.labels = Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        if (Array.isArray(object?.entries))
            obj.entries = object.entries.map((e) => LogEntry.fromJSON(e));
        if (isSet(object.partialSuccess))
            obj.partialSuccess = Boolean(object.partialSuccess);
        if (isSet(object.dryRun))
            obj.dryRun = Boolean(object.dryRun);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.logName !== undefined && (obj.logName = message.logName);
        message.resource !== undefined && (obj.resource = message.resource ? MonitoredResource.toJSON(message.resource) : undefined);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toJSON(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        message.partialSuccess !== undefined && (obj.partialSuccess = message.partialSuccess);
        message.dryRun !== undefined && (obj.dryRun = message.dryRun);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseWriteLogEntriesRequest();
        message.logName = object.logName ?? "";
        if (object.resource !== undefined && object.resource !== null) {
            message.resource = MonitoredResource.fromPartial(object.resource);
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.entries = object.entries?.map(e => LogEntry.fromPartial(e)) || [];
        message.partialSuccess = object.partialSuccess ?? false;
        message.dryRun = object.dryRun ?? false;
        return message;
    },
    fromSDK(object) {
        return {
            logName: object?.log_name,
            resource: object.resource ? MonitoredResource.fromSDK(object.resource) : undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDK(e)) : [],
            partialSuccess: object?.partial_success,
            dryRun: object?.dry_run
        };
    },
    fromSDKJSON(object) {
        return {
            log_name: isSet(object.log_name) ? String(object.log_name) : "",
            resource: isSet(object.resource) ? MonitoredResource.fromSDKJSON(object.resource) : undefined,
            labels: isObject(object.labels) ? Object.entries(object.labels).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {},
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDKJSON(e)) : [],
            partial_success: isSet(object.partial_success) ? Boolean(object.partial_success) : false,
            dry_run: isSet(object.dry_run) ? Boolean(object.dry_run) : false
        };
    },
    toSDK(message) {
        const obj = {};
        obj.log_name = message.logName;
        message.resource !== undefined && (obj.resource = message.resource ? MonitoredResource.toSDK(message.resource) : undefined);
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toSDK(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        obj.partial_success = message.partialSuccess;
        obj.dry_run = message.dryRun;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseWriteLogEntriesRequest();
        if (object.log_name !== undefined && object.log_name !== null) {
            message.logName = object.log_name;
        }
        if (object.resource !== undefined && object.resource !== null) {
            message.resource = MonitoredResource.fromAmino(object.resource);
        }
        message.labels = Object.entries(object.labels ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        message.entries = object.entries?.map(e => LogEntry.fromAmino(e)) || [];
        if (object.partial_success !== undefined && object.partial_success !== null) {
            message.partialSuccess = object.partial_success;
        }
        if (object.dry_run !== undefined && object.dry_run !== null) {
            message.dryRun = object.dry_run;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.log_name = message.logName === "" ? undefined : message.logName;
        obj.resource = message.resource ? MonitoredResource.toAmino(message.resource) : undefined;
        obj.labels = {};
        if (message.labels) {
            Object.entries(message.labels).forEach(([k, v]) => {
                obj.labels[k] = v;
            });
        }
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toAmino(e) : undefined);
        }
        else {
            obj.entries = message.entries;
        }
        obj.partial_success = message.partialSuccess === false ? undefined : message.partialSuccess;
        obj.dry_run = message.dryRun === false ? undefined : message.dryRun;
        return obj;
    },
    fromAminoMsg(object) {
        return WriteLogEntriesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return WriteLogEntriesRequest.decode(message.value);
    },
    toProto(message) {
        return WriteLogEntriesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.WriteLogEntriesRequest",
            value: WriteLogEntriesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        MonitoredResource.registerTypeUrl();
        LogEntry.registerTypeUrl();
    }
};
function createBaseWriteLogEntriesResponse() {
    return {};
}
export const WriteLogEntriesResponse = {
    typeUrl: "/google.logging.v2.WriteLogEntriesResponse",
    is(o) {
        return o && o.$typeUrl === WriteLogEntriesResponse.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === WriteLogEntriesResponse.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === WriteLogEntriesResponse.typeUrl;
    },
    encode(_, writer = BinaryWriter.create()) {
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseWriteLogEntriesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(_) {
        const obj = createBaseWriteLogEntriesResponse();
        return obj;
    },
    toJSON(_) {
        const obj = {};
        return obj;
    },
    fromPartial(_) {
        const message = createBaseWriteLogEntriesResponse();
        return message;
    },
    fromSDK(_) {
        return {};
    },
    fromSDKJSON(_) {
        return {};
    },
    toSDK(_) {
        const obj = {};
        return obj;
    },
    fromAmino(_) {
        const message = createBaseWriteLogEntriesResponse();
        return message;
    },
    toAmino(_) {
        const obj = {};
        return obj;
    },
    fromAminoMsg(object) {
        return WriteLogEntriesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return WriteLogEntriesResponse.decode(message.value);
    },
    toProto(message) {
        return WriteLogEntriesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.WriteLogEntriesResponse",
            value: WriteLogEntriesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseWriteLogEntriesPartialErrors_LogEntryErrorsEntry() {
    return {
        key: 0,
        value: undefined
    };
}
export const WriteLogEntriesPartialErrors_LogEntryErrorsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(8).int32(message.key);
        }
        if (message.value !== undefined) {
            Status.encode(message.value, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseWriteLogEntriesPartialErrors_LogEntryErrorsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.int32();
                    break;
                case 2:
                    message.value = Status.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseWriteLogEntriesPartialErrors_LogEntryErrorsEntry();
        if (isSet(object.key))
            obj.key = Number(object.key);
        if (isSet(object.value))
            obj.value = Status.fromJSON(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = Math.round(message.key));
        message.value !== undefined && (obj.value = message.value ? Status.toJSON(message.value) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseWriteLogEntriesPartialErrors_LogEntryErrorsEntry();
        message.key = object.key ?? 0;
        if (object.value !== undefined && object.value !== null) {
            message.value = Status.fromPartial(object.value);
        }
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object.value ? Status.fromSDK(object.value) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? Number(object.key) : 0,
            value: isSet(object.value) ? Status.fromSDKJSON(object.value) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        message.value !== undefined && (obj.value = message.value ? Status.toSDK(message.value) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseWriteLogEntriesPartialErrors_LogEntryErrorsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = Status.fromAmino(object.value);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === 0 ? undefined : message.key;
        obj.value = message.value ? Status.toAmino(message.value) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return WriteLogEntriesPartialErrors_LogEntryErrorsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return WriteLogEntriesPartialErrors_LogEntryErrorsEntry.decode(message.value);
    },
    toProto(message) {
        return WriteLogEntriesPartialErrors_LogEntryErrorsEntry.encode(message).finish();
    },
    registerTypeUrl() {
        Status.registerTypeUrl();
    }
};
function createBaseWriteLogEntriesPartialErrors() {
    return {
        logEntryErrors: {}
    };
}
export const WriteLogEntriesPartialErrors = {
    typeUrl: "/google.logging.v2.WriteLogEntriesPartialErrors",
    is(o) {
        return o && (o.$typeUrl === WriteLogEntriesPartialErrors.typeUrl || isSet(o.logEntryErrors));
    },
    isSDK(o) {
        return o && (o.$typeUrl === WriteLogEntriesPartialErrors.typeUrl || isSet(o.log_entry_errors));
    },
    isAmino(o) {
        return o && (o.$typeUrl === WriteLogEntriesPartialErrors.typeUrl || isSet(o.log_entry_errors));
    },
    encode(message, writer = BinaryWriter.create()) {
        Object.entries(message.logEntryErrors).forEach(([key, value]) => {
            WriteLogEntriesPartialErrors_LogEntryErrorsEntry.encode({
                key: key,
                value
            }, writer.uint32(10).fork()).ldelim();
        });
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseWriteLogEntriesPartialErrors();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    const entry1 = WriteLogEntriesPartialErrors_LogEntryErrorsEntry.decode(reader, reader.uint32());
                    if (entry1.value !== undefined) {
                        message.logEntryErrors[entry1.key] = entry1.value;
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseWriteLogEntriesPartialErrors();
        if (isObject(object.logEntryErrors))
            obj.logEntryErrors = Object.entries(object.logEntryErrors).reduce((acc, [key, value]) => {
                acc[Number(key)] = Status.fromJSON(value);
                return acc;
            }, {});
        return obj;
    },
    toJSON(message) {
        const obj = {};
        obj.logEntryErrors = {};
        if (message.logEntryErrors) {
            Object.entries(message.logEntryErrors).forEach(([k, v]) => {
                obj.logEntryErrors[k] = Status.toJSON(v);
            });
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseWriteLogEntriesPartialErrors();
        message.logEntryErrors = Object.entries(object.logEntryErrors ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[Number(key)] = Status.fromPartial(value);
            }
            return acc;
        }, {});
        return message;
    },
    fromSDK(object) {
        return {
            logEntryErrors: isObject(object.log_entry_errors) ? Object.entries(object.log_entry_errors).reduce((acc, [key, value]) => {
                acc[Number(key)] = Status.fromSDK(value);
                return acc;
            }, {}) : {}
        };
    },
    fromSDKJSON(object) {
        return {
            //@ts-ignore
            log_entry_errors: isObject(object.log_entry_errors) ? Object.entries(object.log_entry_errors).reduce((acc, [key, value]) => {
                //@ts-ignore
                acc[Number(key)] = Status.fromSDKJSON(value);
                return acc;
            }, {}) : {}
        };
    },
    toSDK(message) {
        const obj = {};
        obj.log_entry_errors = {};
        if (message.logEntryErrors) {
            Object.entries(message.logEntryErrors).forEach(([k, v]) => {
                obj.log_entry_errors[k] = Status.toSDK(v);
            });
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseWriteLogEntriesPartialErrors();
        message.logEntryErrors = Object.entries(object.log_entry_errors ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[Number(key)] = Status.fromAmino(value);
            }
            return acc;
        }, {});
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.log_entry_errors = {};
        if (message.logEntryErrors) {
            Object.entries(message.logEntryErrors).forEach(([k, v]) => {
                obj.log_entry_errors[k] = Status.toAmino(v);
            });
        }
        return obj;
    },
    fromAminoMsg(object) {
        return WriteLogEntriesPartialErrors.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return WriteLogEntriesPartialErrors.decode(message.value);
    },
    toProto(message) {
        return WriteLogEntriesPartialErrors.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.WriteLogEntriesPartialErrors",
            value: WriteLogEntriesPartialErrors.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Status.registerTypeUrl();
    }
};
function createBaseListLogEntriesRequest() {
    return {
        resourceNames: [],
        filter: "",
        orderBy: "",
        pageSize: 0,
        pageToken: ""
    };
}
export const ListLogEntriesRequest = {
    typeUrl: "/google.logging.v2.ListLogEntriesRequest",
    is(o) {
        return o && (o.$typeUrl === ListLogEntriesRequest.typeUrl || Array.isArray(o.resourceNames) && (!o.resourceNames.length || typeof o.resourceNames[0] === "string") && typeof o.filter === "string" && typeof o.orderBy === "string" && typeof o.pageSize === "number" && typeof o.pageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListLogEntriesRequest.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string") && typeof o.filter === "string" && typeof o.order_by === "string" && typeof o.page_size === "number" && typeof o.page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListLogEntriesRequest.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string") && typeof o.filter === "string" && typeof o.order_by === "string" && typeof o.page_size === "number" && typeof o.page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.resourceNames) {
            writer.uint32(66).string(v);
        }
        if (message.filter !== undefined) {
            writer.uint32(18).string(message.filter);
        }
        if (message.orderBy !== undefined) {
            writer.uint32(26).string(message.orderBy);
        }
        if (message.pageSize !== undefined) {
            writer.uint32(32).int32(message.pageSize);
        }
        if (message.pageToken !== undefined) {
            writer.uint32(42).string(message.pageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListLogEntriesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 8:
                    message.resourceNames.push(reader.string());
                    break;
                case 2:
                    message.filter = reader.string();
                    break;
                case 3:
                    message.orderBy = reader.string();
                    break;
                case 4:
                    message.pageSize = reader.int32();
                    break;
                case 5:
                    message.pageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListLogEntriesRequest();
        if (Array.isArray(object?.resourceNames))
            obj.resourceNames = object.resourceNames.map((e) => String(e));
        if (isSet(object.filter))
            obj.filter = String(object.filter);
        if (isSet(object.orderBy))
            obj.orderBy = String(object.orderBy);
        if (isSet(object.pageSize))
            obj.pageSize = Number(object.pageSize);
        if (isSet(object.pageToken))
            obj.pageToken = String(object.pageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resourceNames = message.resourceNames.map(e => e);
        }
        else {
            obj.resourceNames = [];
        }
        message.filter !== undefined && (obj.filter = message.filter);
        message.orderBy !== undefined && (obj.orderBy = message.orderBy);
        message.pageSize !== undefined && (obj.pageSize = Math.round(message.pageSize));
        message.pageToken !== undefined && (obj.pageToken = message.pageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListLogEntriesRequest();
        message.resourceNames = object.resourceNames?.map(e => e) || [];
        message.filter = object.filter ?? "";
        message.orderBy = object.orderBy ?? "";
        message.pageSize = object.pageSize ?? 0;
        message.pageToken = object.pageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            resourceNames: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => e) : [],
            filter: object?.filter,
            orderBy: object?.order_by,
            pageSize: object?.page_size,
            pageToken: object?.page_token
        };
    },
    fromSDKJSON(object) {
        return {
            resource_names: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => String(e)) : [],
            filter: isSet(object.filter) ? String(object.filter) : "",
            order_by: isSet(object.order_by) ? String(object.order_by) : "",
            page_size: isSet(object.page_size) ? Number(object.page_size) : 0,
            page_token: isSet(object.page_token) ? String(object.page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = [];
        }
        obj.filter = message.filter;
        obj.order_by = message.orderBy;
        obj.page_size = message.pageSize;
        obj.page_token = message.pageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListLogEntriesRequest();
        message.resourceNames = object.resource_names?.map(e => e) || [];
        if (object.filter !== undefined && object.filter !== null) {
            message.filter = object.filter;
        }
        if (object.order_by !== undefined && object.order_by !== null) {
            message.orderBy = object.order_by;
        }
        if (object.page_size !== undefined && object.page_size !== null) {
            message.pageSize = object.page_size;
        }
        if (object.page_token !== undefined && object.page_token !== null) {
            message.pageToken = object.page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = message.resourceNames;
        }
        obj.filter = message.filter === "" ? undefined : message.filter;
        obj.order_by = message.orderBy === "" ? undefined : message.orderBy;
        obj.page_size = message.pageSize === 0 ? undefined : message.pageSize;
        obj.page_token = message.pageToken === "" ? undefined : message.pageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListLogEntriesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListLogEntriesRequest.decode(message.value);
    },
    toProto(message) {
        return ListLogEntriesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListLogEntriesRequest",
            value: ListLogEntriesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseListLogEntriesResponse() {
    return {
        entries: [],
        nextPageToken: ""
    };
}
export const ListLogEntriesResponse = {
    typeUrl: "/google.logging.v2.ListLogEntriesResponse",
    is(o) {
        return o && (o.$typeUrl === ListLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.is(o.entries[0])) && typeof o.nextPageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.isSDK(o.entries[0])) && typeof o.next_page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.isAmino(o.entries[0])) && typeof o.next_page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.entries) {
            LogEntry.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.nextPageToken !== undefined) {
            writer.uint32(18).string(message.nextPageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListLogEntriesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.entries.push(LogEntry.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.nextPageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListLogEntriesResponse();
        if (Array.isArray(object?.entries))
            obj.entries = object.entries.map((e) => LogEntry.fromJSON(e));
        if (isSet(object.nextPageToken))
            obj.nextPageToken = String(object.nextPageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toJSON(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        message.nextPageToken !== undefined && (obj.nextPageToken = message.nextPageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListLogEntriesResponse();
        message.entries = object.entries?.map(e => LogEntry.fromPartial(e)) || [];
        message.nextPageToken = object.nextPageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDK(e)) : [],
            nextPageToken: object?.next_page_token
        };
    },
    fromSDKJSON(object) {
        return {
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDKJSON(e)) : [],
            next_page_token: isSet(object.next_page_token) ? String(object.next_page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toSDK(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        obj.next_page_token = message.nextPageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListLogEntriesResponse();
        message.entries = object.entries?.map(e => LogEntry.fromAmino(e)) || [];
        if (object.next_page_token !== undefined && object.next_page_token !== null) {
            message.nextPageToken = object.next_page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toAmino(e) : undefined);
        }
        else {
            obj.entries = message.entries;
        }
        obj.next_page_token = message.nextPageToken === "" ? undefined : message.nextPageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListLogEntriesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListLogEntriesResponse.decode(message.value);
    },
    toProto(message) {
        return ListLogEntriesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListLogEntriesResponse",
            value: ListLogEntriesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        LogEntry.registerTypeUrl();
    }
};
function createBaseListMonitoredResourceDescriptorsRequest() {
    return {
        pageSize: 0,
        pageToken: ""
    };
}
export const ListMonitoredResourceDescriptorsRequest = {
    typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsRequest",
    is(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsRequest.typeUrl || typeof o.pageSize === "number" && typeof o.pageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsRequest.typeUrl || typeof o.page_size === "number" && typeof o.page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsRequest.typeUrl || typeof o.page_size === "number" && typeof o.page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.pageSize !== undefined) {
            writer.uint32(8).int32(message.pageSize);
        }
        if (message.pageToken !== undefined) {
            writer.uint32(18).string(message.pageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListMonitoredResourceDescriptorsRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.pageSize = reader.int32();
                    break;
                case 2:
                    message.pageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListMonitoredResourceDescriptorsRequest();
        if (isSet(object.pageSize))
            obj.pageSize = Number(object.pageSize);
        if (isSet(object.pageToken))
            obj.pageToken = String(object.pageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.pageSize !== undefined && (obj.pageSize = Math.round(message.pageSize));
        message.pageToken !== undefined && (obj.pageToken = message.pageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListMonitoredResourceDescriptorsRequest();
        message.pageSize = object.pageSize ?? 0;
        message.pageToken = object.pageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            pageSize: object?.page_size,
            pageToken: object?.page_token
        };
    },
    fromSDKJSON(object) {
        return {
            page_size: isSet(object.page_size) ? Number(object.page_size) : 0,
            page_token: isSet(object.page_token) ? String(object.page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.page_size = message.pageSize;
        obj.page_token = message.pageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListMonitoredResourceDescriptorsRequest();
        if (object.page_size !== undefined && object.page_size !== null) {
            message.pageSize = object.page_size;
        }
        if (object.page_token !== undefined && object.page_token !== null) {
            message.pageToken = object.page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.page_size = message.pageSize === 0 ? undefined : message.pageSize;
        obj.page_token = message.pageToken === "" ? undefined : message.pageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListMonitoredResourceDescriptorsRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListMonitoredResourceDescriptorsRequest.decode(message.value);
    },
    toProto(message) {
        return ListMonitoredResourceDescriptorsRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsRequest",
            value: ListMonitoredResourceDescriptorsRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseListMonitoredResourceDescriptorsResponse() {
    return {
        resourceDescriptors: [],
        nextPageToken: ""
    };
}
export const ListMonitoredResourceDescriptorsResponse = {
    typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsResponse",
    is(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsResponse.typeUrl || Array.isArray(o.resourceDescriptors) && (!o.resourceDescriptors.length || MonitoredResourceDescriptor.is(o.resourceDescriptors[0])) && typeof o.nextPageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsResponse.typeUrl || Array.isArray(o.resource_descriptors) && (!o.resource_descriptors.length || MonitoredResourceDescriptor.isSDK(o.resource_descriptors[0])) && typeof o.next_page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListMonitoredResourceDescriptorsResponse.typeUrl || Array.isArray(o.resource_descriptors) && (!o.resource_descriptors.length || MonitoredResourceDescriptor.isAmino(o.resource_descriptors[0])) && typeof o.next_page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.resourceDescriptors) {
            MonitoredResourceDescriptor.encode(v, writer.uint32(10).fork()).ldelim();
        }
        if (message.nextPageToken !== undefined) {
            writer.uint32(18).string(message.nextPageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListMonitoredResourceDescriptorsResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.resourceDescriptors.push(MonitoredResourceDescriptor.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.nextPageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListMonitoredResourceDescriptorsResponse();
        if (Array.isArray(object?.resourceDescriptors))
            obj.resourceDescriptors = object.resourceDescriptors.map((e) => MonitoredResourceDescriptor.fromJSON(e));
        if (isSet(object.nextPageToken))
            obj.nextPageToken = String(object.nextPageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.resourceDescriptors) {
            obj.resourceDescriptors = message.resourceDescriptors.map(e => e ? MonitoredResourceDescriptor.toJSON(e) : undefined);
        }
        else {
            obj.resourceDescriptors = [];
        }
        message.nextPageToken !== undefined && (obj.nextPageToken = message.nextPageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListMonitoredResourceDescriptorsResponse();
        message.resourceDescriptors = object.resourceDescriptors?.map(e => MonitoredResourceDescriptor.fromPartial(e)) || [];
        message.nextPageToken = object.nextPageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            resourceDescriptors: Array.isArray(object?.resource_descriptors) ? object.resource_descriptors.map((e) => MonitoredResourceDescriptor.fromSDK(e)) : [],
            nextPageToken: object?.next_page_token
        };
    },
    fromSDKJSON(object) {
        return {
            resource_descriptors: Array.isArray(object?.resource_descriptors) ? object.resource_descriptors.map((e) => MonitoredResourceDescriptor.fromSDKJSON(e)) : [],
            next_page_token: isSet(object.next_page_token) ? String(object.next_page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.resourceDescriptors) {
            obj.resource_descriptors = message.resourceDescriptors.map(e => e ? MonitoredResourceDescriptor.toSDK(e) : undefined);
        }
        else {
            obj.resource_descriptors = [];
        }
        obj.next_page_token = message.nextPageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListMonitoredResourceDescriptorsResponse();
        message.resourceDescriptors = object.resource_descriptors?.map(e => MonitoredResourceDescriptor.fromAmino(e)) || [];
        if (object.next_page_token !== undefined && object.next_page_token !== null) {
            message.nextPageToken = object.next_page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.resourceDescriptors) {
            obj.resource_descriptors = message.resourceDescriptors.map(e => e ? MonitoredResourceDescriptor.toAmino(e) : undefined);
        }
        else {
            obj.resource_descriptors = message.resourceDescriptors;
        }
        obj.next_page_token = message.nextPageToken === "" ? undefined : message.nextPageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListMonitoredResourceDescriptorsResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListMonitoredResourceDescriptorsResponse.decode(message.value);
    },
    toProto(message) {
        return ListMonitoredResourceDescriptorsResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsResponse",
            value: ListMonitoredResourceDescriptorsResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        MonitoredResourceDescriptor.registerTypeUrl();
    }
};
function createBaseListLogsRequest() {
    return {
        parent: "",
        pageSize: 0,
        pageToken: "",
        resourceNames: []
    };
}
export const ListLogsRequest = {
    typeUrl: "/google.logging.v2.ListLogsRequest",
    is(o) {
        return o && (o.$typeUrl === ListLogsRequest.typeUrl || typeof o.parent === "string" && typeof o.pageSize === "number" && typeof o.pageToken === "string" && Array.isArray(o.resourceNames) && (!o.resourceNames.length || typeof o.resourceNames[0] === "string"));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListLogsRequest.typeUrl || typeof o.parent === "string" && typeof o.page_size === "number" && typeof o.page_token === "string" && Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string"));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListLogsRequest.typeUrl || typeof o.parent === "string" && typeof o.page_size === "number" && typeof o.page_token === "string" && Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string"));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.parent !== undefined) {
            writer.uint32(10).string(message.parent);
        }
        if (message.pageSize !== undefined) {
            writer.uint32(16).int32(message.pageSize);
        }
        if (message.pageToken !== undefined) {
            writer.uint32(26).string(message.pageToken);
        }
        for (const v of message.resourceNames) {
            writer.uint32(66).string(v);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListLogsRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.parent = reader.string();
                    break;
                case 2:
                    message.pageSize = reader.int32();
                    break;
                case 3:
                    message.pageToken = reader.string();
                    break;
                case 8:
                    message.resourceNames.push(reader.string());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListLogsRequest();
        if (isSet(object.parent))
            obj.parent = String(object.parent);
        if (isSet(object.pageSize))
            obj.pageSize = Number(object.pageSize);
        if (isSet(object.pageToken))
            obj.pageToken = String(object.pageToken);
        if (Array.isArray(object?.resourceNames))
            obj.resourceNames = object.resourceNames.map((e) => String(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.parent !== undefined && (obj.parent = message.parent);
        message.pageSize !== undefined && (obj.pageSize = Math.round(message.pageSize));
        message.pageToken !== undefined && (obj.pageToken = message.pageToken);
        if (message.resourceNames) {
            obj.resourceNames = message.resourceNames.map(e => e);
        }
        else {
            obj.resourceNames = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListLogsRequest();
        message.parent = object.parent ?? "";
        message.pageSize = object.pageSize ?? 0;
        message.pageToken = object.pageToken ?? "";
        message.resourceNames = object.resourceNames?.map(e => e) || [];
        return message;
    },
    fromSDK(object) {
        return {
            parent: object?.parent,
            pageSize: object?.page_size,
            pageToken: object?.page_token,
            resourceNames: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => e) : []
        };
    },
    fromSDKJSON(object) {
        return {
            parent: isSet(object.parent) ? String(object.parent) : "",
            page_size: isSet(object.page_size) ? Number(object.page_size) : 0,
            page_token: isSet(object.page_token) ? String(object.page_token) : "",
            resource_names: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => String(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.parent = message.parent;
        obj.page_size = message.pageSize;
        obj.page_token = message.pageToken;
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListLogsRequest();
        if (object.parent !== undefined && object.parent !== null) {
            message.parent = object.parent;
        }
        if (object.page_size !== undefined && object.page_size !== null) {
            message.pageSize = object.page_size;
        }
        if (object.page_token !== undefined && object.page_token !== null) {
            message.pageToken = object.page_token;
        }
        message.resourceNames = object.resource_names?.map(e => e) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.parent = message.parent === "" ? undefined : message.parent;
        obj.page_size = message.pageSize === 0 ? undefined : message.pageSize;
        obj.page_token = message.pageToken === "" ? undefined : message.pageToken;
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = message.resourceNames;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ListLogsRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListLogsRequest.decode(message.value);
    },
    toProto(message) {
        return ListLogsRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListLogsRequest",
            value: ListLogsRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseListLogsResponse() {
    return {
        logNames: [],
        nextPageToken: ""
    };
}
export const ListLogsResponse = {
    typeUrl: "/google.logging.v2.ListLogsResponse",
    is(o) {
        return o && (o.$typeUrl === ListLogsResponse.typeUrl || Array.isArray(o.logNames) && (!o.logNames.length || typeof o.logNames[0] === "string") && typeof o.nextPageToken === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListLogsResponse.typeUrl || Array.isArray(o.log_names) && (!o.log_names.length || typeof o.log_names[0] === "string") && typeof o.next_page_token === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListLogsResponse.typeUrl || Array.isArray(o.log_names) && (!o.log_names.length || typeof o.log_names[0] === "string") && typeof o.next_page_token === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.logNames) {
            writer.uint32(26).string(v);
        }
        if (message.nextPageToken !== undefined) {
            writer.uint32(18).string(message.nextPageToken);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListLogsResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 3:
                    message.logNames.push(reader.string());
                    break;
                case 2:
                    message.nextPageToken = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListLogsResponse();
        if (Array.isArray(object?.logNames))
            obj.logNames = object.logNames.map((e) => String(e));
        if (isSet(object.nextPageToken))
            obj.nextPageToken = String(object.nextPageToken);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.logNames) {
            obj.logNames = message.logNames.map(e => e);
        }
        else {
            obj.logNames = [];
        }
        message.nextPageToken !== undefined && (obj.nextPageToken = message.nextPageToken);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListLogsResponse();
        message.logNames = object.logNames?.map(e => e) || [];
        message.nextPageToken = object.nextPageToken ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            logNames: Array.isArray(object?.log_names) ? object.log_names.map((e) => e) : [],
            nextPageToken: object?.next_page_token
        };
    },
    fromSDKJSON(object) {
        return {
            log_names: Array.isArray(object?.log_names) ? object.log_names.map((e) => String(e)) : [],
            next_page_token: isSet(object.next_page_token) ? String(object.next_page_token) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.logNames) {
            obj.log_names = message.logNames.map(e => e);
        }
        else {
            obj.log_names = [];
        }
        obj.next_page_token = message.nextPageToken;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListLogsResponse();
        message.logNames = object.log_names?.map(e => e) || [];
        if (object.next_page_token !== undefined && object.next_page_token !== null) {
            message.nextPageToken = object.next_page_token;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.logNames) {
            obj.log_names = message.logNames.map(e => e);
        }
        else {
            obj.log_names = message.logNames;
        }
        obj.next_page_token = message.nextPageToken === "" ? undefined : message.nextPageToken;
        return obj;
    },
    fromAminoMsg(object) {
        return ListLogsResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListLogsResponse.decode(message.value);
    },
    toProto(message) {
        return ListLogsResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.ListLogsResponse",
            value: ListLogsResponse.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseTailLogEntriesRequest() {
    return {
        resourceNames: [],
        filter: "",
        bufferWindow: undefined
    };
}
export const TailLogEntriesRequest = {
    typeUrl: "/google.logging.v2.TailLogEntriesRequest",
    is(o) {
        return o && (o.$typeUrl === TailLogEntriesRequest.typeUrl || Array.isArray(o.resourceNames) && (!o.resourceNames.length || typeof o.resourceNames[0] === "string") && typeof o.filter === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === TailLogEntriesRequest.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string") && typeof o.filter === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === TailLogEntriesRequest.typeUrl || Array.isArray(o.resource_names) && (!o.resource_names.length || typeof o.resource_names[0] === "string") && typeof o.filter === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.resourceNames) {
            writer.uint32(10).string(v);
        }
        if (message.filter !== undefined) {
            writer.uint32(18).string(message.filter);
        }
        if (message.bufferWindow !== undefined) {
            Duration.encode(message.bufferWindow, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseTailLogEntriesRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.resourceNames.push(reader.string());
                    break;
                case 2:
                    message.filter = reader.string();
                    break;
                case 3:
                    message.bufferWindow = Duration.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseTailLogEntriesRequest();
        if (Array.isArray(object?.resourceNames))
            obj.resourceNames = object.resourceNames.map((e) => String(e));
        if (isSet(object.filter))
            obj.filter = String(object.filter);
        if (isSet(object.bufferWindow))
            obj.bufferWindow = Duration.fromJSON(object.bufferWindow);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resourceNames = message.resourceNames.map(e => e);
        }
        else {
            obj.resourceNames = [];
        }
        message.filter !== undefined && (obj.filter = message.filter);
        message.bufferWindow !== undefined && (obj.bufferWindow = message.bufferWindow ? Duration.toJSON(message.bufferWindow) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseTailLogEntriesRequest();
        message.resourceNames = object.resourceNames?.map(e => e) || [];
        message.filter = object.filter ?? "";
        if (object.bufferWindow !== undefined && object.bufferWindow !== null) {
            message.bufferWindow = Duration.fromPartial(object.bufferWindow);
        }
        return message;
    },
    fromSDK(object) {
        return {
            resourceNames: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => e) : [],
            filter: object?.filter,
            bufferWindow: object.buffer_window ? Duration.fromSDK(object.buffer_window) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            resource_names: Array.isArray(object?.resource_names) ? object.resource_names.map((e) => String(e)) : [],
            filter: isSet(object.filter) ? String(object.filter) : "",
            buffer_window: isSet(object.buffer_window) ? Duration.fromSDKJSON(object.buffer_window) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = [];
        }
        obj.filter = message.filter;
        message.bufferWindow !== undefined && (obj.buffer_window = message.bufferWindow ? Duration.toSDK(message.bufferWindow) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseTailLogEntriesRequest();
        message.resourceNames = object.resource_names?.map(e => e) || [];
        if (object.filter !== undefined && object.filter !== null) {
            message.filter = object.filter;
        }
        if (object.buffer_window !== undefined && object.buffer_window !== null) {
            message.bufferWindow = Duration.fromAmino(object.buffer_window);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.resourceNames) {
            obj.resource_names = message.resourceNames.map(e => e);
        }
        else {
            obj.resource_names = message.resourceNames;
        }
        obj.filter = message.filter === "" ? undefined : message.filter;
        obj.buffer_window = message.bufferWindow ? Duration.toAmino(message.bufferWindow) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return TailLogEntriesRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return TailLogEntriesRequest.decode(message.value);
    },
    toProto(message) {
        return TailLogEntriesRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.TailLogEntriesRequest",
            value: TailLogEntriesRequest.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseTailLogEntriesResponse() {
    return {
        entries: [],
        suppressionInfo: []
    };
}
export const TailLogEntriesResponse = {
    typeUrl: "/google.logging.v2.TailLogEntriesResponse",
    is(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.is(o.entries[0])) && Array.isArray(o.suppressionInfo) && (!o.suppressionInfo.length || TailLogEntriesResponse_SuppressionInfo.is(o.suppressionInfo[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.isSDK(o.entries[0])) && Array.isArray(o.suppression_info) && (!o.suppression_info.length || TailLogEntriesResponse_SuppressionInfo.isSDK(o.suppression_info[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse.typeUrl || Array.isArray(o.entries) && (!o.entries.length || LogEntry.isAmino(o.entries[0])) && Array.isArray(o.suppression_info) && (!o.suppression_info.length || TailLogEntriesResponse_SuppressionInfo.isAmino(o.suppression_info[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.entries) {
            LogEntry.encode(v, writer.uint32(10).fork()).ldelim();
        }
        for (const v of message.suppressionInfo) {
            TailLogEntriesResponse_SuppressionInfo.encode(v, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseTailLogEntriesResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.entries.push(LogEntry.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.suppressionInfo.push(TailLogEntriesResponse_SuppressionInfo.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseTailLogEntriesResponse();
        if (Array.isArray(object?.entries))
            obj.entries = object.entries.map((e) => LogEntry.fromJSON(e));
        if (Array.isArray(object?.suppressionInfo))
            obj.suppressionInfo = object.suppressionInfo.map((e) => TailLogEntriesResponse_SuppressionInfo.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toJSON(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        if (message.suppressionInfo) {
            obj.suppressionInfo = message.suppressionInfo.map(e => e ? TailLogEntriesResponse_SuppressionInfo.toJSON(e) : undefined);
        }
        else {
            obj.suppressionInfo = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseTailLogEntriesResponse();
        message.entries = object.entries?.map(e => LogEntry.fromPartial(e)) || [];
        message.suppressionInfo = object.suppressionInfo?.map(e => TailLogEntriesResponse_SuppressionInfo.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDK(e)) : [],
            suppressionInfo: Array.isArray(object?.suppression_info) ? object.suppression_info.map((e) => TailLogEntriesResponse_SuppressionInfo.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            entries: Array.isArray(object?.entries) ? object.entries.map((e) => LogEntry.fromSDKJSON(e)) : [],
            suppression_info: Array.isArray(object?.suppression_info) ? object.suppression_info.map((e) => TailLogEntriesResponse_SuppressionInfo.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toSDK(e) : undefined);
        }
        else {
            obj.entries = [];
        }
        if (message.suppressionInfo) {
            obj.suppression_info = message.suppressionInfo.map(e => e ? TailLogEntriesResponse_SuppressionInfo.toSDK(e) : undefined);
        }
        else {
            obj.suppression_info = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseTailLogEntriesResponse();
        message.entries = object.entries?.map(e => LogEntry.fromAmino(e)) || [];
        message.suppressionInfo = object.suppression_info?.map(e => TailLogEntriesResponse_SuppressionInfo.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.entries) {
            obj.entries = message.entries.map(e => e ? LogEntry.toAmino(e) : undefined);
        }
        else {
            obj.entries = message.entries;
        }
        if (message.suppressionInfo) {
            obj.suppression_info = message.suppressionInfo.map(e => e ? TailLogEntriesResponse_SuppressionInfo.toAmino(e) : undefined);
        }
        else {
            obj.suppression_info = message.suppressionInfo;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return TailLogEntriesResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return TailLogEntriesResponse.decode(message.value);
    },
    toProto(message) {
        return TailLogEntriesResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.TailLogEntriesResponse",
            value: TailLogEntriesResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        LogEntry.registerTypeUrl();
        TailLogEntriesResponse_SuppressionInfo.registerTypeUrl();
    }
};
function createBaseTailLogEntriesResponse_SuppressionInfo() {
    return {
        reason: 0,
        suppressedCount: 0
    };
}
export const TailLogEntriesResponse_SuppressionInfo = {
    typeUrl: "/google.logging.v2.SuppressionInfo",
    is(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse_SuppressionInfo.typeUrl || isSet(o.reason) && typeof o.suppressedCount === "number");
    },
    isSDK(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse_SuppressionInfo.typeUrl || isSet(o.reason) && typeof o.suppressed_count === "number");
    },
    isAmino(o) {
        return o && (o.$typeUrl === TailLogEntriesResponse_SuppressionInfo.typeUrl || isSet(o.reason) && typeof o.suppressed_count === "number");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.reason !== 0) {
            writer.uint32(8).int32(message.reason);
        }
        if (message.suppressedCount !== undefined) {
            writer.uint32(16).int32(message.suppressedCount);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseTailLogEntriesResponse_SuppressionInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.reason = reader.int32();
                    break;
                case 2:
                    message.suppressedCount = reader.int32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseTailLogEntriesResponse_SuppressionInfo();
        if (isSet(object.reason))
            obj.reason = tailLogEntriesResponse_SuppressionInfo_ReasonFromJSON(object.reason);
        if (isSet(object.suppressedCount))
            obj.suppressedCount = Number(object.suppressedCount);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.reason !== undefined && (obj.reason = tailLogEntriesResponse_SuppressionInfo_ReasonToJSON(message.reason));
        message.suppressedCount !== undefined && (obj.suppressedCount = Math.round(message.suppressedCount));
        return obj;
    },
    fromPartial(object) {
        const message = createBaseTailLogEntriesResponse_SuppressionInfo();
        message.reason = object.reason ?? 0;
        message.suppressedCount = object.suppressedCount ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            reason: isSet(object.reason) ? tailLogEntriesResponse_SuppressionInfo_ReasonFromJSON(object.reason) : -1,
            suppressedCount: object?.suppressed_count
        };
    },
    fromSDKJSON(object) {
        return {
            reason: isSet(object.reason) ? tailLogEntriesResponse_SuppressionInfo_ReasonFromJSON(object.reason) : -1,
            suppressed_count: isSet(object.suppressed_count) ? Number(object.suppressed_count) : 0
        };
    },
    toSDK(message) {
        const obj = {};
        message.reason !== undefined && (obj.reason = tailLogEntriesResponse_SuppressionInfo_ReasonToJSON(message.reason));
        obj.suppressed_count = message.suppressedCount;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseTailLogEntriesResponse_SuppressionInfo();
        if (object.reason !== undefined && object.reason !== null) {
            message.reason = object.reason;
        }
        if (object.suppressed_count !== undefined && object.suppressed_count !== null) {
            message.suppressedCount = object.suppressed_count;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.reason = message.reason === 0 ? undefined : message.reason;
        obj.suppressed_count = message.suppressedCount === 0 ? undefined : message.suppressedCount;
        return obj;
    },
    fromAminoMsg(object) {
        return TailLogEntriesResponse_SuppressionInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return TailLogEntriesResponse_SuppressionInfo.decode(message.value);
    },
    toProto(message) {
        return TailLogEntriesResponse_SuppressionInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.logging.v2.SuppressionInfo",
            value: TailLogEntriesResponse_SuppressionInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
