import { FileDescriptorProto } from "../descriptor";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "google.protobuf.compiler";
function createBaseVersion() {
    return {
        major: 0,
        minor: 0,
        patch: 0,
        suffix: ""
    };
}
export const Version = {
    typeUrl: "/google.protobuf.compiler.Version",
    is(o) {
        return o && (o.$typeUrl === Version.typeUrl || typeof o.major === "number" && typeof o.minor === "number" && typeof o.patch === "number" && typeof o.suffix === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Version.typeUrl || typeof o.major === "number" && typeof o.minor === "number" && typeof o.patch === "number" && typeof o.suffix === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Version.typeUrl || typeof o.major === "number" && typeof o.minor === "number" && typeof o.patch === "number" && typeof o.suffix === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.major !== undefined) {
            writer.uint32(8).int32(message.major);
        }
        if (message.minor !== undefined) {
            writer.uint32(16).int32(message.minor);
        }
        if (message.patch !== undefined) {
            writer.uint32(24).int32(message.patch);
        }
        if (message.suffix !== undefined) {
            writer.uint32(34).string(message.suffix);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseVersion();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.major = reader.int32();
                    break;
                case 2:
                    message.minor = reader.int32();
                    break;
                case 3:
                    message.patch = reader.int32();
                    break;
                case 4:
                    message.suffix = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseVersion();
        if (isSet(object.major))
            obj.major = Number(object.major);
        if (isSet(object.minor))
            obj.minor = Number(object.minor);
        if (isSet(object.patch))
            obj.patch = Number(object.patch);
        if (isSet(object.suffix))
            obj.suffix = String(object.suffix);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.major !== undefined && (obj.major = Math.round(message.major));
        message.minor !== undefined && (obj.minor = Math.round(message.minor));
        message.patch !== undefined && (obj.patch = Math.round(message.patch));
        message.suffix !== undefined && (obj.suffix = message.suffix);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseVersion();
        message.major = object.major ?? 0;
        message.minor = object.minor ?? 0;
        message.patch = object.patch ?? 0;
        message.suffix = object.suffix ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            major: object?.major,
            minor: object?.minor,
            patch: object?.patch,
            suffix: object?.suffix
        };
    },
    fromSDKJSON(object) {
        return {
            major: isSet(object.major) ? Number(object.major) : 0,
            minor: isSet(object.minor) ? Number(object.minor) : 0,
            patch: isSet(object.patch) ? Number(object.patch) : 0,
            suffix: isSet(object.suffix) ? String(object.suffix) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.major = message.major;
        obj.minor = message.minor;
        obj.patch = message.patch;
        obj.suffix = message.suffix;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseVersion();
        if (object.major !== undefined && object.major !== null) {
            message.major = object.major;
        }
        if (object.minor !== undefined && object.minor !== null) {
            message.minor = object.minor;
        }
        if (object.patch !== undefined && object.patch !== null) {
            message.patch = object.patch;
        }
        if (object.suffix !== undefined && object.suffix !== null) {
            message.suffix = object.suffix;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.major = message.major === 0 ? undefined : message.major;
        obj.minor = message.minor === 0 ? undefined : message.minor;
        obj.patch = message.patch === 0 ? undefined : message.patch;
        obj.suffix = message.suffix === "" ? undefined : message.suffix;
        return obj;
    },
    fromAminoMsg(object) {
        return Version.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Version.decode(message.value);
    },
    toProto(message) {
        return Version.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.compiler.Version",
            value: Version.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseCodeGeneratorRequest() {
    return {
        fileToGenerate: [],
        parameter: "",
        protoFile: [],
        compilerVersion: undefined
    };
}
export const CodeGeneratorRequest = {
    typeUrl: "/google.protobuf.compiler.CodeGeneratorRequest",
    is(o) {
        return o && (o.$typeUrl === CodeGeneratorRequest.typeUrl || Array.isArray(o.fileToGenerate) && (!o.fileToGenerate.length || typeof o.fileToGenerate[0] === "string") && typeof o.parameter === "string" && Array.isArray(o.protoFile) && (!o.protoFile.length || FileDescriptorProto.is(o.protoFile[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === CodeGeneratorRequest.typeUrl || Array.isArray(o.file_to_generate) && (!o.file_to_generate.length || typeof o.file_to_generate[0] === "string") && typeof o.parameter === "string" && Array.isArray(o.proto_file) && (!o.proto_file.length || FileDescriptorProto.isSDK(o.proto_file[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === CodeGeneratorRequest.typeUrl || Array.isArray(o.file_to_generate) && (!o.file_to_generate.length || typeof o.file_to_generate[0] === "string") && typeof o.parameter === "string" && Array.isArray(o.proto_file) && (!o.proto_file.length || FileDescriptorProto.isAmino(o.proto_file[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.fileToGenerate) {
            writer.uint32(10).string(v);
        }
        if (message.parameter !== undefined) {
            writer.uint32(18).string(message.parameter);
        }
        for (const v of message.protoFile) {
            FileDescriptorProto.encode(v, writer.uint32(122).fork()).ldelim();
        }
        if (message.compilerVersion !== undefined) {
            Version.encode(message.compilerVersion, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCodeGeneratorRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.fileToGenerate.push(reader.string());
                    break;
                case 2:
                    message.parameter = reader.string();
                    break;
                case 15:
                    message.protoFile.push(FileDescriptorProto.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.compilerVersion = Version.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCodeGeneratorRequest();
        if (Array.isArray(object?.fileToGenerate))
            obj.fileToGenerate = object.fileToGenerate.map((e) => String(e));
        if (isSet(object.parameter))
            obj.parameter = String(object.parameter);
        if (Array.isArray(object?.protoFile))
            obj.protoFile = object.protoFile.map((e) => FileDescriptorProto.fromJSON(e));
        if (isSet(object.compilerVersion))
            obj.compilerVersion = Version.fromJSON(object.compilerVersion);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.fileToGenerate) {
            obj.fileToGenerate = message.fileToGenerate.map(e => e);
        }
        else {
            obj.fileToGenerate = [];
        }
        message.parameter !== undefined && (obj.parameter = message.parameter);
        if (message.protoFile) {
            obj.protoFile = message.protoFile.map(e => e ? FileDescriptorProto.toJSON(e) : undefined);
        }
        else {
            obj.protoFile = [];
        }
        message.compilerVersion !== undefined && (obj.compilerVersion = message.compilerVersion ? Version.toJSON(message.compilerVersion) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCodeGeneratorRequest();
        message.fileToGenerate = object.fileToGenerate?.map(e => e) || [];
        message.parameter = object.parameter ?? "";
        message.protoFile = object.protoFile?.map(e => FileDescriptorProto.fromPartial(e)) || [];
        if (object.compilerVersion !== undefined && object.compilerVersion !== null) {
            message.compilerVersion = Version.fromPartial(object.compilerVersion);
        }
        return message;
    },
    fromSDK(object) {
        return {
            fileToGenerate: Array.isArray(object?.file_to_generate) ? object.file_to_generate.map((e) => e) : [],
            parameter: object?.parameter,
            protoFile: Array.isArray(object?.proto_file) ? object.proto_file.map((e) => FileDescriptorProto.fromSDK(e)) : [],
            compilerVersion: object.compiler_version ? Version.fromSDK(object.compiler_version) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            file_to_generate: Array.isArray(object?.file_to_generate) ? object.file_to_generate.map((e) => String(e)) : [],
            parameter: isSet(object.parameter) ? String(object.parameter) : "",
            proto_file: Array.isArray(object?.proto_file) ? object.proto_file.map((e) => FileDescriptorProto.fromSDKJSON(e)) : [],
            compiler_version: isSet(object.compiler_version) ? Version.fromSDKJSON(object.compiler_version) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.fileToGenerate) {
            obj.file_to_generate = message.fileToGenerate.map(e => e);
        }
        else {
            obj.file_to_generate = [];
        }
        obj.parameter = message.parameter;
        if (message.protoFile) {
            obj.proto_file = message.protoFile.map(e => e ? FileDescriptorProto.toSDK(e) : undefined);
        }
        else {
            obj.proto_file = [];
        }
        message.compilerVersion !== undefined && (obj.compiler_version = message.compilerVersion ? Version.toSDK(message.compilerVersion) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCodeGeneratorRequest();
        message.fileToGenerate = object.file_to_generate?.map(e => e) || [];
        if (object.parameter !== undefined && object.parameter !== null) {
            message.parameter = object.parameter;
        }
        message.protoFile = object.proto_file?.map(e => FileDescriptorProto.fromAmino(e)) || [];
        if (object.compiler_version !== undefined && object.compiler_version !== null) {
            message.compilerVersion = Version.fromAmino(object.compiler_version);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.fileToGenerate) {
            obj.file_to_generate = message.fileToGenerate.map(e => e);
        }
        else {
            obj.file_to_generate = message.fileToGenerate;
        }
        obj.parameter = message.parameter === "" ? undefined : message.parameter;
        if (message.protoFile) {
            obj.proto_file = message.protoFile.map(e => e ? FileDescriptorProto.toAmino(e) : undefined);
        }
        else {
            obj.proto_file = message.protoFile;
        }
        obj.compiler_version = message.compilerVersion ? Version.toAmino(message.compilerVersion) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return CodeGeneratorRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CodeGeneratorRequest.decode(message.value);
    },
    toProto(message) {
        return CodeGeneratorRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.compiler.CodeGeneratorRequest",
            value: CodeGeneratorRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        FileDescriptorProto.registerTypeUrl();
        Version.registerTypeUrl();
    }
};
function createBaseCodeGeneratorResponse() {
    return {
        error: "",
        file: []
    };
}
export const CodeGeneratorResponse = {
    typeUrl: "/google.protobuf.compiler.CodeGeneratorResponse",
    is(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse.typeUrl || typeof o.error === "string" && Array.isArray(o.file) && (!o.file.length || CodeGeneratorResponse_File.is(o.file[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse.typeUrl || typeof o.error === "string" && Array.isArray(o.file) && (!o.file.length || CodeGeneratorResponse_File.isSDK(o.file[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse.typeUrl || typeof o.error === "string" && Array.isArray(o.file) && (!o.file.length || CodeGeneratorResponse_File.isAmino(o.file[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.error !== undefined) {
            writer.uint32(10).string(message.error);
        }
        for (const v of message.file) {
            CodeGeneratorResponse_File.encode(v, writer.uint32(122).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCodeGeneratorResponse();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.error = reader.string();
                    break;
                case 15:
                    message.file.push(CodeGeneratorResponse_File.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCodeGeneratorResponse();
        if (isSet(object.error))
            obj.error = String(object.error);
        if (Array.isArray(object?.file))
            obj.file = object.file.map((e) => CodeGeneratorResponse_File.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.error !== undefined && (obj.error = message.error);
        if (message.file) {
            obj.file = message.file.map(e => e ? CodeGeneratorResponse_File.toJSON(e) : undefined);
        }
        else {
            obj.file = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCodeGeneratorResponse();
        message.error = object.error ?? "";
        message.file = object.file?.map(e => CodeGeneratorResponse_File.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            error: object?.error,
            file: Array.isArray(object?.file) ? object.file.map((e) => CodeGeneratorResponse_File.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            error: isSet(object.error) ? String(object.error) : "",
            file: Array.isArray(object?.file) ? object.file.map((e) => CodeGeneratorResponse_File.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.error = message.error;
        if (message.file) {
            obj.file = message.file.map(e => e ? CodeGeneratorResponse_File.toSDK(e) : undefined);
        }
        else {
            obj.file = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCodeGeneratorResponse();
        if (object.error !== undefined && object.error !== null) {
            message.error = object.error;
        }
        message.file = object.file?.map(e => CodeGeneratorResponse_File.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.error = message.error === "" ? undefined : message.error;
        if (message.file) {
            obj.file = message.file.map(e => e ? CodeGeneratorResponse_File.toAmino(e) : undefined);
        }
        else {
            obj.file = message.file;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return CodeGeneratorResponse.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CodeGeneratorResponse.decode(message.value);
    },
    toProto(message) {
        return CodeGeneratorResponse.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.compiler.CodeGeneratorResponse",
            value: CodeGeneratorResponse.encode(message).finish()
        };
    },
    registerTypeUrl() {
        CodeGeneratorResponse_File.registerTypeUrl();
    }
};
function createBaseCodeGeneratorResponse_File() {
    return {
        name: "",
        insertionPoint: "",
        content: ""
    };
}
export const CodeGeneratorResponse_File = {
    typeUrl: "/google.protobuf.compiler.File",
    is(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse_File.typeUrl || typeof o.name === "string" && typeof o.insertionPoint === "string" && typeof o.content === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse_File.typeUrl || typeof o.name === "string" && typeof o.insertion_point === "string" && typeof o.content === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === CodeGeneratorResponse_File.typeUrl || typeof o.name === "string" && typeof o.insertion_point === "string" && typeof o.content === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.insertionPoint !== undefined) {
            writer.uint32(18).string(message.insertionPoint);
        }
        if (message.content !== undefined) {
            writer.uint32(122).string(message.content);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseCodeGeneratorResponse_File();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.insertionPoint = reader.string();
                    break;
                case 15:
                    message.content = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseCodeGeneratorResponse_File();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.insertionPoint))
            obj.insertionPoint = String(object.insertionPoint);
        if (isSet(object.content))
            obj.content = String(object.content);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.insertionPoint !== undefined && (obj.insertionPoint = message.insertionPoint);
        message.content !== undefined && (obj.content = message.content);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseCodeGeneratorResponse_File();
        message.name = object.name ?? "";
        message.insertionPoint = object.insertionPoint ?? "";
        message.content = object.content ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            insertionPoint: object?.insertion_point,
            content: object?.content
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            insertion_point: isSet(object.insertion_point) ? String(object.insertion_point) : "",
            content: isSet(object.content) ? String(object.content) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        obj.insertion_point = message.insertionPoint;
        obj.content = message.content;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseCodeGeneratorResponse_File();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.insertion_point !== undefined && object.insertion_point !== null) {
            message.insertionPoint = object.insertion_point;
        }
        if (object.content !== undefined && object.content !== null) {
            message.content = object.content;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.insertion_point = message.insertionPoint === "" ? undefined : message.insertionPoint;
        obj.content = message.content === "" ? undefined : message.content;
        return obj;
    },
    fromAminoMsg(object) {
        return CodeGeneratorResponse_File.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return CodeGeneratorResponse_File.decode(message.value);
    },
    toProto(message) {
        return CodeGeneratorResponse_File.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.compiler.File",
            value: CodeGeneratorResponse_File.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
