import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet, isObject } from "../../helpers";
export const protobufPackage = "google.protobuf";
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 *  The JSON representation for `NullValue` is JSON `null`.
 */
export var NullValue;
(function (NullValue) {
    /** NULL_VALUE - Null value. */
    NullValue[NullValue["NULL_VALUE"] = 0] = "NULL_VALUE";
    NullValue[NullValue["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(NullValue || (NullValue = {}));
export const NullValueSDKType = NullValue;
export const NullValueAmino = NullValue;
export function nullValueFromJSON(object) {
    switch (object) {
        case 0:
        case "NULL_VALUE":
            return NullValue.NULL_VALUE;
        case -1:
        case "UNRECOGNIZED":
        default:
            return NullValue.UNRECOGNIZED;
    }
}
export function nullValueToJSON(object) {
    switch (object) {
        case NullValue.NULL_VALUE:
            return "NULL_VALUE";
        case NullValue.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseStruct_FieldsEntry() {
    return {
        key: "",
        value: undefined
    };
}
export const Struct_FieldsEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            Value.encode(message.value, writer.uint32(18).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseStruct_FieldsEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = Value.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseStruct_FieldsEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = Value.fromJSON(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value ? Value.toJSON(message.value) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseStruct_FieldsEntry();
        message.key = object.key ?? "";
        if (object.value !== undefined && object.value !== null) {
            message.value = Value.fromPartial(object.value);
        }
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object.value ? Value.fromSDK(object.value) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? Value.fromSDKJSON(object.value) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        message.value !== undefined && (obj.value = message.value ? Value.toSDK(message.value) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseStruct_FieldsEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = Value.fromAmino(object.value);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value ? Value.toAmino(message.value) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return Struct_FieldsEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Struct_FieldsEntry.decode(message.value);
    },
    toProto(message) {
        return Struct_FieldsEntry.encode(message).finish();
    },
    registerTypeUrl() {
        Value.registerTypeUrl();
    }
};
function createBaseStruct() {
    return {
        fields: {}
    };
}
export const Struct = {
    typeUrl: "/google.protobuf.Struct",
    is(o) {
        return o && (o.$typeUrl === Struct.typeUrl || isSet(o.fields));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Struct.typeUrl || isSet(o.fields));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Struct.typeUrl || isSet(o.fields));
    },
    encode(message, writer = BinaryWriter.create()) {
        Object.entries(message.fields).forEach(([key, value]) => {
            Struct_FieldsEntry.encode({
                key: key,
                value
            }, writer.uint32(10).fork()).ldelim();
        });
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseStruct();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    const entry1 = Struct_FieldsEntry.decode(reader, reader.uint32());
                    if (entry1.value !== undefined) {
                        message.fields[entry1.key] = entry1.value;
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseStruct();
        if (isObject(object.fields))
            obj.fields = Object.entries(object.fields).reduce((acc, [key, value]) => {
                acc[key] = Value.fromJSON(value);
                return acc;
            }, {});
        return obj;
    },
    toJSON(message) {
        const obj = {};
        obj.fields = {};
        if (message.fields) {
            Object.entries(message.fields).forEach(([k, v]) => {
                obj.fields[k] = Value.toJSON(v);
            });
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseStruct();
        message.fields = Object.entries(object.fields ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = Value.fromPartial(value);
            }
            return acc;
        }, {});
        return message;
    },
    fromSDK(object) {
        return {
            fields: isObject(object.fields) ? Object.entries(object.fields).reduce((acc, [key, value]) => {
                acc[key] = Value.fromSDK(value);
                return acc;
            }, {}) : {}
        };
    },
    fromSDKJSON(object) {
        return {
            //@ts-ignore
            fields: isObject(object.fields) ? Object.entries(object.fields).reduce((acc, [key, value]) => {
                //@ts-ignore
                acc[key] = Value.fromSDKJSON(value);
                return acc;
            }, {}) : {}
        };
    },
    toSDK(message) {
        const obj = {};
        obj.fields = {};
        if (message.fields) {
            Object.entries(message.fields).forEach(([k, v]) => {
                obj.fields[k] = Value.toSDK(v);
            });
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseStruct();
        message.fields = Object.entries(object.fields ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = Value.fromAmino(value);
            }
            return acc;
        }, {});
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.fields = {};
        if (message.fields) {
            Object.entries(message.fields).forEach(([k, v]) => {
                obj.fields[k] = Value.toAmino(v);
            });
        }
        return obj;
    },
    fromAminoMsg(object) {
        return Struct.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Struct.decode(message.value);
    },
    toProto(message) {
        return Struct.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.Struct",
            value: Struct.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Value.registerTypeUrl();
    }
};
function createBaseValue() {
    return {
        nullValue: undefined,
        numberValue: undefined,
        stringValue: undefined,
        boolValue: undefined,
        structValue: undefined,
        listValue: undefined
    };
}
export const Value = {
    typeUrl: "/google.protobuf.Value",
    is(o) {
        return o && o.$typeUrl === Value.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === Value.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === Value.typeUrl;
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.nullValue !== undefined) {
            writer.uint32(8).int32(message.nullValue);
        }
        if (message.numberValue !== undefined) {
            writer.uint32(17).double(message.numberValue);
        }
        if (message.stringValue !== undefined) {
            writer.uint32(26).string(message.stringValue);
        }
        if (message.boolValue !== undefined) {
            writer.uint32(32).bool(message.boolValue);
        }
        if (message.structValue !== undefined) {
            Struct.encode(message.structValue, writer.uint32(42).fork()).ldelim();
        }
        if (message.listValue !== undefined) {
            ListValue.encode(message.listValue, writer.uint32(50).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseValue();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.nullValue = reader.int32();
                    break;
                case 2:
                    message.numberValue = reader.double();
                    break;
                case 3:
                    message.stringValue = reader.string();
                    break;
                case 4:
                    message.boolValue = reader.bool();
                    break;
                case 5:
                    message.structValue = Struct.decode(reader, reader.uint32());
                    break;
                case 6:
                    message.listValue = ListValue.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseValue();
        if (isSet(object.nullValue))
            obj.nullValue = nullValueFromJSON(object.nullValue);
        if (isSet(object.numberValue))
            obj.numberValue = Number(object.numberValue);
        if (isSet(object.stringValue))
            obj.stringValue = String(object.stringValue);
        if (isSet(object.boolValue))
            obj.boolValue = Boolean(object.boolValue);
        if (isSet(object.structValue))
            obj.structValue = Struct.fromJSON(object.structValue);
        if (isSet(object.listValue))
            obj.listValue = ListValue.fromJSON(object.listValue);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.nullValue !== undefined && (obj.nullValue = nullValueToJSON(message.nullValue));
        message.numberValue !== undefined && (obj.numberValue = message.numberValue);
        message.stringValue !== undefined && (obj.stringValue = message.stringValue);
        message.boolValue !== undefined && (obj.boolValue = message.boolValue);
        message.structValue !== undefined && (obj.structValue = message.structValue ? Struct.toJSON(message.structValue) : undefined);
        message.listValue !== undefined && (obj.listValue = message.listValue ? ListValue.toJSON(message.listValue) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseValue();
        message.nullValue = object.nullValue ?? undefined;
        message.numberValue = object.numberValue ?? undefined;
        message.stringValue = object.stringValue ?? undefined;
        message.boolValue = object.boolValue ?? undefined;
        if (object.structValue !== undefined && object.structValue !== null) {
            message.structValue = Struct.fromPartial(object.structValue);
        }
        if (object.listValue !== undefined && object.listValue !== null) {
            message.listValue = ListValue.fromPartial(object.listValue);
        }
        return message;
    },
    fromSDK(object) {
        return {
            nullValue: isSet(object.null_value) ? nullValueFromJSON(object.null_value) : undefined,
            numberValue: object?.number_value,
            stringValue: object?.string_value,
            boolValue: object?.bool_value,
            structValue: object.struct_value ? Struct.fromSDK(object.struct_value) : undefined,
            listValue: object.list_value ? ListValue.fromSDK(object.list_value) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            null_value: isSet(object.null_value) ? nullValueFromJSON(object.null_value) : undefined,
            number_value: isSet(object.number_value) ? Number(object.number_value) : undefined,
            string_value: isSet(object.string_value) ? String(object.string_value) : undefined,
            bool_value: isSet(object.bool_value) ? Boolean(object.bool_value) : undefined,
            struct_value: isSet(object.struct_value) ? Struct.fromSDKJSON(object.struct_value) : undefined,
            list_value: isSet(object.list_value) ? ListValue.fromSDKJSON(object.list_value) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.nullValue !== undefined && (obj.null_value = nullValueToJSON(message.nullValue));
        obj.number_value = message.numberValue;
        obj.string_value = message.stringValue;
        obj.bool_value = message.boolValue;
        message.structValue !== undefined && (obj.struct_value = message.structValue ? Struct.toSDK(message.structValue) : undefined);
        message.listValue !== undefined && (obj.list_value = message.listValue ? ListValue.toSDK(message.listValue) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseValue();
        if (object.null_value !== undefined && object.null_value !== null) {
            message.nullValue = object.null_value;
        }
        if (object.number_value !== undefined && object.number_value !== null) {
            message.numberValue = object.number_value;
        }
        if (object.string_value !== undefined && object.string_value !== null) {
            message.stringValue = object.string_value;
        }
        if (object.bool_value !== undefined && object.bool_value !== null) {
            message.boolValue = object.bool_value;
        }
        if (object.struct_value !== undefined && object.struct_value !== null) {
            message.structValue = Struct.fromAmino(object.struct_value);
        }
        if (object.list_value !== undefined && object.list_value !== null) {
            message.listValue = ListValue.fromAmino(object.list_value);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.null_value = message.nullValue === null ? undefined : message.nullValue;
        obj.number_value = message.numberValue === null ? undefined : message.numberValue;
        obj.string_value = message.stringValue === null ? undefined : message.stringValue;
        obj.bool_value = message.boolValue === null ? undefined : message.boolValue;
        obj.struct_value = message.structValue ? Struct.toAmino(message.structValue) : undefined;
        obj.list_value = message.listValue ? ListValue.toAmino(message.listValue) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return Value.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Value.decode(message.value);
    },
    toProto(message) {
        return Value.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.Value",
            value: Value.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Struct.registerTypeUrl();
        ListValue.registerTypeUrl();
    }
};
function createBaseListValue() {
    return {
        values: []
    };
}
export const ListValue = {
    typeUrl: "/google.protobuf.ListValue",
    is(o) {
        return o && (o.$typeUrl === ListValue.typeUrl || Array.isArray(o.values) && (!o.values.length || Value.is(o.values[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ListValue.typeUrl || Array.isArray(o.values) && (!o.values.length || Value.isSDK(o.values[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ListValue.typeUrl || Array.isArray(o.values) && (!o.values.length || Value.isAmino(o.values[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.values) {
            Value.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseListValue();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.values.push(Value.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseListValue();
        if (Array.isArray(object?.values))
            obj.values = object.values.map((e) => Value.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.values) {
            obj.values = message.values.map(e => e ? Value.toJSON(e) : undefined);
        }
        else {
            obj.values = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseListValue();
        message.values = object.values?.map(e => Value.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            values: Array.isArray(object?.values) ? object.values.map((e) => Value.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            values: Array.isArray(object?.values) ? object.values.map((e) => Value.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.values) {
            obj.values = message.values.map(e => e ? Value.toSDK(e) : undefined);
        }
        else {
            obj.values = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseListValue();
        message.values = object.values?.map(e => Value.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.values) {
            obj.values = message.values.map(e => e ? Value.toAmino(e) : undefined);
        }
        else {
            obj.values = message.values;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ListValue.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ListValue.decode(message.value);
    },
    toProto(message) {
        return ListValue.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.protobuf.ListValue",
            value: ListValue.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Value.registerTypeUrl();
    }
};
