import { PageRequest } from "../../../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../../helpers";
import { QueryClientStateResponse, QueryClientStatesResponse, QueryConsensusStateResponse, QueryConsensusStatesResponse, QueryClientStatusResponse, QueryClientParamsResponse, QueryUpgradedClientStateResponse, QueryUpgradedConsensusStateResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* ClientState queries an IBC light client. */
    clientState = async (params) => {
        const endpoint = `ibc/core/client/v1/client_states/${params.clientId}`;
        return QueryClientStateResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ClientStates queries all the IBC light clients of a chain. */
    clientStates = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `ibc/core/client/v1/client_states`;
        return QueryClientStatesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ConsensusState queries a consensus state associated with a client state at
     a given height. */
    consensusState = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.latestHeight !== "undefined") {
            options.params.latest_height = params.latestHeight;
        }
        const endpoint = `ibc/core/client/v1/consensus_states/${params.clientId}/revision/${params.revisionNumber}/height/${params.revisionHeight}`;
        return QueryConsensusStateResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ConsensusStates queries all the consensus state associated with a given
     client. */
    consensusStates = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `ibc/core/client/v1/consensus_states/${params.clientId}`;
        return QueryConsensusStatesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Status queries the status of an IBC client. */
    clientStatus = async (params) => {
        const endpoint = `ibc/core/client/v1/client_status/${params.clientId}`;
        return QueryClientStatusResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* ClientParams queries all parameters of the ibc client. */
    clientParams = async (_params = {}) => {
        const endpoint = `ibc/client/v1/params`;
        return QueryClientParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* UpgradedClientState queries an Upgraded IBC light client. */
    upgradedClientState = async (_params = {}) => {
        const endpoint = `ibc/core/client/v1/upgraded_client_states`;
        return QueryUpgradedClientStateResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* UpgradedConsensusState queries an Upgraded IBC consensus state. */
    upgradedConsensusState = async (_params = {}) => {
        const endpoint = `ibc/core/client/v1/upgraded_consensus_states`;
        return QueryUpgradedConsensusStateResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
