import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QuerySpotPriceRequest, QuerySpotPriceResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* SpotPrice defines a gRPC query handler that returns the spot price given
     a base denomination and a quote denomination. */
    spotPrice = async (request) => {
        const data = QuerySpotPriceRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v2.Query", "SpotPrice", data);
        return promise.then(data => QuerySpotPriceResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useSpotPrice = ({ request, options }) => {
        return useQuery(["spotPriceQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.spotPrice(request);
        }, options);
    };
    return {
        /**
         * SpotPrice defines a gRPC query handler that returns the spot price given
         * a base denomination and a quote denomination.
         */
        useSpotPrice
    };
};
