import { PeriodLock, SyntheticLock } from "./lock";
import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet } from "../../helpers";
export const protobufPackage = "osmosis.lockup";
function createBaseGenesisState() {
    return {
        lastLockId: BigInt(0),
        locks: [],
        syntheticLocks: []
    };
}
export const GenesisState = {
    typeUrl: "/osmosis.lockup.GenesisState",
    aminoType: "osmosis/lockup/genesis-state",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || typeof o.lastLockId === "bigint" && Array.isArray(o.locks) && (!o.locks.length || PeriodLock.is(o.locks[0])) && Array.isArray(o.syntheticLocks) && (!o.syntheticLocks.length || SyntheticLock.is(o.syntheticLocks[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || typeof o.last_lock_id === "bigint" && Array.isArray(o.locks) && (!o.locks.length || PeriodLock.isSDK(o.locks[0])) && Array.isArray(o.synthetic_locks) && (!o.synthetic_locks.length || SyntheticLock.isSDK(o.synthetic_locks[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || typeof o.last_lock_id === "bigint" && Array.isArray(o.locks) && (!o.locks.length || PeriodLock.isAmino(o.locks[0])) && Array.isArray(o.synthetic_locks) && (!o.synthetic_locks.length || SyntheticLock.isAmino(o.synthetic_locks[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.lastLockId !== undefined) {
            writer.uint32(8).uint64(message.lastLockId);
        }
        for (const v of message.locks) {
            PeriodLock.encode(v, writer.uint32(18).fork()).ldelim();
        }
        for (const v of message.syntheticLocks) {
            SyntheticLock.encode(v, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.lastLockId = reader.uint64();
                    break;
                case 2:
                    message.locks.push(PeriodLock.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.syntheticLocks.push(SyntheticLock.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (isSet(object.lastLockId))
            obj.lastLockId = BigInt(object.lastLockId.toString());
        if (Array.isArray(object?.locks))
            obj.locks = object.locks.map((e) => PeriodLock.fromJSON(e));
        if (Array.isArray(object?.syntheticLocks))
            obj.syntheticLocks = object.syntheticLocks.map((e) => SyntheticLock.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.lastLockId !== undefined && (obj.lastLockId = (message.lastLockId || BigInt(0)).toString());
        if (message.locks) {
            obj.locks = message.locks.map(e => e ? PeriodLock.toJSON(e) : undefined);
        }
        else {
            obj.locks = [];
        }
        if (message.syntheticLocks) {
            obj.syntheticLocks = message.syntheticLocks.map(e => e ? SyntheticLock.toJSON(e) : undefined);
        }
        else {
            obj.syntheticLocks = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        if (object.lastLockId !== undefined && object.lastLockId !== null) {
            message.lastLockId = BigInt(object.lastLockId.toString());
        }
        message.locks = object.locks?.map(e => PeriodLock.fromPartial(e)) || [];
        message.syntheticLocks = object.syntheticLocks?.map(e => SyntheticLock.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            lastLockId: object?.last_lock_id,
            locks: Array.isArray(object?.locks) ? object.locks.map((e) => PeriodLock.fromSDK(e)) : [],
            syntheticLocks: Array.isArray(object?.synthetic_locks) ? object.synthetic_locks.map((e) => SyntheticLock.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            last_lock_id: isSet(object.last_lock_id) ? BigInt(object.last_lock_id.toString()) : BigInt(0),
            locks: Array.isArray(object?.locks) ? object.locks.map((e) => PeriodLock.fromSDKJSON(e)) : [],
            synthetic_locks: Array.isArray(object?.synthetic_locks) ? object.synthetic_locks.map((e) => SyntheticLock.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.last_lock_id = message.lastLockId;
        if (message.locks) {
            obj.locks = message.locks.map(e => e ? PeriodLock.toSDK(e) : undefined);
        }
        else {
            obj.locks = [];
        }
        if (message.syntheticLocks) {
            obj.synthetic_locks = message.syntheticLocks.map(e => e ? SyntheticLock.toSDK(e) : undefined);
        }
        else {
            obj.synthetic_locks = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        if (object.last_lock_id !== undefined && object.last_lock_id !== null) {
            message.lastLockId = BigInt(object.last_lock_id);
        }
        message.locks = object.locks?.map(e => PeriodLock.fromAmino(e)) || [];
        message.syntheticLocks = object.synthetic_locks?.map(e => SyntheticLock.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.last_lock_id = message.lastLockId !== BigInt(0) ? message.lastLockId?.toString() : undefined;
        if (message.locks) {
            obj.locks = message.locks.map(e => e ? PeriodLock.toAmino(e) : undefined);
        }
        else {
            obj.locks = message.locks;
        }
        if (message.syntheticLocks) {
            obj.synthetic_locks = message.syntheticLocks.map(e => e ? SyntheticLock.toAmino(e) : undefined);
        }
        else {
            obj.synthetic_locks = message.syntheticLocks;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/lockup/genesis-state",
            value: GenesisState.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.lockup.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        PeriodLock.registerTypeUrl();
        SyntheticLock.registerTypeUrl();
    }
};
