import { PageRequest } from "../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../binary";
import { QueryParamsRequest, QueryParamsResponse, AssetTypeRequest, AssetTypeResponse, AllAssetsRequest, AllAssetsResponse, AssetMultiplierRequest, AssetMultiplierResponse, AllIntermediaryAccountsRequest, AllIntermediaryAccountsResponse, ConnectedIntermediaryAccountRequest, ConnectedIntermediaryAccountResponse, QueryTotalDelegationByValidatorForDenomRequest, QueryTotalDelegationByValidatorForDenomResponse, TotalSuperfluidDelegationsRequest, TotalSuperfluidDelegationsResponse, SuperfluidDelegationAmountRequest, SuperfluidDelegationAmountResponse, SuperfluidDelegationsByDelegatorRequest, SuperfluidDelegationsByDelegatorResponse, SuperfluidUndelegationsByDelegatorRequest, SuperfluidUndelegationsByDelegatorResponse, SuperfluidDelegationsByValidatorDenomRequest, SuperfluidDelegationsByValidatorDenomResponse, EstimateSuperfluidDelegatedAmountByValidatorDenomRequest, EstimateSuperfluidDelegatedAmountByValidatorDenomResponse, QueryTotalDelegationByDelegatorRequest, QueryTotalDelegationByDelegatorResponse, QueryUnpoolWhitelistRequest, QueryUnpoolWhitelistResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Params returns the total set of superfluid parameters. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* Returns superfluid asset type, whether if it's a native asset or an lp
     share. */
    assetType = async (request) => {
        const data = AssetTypeRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "AssetType", data);
        return promise.then(data => AssetTypeResponse.decode(new BinaryReader(data)));
    };
    /* Returns all registered superfluid assets. */
    allAssets = async (request = {}) => {
        const data = AllAssetsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "AllAssets", data);
        return promise.then(data => AllAssetsResponse.decode(new BinaryReader(data)));
    };
    /* Returns the osmo equivalent multiplier used in the most recent epoch. */
    assetMultiplier = async (request) => {
        const data = AssetMultiplierRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "AssetMultiplier", data);
        return promise.then(data => AssetMultiplierResponse.decode(new BinaryReader(data)));
    };
    /* Returns all superfluid intermediary accounts. */
    allIntermediaryAccounts = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = AllIntermediaryAccountsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "AllIntermediaryAccounts", data);
        return promise.then(data => AllIntermediaryAccountsResponse.decode(new BinaryReader(data)));
    };
    /* Returns intermediary account connected to a superfluid staked lock by id */
    connectedIntermediaryAccount = async (request) => {
        const data = ConnectedIntermediaryAccountRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "ConnectedIntermediaryAccount", data);
        return promise.then(data => ConnectedIntermediaryAccountResponse.decode(new BinaryReader(data)));
    };
    /* Returns the amount of delegations of specific denom for all validators */
    totalDelegationByValidatorForDenom = async (request) => {
        const data = QueryTotalDelegationByValidatorForDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "TotalDelegationByValidatorForDenom", data);
        return promise.then(data => QueryTotalDelegationByValidatorForDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns the total amount of osmo superfluidly staked.
     Response is denominated in uosmo. */
    totalSuperfluidDelegations = async (request = {}) => {
        const data = TotalSuperfluidDelegationsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "TotalSuperfluidDelegations", data);
        return promise.then(data => TotalSuperfluidDelegationsResponse.decode(new BinaryReader(data)));
    };
    /* Returns the coins superfluid delegated for the delegator, validator, denom
     triplet */
    superfluidDelegationAmount = async (request) => {
        const data = SuperfluidDelegationAmountRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "SuperfluidDelegationAmount", data);
        return promise.then(data => SuperfluidDelegationAmountResponse.decode(new BinaryReader(data)));
    };
    /* Returns all the delegated superfluid poistions for a specific delegator. */
    superfluidDelegationsByDelegator = async (request) => {
        const data = SuperfluidDelegationsByDelegatorRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "SuperfluidDelegationsByDelegator", data);
        return promise.then(data => SuperfluidDelegationsByDelegatorResponse.decode(new BinaryReader(data)));
    };
    /* Returns all the undelegating superfluid poistions for a specific delegator. */
    superfluidUndelegationsByDelegator = async (request) => {
        const data = SuperfluidUndelegationsByDelegatorRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "SuperfluidUndelegationsByDelegator", data);
        return promise.then(data => SuperfluidUndelegationsByDelegatorResponse.decode(new BinaryReader(data)));
    };
    /* Returns all the superfluid positions of a specific denom delegated to one
     validator */
    superfluidDelegationsByValidatorDenom = async (request) => {
        const data = SuperfluidDelegationsByValidatorDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "SuperfluidDelegationsByValidatorDenom", data);
        return promise.then(data => SuperfluidDelegationsByValidatorDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns the amount of a specific denom delegated to a specific validator
     This is labeled an estimate, because the way it calculates the amount can
     lead rounding errors from the true delegated amount */
    estimateSuperfluidDelegatedAmountByValidatorDenom = async (request) => {
        const data = EstimateSuperfluidDelegatedAmountByValidatorDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "EstimateSuperfluidDelegatedAmountByValidatorDenom", data);
        return promise.then(data => EstimateSuperfluidDelegatedAmountByValidatorDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns the specified delegations for a specific delegator */
    totalDelegationByDelegator = async (request) => {
        const data = QueryTotalDelegationByDelegatorRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "TotalDelegationByDelegator", data);
        return promise.then(data => QueryTotalDelegationByDelegatorResponse.decode(new BinaryReader(data)));
    };
    /* Returns a list of whitelisted pool ids to unpool. */
    unpoolWhitelist = async (request = {}) => {
        const data = QueryUnpoolWhitelistRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.superfluid.Query", "UnpoolWhitelist", data);
        return promise.then(data => QueryUnpoolWhitelistResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
