import { QueryFeeTokensResponse, QueryDenomSpotPriceResponse, QueryDenomPoolIdResponse, QueryBaseDenomResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* FeeTokens returns a list of all the whitelisted fee tokens and their
     corresponding pools. It does not include the BaseDenom, which has its own
     query endpoint */
    feeTokens = async (_params = {}) => {
        const endpoint = `osmosis/txfees/v1beta1/fee_tokens`;
        return QueryFeeTokensResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DenomSpotPrice returns all spot prices by each registered token denom. */
    denomSpotPrice = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/txfees/v1beta1/spot_price_by_denom`;
        return QueryDenomSpotPriceResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns the poolID for a specified denom input. */
    denomPoolId = async (params) => {
        const endpoint = `osmosis/txfees/v1beta1/denom_pool_id/${params.denom}`;
        return QueryDenomPoolIdResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns a list of all base denom tokens and their corresponding pools. */
    baseDenom = async (_params = {}) => {
        const endpoint = `osmosis/txfees/v1beta1/base_denom`;
        return QueryBaseDenomResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
