import { BinaryReader } from "../../../binary";
import { QueryFeeTokensRequest, QueryFeeTokensResponse, QueryDenomSpotPriceRequest, QueryDenomSpotPriceResponse, QueryDenomPoolIdRequest, QueryDenomPoolIdResponse, QueryBaseDenomRequest, QueryBaseDenomResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* FeeTokens returns a list of all the whitelisted fee tokens and their
     corresponding pools. It does not include the BaseDenom, which has its own
     query endpoint */
    feeTokens = async (request = {}) => {
        const data = QueryFeeTokensRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.txfees.v1beta1.Query", "FeeTokens", data);
        return promise.then(data => QueryFeeTokensResponse.decode(new BinaryReader(data)));
    };
    /* DenomSpotPrice returns all spot prices by each registered token denom. */
    denomSpotPrice = async (request) => {
        const data = QueryDenomSpotPriceRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.txfees.v1beta1.Query", "DenomSpotPrice", data);
        return promise.then(data => QueryDenomSpotPriceResponse.decode(new BinaryReader(data)));
    };
    /* Returns the poolID for a specified denom input. */
    denomPoolId = async (request) => {
        const data = QueryDenomPoolIdRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.txfees.v1beta1.Query", "DenomPoolId", data);
        return promise.then(data => QueryDenomPoolIdResponse.decode(new BinaryReader(data)));
    };
    /* Returns a list of all base denom tokens and their corresponding pools. */
    baseDenom = async (request = {}) => {
        const data = QueryBaseDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.txfees.v1beta1.Query", "BaseDenom", data);
        return promise.then(data => QueryBaseDenomResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
