import { Timestamp } from "../../google/protobuf/timestamp";
import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet, bytesFromBase64, base64FromBytes, toTimestamp, fromTimestamp } from "../../helpers";
export const protobufPackage = "tendermint.p2p";
function createBaseProtocolVersion() {
    return {
        p2p: BigInt(0),
        block: BigInt(0),
        app: BigInt(0)
    };
}
export const ProtocolVersion = {
    typeUrl: "/tendermint.p2p.ProtocolVersion",
    is(o) {
        return o && (o.$typeUrl === ProtocolVersion.typeUrl || typeof o.p2p === "bigint" && typeof o.block === "bigint" && typeof o.app === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ProtocolVersion.typeUrl || typeof o.p2p === "bigint" && typeof o.block === "bigint" && typeof o.app === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ProtocolVersion.typeUrl || typeof o.p2p === "bigint" && typeof o.block === "bigint" && typeof o.app === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.p2p !== undefined) {
            writer.uint32(8).uint64(message.p2p);
        }
        if (message.block !== undefined) {
            writer.uint32(16).uint64(message.block);
        }
        if (message.app !== undefined) {
            writer.uint32(24).uint64(message.app);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseProtocolVersion();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.p2p = reader.uint64();
                    break;
                case 2:
                    message.block = reader.uint64();
                    break;
                case 3:
                    message.app = reader.uint64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseProtocolVersion();
        if (isSet(object.p2p))
            obj.p2p = BigInt(object.p2p.toString());
        if (isSet(object.block))
            obj.block = BigInt(object.block.toString());
        if (isSet(object.app))
            obj.app = BigInt(object.app.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.p2p !== undefined && (obj.p2p = (message.p2p || BigInt(0)).toString());
        message.block !== undefined && (obj.block = (message.block || BigInt(0)).toString());
        message.app !== undefined && (obj.app = (message.app || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseProtocolVersion();
        if (object.p2p !== undefined && object.p2p !== null) {
            message.p2p = BigInt(object.p2p.toString());
        }
        if (object.block !== undefined && object.block !== null) {
            message.block = BigInt(object.block.toString());
        }
        if (object.app !== undefined && object.app !== null) {
            message.app = BigInt(object.app.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            p2p: object?.p2p,
            block: object?.block,
            app: object?.app
        };
    },
    fromSDKJSON(object) {
        return {
            p2p: isSet(object.p2p) ? BigInt(object.p2p.toString()) : BigInt(0),
            block: isSet(object.block) ? BigInt(object.block.toString()) : BigInt(0),
            app: isSet(object.app) ? BigInt(object.app.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        obj.p2p = message.p2p;
        obj.block = message.block;
        obj.app = message.app;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseProtocolVersion();
        if (object.p2p !== undefined && object.p2p !== null) {
            message.p2p = BigInt(object.p2p);
        }
        if (object.block !== undefined && object.block !== null) {
            message.block = BigInt(object.block);
        }
        if (object.app !== undefined && object.app !== null) {
            message.app = BigInt(object.app);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.p2p = message.p2p !== BigInt(0) ? message.p2p?.toString() : undefined;
        obj.block = message.block !== BigInt(0) ? message.block?.toString() : undefined;
        obj.app = message.app !== BigInt(0) ? message.app?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return ProtocolVersion.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ProtocolVersion.decode(message.value);
    },
    toProto(message) {
        return ProtocolVersion.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/tendermint.p2p.ProtocolVersion",
            value: ProtocolVersion.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseNodeInfo() {
    return {
        protocolVersion: ProtocolVersion.fromPartial({}),
        nodeId: "",
        listenAddr: "",
        network: "",
        version: "",
        channels: new Uint8Array(),
        moniker: "",
        other: NodeInfoOther.fromPartial({})
    };
}
export const NodeInfo = {
    typeUrl: "/tendermint.p2p.NodeInfo",
    is(o) {
        return o && (o.$typeUrl === NodeInfo.typeUrl || ProtocolVersion.is(o.protocolVersion) && typeof o.nodeId === "string" && typeof o.listenAddr === "string" && typeof o.network === "string" && typeof o.version === "string" && (o.channels instanceof Uint8Array || typeof o.channels === "string") && typeof o.moniker === "string" && NodeInfoOther.is(o.other));
    },
    isSDK(o) {
        return o && (o.$typeUrl === NodeInfo.typeUrl || ProtocolVersion.isSDK(o.protocol_version) && typeof o.node_id === "string" && typeof o.listen_addr === "string" && typeof o.network === "string" && typeof o.version === "string" && (o.channels instanceof Uint8Array || typeof o.channels === "string") && typeof o.moniker === "string" && NodeInfoOther.isSDK(o.other));
    },
    isAmino(o) {
        return o && (o.$typeUrl === NodeInfo.typeUrl || ProtocolVersion.isAmino(o.protocol_version) && typeof o.node_id === "string" && typeof o.listen_addr === "string" && typeof o.network === "string" && typeof o.version === "string" && (o.channels instanceof Uint8Array || typeof o.channels === "string") && typeof o.moniker === "string" && NodeInfoOther.isAmino(o.other));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.protocolVersion !== undefined) {
            ProtocolVersion.encode(message.protocolVersion, writer.uint32(10).fork()).ldelim();
        }
        if (message.nodeId !== undefined) {
            writer.uint32(18).string(message.nodeId);
        }
        if (message.listenAddr !== undefined) {
            writer.uint32(26).string(message.listenAddr);
        }
        if (message.network !== undefined) {
            writer.uint32(34).string(message.network);
        }
        if (message.version !== undefined) {
            writer.uint32(42).string(message.version);
        }
        if (message.channels.length !== 0) {
            writer.uint32(50).bytes(message.channels);
        }
        if (message.moniker !== undefined) {
            writer.uint32(58).string(message.moniker);
        }
        if (message.other !== undefined) {
            NodeInfoOther.encode(message.other, writer.uint32(66).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseNodeInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.protocolVersion = ProtocolVersion.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.nodeId = reader.string();
                    break;
                case 3:
                    message.listenAddr = reader.string();
                    break;
                case 4:
                    message.network = reader.string();
                    break;
                case 5:
                    message.version = reader.string();
                    break;
                case 6:
                    message.channels = reader.bytes();
                    break;
                case 7:
                    message.moniker = reader.string();
                    break;
                case 8:
                    message.other = NodeInfoOther.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseNodeInfo();
        if (isSet(object.protocolVersion))
            obj.protocolVersion = ProtocolVersion.fromJSON(object.protocolVersion);
        if (isSet(object.nodeId))
            obj.nodeId = String(object.nodeId);
        if (isSet(object.listenAddr))
            obj.listenAddr = String(object.listenAddr);
        if (isSet(object.network))
            obj.network = String(object.network);
        if (isSet(object.version))
            obj.version = String(object.version);
        if (isSet(object.channels))
            obj.channels = bytesFromBase64(object.channels);
        if (isSet(object.moniker))
            obj.moniker = String(object.moniker);
        if (isSet(object.other))
            obj.other = NodeInfoOther.fromJSON(object.other);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.protocolVersion !== undefined && (obj.protocolVersion = message.protocolVersion ? ProtocolVersion.toJSON(message.protocolVersion) : undefined);
        message.nodeId !== undefined && (obj.nodeId = message.nodeId);
        message.listenAddr !== undefined && (obj.listenAddr = message.listenAddr);
        message.network !== undefined && (obj.network = message.network);
        message.version !== undefined && (obj.version = message.version);
        message.channels !== undefined && (obj.channels = base64FromBytes(message.channels !== undefined ? message.channels : new Uint8Array()));
        message.moniker !== undefined && (obj.moniker = message.moniker);
        message.other !== undefined && (obj.other = message.other ? NodeInfoOther.toJSON(message.other) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseNodeInfo();
        if (object.protocolVersion !== undefined && object.protocolVersion !== null) {
            message.protocolVersion = ProtocolVersion.fromPartial(object.protocolVersion);
        }
        message.nodeId = object.nodeId ?? "";
        message.listenAddr = object.listenAddr ?? "";
        message.network = object.network ?? "";
        message.version = object.version ?? "";
        message.channels = object.channels ?? new Uint8Array();
        message.moniker = object.moniker ?? "";
        if (object.other !== undefined && object.other !== null) {
            message.other = NodeInfoOther.fromPartial(object.other);
        }
        return message;
    },
    fromSDK(object) {
        return {
            protocolVersion: object.protocol_version ? ProtocolVersion.fromSDK(object.protocol_version) : undefined,
            nodeId: object?.node_id,
            listenAddr: object?.listen_addr,
            network: object?.network,
            version: object?.version,
            channels: object?.channels,
            moniker: object?.moniker,
            other: object.other ? NodeInfoOther.fromSDK(object.other) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            protocol_version: isSet(object.protocol_version) ? ProtocolVersion.fromSDKJSON(object.protocol_version) : undefined,
            node_id: isSet(object.node_id) ? String(object.node_id) : "",
            listen_addr: isSet(object.listen_addr) ? String(object.listen_addr) : "",
            network: isSet(object.network) ? String(object.network) : "",
            version: isSet(object.version) ? String(object.version) : "",
            channels: isSet(object.channels) ? bytesFromBase64(object.channels) : new Uint8Array(),
            moniker: isSet(object.moniker) ? String(object.moniker) : "",
            other: isSet(object.other) ? NodeInfoOther.fromSDKJSON(object.other) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.protocolVersion !== undefined && (obj.protocol_version = message.protocolVersion ? ProtocolVersion.toSDK(message.protocolVersion) : undefined);
        obj.node_id = message.nodeId;
        obj.listen_addr = message.listenAddr;
        obj.network = message.network;
        obj.version = message.version;
        obj.channels = message.channels;
        obj.moniker = message.moniker;
        message.other !== undefined && (obj.other = message.other ? NodeInfoOther.toSDK(message.other) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseNodeInfo();
        if (object.protocol_version !== undefined && object.protocol_version !== null) {
            message.protocolVersion = ProtocolVersion.fromAmino(object.protocol_version);
        }
        if (object.node_id !== undefined && object.node_id !== null) {
            message.nodeId = object.node_id;
        }
        if (object.listen_addr !== undefined && object.listen_addr !== null) {
            message.listenAddr = object.listen_addr;
        }
        if (object.network !== undefined && object.network !== null) {
            message.network = object.network;
        }
        if (object.version !== undefined && object.version !== null) {
            message.version = object.version;
        }
        if (object.channels !== undefined && object.channels !== null) {
            message.channels = bytesFromBase64(object.channels);
        }
        if (object.moniker !== undefined && object.moniker !== null) {
            message.moniker = object.moniker;
        }
        if (object.other !== undefined && object.other !== null) {
            message.other = NodeInfoOther.fromAmino(object.other);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.protocol_version = message.protocolVersion ? ProtocolVersion.toAmino(message.protocolVersion) : undefined;
        obj.node_id = message.nodeId === "" ? undefined : message.nodeId;
        obj.listen_addr = message.listenAddr === "" ? undefined : message.listenAddr;
        obj.network = message.network === "" ? undefined : message.network;
        obj.version = message.version === "" ? undefined : message.version;
        obj.channels = message.channels ? base64FromBytes(message.channels) : undefined;
        obj.moniker = message.moniker === "" ? undefined : message.moniker;
        obj.other = message.other ? NodeInfoOther.toAmino(message.other) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return NodeInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return NodeInfo.decode(message.value);
    },
    toProto(message) {
        return NodeInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/tendermint.p2p.NodeInfo",
            value: NodeInfo.encode(message).finish()
        };
    },
    registerTypeUrl() {
        ProtocolVersion.registerTypeUrl();
        NodeInfoOther.registerTypeUrl();
    }
};
function createBaseNodeInfoOther() {
    return {
        txIndex: "",
        rpcAddress: ""
    };
}
export const NodeInfoOther = {
    typeUrl: "/tendermint.p2p.NodeInfoOther",
    is(o) {
        return o && (o.$typeUrl === NodeInfoOther.typeUrl || typeof o.txIndex === "string" && typeof o.rpcAddress === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === NodeInfoOther.typeUrl || typeof o.tx_index === "string" && typeof o.rpc_address === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === NodeInfoOther.typeUrl || typeof o.tx_index === "string" && typeof o.rpc_address === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.txIndex !== undefined) {
            writer.uint32(10).string(message.txIndex);
        }
        if (message.rpcAddress !== undefined) {
            writer.uint32(18).string(message.rpcAddress);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseNodeInfoOther();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.txIndex = reader.string();
                    break;
                case 2:
                    message.rpcAddress = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseNodeInfoOther();
        if (isSet(object.txIndex))
            obj.txIndex = String(object.txIndex);
        if (isSet(object.rpcAddress))
            obj.rpcAddress = String(object.rpcAddress);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.txIndex !== undefined && (obj.txIndex = message.txIndex);
        message.rpcAddress !== undefined && (obj.rpcAddress = message.rpcAddress);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseNodeInfoOther();
        message.txIndex = object.txIndex ?? "";
        message.rpcAddress = object.rpcAddress ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            txIndex: object?.tx_index,
            rpcAddress: object?.rpc_address
        };
    },
    fromSDKJSON(object) {
        return {
            tx_index: isSet(object.tx_index) ? String(object.tx_index) : "",
            rpc_address: isSet(object.rpc_address) ? String(object.rpc_address) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.tx_index = message.txIndex;
        obj.rpc_address = message.rpcAddress;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseNodeInfoOther();
        if (object.tx_index !== undefined && object.tx_index !== null) {
            message.txIndex = object.tx_index;
        }
        if (object.rpc_address !== undefined && object.rpc_address !== null) {
            message.rpcAddress = object.rpc_address;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.tx_index = message.txIndex === "" ? undefined : message.txIndex;
        obj.rpc_address = message.rpcAddress === "" ? undefined : message.rpcAddress;
        return obj;
    },
    fromAminoMsg(object) {
        return NodeInfoOther.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return NodeInfoOther.decode(message.value);
    },
    toProto(message) {
        return NodeInfoOther.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/tendermint.p2p.NodeInfoOther",
            value: NodeInfoOther.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBasePeerInfo() {
    return {
        id: "",
        addressInfo: [],
        lastConnected: undefined
    };
}
export const PeerInfo = {
    typeUrl: "/tendermint.p2p.PeerInfo",
    is(o) {
        return o && (o.$typeUrl === PeerInfo.typeUrl || typeof o.id === "string" && Array.isArray(o.addressInfo) && (!o.addressInfo.length || PeerAddressInfo.is(o.addressInfo[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === PeerInfo.typeUrl || typeof o.id === "string" && Array.isArray(o.address_info) && (!o.address_info.length || PeerAddressInfo.isSDK(o.address_info[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === PeerInfo.typeUrl || typeof o.id === "string" && Array.isArray(o.address_info) && (!o.address_info.length || PeerAddressInfo.isAmino(o.address_info[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.id !== undefined) {
            writer.uint32(10).string(message.id);
        }
        for (const v of message.addressInfo) {
            PeerAddressInfo.encode(v, writer.uint32(18).fork()).ldelim();
        }
        if (message.lastConnected !== undefined) {
            Timestamp.encode(toTimestamp(message.lastConnected), writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBasePeerInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.id = reader.string();
                    break;
                case 2:
                    message.addressInfo.push(PeerAddressInfo.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.lastConnected = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBasePeerInfo();
        if (isSet(object.id))
            obj.id = String(object.id);
        if (Array.isArray(object?.addressInfo))
            obj.addressInfo = object.addressInfo.map((e) => PeerAddressInfo.fromJSON(e));
        if (isSet(object.lastConnected))
            obj.lastConnected = new Date(object.lastConnected);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.id !== undefined && (obj.id = message.id);
        if (message.addressInfo) {
            obj.addressInfo = message.addressInfo.map(e => e ? PeerAddressInfo.toJSON(e) : undefined);
        }
        else {
            obj.addressInfo = [];
        }
        message.lastConnected !== undefined && (obj.lastConnected = message.lastConnected.toISOString());
        return obj;
    },
    fromPartial(object) {
        const message = createBasePeerInfo();
        message.id = object.id ?? "";
        message.addressInfo = object.addressInfo?.map(e => PeerAddressInfo.fromPartial(e)) || [];
        message.lastConnected = object.lastConnected ?? undefined;
        return message;
    },
    fromSDK(object) {
        return {
            id: object?.id,
            addressInfo: Array.isArray(object?.address_info) ? object.address_info.map((e) => PeerAddressInfo.fromSDK(e)) : [],
            lastConnected: object.last_connected ?? undefined
        };
    },
    fromSDKJSON(object) {
        return {
            id: isSet(object.id) ? String(object.id) : "",
            address_info: Array.isArray(object?.address_info) ? object.address_info.map((e) => PeerAddressInfo.fromSDKJSON(e)) : [],
            last_connected: isSet(object.last_connected) ? new Date(object.last_connected) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        obj.id = message.id;
        if (message.addressInfo) {
            obj.address_info = message.addressInfo.map(e => e ? PeerAddressInfo.toSDK(e) : undefined);
        }
        else {
            obj.address_info = [];
        }
        message.lastConnected !== undefined && (obj.last_connected = message.lastConnected ?? undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBasePeerInfo();
        if (object.id !== undefined && object.id !== null) {
            message.id = object.id;
        }
        message.addressInfo = object.address_info?.map(e => PeerAddressInfo.fromAmino(e)) || [];
        if (object.last_connected !== undefined && object.last_connected !== null) {
            message.lastConnected = fromTimestamp(Timestamp.fromAmino(object.last_connected));
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.id = message.id === "" ? undefined : message.id;
        if (message.addressInfo) {
            obj.address_info = message.addressInfo.map(e => e ? PeerAddressInfo.toAmino(e) : undefined);
        }
        else {
            obj.address_info = message.addressInfo;
        }
        obj.last_connected = message.lastConnected ? Timestamp.toAmino(toTimestamp(message.lastConnected)) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return PeerInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return PeerInfo.decode(message.value);
    },
    toProto(message) {
        return PeerInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/tendermint.p2p.PeerInfo",
            value: PeerInfo.encode(message).finish()
        };
    },
    registerTypeUrl() {
        PeerAddressInfo.registerTypeUrl();
    }
};
function createBasePeerAddressInfo() {
    return {
        address: "",
        lastDialSuccess: undefined,
        lastDialFailure: undefined,
        dialFailures: 0
    };
}
export const PeerAddressInfo = {
    typeUrl: "/tendermint.p2p.PeerAddressInfo",
    is(o) {
        return o && (o.$typeUrl === PeerAddressInfo.typeUrl || typeof o.address === "string" && typeof o.dialFailures === "number");
    },
    isSDK(o) {
        return o && (o.$typeUrl === PeerAddressInfo.typeUrl || typeof o.address === "string" && typeof o.dial_failures === "number");
    },
    isAmino(o) {
        return o && (o.$typeUrl === PeerAddressInfo.typeUrl || typeof o.address === "string" && typeof o.dial_failures === "number");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.address !== undefined) {
            writer.uint32(10).string(message.address);
        }
        if (message.lastDialSuccess !== undefined) {
            Timestamp.encode(toTimestamp(message.lastDialSuccess), writer.uint32(18).fork()).ldelim();
        }
        if (message.lastDialFailure !== undefined) {
            Timestamp.encode(toTimestamp(message.lastDialFailure), writer.uint32(26).fork()).ldelim();
        }
        if (message.dialFailures !== undefined) {
            writer.uint32(32).uint32(message.dialFailures);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBasePeerAddressInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.address = reader.string();
                    break;
                case 2:
                    message.lastDialSuccess = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 3:
                    message.lastDialFailure = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 4:
                    message.dialFailures = reader.uint32();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBasePeerAddressInfo();
        if (isSet(object.address))
            obj.address = String(object.address);
        if (isSet(object.lastDialSuccess))
            obj.lastDialSuccess = new Date(object.lastDialSuccess);
        if (isSet(object.lastDialFailure))
            obj.lastDialFailure = new Date(object.lastDialFailure);
        if (isSet(object.dialFailures))
            obj.dialFailures = Number(object.dialFailures);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.address !== undefined && (obj.address = message.address);
        message.lastDialSuccess !== undefined && (obj.lastDialSuccess = message.lastDialSuccess.toISOString());
        message.lastDialFailure !== undefined && (obj.lastDialFailure = message.lastDialFailure.toISOString());
        message.dialFailures !== undefined && (obj.dialFailures = Math.round(message.dialFailures));
        return obj;
    },
    fromPartial(object) {
        const message = createBasePeerAddressInfo();
        message.address = object.address ?? "";
        message.lastDialSuccess = object.lastDialSuccess ?? undefined;
        message.lastDialFailure = object.lastDialFailure ?? undefined;
        message.dialFailures = object.dialFailures ?? 0;
        return message;
    },
    fromSDK(object) {
        return {
            address: object?.address,
            lastDialSuccess: object.last_dial_success ?? undefined,
            lastDialFailure: object.last_dial_failure ?? undefined,
            dialFailures: object?.dial_failures
        };
    },
    fromSDKJSON(object) {
        return {
            address: isSet(object.address) ? String(object.address) : "",
            last_dial_success: isSet(object.last_dial_success) ? new Date(object.last_dial_success) : undefined,
            last_dial_failure: isSet(object.last_dial_failure) ? new Date(object.last_dial_failure) : undefined,
            dial_failures: isSet(object.dial_failures) ? Number(object.dial_failures) : 0
        };
    },
    toSDK(message) {
        const obj = {};
        obj.address = message.address;
        message.lastDialSuccess !== undefined && (obj.last_dial_success = message.lastDialSuccess ?? undefined);
        message.lastDialFailure !== undefined && (obj.last_dial_failure = message.lastDialFailure ?? undefined);
        obj.dial_failures = message.dialFailures;
        return obj;
    },
    fromAmino(object) {
        const message = createBasePeerAddressInfo();
        if (object.address !== undefined && object.address !== null) {
            message.address = object.address;
        }
        if (object.last_dial_success !== undefined && object.last_dial_success !== null) {
            message.lastDialSuccess = fromTimestamp(Timestamp.fromAmino(object.last_dial_success));
        }
        if (object.last_dial_failure !== undefined && object.last_dial_failure !== null) {
            message.lastDialFailure = fromTimestamp(Timestamp.fromAmino(object.last_dial_failure));
        }
        if (object.dial_failures !== undefined && object.dial_failures !== null) {
            message.dialFailures = object.dial_failures;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.address = message.address === "" ? undefined : message.address;
        obj.last_dial_success = message.lastDialSuccess ? Timestamp.toAmino(toTimestamp(message.lastDialSuccess)) : undefined;
        obj.last_dial_failure = message.lastDialFailure ? Timestamp.toAmino(toTimestamp(message.lastDialFailure)) : undefined;
        obj.dial_failures = message.dialFailures === 0 ? undefined : message.dialFailures;
        return obj;
    },
    fromAminoMsg(object) {
        return PeerAddressInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return PeerAddressInfo.decode(message.value);
    },
    toProto(message) {
        return PeerAddressInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/tendermint.p2p.PeerAddressInfo",
            value: PeerAddressInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
