import { DeepPartial } from "../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.claims.v1";
/** Action defines the list of available actions to claim the airdrop tokens. */
export declare enum Action {
    /** ACTION_UNSPECIFIED - UNSPECIFIED defines an invalid action. */
    ACTION_UNSPECIFIED = 0,
    /** ACTION_VOTE - VOTE defines a proposal vote. */
    ACTION_VOTE = 1,
    /** ACTION_DELEGATE - DELEGATE defines an staking delegation. */
    ACTION_DELEGATE = 2,
    /** ACTION_EVM - EVM defines an EVM transaction. */
    ACTION_EVM = 3,
    /** ACTION_IBC_TRANSFER - IBC Transfer defines a fungible token transfer transaction via IBC. */
    ACTION_IBC_TRANSFER = 4,
    UNRECOGNIZED = -1
}
export declare const ActionSDKType: typeof Action;
export declare const ActionAmino: typeof Action;
export declare function actionFromJSON(object: any): Action;
export declare function actionToJSON(object: Action): string;
/**
 * Claim defines the action, completed flag and the remaining claimable amount
 * for a given user. This is only used during client queries.
 */
export interface Claim {
    /** action enum */
    action: Action;
    /** true if the action has been completed */
    completed: boolean;
    /** claimable token amount for the action. Zero if completed */
    claimableAmount: string;
}
export interface ClaimProtoMsg {
    typeUrl: "/evmos.claims.v1.Claim";
    value: Uint8Array;
}
/**
 * Claim defines the action, completed flag and the remaining claimable amount
 * for a given user. This is only used during client queries.
 */
export interface ClaimAmino {
    /** action enum */
    action?: Action;
    /** true if the action has been completed */
    completed?: boolean;
    /** claimable token amount for the action. Zero if completed */
    claimable_amount?: string;
}
export interface ClaimAminoMsg {
    type: "/evmos.claims.v1.Claim";
    value: ClaimAmino;
}
/**
 * Claim defines the action, completed flag and the remaining claimable amount
 * for a given user. This is only used during client queries.
 */
export interface ClaimSDKType {
    action: Action;
    completed: boolean;
    claimable_amount: string;
}
/** ClaimsRecordAddress is the claims metadata per address that is used at Genesis. */
export interface ClaimsRecordAddress {
    /** bech32 or hex address of claim user */
    address: string;
    /** total initial claimable amount for the user */
    initialClaimableAmount: string;
    /** slice of the available actions completed */
    actionsCompleted: boolean[];
}
export interface ClaimsRecordAddressProtoMsg {
    typeUrl: "/evmos.claims.v1.ClaimsRecordAddress";
    value: Uint8Array;
}
/** ClaimsRecordAddress is the claims metadata per address that is used at Genesis. */
export interface ClaimsRecordAddressAmino {
    /** bech32 or hex address of claim user */
    address?: string;
    /** total initial claimable amount for the user */
    initial_claimable_amount?: string;
    /** slice of the available actions completed */
    actions_completed?: boolean[];
}
export interface ClaimsRecordAddressAminoMsg {
    type: "/evmos.claims.v1.ClaimsRecordAddress";
    value: ClaimsRecordAddressAmino;
}
/** ClaimsRecordAddress is the claims metadata per address that is used at Genesis. */
export interface ClaimsRecordAddressSDKType {
    address: string;
    initial_claimable_amount: string;
    actions_completed: boolean[];
}
/**
 * ClaimsRecord defines the initial claimable airdrop amount and the list of
 * completed actions to claim the tokens.
 */
export interface ClaimsRecord {
    /** total initial claimable amount for the user */
    initialClaimableAmount: string;
    /** slice of the available actions completed */
    actionsCompleted: boolean[];
}
export interface ClaimsRecordProtoMsg {
    typeUrl: "/evmos.claims.v1.ClaimsRecord";
    value: Uint8Array;
}
/**
 * ClaimsRecord defines the initial claimable airdrop amount and the list of
 * completed actions to claim the tokens.
 */
export interface ClaimsRecordAmino {
    /** total initial claimable amount for the user */
    initial_claimable_amount?: string;
    /** slice of the available actions completed */
    actions_completed?: boolean[];
}
export interface ClaimsRecordAminoMsg {
    type: "/evmos.claims.v1.ClaimsRecord";
    value: ClaimsRecordAmino;
}
/**
 * ClaimsRecord defines the initial claimable airdrop amount and the list of
 * completed actions to claim the tokens.
 */
export interface ClaimsRecordSDKType {
    initial_claimable_amount: string;
    actions_completed: boolean[];
}
export declare const Claim: {
    typeUrl: string;
    is(o: any): o is Claim;
    isSDK(o: any): o is ClaimSDKType;
    isAmino(o: any): o is ClaimAmino;
    encode(message: Claim, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Claim;
    fromJSON(object: any): Claim;
    toJSON(message: Claim): JsonSafe<Claim>;
    fromPartial(object: DeepPartial<Claim>): Claim;
    fromSDK(object: ClaimSDKType): Claim;
    fromSDKJSON(object: any): ClaimSDKType;
    toSDK(message: Claim): ClaimSDKType;
    fromAmino(object: ClaimAmino): Claim;
    toAmino(message: Claim): ClaimAmino;
    fromAminoMsg(object: ClaimAminoMsg): Claim;
    fromProtoMsg(message: ClaimProtoMsg): Claim;
    toProto(message: Claim): Uint8Array;
    toProtoMsg(message: Claim): ClaimProtoMsg;
    registerTypeUrl(): void;
};
export declare const ClaimsRecordAddress: {
    typeUrl: string;
    is(o: any): o is ClaimsRecordAddress;
    isSDK(o: any): o is ClaimsRecordAddressSDKType;
    isAmino(o: any): o is ClaimsRecordAddressAmino;
    encode(message: ClaimsRecordAddress, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ClaimsRecordAddress;
    fromJSON(object: any): ClaimsRecordAddress;
    toJSON(message: ClaimsRecordAddress): JsonSafe<ClaimsRecordAddress>;
    fromPartial(object: DeepPartial<ClaimsRecordAddress>): ClaimsRecordAddress;
    fromSDK(object: ClaimsRecordAddressSDKType): ClaimsRecordAddress;
    fromSDKJSON(object: any): ClaimsRecordAddressSDKType;
    toSDK(message: ClaimsRecordAddress): ClaimsRecordAddressSDKType;
    fromAmino(object: ClaimsRecordAddressAmino): ClaimsRecordAddress;
    toAmino(message: ClaimsRecordAddress): ClaimsRecordAddressAmino;
    fromAminoMsg(object: ClaimsRecordAddressAminoMsg): ClaimsRecordAddress;
    fromProtoMsg(message: ClaimsRecordAddressProtoMsg): ClaimsRecordAddress;
    toProto(message: ClaimsRecordAddress): Uint8Array;
    toProtoMsg(message: ClaimsRecordAddress): ClaimsRecordAddressProtoMsg;
    registerTypeUrl(): void;
};
export declare const ClaimsRecord: {
    typeUrl: string;
    is(o: any): o is ClaimsRecord;
    isSDK(o: any): o is ClaimsRecordSDKType;
    isAmino(o: any): o is ClaimsRecordAmino;
    encode(message: ClaimsRecord, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ClaimsRecord;
    fromJSON(object: any): ClaimsRecord;
    toJSON(message: ClaimsRecord): JsonSafe<ClaimsRecord>;
    fromPartial(object: DeepPartial<ClaimsRecord>): ClaimsRecord;
    fromSDK(object: ClaimsRecordSDKType): ClaimsRecord;
    fromSDKJSON(object: any): ClaimsRecordSDKType;
    toSDK(message: ClaimsRecord): ClaimsRecordSDKType;
    fromAmino(object: ClaimsRecordAmino): ClaimsRecord;
    toAmino(message: ClaimsRecord): ClaimsRecordAmino;
    fromAminoMsg(object: ClaimsRecordAminoMsg): ClaimsRecord;
    fromProtoMsg(message: ClaimsRecordProtoMsg): ClaimsRecord;
    toProto(message: ClaimsRecord): Uint8Array;
    toProtoMsg(message: ClaimsRecord): ClaimsRecordProtoMsg;
    registerTypeUrl(): void;
};
