import { ClaimsRecordAddress, ClaimsRecordAddressAmino, ClaimsRecordAddressSDKType } from "./claims";
import { Duration, DurationAmino, DurationSDKType } from "../../../google/protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.claims.v1";
/** GenesisState define the claims module's genesis state. */
export interface GenesisState {
    /** params defines all the parameters of the module. */
    params: Params;
    /** list of claim records with the corresponding airdrop recipient */
    claimsRecords: ClaimsRecordAddress[];
}
export interface GenesisStateProtoMsg {
    typeUrl: "/evmos.claims.v1.GenesisState";
    value: Uint8Array;
}
/** GenesisState define the claims module's genesis state. */
export interface GenesisStateAmino {
    /** params defines all the parameters of the module. */
    params?: ParamsAmino;
    /** list of claim records with the corresponding airdrop recipient */
    claims_records?: ClaimsRecordAddressAmino[];
}
export interface GenesisStateAminoMsg {
    type: "/evmos.claims.v1.GenesisState";
    value: GenesisStateAmino;
}
/** GenesisState define the claims module's genesis state. */
export interface GenesisStateSDKType {
    params: ParamsSDKType;
    claims_records: ClaimsRecordAddressSDKType[];
}
/** Params defines the claims module's parameters. */
export interface Params {
    /** enable claiming process */
    enableClaims: boolean;
    /** timestamp of the airdrop start */
    airdropStartTime: Date;
    /** duration until decay of claimable tokens begin */
    durationUntilDecay: Duration;
    /** duration of the token claim decay period */
    durationOfDecay: Duration;
    /** denom of claimable coin */
    claimsDenom: string;
    /**
     * list of authorized channel identifiers that can perform address
     * attestations via IBC.
     */
    authorizedChannels: string[];
    /** list of channel identifiers from EVM compatible chains */
    evmChannels: string[];
}
export interface ParamsProtoMsg {
    typeUrl: "/evmos.claims.v1.Params";
    value: Uint8Array;
}
/** Params defines the claims module's parameters. */
export interface ParamsAmino {
    /** enable claiming process */
    enable_claims?: boolean;
    /** timestamp of the airdrop start */
    airdrop_start_time?: string;
    /** duration until decay of claimable tokens begin */
    duration_until_decay?: DurationAmino;
    /** duration of the token claim decay period */
    duration_of_decay?: DurationAmino;
    /** denom of claimable coin */
    claims_denom?: string;
    /**
     * list of authorized channel identifiers that can perform address
     * attestations via IBC.
     */
    authorized_channels?: string[];
    /** list of channel identifiers from EVM compatible chains */
    evm_channels?: string[];
}
export interface ParamsAminoMsg {
    type: "/evmos.claims.v1.Params";
    value: ParamsAmino;
}
/** Params defines the claims module's parameters. */
export interface ParamsSDKType {
    enable_claims: boolean;
    airdrop_start_time: Date;
    duration_until_decay: DurationSDKType;
    duration_of_decay: DurationSDKType;
    claims_denom: string;
    authorized_channels: string[];
    evm_channels: string[];
}
export declare const GenesisState: {
    typeUrl: string;
    is(o: any): o is GenesisState;
    isSDK(o: any): o is GenesisStateSDKType;
    isAmino(o: any): o is GenesisStateAmino;
    encode(message: GenesisState, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GenesisState;
    fromJSON(object: any): GenesisState;
    toJSON(message: GenesisState): JsonSafe<GenesisState>;
    fromPartial(object: DeepPartial<GenesisState>): GenesisState;
    fromSDK(object: GenesisStateSDKType): GenesisState;
    fromSDKJSON(object: any): GenesisStateSDKType;
    toSDK(message: GenesisState): GenesisStateSDKType;
    fromAmino(object: GenesisStateAmino): GenesisState;
    toAmino(message: GenesisState): GenesisStateAmino;
    fromAminoMsg(object: GenesisStateAminoMsg): GenesisState;
    fromProtoMsg(message: GenesisStateProtoMsg): GenesisState;
    toProto(message: GenesisState): Uint8Array;
    toProtoMsg(message: GenesisState): GenesisStateProtoMsg;
    registerTypeUrl(): void;
};
export declare const Params: {
    typeUrl: string;
    is(o: any): o is Params;
    isSDK(o: any): o is ParamsSDKType;
    isAmino(o: any): o is ParamsAmino;
    encode(message: Params, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): JsonSafe<Params>;
    fromPartial(object: DeepPartial<Params>): Params;
    fromSDK(object: ParamsSDKType): Params;
    fromSDKJSON(object: any): ParamsSDKType;
    toSDK(message: Params): ParamsSDKType;
    fromAmino(object: ParamsAmino): Params;
    toAmino(message: Params): ParamsAmino;
    fromAminoMsg(object: ParamsAminoMsg): Params;
    fromProtoMsg(message: ParamsProtoMsg): Params;
    toProto(message: Params): Uint8Array;
    toProtoMsg(message: Params): ParamsProtoMsg;
    registerTypeUrl(): void;
};
