import { Metadata, MetadataAmino, MetadataSDKType } from "../../../cosmos/bank/v1beta1/bank";
import { DeepPartial } from "../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.erc20.v1";
/** Owner enumerates the ownership of a ERC20 contract. */
export declare enum Owner {
    /** OWNER_UNSPECIFIED - OWNER_UNSPECIFIED defines an invalid/undefined owner. */
    OWNER_UNSPECIFIED = 0,
    /** OWNER_MODULE - OWNER_MODULE erc20 is owned by the erc20 module account. */
    OWNER_MODULE = 1,
    /** OWNER_EXTERNAL - EXTERNAL erc20 is owned by an external account. */
    OWNER_EXTERNAL = 2,
    UNRECOGNIZED = -1
}
export declare const OwnerSDKType: typeof Owner;
export declare const OwnerAmino: typeof Owner;
export declare function ownerFromJSON(object: any): Owner;
export declare function ownerToJSON(object: Owner): string;
/**
 * TokenPair defines an instance that records a pairing consisting of a native
 *  Cosmos Coin and an ERC20 token address.
 */
export interface TokenPair {
    /** address of ERC20 contract token */
    erc20Address: string;
    /** cosmos base denomination to be mapped to */
    denom: string;
    /** shows token mapping enable status */
    enabled: boolean;
    /** ERC20 owner address ENUM (0 invalid, 1 ModuleAccount, 2 external address) */
    contractOwner: Owner;
}
export interface TokenPairProtoMsg {
    typeUrl: "/evmos.erc20.v1.TokenPair";
    value: Uint8Array;
}
/**
 * TokenPair defines an instance that records a pairing consisting of a native
 *  Cosmos Coin and an ERC20 token address.
 */
export interface TokenPairAmino {
    /** address of ERC20 contract token */
    erc20_address?: string;
    /** cosmos base denomination to be mapped to */
    denom?: string;
    /** shows token mapping enable status */
    enabled?: boolean;
    /** ERC20 owner address ENUM (0 invalid, 1 ModuleAccount, 2 external address) */
    contract_owner?: Owner;
}
export interface TokenPairAminoMsg {
    type: "/evmos.erc20.v1.TokenPair";
    value: TokenPairAmino;
}
/**
 * TokenPair defines an instance that records a pairing consisting of a native
 *  Cosmos Coin and an ERC20 token address.
 */
export interface TokenPairSDKType {
    erc20_address: string;
    denom: string;
    enabled: boolean;
    contract_owner: Owner;
}
/**
 * RegisterCoinProposal is a gov Content type to register a token pair for a
 * native Cosmos coin.
 */
export interface RegisterCoinProposal {
    /** title of the proposal */
    title: string;
    /** proposal description */
    description: string;
    /** metadata of the native Cosmos coin */
    metadata: Metadata;
}
export interface RegisterCoinProposalProtoMsg {
    typeUrl: "/evmos.erc20.v1.RegisterCoinProposal";
    value: Uint8Array;
}
/**
 * RegisterCoinProposal is a gov Content type to register a token pair for a
 * native Cosmos coin.
 */
export interface RegisterCoinProposalAmino {
    /** title of the proposal */
    title?: string;
    /** proposal description */
    description?: string;
    /** metadata of the native Cosmos coin */
    metadata?: MetadataAmino;
}
export interface RegisterCoinProposalAminoMsg {
    type: "/evmos.erc20.v1.RegisterCoinProposal";
    value: RegisterCoinProposalAmino;
}
/**
 * RegisterCoinProposal is a gov Content type to register a token pair for a
 * native Cosmos coin.
 */
export interface RegisterCoinProposalSDKType {
    title: string;
    description: string;
    metadata: MetadataSDKType;
}
/**
 * RegisterERC20Proposal is a gov Content type to register a token pair for an
 * ERC20 token
 */
export interface RegisterERC20Proposal {
    /** title of the proposal */
    title: string;
    /** proposal description */
    description: string;
    /** contract address of ERC20 token */
    erc20address: string;
}
export interface RegisterERC20ProposalProtoMsg {
    typeUrl: "/evmos.erc20.v1.RegisterERC20Proposal";
    value: Uint8Array;
}
/**
 * RegisterERC20Proposal is a gov Content type to register a token pair for an
 * ERC20 token
 */
export interface RegisterERC20ProposalAmino {
    /** title of the proposal */
    title?: string;
    /** proposal description */
    description?: string;
    /** contract address of ERC20 token */
    erc20address?: string;
}
export interface RegisterERC20ProposalAminoMsg {
    type: "/evmos.erc20.v1.RegisterERC20Proposal";
    value: RegisterERC20ProposalAmino;
}
/**
 * RegisterERC20Proposal is a gov Content type to register a token pair for an
 * ERC20 token
 */
export interface RegisterERC20ProposalSDKType {
    title: string;
    description: string;
    erc20address: string;
}
/**
 * ToggleTokenConversionProposal is a gov Content type to toggle the conversion
 * of a token pair.
 */
export interface ToggleTokenConversionProposal {
    /** title of the proposal */
    title: string;
    /** proposal description */
    description: string;
    /**
     * token identifier can be either the hex contract address of the ERC20 or the
     * Cosmos base denomination
     */
    token: string;
}
export interface ToggleTokenConversionProposalProtoMsg {
    typeUrl: "/evmos.erc20.v1.ToggleTokenConversionProposal";
    value: Uint8Array;
}
/**
 * ToggleTokenConversionProposal is a gov Content type to toggle the conversion
 * of a token pair.
 */
export interface ToggleTokenConversionProposalAmino {
    /** title of the proposal */
    title?: string;
    /** proposal description */
    description?: string;
    /**
     * token identifier can be either the hex contract address of the ERC20 or the
     * Cosmos base denomination
     */
    token?: string;
}
export interface ToggleTokenConversionProposalAminoMsg {
    type: "/evmos.erc20.v1.ToggleTokenConversionProposal";
    value: ToggleTokenConversionProposalAmino;
}
/**
 * ToggleTokenConversionProposal is a gov Content type to toggle the conversion
 * of a token pair.
 */
export interface ToggleTokenConversionProposalSDKType {
    title: string;
    description: string;
    token: string;
}
export declare const TokenPair: {
    typeUrl: string;
    is(o: any): o is TokenPair;
    isSDK(o: any): o is TokenPairSDKType;
    isAmino(o: any): o is TokenPairAmino;
    encode(message: TokenPair, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TokenPair;
    fromJSON(object: any): TokenPair;
    toJSON(message: TokenPair): JsonSafe<TokenPair>;
    fromPartial(object: DeepPartial<TokenPair>): TokenPair;
    fromSDK(object: TokenPairSDKType): TokenPair;
    fromSDKJSON(object: any): TokenPairSDKType;
    toSDK(message: TokenPair): TokenPairSDKType;
    fromAmino(object: TokenPairAmino): TokenPair;
    toAmino(message: TokenPair): TokenPairAmino;
    fromAminoMsg(object: TokenPairAminoMsg): TokenPair;
    fromProtoMsg(message: TokenPairProtoMsg): TokenPair;
    toProto(message: TokenPair): Uint8Array;
    toProtoMsg(message: TokenPair): TokenPairProtoMsg;
    registerTypeUrl(): void;
};
export declare const RegisterCoinProposal: {
    typeUrl: string;
    is(o: any): o is RegisterCoinProposal;
    isSDK(o: any): o is RegisterCoinProposalSDKType;
    isAmino(o: any): o is RegisterCoinProposalAmino;
    encode(message: RegisterCoinProposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): RegisterCoinProposal;
    fromJSON(object: any): RegisterCoinProposal;
    toJSON(message: RegisterCoinProposal): JsonSafe<RegisterCoinProposal>;
    fromPartial(object: DeepPartial<RegisterCoinProposal>): RegisterCoinProposal;
    fromSDK(object: RegisterCoinProposalSDKType): RegisterCoinProposal;
    fromSDKJSON(object: any): RegisterCoinProposalSDKType;
    toSDK(message: RegisterCoinProposal): RegisterCoinProposalSDKType;
    fromAmino(object: RegisterCoinProposalAmino): RegisterCoinProposal;
    toAmino(message: RegisterCoinProposal): RegisterCoinProposalAmino;
    fromAminoMsg(object: RegisterCoinProposalAminoMsg): RegisterCoinProposal;
    fromProtoMsg(message: RegisterCoinProposalProtoMsg): RegisterCoinProposal;
    toProto(message: RegisterCoinProposal): Uint8Array;
    toProtoMsg(message: RegisterCoinProposal): RegisterCoinProposalProtoMsg;
    registerTypeUrl(): void;
};
export declare const RegisterERC20Proposal: {
    typeUrl: string;
    is(o: any): o is RegisterERC20Proposal;
    isSDK(o: any): o is RegisterERC20ProposalSDKType;
    isAmino(o: any): o is RegisterERC20ProposalAmino;
    encode(message: RegisterERC20Proposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): RegisterERC20Proposal;
    fromJSON(object: any): RegisterERC20Proposal;
    toJSON(message: RegisterERC20Proposal): JsonSafe<RegisterERC20Proposal>;
    fromPartial(object: DeepPartial<RegisterERC20Proposal>): RegisterERC20Proposal;
    fromSDK(object: RegisterERC20ProposalSDKType): RegisterERC20Proposal;
    fromSDKJSON(object: any): RegisterERC20ProposalSDKType;
    toSDK(message: RegisterERC20Proposal): RegisterERC20ProposalSDKType;
    fromAmino(object: RegisterERC20ProposalAmino): RegisterERC20Proposal;
    toAmino(message: RegisterERC20Proposal): RegisterERC20ProposalAmino;
    fromAminoMsg(object: RegisterERC20ProposalAminoMsg): RegisterERC20Proposal;
    fromProtoMsg(message: RegisterERC20ProposalProtoMsg): RegisterERC20Proposal;
    toProto(message: RegisterERC20Proposal): Uint8Array;
    toProtoMsg(message: RegisterERC20Proposal): RegisterERC20ProposalProtoMsg;
    registerTypeUrl(): void;
};
export declare const ToggleTokenConversionProposal: {
    typeUrl: string;
    is(o: any): o is ToggleTokenConversionProposal;
    isSDK(o: any): o is ToggleTokenConversionProposalSDKType;
    isAmino(o: any): o is ToggleTokenConversionProposalAmino;
    encode(message: ToggleTokenConversionProposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ToggleTokenConversionProposal;
    fromJSON(object: any): ToggleTokenConversionProposal;
    toJSON(message: ToggleTokenConversionProposal): JsonSafe<ToggleTokenConversionProposal>;
    fromPartial(object: DeepPartial<ToggleTokenConversionProposal>): ToggleTokenConversionProposal;
    fromSDK(object: ToggleTokenConversionProposalSDKType): ToggleTokenConversionProposal;
    fromSDKJSON(object: any): ToggleTokenConversionProposalSDKType;
    toSDK(message: ToggleTokenConversionProposal): ToggleTokenConversionProposalSDKType;
    fromAmino(object: ToggleTokenConversionProposalAmino): ToggleTokenConversionProposal;
    toAmino(message: ToggleTokenConversionProposal): ToggleTokenConversionProposalAmino;
    fromAminoMsg(object: ToggleTokenConversionProposalAminoMsg): ToggleTokenConversionProposal;
    fromProtoMsg(message: ToggleTokenConversionProposalProtoMsg): ToggleTokenConversionProposal;
    toProto(message: ToggleTokenConversionProposal): Uint8Array;
    toProtoMsg(message: ToggleTokenConversionProposal): ToggleTokenConversionProposalProtoMsg;
    registerTypeUrl(): void;
};
