import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryTokenPairsRequest, QueryTokenPairsResponse, QueryTokenPairRequest, QueryTokenPairResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* TokenPairs retrieves registered token pairs */
    tokenPairs = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryTokenPairsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.erc20.v1.Query", "TokenPairs", data);
        return promise.then(data => QueryTokenPairsResponse.decode(new BinaryReader(data)));
    };
    /* TokenPair retrieves a registered token pair */
    tokenPair = async (request) => {
        const data = QueryTokenPairRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.erc20.v1.Query", "TokenPair", data);
        return promise.then(data => QueryTokenPairResponse.decode(new BinaryReader(data)));
    };
    /* Params retrieves the erc20 module params */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.erc20.v1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
