import { Coin, CoinAmino, CoinSDKType } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.erc20.v1";
/** MsgConvertCoin defines a Msg to convert a native Cosmos coin to a ERC20 token */
export interface MsgConvertCoin {
    /**
     * Cosmos coin which denomination is registered in a token pair. The coin
     * amount defines the amount of coins to convert.
     */
    coin: Coin;
    /** recipient hex address to receive ERC20 token */
    receiver: string;
    /** cosmos bech32 address from the owner of the given Cosmos coins */
    sender: string;
}
export interface MsgConvertCoinProtoMsg {
    typeUrl: "/evmos.erc20.v1.MsgConvertCoin";
    value: Uint8Array;
}
/** MsgConvertCoin defines a Msg to convert a native Cosmos coin to a ERC20 token */
export interface MsgConvertCoinAmino {
    /**
     * Cosmos coin which denomination is registered in a token pair. The coin
     * amount defines the amount of coins to convert.
     */
    coin?: CoinAmino;
    /** recipient hex address to receive ERC20 token */
    receiver?: string;
    /** cosmos bech32 address from the owner of the given Cosmos coins */
    sender?: string;
}
export interface MsgConvertCoinAminoMsg {
    type: "/evmos.erc20.v1.MsgConvertCoin";
    value: MsgConvertCoinAmino;
}
/** MsgConvertCoin defines a Msg to convert a native Cosmos coin to a ERC20 token */
export interface MsgConvertCoinSDKType {
    coin: CoinSDKType;
    receiver: string;
    sender: string;
}
/** MsgConvertCoinResponse returns no fields */
export interface MsgConvertCoinResponse {
}
export interface MsgConvertCoinResponseProtoMsg {
    typeUrl: "/evmos.erc20.v1.MsgConvertCoinResponse";
    value: Uint8Array;
}
/** MsgConvertCoinResponse returns no fields */
export interface MsgConvertCoinResponseAmino {
}
export interface MsgConvertCoinResponseAminoMsg {
    type: "/evmos.erc20.v1.MsgConvertCoinResponse";
    value: MsgConvertCoinResponseAmino;
}
/** MsgConvertCoinResponse returns no fields */
export interface MsgConvertCoinResponseSDKType {
}
/**
 * MsgConvertERC20 defines a Msg to convert a ERC20 token to a native Cosmos
 * coin.
 */
export interface MsgConvertERC20 {
    /** ERC20 token contract address registered in a token pair */
    contractAddress: string;
    /** amount of ERC20 tokens to convert */
    amount: string;
    /** bech32 address to receive native Cosmos coins */
    receiver: string;
    /** sender hex address from the owner of the given ERC20 tokens */
    sender: string;
}
export interface MsgConvertERC20ProtoMsg {
    typeUrl: "/evmos.erc20.v1.MsgConvertERC20";
    value: Uint8Array;
}
/**
 * MsgConvertERC20 defines a Msg to convert a ERC20 token to a native Cosmos
 * coin.
 */
export interface MsgConvertERC20Amino {
    /** ERC20 token contract address registered in a token pair */
    contract_address?: string;
    /** amount of ERC20 tokens to convert */
    amount?: string;
    /** bech32 address to receive native Cosmos coins */
    receiver?: string;
    /** sender hex address from the owner of the given ERC20 tokens */
    sender?: string;
}
export interface MsgConvertERC20AminoMsg {
    type: "/evmos.erc20.v1.MsgConvertERC20";
    value: MsgConvertERC20Amino;
}
/**
 * MsgConvertERC20 defines a Msg to convert a ERC20 token to a native Cosmos
 * coin.
 */
export interface MsgConvertERC20SDKType {
    contract_address: string;
    amount: string;
    receiver: string;
    sender: string;
}
/** MsgConvertERC20Response returns no fields */
export interface MsgConvertERC20Response {
}
export interface MsgConvertERC20ResponseProtoMsg {
    typeUrl: "/evmos.erc20.v1.MsgConvertERC20Response";
    value: Uint8Array;
}
/** MsgConvertERC20Response returns no fields */
export interface MsgConvertERC20ResponseAmino {
}
export interface MsgConvertERC20ResponseAminoMsg {
    type: "/evmos.erc20.v1.MsgConvertERC20Response";
    value: MsgConvertERC20ResponseAmino;
}
/** MsgConvertERC20Response returns no fields */
export interface MsgConvertERC20ResponseSDKType {
}
export declare const MsgConvertCoin: {
    typeUrl: string;
    is(o: any): o is MsgConvertCoin;
    isSDK(o: any): o is MsgConvertCoinSDKType;
    isAmino(o: any): o is MsgConvertCoinAmino;
    encode(message: MsgConvertCoin, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgConvertCoin;
    fromJSON(object: any): MsgConvertCoin;
    toJSON(message: MsgConvertCoin): JsonSafe<MsgConvertCoin>;
    fromPartial(object: DeepPartial<MsgConvertCoin>): MsgConvertCoin;
    fromSDK(object: MsgConvertCoinSDKType): MsgConvertCoin;
    fromSDKJSON(object: any): MsgConvertCoinSDKType;
    toSDK(message: MsgConvertCoin): MsgConvertCoinSDKType;
    fromAmino(object: MsgConvertCoinAmino): MsgConvertCoin;
    toAmino(message: MsgConvertCoin): MsgConvertCoinAmino;
    fromAminoMsg(object: MsgConvertCoinAminoMsg): MsgConvertCoin;
    fromProtoMsg(message: MsgConvertCoinProtoMsg): MsgConvertCoin;
    toProto(message: MsgConvertCoin): Uint8Array;
    toProtoMsg(message: MsgConvertCoin): MsgConvertCoinProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgConvertCoinResponse: {
    typeUrl: string;
    is(o: any): o is MsgConvertCoinResponse;
    isSDK(o: any): o is MsgConvertCoinResponseSDKType;
    isAmino(o: any): o is MsgConvertCoinResponseAmino;
    encode(_: MsgConvertCoinResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgConvertCoinResponse;
    fromJSON(_: any): MsgConvertCoinResponse;
    toJSON(_: MsgConvertCoinResponse): JsonSafe<MsgConvertCoinResponse>;
    fromPartial(_: DeepPartial<MsgConvertCoinResponse>): MsgConvertCoinResponse;
    fromSDK(_: MsgConvertCoinResponseSDKType): MsgConvertCoinResponse;
    fromSDKJSON(_: any): MsgConvertCoinResponseSDKType;
    toSDK(_: MsgConvertCoinResponse): MsgConvertCoinResponseSDKType;
    fromAmino(_: MsgConvertCoinResponseAmino): MsgConvertCoinResponse;
    toAmino(_: MsgConvertCoinResponse): MsgConvertCoinResponseAmino;
    fromAminoMsg(object: MsgConvertCoinResponseAminoMsg): MsgConvertCoinResponse;
    fromProtoMsg(message: MsgConvertCoinResponseProtoMsg): MsgConvertCoinResponse;
    toProto(message: MsgConvertCoinResponse): Uint8Array;
    toProtoMsg(message: MsgConvertCoinResponse): MsgConvertCoinResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgConvertERC20: {
    typeUrl: string;
    is(o: any): o is MsgConvertERC20;
    isSDK(o: any): o is MsgConvertERC20SDKType;
    isAmino(o: any): o is MsgConvertERC20Amino;
    encode(message: MsgConvertERC20, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgConvertERC20;
    fromJSON(object: any): MsgConvertERC20;
    toJSON(message: MsgConvertERC20): JsonSafe<MsgConvertERC20>;
    fromPartial(object: DeepPartial<MsgConvertERC20>): MsgConvertERC20;
    fromSDK(object: MsgConvertERC20SDKType): MsgConvertERC20;
    fromSDKJSON(object: any): MsgConvertERC20SDKType;
    toSDK(message: MsgConvertERC20): MsgConvertERC20SDKType;
    fromAmino(object: MsgConvertERC20Amino): MsgConvertERC20;
    toAmino(message: MsgConvertERC20): MsgConvertERC20Amino;
    fromAminoMsg(object: MsgConvertERC20AminoMsg): MsgConvertERC20;
    fromProtoMsg(message: MsgConvertERC20ProtoMsg): MsgConvertERC20;
    toProto(message: MsgConvertERC20): Uint8Array;
    toProtoMsg(message: MsgConvertERC20): MsgConvertERC20ProtoMsg;
    registerTypeUrl(): void;
};
export declare const MsgConvertERC20Response: {
    typeUrl: string;
    is(o: any): o is MsgConvertERC20Response;
    isSDK(o: any): o is MsgConvertERC20ResponseSDKType;
    isAmino(o: any): o is MsgConvertERC20ResponseAmino;
    encode(_: MsgConvertERC20Response, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgConvertERC20Response;
    fromJSON(_: any): MsgConvertERC20Response;
    toJSON(_: MsgConvertERC20Response): JsonSafe<MsgConvertERC20Response>;
    fromPartial(_: DeepPartial<MsgConvertERC20Response>): MsgConvertERC20Response;
    fromSDK(_: MsgConvertERC20ResponseSDKType): MsgConvertERC20Response;
    fromSDKJSON(_: any): MsgConvertERC20ResponseSDKType;
    toSDK(_: MsgConvertERC20Response): MsgConvertERC20ResponseSDKType;
    fromAmino(_: MsgConvertERC20ResponseAmino): MsgConvertERC20Response;
    toAmino(_: MsgConvertERC20Response): MsgConvertERC20ResponseAmino;
    fromAminoMsg(object: MsgConvertERC20ResponseAminoMsg): MsgConvertERC20Response;
    fromProtoMsg(message: MsgConvertERC20ResponseProtoMsg): MsgConvertERC20Response;
    toProto(message: MsgConvertERC20Response): Uint8Array;
    toProtoMsg(message: MsgConvertERC20Response): MsgConvertERC20ResponseProtoMsg;
    registerTypeUrl(): void;
};
