import { DevFeeInfo, DevFeeInfoAmino, DevFeeInfoSDKType } from "./fees";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.fees.v1";
/** GenesisState defines the module's genesis state. */
export interface GenesisState {
    /** module parameters */
    params: Params;
    /** active registered contracts */
    devFeeInfos: DevFeeInfo[];
}
export interface GenesisStateProtoMsg {
    typeUrl: "/evmos.fees.v1.GenesisState";
    value: Uint8Array;
}
/** GenesisState defines the module's genesis state. */
export interface GenesisStateAmino {
    /** module parameters */
    params?: ParamsAmino;
    /** active registered contracts */
    dev_fee_infos?: DevFeeInfoAmino[];
}
export interface GenesisStateAminoMsg {
    type: "/evmos.fees.v1.GenesisState";
    value: GenesisStateAmino;
}
/** GenesisState defines the module's genesis state. */
export interface GenesisStateSDKType {
    params: ParamsSDKType;
    dev_fee_infos: DevFeeInfoSDKType[];
}
/** Params defines the fees module params */
export interface Params {
    /** parameter to enable fees */
    enableFees: boolean;
    /**
     * developer_shares defines the proportion of the transaction fees to be
     * distributed to the registered contract owner
     */
    developerShares: string;
    /**
     * developer_shares defines the proportion of the transaction fees to be
     * distributed to validators
     */
    validatorShares: string;
    /**
     * addr_derivation_cost_create defines the cost of address derivation for
     * verifying the contract deployer at fee registration
     */
    addrDerivationCostCreate: bigint;
    /** min_gas_price defines the minimum gas price value for cosmos and eth transactions */
    minGasPrice: string;
}
export interface ParamsProtoMsg {
    typeUrl: "/evmos.fees.v1.Params";
    value: Uint8Array;
}
/** Params defines the fees module params */
export interface ParamsAmino {
    /** parameter to enable fees */
    enable_fees?: boolean;
    /**
     * developer_shares defines the proportion of the transaction fees to be
     * distributed to the registered contract owner
     */
    developer_shares?: string;
    /**
     * developer_shares defines the proportion of the transaction fees to be
     * distributed to validators
     */
    validator_shares?: string;
    /**
     * addr_derivation_cost_create defines the cost of address derivation for
     * verifying the contract deployer at fee registration
     */
    addr_derivation_cost_create?: string;
    /** min_gas_price defines the minimum gas price value for cosmos and eth transactions */
    min_gas_price?: string;
}
export interface ParamsAminoMsg {
    type: "/evmos.fees.v1.Params";
    value: ParamsAmino;
}
/** Params defines the fees module params */
export interface ParamsSDKType {
    enable_fees: boolean;
    developer_shares: string;
    validator_shares: string;
    addr_derivation_cost_create: bigint;
    min_gas_price: string;
}
export declare const GenesisState: {
    typeUrl: string;
    is(o: any): o is GenesisState;
    isSDK(o: any): o is GenesisStateSDKType;
    isAmino(o: any): o is GenesisStateAmino;
    encode(message: GenesisState, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GenesisState;
    fromJSON(object: any): GenesisState;
    toJSON(message: GenesisState): JsonSafe<GenesisState>;
    fromPartial(object: DeepPartial<GenesisState>): GenesisState;
    fromSDK(object: GenesisStateSDKType): GenesisState;
    fromSDKJSON(object: any): GenesisStateSDKType;
    toSDK(message: GenesisState): GenesisStateSDKType;
    fromAmino(object: GenesisStateAmino): GenesisState;
    toAmino(message: GenesisState): GenesisStateAmino;
    fromAminoMsg(object: GenesisStateAminoMsg): GenesisState;
    fromProtoMsg(message: GenesisStateProtoMsg): GenesisState;
    toProto(message: GenesisState): Uint8Array;
    toProtoMsg(message: GenesisState): GenesisStateProtoMsg;
    registerTypeUrl(): void;
};
export declare const Params: {
    typeUrl: string;
    is(o: any): o is Params;
    isSDK(o: any): o is ParamsSDKType;
    isAmino(o: any): o is ParamsAmino;
    encode(message: Params, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): JsonSafe<Params>;
    fromPartial(object: DeepPartial<Params>): Params;
    fromSDK(object: ParamsSDKType): Params;
    fromSDKJSON(object: any): ParamsSDKType;
    toSDK(message: Params): ParamsSDKType;
    fromAmino(object: ParamsAmino): Params;
    toAmino(message: Params): ParamsAmino;
    fromAminoMsg(object: ParamsAminoMsg): Params;
    fromProtoMsg(message: ParamsProtoMsg): Params;
    toProto(message: Params): Uint8Array;
    toProtoMsg(message: Params): ParamsProtoMsg;
    registerTypeUrl(): void;
};
