import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../../helpers";
import { QueryDevFeeInfosResponse, QueryDevFeeInfoResponse, QueryParamsResponse, QueryDevFeeInfosPerDeployerResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* DevFeeInfos retrieves all registered contracts for fee distribution */
    devFeeInfos = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `evmos/fees/v1/fees`;
        return QueryDevFeeInfosResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DevFeeInfo retrieves a registered contract for fee distribution */
    devFeeInfo = async (params) => {
        const endpoint = `evmos/fees/v1/fees/${params.contractAddress}`;
        return QueryDevFeeInfoResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Params retrieves the fees module params */
    params = async (_params = {}) => {
        const endpoint = `evmos/fees/v1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DevFeeInfosPerDeployer retrieves all contracts that a deployer has
     registered for fee distribution */
    devFeeInfosPerDeployer = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `evmos/fees/v1/fees/${params.deployerAddress}`;
        return QueryDevFeeInfosPerDeployerResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
