import { DecCoin, DecCoinAmino, DecCoinSDKType } from "../../../cosmos/base/v1beta1/coin";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.incentives.v1";
/**
 * Incentive defines an instance that organizes distribution conditions for a
 * given smart contract
 */
export interface Incentive {
    /** contract address */
    contract: string;
    /** denoms and percentage of rewards to be allocated */
    allocations: DecCoin[];
    /** number of remaining epochs */
    epochs: number;
    /** distribution start time */
    startTime: Date;
    /** cumulative gas spent by all gasmeters of the incentive during the epoch */
    totalGas: bigint;
}
export interface IncentiveProtoMsg {
    typeUrl: "/evmos.incentives.v1.Incentive";
    value: Uint8Array;
}
/**
 * Incentive defines an instance that organizes distribution conditions for a
 * given smart contract
 */
export interface IncentiveAmino {
    /** contract address */
    contract?: string;
    /** denoms and percentage of rewards to be allocated */
    allocations?: DecCoinAmino[];
    /** number of remaining epochs */
    epochs?: number;
    /** distribution start time */
    start_time?: string;
    /** cumulative gas spent by all gasmeters of the incentive during the epoch */
    total_gas?: string;
}
export interface IncentiveAminoMsg {
    type: "/evmos.incentives.v1.Incentive";
    value: IncentiveAmino;
}
/**
 * Incentive defines an instance that organizes distribution conditions for a
 * given smart contract
 */
export interface IncentiveSDKType {
    contract: string;
    allocations: DecCoinSDKType[];
    epochs: number;
    start_time: Date;
    total_gas: bigint;
}
/** GasMeter tracks the cumulative gas spent per participant in one epoch */
export interface GasMeter {
    /** hex address of the incentivized contract */
    contract: string;
    /** participant address that interacts with the incentive */
    participant: string;
    /** cumulative gas spent during the epoch */
    cumulativeGas: bigint;
}
export interface GasMeterProtoMsg {
    typeUrl: "/evmos.incentives.v1.GasMeter";
    value: Uint8Array;
}
/** GasMeter tracks the cumulative gas spent per participant in one epoch */
export interface GasMeterAmino {
    /** hex address of the incentivized contract */
    contract?: string;
    /** participant address that interacts with the incentive */
    participant?: string;
    /** cumulative gas spent during the epoch */
    cumulative_gas?: string;
}
export interface GasMeterAminoMsg {
    type: "/evmos.incentives.v1.GasMeter";
    value: GasMeterAmino;
}
/** GasMeter tracks the cumulative gas spent per participant in one epoch */
export interface GasMeterSDKType {
    contract: string;
    participant: string;
    cumulative_gas: bigint;
}
/** RegisterIncentiveProposal is a gov Content type to register an incentive */
export interface RegisterIncentiveProposal {
    $typeUrl?: "/evmos.incentives.v1.RegisterIncentiveProposal";
    /** title of the proposal */
    title: string;
    /** proposal description */
    description: string;
    /** contract address */
    contract: string;
    /** denoms and percentage of rewards to be allocated */
    allocations: DecCoin[];
    /** number of remaining epochs */
    epochs: number;
}
export interface RegisterIncentiveProposalProtoMsg {
    typeUrl: "/evmos.incentives.v1.RegisterIncentiveProposal";
    value: Uint8Array;
}
/** RegisterIncentiveProposal is a gov Content type to register an incentive */
export interface RegisterIncentiveProposalAmino {
    /** title of the proposal */
    title?: string;
    /** proposal description */
    description?: string;
    /** contract address */
    contract?: string;
    /** denoms and percentage of rewards to be allocated */
    allocations?: DecCoinAmino[];
    /** number of remaining epochs */
    epochs?: number;
}
export interface RegisterIncentiveProposalAminoMsg {
    type: "/evmos.incentives.v1.RegisterIncentiveProposal";
    value: RegisterIncentiveProposalAmino;
}
/** RegisterIncentiveProposal is a gov Content type to register an incentive */
export interface RegisterIncentiveProposalSDKType {
    $typeUrl?: "/evmos.incentives.v1.RegisterIncentiveProposal";
    title: string;
    description: string;
    contract: string;
    allocations: DecCoinSDKType[];
    epochs: number;
}
/** CancelIncentiveProposal is a gov Content type to cancel an incentive */
export interface CancelIncentiveProposal {
    /** title of the proposal */
    title: string;
    /** proposal description */
    description: string;
    /** contract address */
    contract: string;
}
export interface CancelIncentiveProposalProtoMsg {
    typeUrl: "/evmos.incentives.v1.CancelIncentiveProposal";
    value: Uint8Array;
}
/** CancelIncentiveProposal is a gov Content type to cancel an incentive */
export interface CancelIncentiveProposalAmino {
    /** title of the proposal */
    title?: string;
    /** proposal description */
    description?: string;
    /** contract address */
    contract?: string;
}
export interface CancelIncentiveProposalAminoMsg {
    type: "/evmos.incentives.v1.CancelIncentiveProposal";
    value: CancelIncentiveProposalAmino;
}
/** CancelIncentiveProposal is a gov Content type to cancel an incentive */
export interface CancelIncentiveProposalSDKType {
    title: string;
    description: string;
    contract: string;
}
export declare const Incentive: {
    typeUrl: string;
    is(o: any): o is Incentive;
    isSDK(o: any): o is IncentiveSDKType;
    isAmino(o: any): o is IncentiveAmino;
    encode(message: Incentive, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Incentive;
    fromJSON(object: any): Incentive;
    toJSON(message: Incentive): JsonSafe<Incentive>;
    fromPartial(object: DeepPartial<Incentive>): Incentive;
    fromSDK(object: IncentiveSDKType): Incentive;
    fromSDKJSON(object: any): IncentiveSDKType;
    toSDK(message: Incentive): IncentiveSDKType;
    fromAmino(object: IncentiveAmino): Incentive;
    toAmino(message: Incentive): IncentiveAmino;
    fromAminoMsg(object: IncentiveAminoMsg): Incentive;
    fromProtoMsg(message: IncentiveProtoMsg): Incentive;
    toProto(message: Incentive): Uint8Array;
    toProtoMsg(message: Incentive): IncentiveProtoMsg;
    registerTypeUrl(): void;
};
export declare const GasMeter: {
    typeUrl: string;
    is(o: any): o is GasMeter;
    isSDK(o: any): o is GasMeterSDKType;
    isAmino(o: any): o is GasMeterAmino;
    encode(message: GasMeter, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GasMeter;
    fromJSON(object: any): GasMeter;
    toJSON(message: GasMeter): JsonSafe<GasMeter>;
    fromPartial(object: DeepPartial<GasMeter>): GasMeter;
    fromSDK(object: GasMeterSDKType): GasMeter;
    fromSDKJSON(object: any): GasMeterSDKType;
    toSDK(message: GasMeter): GasMeterSDKType;
    fromAmino(object: GasMeterAmino): GasMeter;
    toAmino(message: GasMeter): GasMeterAmino;
    fromAminoMsg(object: GasMeterAminoMsg): GasMeter;
    fromProtoMsg(message: GasMeterProtoMsg): GasMeter;
    toProto(message: GasMeter): Uint8Array;
    toProtoMsg(message: GasMeter): GasMeterProtoMsg;
    registerTypeUrl(): void;
};
export declare const RegisterIncentiveProposal: {
    typeUrl: string;
    is(o: any): o is RegisterIncentiveProposal;
    isSDK(o: any): o is RegisterIncentiveProposalSDKType;
    isAmino(o: any): o is RegisterIncentiveProposalAmino;
    encode(message: RegisterIncentiveProposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): RegisterIncentiveProposal;
    fromJSON(object: any): RegisterIncentiveProposal;
    toJSON(message: RegisterIncentiveProposal): JsonSafe<RegisterIncentiveProposal>;
    fromPartial(object: DeepPartial<RegisterIncentiveProposal>): RegisterIncentiveProposal;
    fromSDK(object: RegisterIncentiveProposalSDKType): RegisterIncentiveProposal;
    fromSDKJSON(object: any): RegisterIncentiveProposalSDKType;
    toSDK(message: RegisterIncentiveProposal): RegisterIncentiveProposalSDKType;
    fromAmino(object: RegisterIncentiveProposalAmino): RegisterIncentiveProposal;
    toAmino(message: RegisterIncentiveProposal): RegisterIncentiveProposalAmino;
    fromAminoMsg(object: RegisterIncentiveProposalAminoMsg): RegisterIncentiveProposal;
    fromProtoMsg(message: RegisterIncentiveProposalProtoMsg): RegisterIncentiveProposal;
    toProto(message: RegisterIncentiveProposal): Uint8Array;
    toProtoMsg(message: RegisterIncentiveProposal): RegisterIncentiveProposalProtoMsg;
    registerTypeUrl(): void;
};
export declare const CancelIncentiveProposal: {
    typeUrl: string;
    is(o: any): o is CancelIncentiveProposal;
    isSDK(o: any): o is CancelIncentiveProposalSDKType;
    isAmino(o: any): o is CancelIncentiveProposalAmino;
    encode(message: CancelIncentiveProposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CancelIncentiveProposal;
    fromJSON(object: any): CancelIncentiveProposal;
    toJSON(message: CancelIncentiveProposal): JsonSafe<CancelIncentiveProposal>;
    fromPartial(object: DeepPartial<CancelIncentiveProposal>): CancelIncentiveProposal;
    fromSDK(object: CancelIncentiveProposalSDKType): CancelIncentiveProposal;
    fromSDKJSON(object: any): CancelIncentiveProposalSDKType;
    toSDK(message: CancelIncentiveProposal): CancelIncentiveProposalSDKType;
    fromAmino(object: CancelIncentiveProposalAmino): CancelIncentiveProposal;
    toAmino(message: CancelIncentiveProposal): CancelIncentiveProposalAmino;
    fromAminoMsg(object: CancelIncentiveProposalAminoMsg): CancelIncentiveProposal;
    fromProtoMsg(message: CancelIncentiveProposalProtoMsg): CancelIncentiveProposal;
    toProto(message: CancelIncentiveProposal): Uint8Array;
    toProtoMsg(message: CancelIncentiveProposal): CancelIncentiveProposalProtoMsg;
    registerTypeUrl(): void;
};
