import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { QueryIncentivesRequest, QueryIncentivesResponse, QueryIncentiveRequest, QueryIncentiveResponse, QueryGasMetersRequest, QueryGasMetersResponse, QueryGasMeterRequest, QueryGasMeterResponse, QueryAllocationMetersRequest, QueryAllocationMetersResponse, QueryAllocationMeterRequest, QueryAllocationMeterResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Incentives retrieves registered incentives */
    incentives = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryIncentivesRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "Incentives", data);
        return promise.then(data => QueryIncentivesResponse.decode(new BinaryReader(data)));
    };
    /* Incentive retrieves a registered incentive */
    incentive = async (request) => {
        const data = QueryIncentiveRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "Incentive", data);
        return promise.then(data => QueryIncentiveResponse.decode(new BinaryReader(data)));
    };
    /* GasMeters retrieves active gas meters for a given contract */
    gasMeters = async (request) => {
        const data = QueryGasMetersRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "GasMeters", data);
        return promise.then(data => QueryGasMetersResponse.decode(new BinaryReader(data)));
    };
    /* GasMeter Retrieves a active gas meter */
    gasMeter = async (request) => {
        const data = QueryGasMeterRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "GasMeter", data);
        return promise.then(data => QueryGasMeterResponse.decode(new BinaryReader(data)));
    };
    /* AllocationMeters retrieves active allocation meters for a given
     denomination */
    allocationMeters = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryAllocationMetersRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "AllocationMeters", data);
        return promise.then(data => QueryAllocationMetersResponse.decode(new BinaryReader(data)));
    };
    /* AllocationMeter Retrieves a active gas meter */
    allocationMeter = async (request) => {
        const data = QueryAllocationMeterRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "AllocationMeter", data);
        return promise.then(data => QueryAllocationMeterResponse.decode(new BinaryReader(data)));
    };
    /* Params retrieves the incentives module params */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("evmos.incentives.v1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
