import { ExponentialCalculation, ExponentialCalculationAmino, ExponentialCalculationSDKType, InflationDistribution, InflationDistributionAmino, InflationDistributionSDKType } from "./inflation";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.inflation.v1";
/** GenesisState defines the inflation module's genesis state. */
export interface GenesisState {
    /** params defines all the paramaters of the module. */
    params: Params;
    /** amount of past periods, based on the epochs per period param */
    period: bigint;
    /** inflation epoch identifier */
    epochIdentifier: string;
    /** number of epochs after which inflation is recalculated */
    epochsPerPeriod: bigint;
    /** number of epochs that have passed while inflation is disabled */
    skippedEpochs: bigint;
}
export interface GenesisStateProtoMsg {
    typeUrl: "/evmos.inflation.v1.GenesisState";
    value: Uint8Array;
}
/** GenesisState defines the inflation module's genesis state. */
export interface GenesisStateAmino {
    /** params defines all the paramaters of the module. */
    params?: ParamsAmino;
    /** amount of past periods, based on the epochs per period param */
    period?: string;
    /** inflation epoch identifier */
    epoch_identifier?: string;
    /** number of epochs after which inflation is recalculated */
    epochs_per_period?: string;
    /** number of epochs that have passed while inflation is disabled */
    skipped_epochs?: string;
}
export interface GenesisStateAminoMsg {
    type: "/evmos.inflation.v1.GenesisState";
    value: GenesisStateAmino;
}
/** GenesisState defines the inflation module's genesis state. */
export interface GenesisStateSDKType {
    params: ParamsSDKType;
    period: bigint;
    epoch_identifier: string;
    epochs_per_period: bigint;
    skipped_epochs: bigint;
}
/** Params holds parameters for the inflation module. */
export interface Params {
    /** type of coin to mint */
    mintDenom: string;
    /** variables to calculate exponential inflation */
    exponentialCalculation: ExponentialCalculation;
    /** inflation distribution of the minted denom */
    inflationDistribution: InflationDistribution;
    /** parameter to enable inflation and halt increasing the skipped_epochs */
    enableInflation: boolean;
}
export interface ParamsProtoMsg {
    typeUrl: "/evmos.inflation.v1.Params";
    value: Uint8Array;
}
/** Params holds parameters for the inflation module. */
export interface ParamsAmino {
    /** type of coin to mint */
    mint_denom?: string;
    /** variables to calculate exponential inflation */
    exponential_calculation?: ExponentialCalculationAmino;
    /** inflation distribution of the minted denom */
    inflation_distribution?: InflationDistributionAmino;
    /** parameter to enable inflation and halt increasing the skipped_epochs */
    enable_inflation?: boolean;
}
export interface ParamsAminoMsg {
    type: "/evmos.inflation.v1.Params";
    value: ParamsAmino;
}
/** Params holds parameters for the inflation module. */
export interface ParamsSDKType {
    mint_denom: string;
    exponential_calculation: ExponentialCalculationSDKType;
    inflation_distribution: InflationDistributionSDKType;
    enable_inflation: boolean;
}
export declare const GenesisState: {
    typeUrl: string;
    is(o: any): o is GenesisState;
    isSDK(o: any): o is GenesisStateSDKType;
    isAmino(o: any): o is GenesisStateAmino;
    encode(message: GenesisState, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GenesisState;
    fromJSON(object: any): GenesisState;
    toJSON(message: GenesisState): JsonSafe<GenesisState>;
    fromPartial(object: DeepPartial<GenesisState>): GenesisState;
    fromSDK(object: GenesisStateSDKType): GenesisState;
    fromSDKJSON(object: any): GenesisStateSDKType;
    toSDK(message: GenesisState): GenesisStateSDKType;
    fromAmino(object: GenesisStateAmino): GenesisState;
    toAmino(message: GenesisState): GenesisStateAmino;
    fromAminoMsg(object: GenesisStateAminoMsg): GenesisState;
    fromProtoMsg(message: GenesisStateProtoMsg): GenesisState;
    toProto(message: GenesisState): Uint8Array;
    toProtoMsg(message: GenesisState): GenesisStateProtoMsg;
    registerTypeUrl(): void;
};
export declare const Params: {
    typeUrl: string;
    is(o: any): o is Params;
    isSDK(o: any): o is ParamsSDKType;
    isAmino(o: any): o is ParamsAmino;
    encode(message: Params, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): JsonSafe<Params>;
    fromPartial(object: DeepPartial<Params>): Params;
    fromSDK(object: ParamsSDKType): Params;
    fromSDKJSON(object: any): ParamsSDKType;
    toSDK(message: Params): ParamsSDKType;
    fromAmino(object: ParamsAmino): Params;
    toAmino(message: Params): ParamsAmino;
    fromAminoMsg(object: ParamsAminoMsg): Params;
    fromProtoMsg(message: ParamsProtoMsg): Params;
    toProto(message: Params): Uint8Array;
    toProtoMsg(message: Params): ParamsProtoMsg;
    registerTypeUrl(): void;
};
