import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "evmos.inflation.v1";
/**
 * InflationDistribution defines the distribution in which inflation is
 * allocated through minting on each epoch (staking, incentives, community). It
 * excludes the team vesting distribution, as this is minted once at genesis.
 * The initial InflationDistribution can be calculated from the Evmos Token
 * Model like this:
 * mintDistribution1 = distribution1 / (1 - teamVestingDistribution)
 * 0.5333333         = 40%           / (1 - 25%)
 */
export interface InflationDistribution {
    /**
     * staking_rewards defines the proportion of the minted minted_denom that is
     * to be allocated as staking rewards
     */
    stakingRewards: string;
    /**
     * usage_incentives defines the proportion of the minted minted_denom that is
     * to be allocated to the incentives module address
     */
    usageIncentives: string;
    /**
     * community_pool defines the proportion of the minted minted_denom that is to
     * be allocated to the community pool
     */
    communityPool: string;
}
export interface InflationDistributionProtoMsg {
    typeUrl: "/evmos.inflation.v1.InflationDistribution";
    value: Uint8Array;
}
/**
 * InflationDistribution defines the distribution in which inflation is
 * allocated through minting on each epoch (staking, incentives, community). It
 * excludes the team vesting distribution, as this is minted once at genesis.
 * The initial InflationDistribution can be calculated from the Evmos Token
 * Model like this:
 * mintDistribution1 = distribution1 / (1 - teamVestingDistribution)
 * 0.5333333         = 40%           / (1 - 25%)
 */
export interface InflationDistributionAmino {
    /**
     * staking_rewards defines the proportion of the minted minted_denom that is
     * to be allocated as staking rewards
     */
    staking_rewards?: string;
    /**
     * usage_incentives defines the proportion of the minted minted_denom that is
     * to be allocated to the incentives module address
     */
    usage_incentives?: string;
    /**
     * community_pool defines the proportion of the minted minted_denom that is to
     * be allocated to the community pool
     */
    community_pool?: string;
}
export interface InflationDistributionAminoMsg {
    type: "/evmos.inflation.v1.InflationDistribution";
    value: InflationDistributionAmino;
}
/**
 * InflationDistribution defines the distribution in which inflation is
 * allocated through minting on each epoch (staking, incentives, community). It
 * excludes the team vesting distribution, as this is minted once at genesis.
 * The initial InflationDistribution can be calculated from the Evmos Token
 * Model like this:
 * mintDistribution1 = distribution1 / (1 - teamVestingDistribution)
 * 0.5333333         = 40%           / (1 - 25%)
 */
export interface InflationDistributionSDKType {
    staking_rewards: string;
    usage_incentives: string;
    community_pool: string;
}
/**
 * ExponentialCalculation holds factors to calculate exponential inflation on
 * each period. Calculation reference:
 * periodProvision = exponentialDecay       *  bondingIncentive
 * f(x)            = (a * (1 - r) ^ x + c)  *  (1 + max_variance - bondedRatio *
 * (max_variance / bonding_target))
 */
export interface ExponentialCalculation {
    /** initial value */
    a: string;
    /** reduction factor */
    r: string;
    /** long term inflation */
    c: string;
    /** bonding target */
    bondingTarget: string;
    /** max variance */
    maxVariance: string;
}
export interface ExponentialCalculationProtoMsg {
    typeUrl: "/evmos.inflation.v1.ExponentialCalculation";
    value: Uint8Array;
}
/**
 * ExponentialCalculation holds factors to calculate exponential inflation on
 * each period. Calculation reference:
 * periodProvision = exponentialDecay       *  bondingIncentive
 * f(x)            = (a * (1 - r) ^ x + c)  *  (1 + max_variance - bondedRatio *
 * (max_variance / bonding_target))
 */
export interface ExponentialCalculationAmino {
    /** initial value */
    a?: string;
    /** reduction factor */
    r?: string;
    /** long term inflation */
    c?: string;
    /** bonding target */
    bonding_target?: string;
    /** max variance */
    max_variance?: string;
}
export interface ExponentialCalculationAminoMsg {
    type: "/evmos.inflation.v1.ExponentialCalculation";
    value: ExponentialCalculationAmino;
}
/**
 * ExponentialCalculation holds factors to calculate exponential inflation on
 * each period. Calculation reference:
 * periodProvision = exponentialDecay       *  bondingIncentive
 * f(x)            = (a * (1 - r) ^ x + c)  *  (1 + max_variance - bondedRatio *
 * (max_variance / bonding_target))
 */
export interface ExponentialCalculationSDKType {
    a: string;
    r: string;
    c: string;
    bonding_target: string;
    max_variance: string;
}
export declare const InflationDistribution: {
    typeUrl: string;
    is(o: any): o is InflationDistribution;
    isSDK(o: any): o is InflationDistributionSDKType;
    isAmino(o: any): o is InflationDistributionAmino;
    encode(message: InflationDistribution, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): InflationDistribution;
    fromJSON(object: any): InflationDistribution;
    toJSON(message: InflationDistribution): JsonSafe<InflationDistribution>;
    fromPartial(object: DeepPartial<InflationDistribution>): InflationDistribution;
    fromSDK(object: InflationDistributionSDKType): InflationDistribution;
    fromSDKJSON(object: any): InflationDistributionSDKType;
    toSDK(message: InflationDistribution): InflationDistributionSDKType;
    fromAmino(object: InflationDistributionAmino): InflationDistribution;
    toAmino(message: InflationDistribution): InflationDistributionAmino;
    fromAminoMsg(object: InflationDistributionAminoMsg): InflationDistribution;
    fromProtoMsg(message: InflationDistributionProtoMsg): InflationDistribution;
    toProto(message: InflationDistribution): Uint8Array;
    toProtoMsg(message: InflationDistribution): InflationDistributionProtoMsg;
    registerTypeUrl(): void;
};
export declare const ExponentialCalculation: {
    typeUrl: string;
    is(o: any): o is ExponentialCalculation;
    isSDK(o: any): o is ExponentialCalculationSDKType;
    isAmino(o: any): o is ExponentialCalculationAmino;
    encode(message: ExponentialCalculation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ExponentialCalculation;
    fromJSON(object: any): ExponentialCalculation;
    toJSON(message: ExponentialCalculation): JsonSafe<ExponentialCalculation>;
    fromPartial(object: DeepPartial<ExponentialCalculation>): ExponentialCalculation;
    fromSDK(object: ExponentialCalculationSDKType): ExponentialCalculation;
    fromSDKJSON(object: any): ExponentialCalculationSDKType;
    toSDK(message: ExponentialCalculation): ExponentialCalculationSDKType;
    fromAmino(object: ExponentialCalculationAmino): ExponentialCalculation;
    toAmino(message: ExponentialCalculation): ExponentialCalculationAmino;
    fromAminoMsg(object: ExponentialCalculationAminoMsg): ExponentialCalculation;
    fromProtoMsg(message: ExponentialCalculationProtoMsg): ExponentialCalculation;
    toProto(message: ExponentialCalculation): Uint8Array;
    toProtoMsg(message: ExponentialCalculation): ExponentialCalculationProtoMsg;
    registerTypeUrl(): void;
};
