import { BaseVestingAccount, Period } from "../../../cosmos/vesting/v1beta1/vesting";
import { Timestamp } from "../../../google/protobuf/timestamp";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { toTimestamp, fromTimestamp, isSet } from "../../../helpers";
export const protobufPackage = "evmos.vesting.v1";
function createBaseClawbackVestingAccount() {
    return {
        baseVestingAccount: undefined,
        funderAddress: "",
        startTime: new Date(),
        lockupPeriods: [],
        vestingPeriods: []
    };
}
export const ClawbackVestingAccount = {
    typeUrl: "/evmos.vesting.v1.ClawbackVestingAccount",
    is(o) {
        return o && (o.$typeUrl === ClawbackVestingAccount.typeUrl || typeof o.funderAddress === "string" && Timestamp.is(o.startTime) && Array.isArray(o.lockupPeriods) && (!o.lockupPeriods.length || Period.is(o.lockupPeriods[0])) && Array.isArray(o.vestingPeriods) && (!o.vestingPeriods.length || Period.is(o.vestingPeriods[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ClawbackVestingAccount.typeUrl || typeof o.funder_address === "string" && Timestamp.isSDK(o.start_time) && Array.isArray(o.lockup_periods) && (!o.lockup_periods.length || Period.isSDK(o.lockup_periods[0])) && Array.isArray(o.vesting_periods) && (!o.vesting_periods.length || Period.isSDK(o.vesting_periods[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ClawbackVestingAccount.typeUrl || typeof o.funder_address === "string" && Timestamp.isAmino(o.start_time) && Array.isArray(o.lockup_periods) && (!o.lockup_periods.length || Period.isAmino(o.lockup_periods[0])) && Array.isArray(o.vesting_periods) && (!o.vesting_periods.length || Period.isAmino(o.vesting_periods[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.baseVestingAccount !== undefined) {
            BaseVestingAccount.encode(message.baseVestingAccount, writer.uint32(10).fork()).ldelim();
        }
        if (message.funderAddress !== undefined) {
            writer.uint32(18).string(message.funderAddress);
        }
        if (message.startTime !== undefined) {
            Timestamp.encode(toTimestamp(message.startTime), writer.uint32(26).fork()).ldelim();
        }
        for (const v of message.lockupPeriods) {
            Period.encode(v, writer.uint32(34).fork()).ldelim();
        }
        for (const v of message.vestingPeriods) {
            Period.encode(v, writer.uint32(42).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseClawbackVestingAccount();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.baseVestingAccount = BaseVestingAccount.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.funderAddress = reader.string();
                    break;
                case 3:
                    message.startTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 4:
                    message.lockupPeriods.push(Period.decode(reader, reader.uint32()));
                    break;
                case 5:
                    message.vestingPeriods.push(Period.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseClawbackVestingAccount();
        if (isSet(object.baseVestingAccount))
            obj.baseVestingAccount = BaseVestingAccount.fromJSON(object.baseVestingAccount);
        if (isSet(object.funderAddress))
            obj.funderAddress = String(object.funderAddress);
        if (isSet(object.startTime))
            obj.startTime = new Date(object.startTime);
        if (Array.isArray(object?.lockupPeriods))
            obj.lockupPeriods = object.lockupPeriods.map((e) => Period.fromJSON(e));
        if (Array.isArray(object?.vestingPeriods))
            obj.vestingPeriods = object.vestingPeriods.map((e) => Period.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.baseVestingAccount !== undefined && (obj.baseVestingAccount = message.baseVestingAccount ? BaseVestingAccount.toJSON(message.baseVestingAccount) : undefined);
        message.funderAddress !== undefined && (obj.funderAddress = message.funderAddress);
        message.startTime !== undefined && (obj.startTime = message.startTime.toISOString());
        if (message.lockupPeriods) {
            obj.lockupPeriods = message.lockupPeriods.map(e => e ? Period.toJSON(e) : undefined);
        }
        else {
            obj.lockupPeriods = [];
        }
        if (message.vestingPeriods) {
            obj.vestingPeriods = message.vestingPeriods.map(e => e ? Period.toJSON(e) : undefined);
        }
        else {
            obj.vestingPeriods = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseClawbackVestingAccount();
        if (object.baseVestingAccount !== undefined && object.baseVestingAccount !== null) {
            message.baseVestingAccount = BaseVestingAccount.fromPartial(object.baseVestingAccount);
        }
        message.funderAddress = object.funderAddress ?? "";
        message.startTime = object.startTime ?? undefined;
        message.lockupPeriods = object.lockupPeriods?.map(e => Period.fromPartial(e)) || [];
        message.vestingPeriods = object.vestingPeriods?.map(e => Period.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            baseVestingAccount: object.base_vesting_account ? BaseVestingAccount.fromSDK(object.base_vesting_account) : undefined,
            funderAddress: object?.funder_address,
            startTime: object.start_time ?? undefined,
            lockupPeriods: Array.isArray(object?.lockup_periods) ? object.lockup_periods.map((e) => Period.fromSDK(e)) : [],
            vestingPeriods: Array.isArray(object?.vesting_periods) ? object.vesting_periods.map((e) => Period.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            base_vesting_account: isSet(object.base_vesting_account) ? BaseVestingAccount.fromSDKJSON(object.base_vesting_account) : undefined,
            funder_address: isSet(object.funder_address) ? String(object.funder_address) : "",
            start_time: isSet(object.start_time) ? new Date(object.start_time) : undefined,
            lockup_periods: Array.isArray(object?.lockup_periods) ? object.lockup_periods.map((e) => Period.fromSDKJSON(e)) : [],
            vesting_periods: Array.isArray(object?.vesting_periods) ? object.vesting_periods.map((e) => Period.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        message.baseVestingAccount !== undefined && (obj.base_vesting_account = message.baseVestingAccount ? BaseVestingAccount.toSDK(message.baseVestingAccount) : undefined);
        obj.funder_address = message.funderAddress;
        message.startTime !== undefined && (obj.start_time = message.startTime ?? undefined);
        if (message.lockupPeriods) {
            obj.lockup_periods = message.lockupPeriods.map(e => e ? Period.toSDK(e) : undefined);
        }
        else {
            obj.lockup_periods = [];
        }
        if (message.vestingPeriods) {
            obj.vesting_periods = message.vestingPeriods.map(e => e ? Period.toSDK(e) : undefined);
        }
        else {
            obj.vesting_periods = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseClawbackVestingAccount();
        if (object.base_vesting_account !== undefined && object.base_vesting_account !== null) {
            message.baseVestingAccount = BaseVestingAccount.fromAmino(object.base_vesting_account);
        }
        if (object.funder_address !== undefined && object.funder_address !== null) {
            message.funderAddress = object.funder_address;
        }
        if (object.start_time !== undefined && object.start_time !== null) {
            message.startTime = fromTimestamp(Timestamp.fromAmino(object.start_time));
        }
        message.lockupPeriods = object.lockup_periods?.map(e => Period.fromAmino(e)) || [];
        message.vestingPeriods = object.vesting_periods?.map(e => Period.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.base_vesting_account = message.baseVestingAccount ? BaseVestingAccount.toAmino(message.baseVestingAccount) : undefined;
        obj.funder_address = message.funderAddress === "" ? undefined : message.funderAddress;
        obj.start_time = message.startTime ? Timestamp.toAmino(toTimestamp(message.startTime)) : undefined;
        if (message.lockupPeriods) {
            obj.lockup_periods = message.lockupPeriods.map(e => e ? Period.toAmino(e) : undefined);
        }
        else {
            obj.lockup_periods = message.lockupPeriods;
        }
        if (message.vestingPeriods) {
            obj.vesting_periods = message.vestingPeriods.map(e => e ? Period.toAmino(e) : undefined);
        }
        else {
            obj.vesting_periods = message.vestingPeriods;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ClawbackVestingAccount.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ClawbackVestingAccount.decode(message.value);
    },
    toProto(message) {
        return ClawbackVestingAccount.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/evmos.vesting.v1.ClawbackVestingAccount",
            value: ClawbackVestingAccount.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BaseVestingAccount.registerTypeUrl();
        Period.registerTypeUrl();
    }
};
