import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * `Authentication` defines the authentication configuration for API methods
 * provided by an API service.
 *
 * Example:
 *
 *     name: calendar.googleapis.com
 *     authentication:
 *       providers:
 *       - id: google_calendar_auth
 *         jwks_uri: https://www.googleapis.com/oauth2/v1/certs
 *         issuer: https://securetoken.google.com
 *       rules:
 *       - selector: "*"
 *         requirements:
 *           provider_id: google_calendar_auth
 *       - selector: google.calendar.Delegate
 *         oauth:
 *           canonical_scopes: https://www.googleapis.com/auth/calendar.read
 */
export interface Authentication {
    /**
     * A list of authentication rules that apply to individual API methods.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules: AuthenticationRule[];
    /** Defines a set of authentication providers that a service supports. */
    providers: AuthProvider[];
}
export interface AuthenticationProtoMsg {
    typeUrl: "/google.api.Authentication";
    value: Uint8Array;
}
/**
 * `Authentication` defines the authentication configuration for API methods
 * provided by an API service.
 *
 * Example:
 *
 *     name: calendar.googleapis.com
 *     authentication:
 *       providers:
 *       - id: google_calendar_auth
 *         jwks_uri: https://www.googleapis.com/oauth2/v1/certs
 *         issuer: https://securetoken.google.com
 *       rules:
 *       - selector: "*"
 *         requirements:
 *           provider_id: google_calendar_auth
 *       - selector: google.calendar.Delegate
 *         oauth:
 *           canonical_scopes: https://www.googleapis.com/auth/calendar.read
 */
export interface AuthenticationAmino {
    /**
     * A list of authentication rules that apply to individual API methods.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules?: AuthenticationRuleAmino[];
    /** Defines a set of authentication providers that a service supports. */
    providers?: AuthProviderAmino[];
}
export interface AuthenticationAminoMsg {
    type: "/google.api.Authentication";
    value: AuthenticationAmino;
}
/**
 * `Authentication` defines the authentication configuration for API methods
 * provided by an API service.
 *
 * Example:
 *
 *     name: calendar.googleapis.com
 *     authentication:
 *       providers:
 *       - id: google_calendar_auth
 *         jwks_uri: https://www.googleapis.com/oauth2/v1/certs
 *         issuer: https://securetoken.google.com
 *       rules:
 *       - selector: "*"
 *         requirements:
 *           provider_id: google_calendar_auth
 *       - selector: google.calendar.Delegate
 *         oauth:
 *           canonical_scopes: https://www.googleapis.com/auth/calendar.read
 */
export interface AuthenticationSDKType {
    rules: AuthenticationRuleSDKType[];
    providers: AuthProviderSDKType[];
}
/**
 * Authentication rules for the service.
 *
 * By default, if a method has any authentication requirements, every request
 * must include a valid credential matching one of the requirements.
 * It's an error to include more than one kind of credential in a single
 * request.
 *
 * If a method doesn't have any auth requirements, request credentials will be
 * ignored.
 */
export interface AuthenticationRule {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector: string;
    /** The requirements for OAuth credentials. */
    oauth?: OAuthRequirements;
    /**
     * If true, the service accepts API keys without any other credential.
     * This flag only applies to HTTP and gRPC requests.
     */
    allowWithoutCredential: boolean;
    /** Requirements for additional authentication providers. */
    requirements: AuthRequirement[];
}
export interface AuthenticationRuleProtoMsg {
    typeUrl: "/google.api.AuthenticationRule";
    value: Uint8Array;
}
/**
 * Authentication rules for the service.
 *
 * By default, if a method has any authentication requirements, every request
 * must include a valid credential matching one of the requirements.
 * It's an error to include more than one kind of credential in a single
 * request.
 *
 * If a method doesn't have any auth requirements, request credentials will be
 * ignored.
 */
export interface AuthenticationRuleAmino {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector?: string;
    /** The requirements for OAuth credentials. */
    oauth?: OAuthRequirementsAmino;
    /**
     * If true, the service accepts API keys without any other credential.
     * This flag only applies to HTTP and gRPC requests.
     */
    allow_without_credential?: boolean;
    /** Requirements for additional authentication providers. */
    requirements?: AuthRequirementAmino[];
}
export interface AuthenticationRuleAminoMsg {
    type: "/google.api.AuthenticationRule";
    value: AuthenticationRuleAmino;
}
/**
 * Authentication rules for the service.
 *
 * By default, if a method has any authentication requirements, every request
 * must include a valid credential matching one of the requirements.
 * It's an error to include more than one kind of credential in a single
 * request.
 *
 * If a method doesn't have any auth requirements, request credentials will be
 * ignored.
 */
export interface AuthenticationRuleSDKType {
    selector: string;
    oauth?: OAuthRequirementsSDKType;
    allow_without_credential: boolean;
    requirements: AuthRequirementSDKType[];
}
/** Specifies a location to extract JWT from an API request. */
export interface JwtLocation {
    /** Specifies HTTP header name to extract JWT token. */
    header?: string;
    /** Specifies URL query parameter name to extract JWT token. */
    query?: string;
    /**
     * The value prefix. The value format is "value_prefix{token}"
     * Only applies to "in" header type. Must be empty for "in" query type.
     * If not empty, the header value has to match (case sensitive) this prefix.
     * If not matched, JWT will not be extracted. If matched, JWT will be
     * extracted after the prefix is removed.
     *
     * For example, for "Authorization: Bearer {JWT}",
     * value_prefix="Bearer " with a space at the end.
     */
    valuePrefix: string;
}
export interface JwtLocationProtoMsg {
    typeUrl: "/google.api.JwtLocation";
    value: Uint8Array;
}
/** Specifies a location to extract JWT from an API request. */
export interface JwtLocationAmino {
    /** Specifies HTTP header name to extract JWT token. */
    header?: string;
    /** Specifies URL query parameter name to extract JWT token. */
    query?: string;
    /**
     * The value prefix. The value format is "value_prefix{token}"
     * Only applies to "in" header type. Must be empty for "in" query type.
     * If not empty, the header value has to match (case sensitive) this prefix.
     * If not matched, JWT will not be extracted. If matched, JWT will be
     * extracted after the prefix is removed.
     *
     * For example, for "Authorization: Bearer {JWT}",
     * value_prefix="Bearer " with a space at the end.
     */
    value_prefix?: string;
}
export interface JwtLocationAminoMsg {
    type: "/google.api.JwtLocation";
    value: JwtLocationAmino;
}
/** Specifies a location to extract JWT from an API request. */
export interface JwtLocationSDKType {
    header?: string;
    query?: string;
    value_prefix: string;
}
/**
 * Configuration for an authentication provider, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthProvider {
    /**
     * The unique identifier of the auth provider. It will be referred to by
     * `AuthRequirement.provider_id`.
     *
     * Example: "bookstore_auth".
     */
    id: string;
    /**
     * Identifies the principal that issued the JWT. See
     * https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.1
     * Usually a URL or an email address.
     *
     * Example: https://securetoken.google.com
     * Example: 1234567-compute@developer.gserviceaccount.com
     */
    issuer: string;
    /**
     * URL of the provider's public key set to validate signature of the JWT. See
     * [OpenID
     * Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata).
     * Optional if the key set document:
     *  - can be retrieved from
     *    [OpenID
     *    Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html)
     *    of the issuer.
     *  - can be inferred from the email domain of the issuer (e.g. a Google
     *  service account).
     *
     * Example: https://www.googleapis.com/oauth2/v1/certs
     */
    jwksUri: string;
    /**
     * The list of JWT
     * [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).
     * that are allowed to access. A JWT containing any of these audiences will
     * be accepted. When this setting is absent, JWTs with audiences:
     *   - "https://[service.name]/[google.protobuf.Api.name]"
     *   - "https://[service.name]/"
     * will be accepted.
     * For example, if no audiences are in the setting, LibraryService API will
     * accept JWTs with the following audiences:
     *   -
     *   https://library-example.googleapis.com/google.example.library.v1.LibraryService
     *   - https://library-example.googleapis.com/
     *
     * Example:
     *
     *     audiences: bookstore_android.apps.googleusercontent.com,
     *                bookstore_web.apps.googleusercontent.com
     */
    audiences: string;
    /**
     * Redirect URL if JWT token is required but not present or is expired.
     * Implement authorizationUrl of securityDefinitions in OpenAPI spec.
     */
    authorizationUrl: string;
    /**
     * Defines the locations to extract the JWT.
     *
     * JWT locations can be either from HTTP headers or URL query parameters.
     * The rule is that the first match wins. The checking order is: checking
     * all headers first, then URL query parameters.
     *
     * If not specified,  default to use following 3 locations:
     *    1) Authorization: Bearer
     *    2) x-goog-iap-jwt-assertion
     *    3) access_token query parameter
     *
     * Default locations can be specified as followings:
     *    jwt_locations:
     *    - header: Authorization
     *      value_prefix: "Bearer "
     *    - header: x-goog-iap-jwt-assertion
     *    - query: access_token
     */
    jwtLocations: JwtLocation[];
}
export interface AuthProviderProtoMsg {
    typeUrl: "/google.api.AuthProvider";
    value: Uint8Array;
}
/**
 * Configuration for an authentication provider, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthProviderAmino {
    /**
     * The unique identifier of the auth provider. It will be referred to by
     * `AuthRequirement.provider_id`.
     *
     * Example: "bookstore_auth".
     */
    id?: string;
    /**
     * Identifies the principal that issued the JWT. See
     * https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.1
     * Usually a URL or an email address.
     *
     * Example: https://securetoken.google.com
     * Example: 1234567-compute@developer.gserviceaccount.com
     */
    issuer?: string;
    /**
     * URL of the provider's public key set to validate signature of the JWT. See
     * [OpenID
     * Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata).
     * Optional if the key set document:
     *  - can be retrieved from
     *    [OpenID
     *    Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html)
     *    of the issuer.
     *  - can be inferred from the email domain of the issuer (e.g. a Google
     *  service account).
     *
     * Example: https://www.googleapis.com/oauth2/v1/certs
     */
    jwks_uri?: string;
    /**
     * The list of JWT
     * [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).
     * that are allowed to access. A JWT containing any of these audiences will
     * be accepted. When this setting is absent, JWTs with audiences:
     *   - "https://[service.name]/[google.protobuf.Api.name]"
     *   - "https://[service.name]/"
     * will be accepted.
     * For example, if no audiences are in the setting, LibraryService API will
     * accept JWTs with the following audiences:
     *   -
     *   https://library-example.googleapis.com/google.example.library.v1.LibraryService
     *   - https://library-example.googleapis.com/
     *
     * Example:
     *
     *     audiences: bookstore_android.apps.googleusercontent.com,
     *                bookstore_web.apps.googleusercontent.com
     */
    audiences?: string;
    /**
     * Redirect URL if JWT token is required but not present or is expired.
     * Implement authorizationUrl of securityDefinitions in OpenAPI spec.
     */
    authorization_url?: string;
    /**
     * Defines the locations to extract the JWT.
     *
     * JWT locations can be either from HTTP headers or URL query parameters.
     * The rule is that the first match wins. The checking order is: checking
     * all headers first, then URL query parameters.
     *
     * If not specified,  default to use following 3 locations:
     *    1) Authorization: Bearer
     *    2) x-goog-iap-jwt-assertion
     *    3) access_token query parameter
     *
     * Default locations can be specified as followings:
     *    jwt_locations:
     *    - header: Authorization
     *      value_prefix: "Bearer "
     *    - header: x-goog-iap-jwt-assertion
     *    - query: access_token
     */
    jwt_locations?: JwtLocationAmino[];
}
export interface AuthProviderAminoMsg {
    type: "/google.api.AuthProvider";
    value: AuthProviderAmino;
}
/**
 * Configuration for an authentication provider, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthProviderSDKType {
    id: string;
    issuer: string;
    jwks_uri: string;
    audiences: string;
    authorization_url: string;
    jwt_locations: JwtLocationSDKType[];
}
/**
 * OAuth scopes are a way to define data and permissions on data. For example,
 * there are scopes defined for "Read-only access to Google Calendar" and
 * "Access to Cloud Platform". Users can consent to a scope for an application,
 * giving it permission to access that data on their behalf.
 *
 * OAuth scope specifications should be fairly coarse grained; a user will need
 * to see and understand the text description of what your scope means.
 *
 * In most cases: use one or at most two OAuth scopes for an entire family of
 * products. If your product has multiple APIs, you should probably be sharing
 * the OAuth scope across all of those APIs.
 *
 * When you need finer grained OAuth consent screens: talk with your product
 * management about how developers will use them in practice.
 *
 * Please note that even though each of the canonical scopes is enough for a
 * request to be accepted and passed to the backend, a request can still fail
 * due to the backend requiring additional scopes or permissions.
 */
export interface OAuthRequirements {
    /**
     * The list of publicly documented OAuth scopes that are allowed access. An
     * OAuth token containing any of these scopes will be accepted.
     *
     * Example:
     *
     *      canonical_scopes: https://www.googleapis.com/auth/calendar,
     *                        https://www.googleapis.com/auth/calendar.read
     */
    canonicalScopes: string;
}
export interface OAuthRequirementsProtoMsg {
    typeUrl: "/google.api.OAuthRequirements";
    value: Uint8Array;
}
/**
 * OAuth scopes are a way to define data and permissions on data. For example,
 * there are scopes defined for "Read-only access to Google Calendar" and
 * "Access to Cloud Platform". Users can consent to a scope for an application,
 * giving it permission to access that data on their behalf.
 *
 * OAuth scope specifications should be fairly coarse grained; a user will need
 * to see and understand the text description of what your scope means.
 *
 * In most cases: use one or at most two OAuth scopes for an entire family of
 * products. If your product has multiple APIs, you should probably be sharing
 * the OAuth scope across all of those APIs.
 *
 * When you need finer grained OAuth consent screens: talk with your product
 * management about how developers will use them in practice.
 *
 * Please note that even though each of the canonical scopes is enough for a
 * request to be accepted and passed to the backend, a request can still fail
 * due to the backend requiring additional scopes or permissions.
 */
export interface OAuthRequirementsAmino {
    /**
     * The list of publicly documented OAuth scopes that are allowed access. An
     * OAuth token containing any of these scopes will be accepted.
     *
     * Example:
     *
     *      canonical_scopes: https://www.googleapis.com/auth/calendar,
     *                        https://www.googleapis.com/auth/calendar.read
     */
    canonical_scopes?: string;
}
export interface OAuthRequirementsAminoMsg {
    type: "/google.api.OAuthRequirements";
    value: OAuthRequirementsAmino;
}
/**
 * OAuth scopes are a way to define data and permissions on data. For example,
 * there are scopes defined for "Read-only access to Google Calendar" and
 * "Access to Cloud Platform". Users can consent to a scope for an application,
 * giving it permission to access that data on their behalf.
 *
 * OAuth scope specifications should be fairly coarse grained; a user will need
 * to see and understand the text description of what your scope means.
 *
 * In most cases: use one or at most two OAuth scopes for an entire family of
 * products. If your product has multiple APIs, you should probably be sharing
 * the OAuth scope across all of those APIs.
 *
 * When you need finer grained OAuth consent screens: talk with your product
 * management about how developers will use them in practice.
 *
 * Please note that even though each of the canonical scopes is enough for a
 * request to be accepted and passed to the backend, a request can still fail
 * due to the backend requiring additional scopes or permissions.
 */
export interface OAuthRequirementsSDKType {
    canonical_scopes: string;
}
/**
 * User-defined authentication requirements, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthRequirement {
    /**
     * [id][google.api.AuthProvider.id] from authentication provider.
     *
     * Example:
     *
     *     provider_id: bookstore_auth
     */
    providerId: string;
    /**
     * NOTE: This will be deprecated soon, once AuthProvider.audiences is
     * implemented and accepted in all the runtime components.
     *
     * The list of JWT
     * [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).
     * that are allowed to access. A JWT containing any of these audiences will
     * be accepted. When this setting is absent, only JWTs with audience
     * "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]"
     * will be accepted. For example, if no audiences are in the setting,
     * LibraryService API will only accept JWTs with the following audience
     * "https://library-example.googleapis.com/google.example.library.v1.LibraryService".
     *
     * Example:
     *
     *     audiences: bookstore_android.apps.googleusercontent.com,
     *                bookstore_web.apps.googleusercontent.com
     */
    audiences: string;
}
export interface AuthRequirementProtoMsg {
    typeUrl: "/google.api.AuthRequirement";
    value: Uint8Array;
}
/**
 * User-defined authentication requirements, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthRequirementAmino {
    /**
     * [id][google.api.AuthProvider.id] from authentication provider.
     *
     * Example:
     *
     *     provider_id: bookstore_auth
     */
    provider_id?: string;
    /**
     * NOTE: This will be deprecated soon, once AuthProvider.audiences is
     * implemented and accepted in all the runtime components.
     *
     * The list of JWT
     * [audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).
     * that are allowed to access. A JWT containing any of these audiences will
     * be accepted. When this setting is absent, only JWTs with audience
     * "https://[Service_name][google.api.Service.name]/[API_name][google.protobuf.Api.name]"
     * will be accepted. For example, if no audiences are in the setting,
     * LibraryService API will only accept JWTs with the following audience
     * "https://library-example.googleapis.com/google.example.library.v1.LibraryService".
     *
     * Example:
     *
     *     audiences: bookstore_android.apps.googleusercontent.com,
     *                bookstore_web.apps.googleusercontent.com
     */
    audiences?: string;
}
export interface AuthRequirementAminoMsg {
    type: "/google.api.AuthRequirement";
    value: AuthRequirementAmino;
}
/**
 * User-defined authentication requirements, including support for
 * [JSON Web Token
 * (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
 */
export interface AuthRequirementSDKType {
    provider_id: string;
    audiences: string;
}
export declare const Authentication: {
    typeUrl: string;
    is(o: any): o is Authentication;
    isSDK(o: any): o is AuthenticationSDKType;
    isAmino(o: any): o is AuthenticationAmino;
    encode(message: Authentication, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Authentication;
    fromJSON(object: any): Authentication;
    toJSON(message: Authentication): JsonSafe<Authentication>;
    fromPartial(object: DeepPartial<Authentication>): Authentication;
    fromSDK(object: AuthenticationSDKType): Authentication;
    fromSDKJSON(object: any): AuthenticationSDKType;
    toSDK(message: Authentication): AuthenticationSDKType;
    fromAmino(object: AuthenticationAmino): Authentication;
    toAmino(message: Authentication): AuthenticationAmino;
    fromAminoMsg(object: AuthenticationAminoMsg): Authentication;
    fromProtoMsg(message: AuthenticationProtoMsg): Authentication;
    toProto(message: Authentication): Uint8Array;
    toProtoMsg(message: Authentication): AuthenticationProtoMsg;
    registerTypeUrl(): void;
};
export declare const AuthenticationRule: {
    typeUrl: string;
    is(o: any): o is AuthenticationRule;
    isSDK(o: any): o is AuthenticationRuleSDKType;
    isAmino(o: any): o is AuthenticationRuleAmino;
    encode(message: AuthenticationRule, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AuthenticationRule;
    fromJSON(object: any): AuthenticationRule;
    toJSON(message: AuthenticationRule): JsonSafe<AuthenticationRule>;
    fromPartial(object: DeepPartial<AuthenticationRule>): AuthenticationRule;
    fromSDK(object: AuthenticationRuleSDKType): AuthenticationRule;
    fromSDKJSON(object: any): AuthenticationRuleSDKType;
    toSDK(message: AuthenticationRule): AuthenticationRuleSDKType;
    fromAmino(object: AuthenticationRuleAmino): AuthenticationRule;
    toAmino(message: AuthenticationRule): AuthenticationRuleAmino;
    fromAminoMsg(object: AuthenticationRuleAminoMsg): AuthenticationRule;
    fromProtoMsg(message: AuthenticationRuleProtoMsg): AuthenticationRule;
    toProto(message: AuthenticationRule): Uint8Array;
    toProtoMsg(message: AuthenticationRule): AuthenticationRuleProtoMsg;
    registerTypeUrl(): void;
};
export declare const JwtLocation: {
    typeUrl: string;
    is(o: any): o is JwtLocation;
    isSDK(o: any): o is JwtLocationSDKType;
    isAmino(o: any): o is JwtLocationAmino;
    encode(message: JwtLocation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): JwtLocation;
    fromJSON(object: any): JwtLocation;
    toJSON(message: JwtLocation): JsonSafe<JwtLocation>;
    fromPartial(object: DeepPartial<JwtLocation>): JwtLocation;
    fromSDK(object: JwtLocationSDKType): JwtLocation;
    fromSDKJSON(object: any): JwtLocationSDKType;
    toSDK(message: JwtLocation): JwtLocationSDKType;
    fromAmino(object: JwtLocationAmino): JwtLocation;
    toAmino(message: JwtLocation): JwtLocationAmino;
    fromAminoMsg(object: JwtLocationAminoMsg): JwtLocation;
    fromProtoMsg(message: JwtLocationProtoMsg): JwtLocation;
    toProto(message: JwtLocation): Uint8Array;
    toProtoMsg(message: JwtLocation): JwtLocationProtoMsg;
    registerTypeUrl(): void;
};
export declare const AuthProvider: {
    typeUrl: string;
    is(o: any): o is AuthProvider;
    isSDK(o: any): o is AuthProviderSDKType;
    isAmino(o: any): o is AuthProviderAmino;
    encode(message: AuthProvider, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AuthProvider;
    fromJSON(object: any): AuthProvider;
    toJSON(message: AuthProvider): JsonSafe<AuthProvider>;
    fromPartial(object: DeepPartial<AuthProvider>): AuthProvider;
    fromSDK(object: AuthProviderSDKType): AuthProvider;
    fromSDKJSON(object: any): AuthProviderSDKType;
    toSDK(message: AuthProvider): AuthProviderSDKType;
    fromAmino(object: AuthProviderAmino): AuthProvider;
    toAmino(message: AuthProvider): AuthProviderAmino;
    fromAminoMsg(object: AuthProviderAminoMsg): AuthProvider;
    fromProtoMsg(message: AuthProviderProtoMsg): AuthProvider;
    toProto(message: AuthProvider): Uint8Array;
    toProtoMsg(message: AuthProvider): AuthProviderProtoMsg;
    registerTypeUrl(): void;
};
export declare const OAuthRequirements: {
    typeUrl: string;
    is(o: any): o is OAuthRequirements;
    isSDK(o: any): o is OAuthRequirementsSDKType;
    isAmino(o: any): o is OAuthRequirementsAmino;
    encode(message: OAuthRequirements, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OAuthRequirements;
    fromJSON(object: any): OAuthRequirements;
    toJSON(message: OAuthRequirements): JsonSafe<OAuthRequirements>;
    fromPartial(object: DeepPartial<OAuthRequirements>): OAuthRequirements;
    fromSDK(object: OAuthRequirementsSDKType): OAuthRequirements;
    fromSDKJSON(object: any): OAuthRequirementsSDKType;
    toSDK(message: OAuthRequirements): OAuthRequirementsSDKType;
    fromAmino(object: OAuthRequirementsAmino): OAuthRequirements;
    toAmino(message: OAuthRequirements): OAuthRequirementsAmino;
    fromAminoMsg(object: OAuthRequirementsAminoMsg): OAuthRequirements;
    fromProtoMsg(message: OAuthRequirementsProtoMsg): OAuthRequirements;
    toProto(message: OAuthRequirements): Uint8Array;
    toProtoMsg(message: OAuthRequirements): OAuthRequirementsProtoMsg;
    registerTypeUrl(): void;
};
export declare const AuthRequirement: {
    typeUrl: string;
    is(o: any): o is AuthRequirement;
    isSDK(o: any): o is AuthRequirementSDKType;
    isAmino(o: any): o is AuthRequirementAmino;
    encode(message: AuthRequirement, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AuthRequirement;
    fromJSON(object: any): AuthRequirement;
    toJSON(message: AuthRequirement): JsonSafe<AuthRequirement>;
    fromPartial(object: DeepPartial<AuthRequirement>): AuthRequirement;
    fromSDK(object: AuthRequirementSDKType): AuthRequirement;
    fromSDKJSON(object: any): AuthRequirementSDKType;
    toSDK(message: AuthRequirement): AuthRequirementSDKType;
    fromAmino(object: AuthRequirementAmino): AuthRequirement;
    toAmino(message: AuthRequirement): AuthRequirementAmino;
    fromAminoMsg(object: AuthRequirementAminoMsg): AuthRequirement;
    fromProtoMsg(message: AuthRequirementProtoMsg): AuthRequirement;
    toProto(message: AuthRequirement): Uint8Array;
    toProtoMsg(message: AuthRequirement): AuthRequirementProtoMsg;
    registerTypeUrl(): void;
};
