import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * Billing related configuration of the service.
 *
 * The following example shows how to configure monitored resources and metrics
 * for billing, `consumer_destinations` is the only supported destination and
 * the monitored resources need at least one label key
 * `cloud.googleapis.com/location` to indicate the location of the billing
 * usage, using different monitored resources between monitoring and billing is
 * recommended so they can be evolved independently:
 *
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/billing_branch
 *       labels:
 *       - key: cloud.googleapis.com/location
 *         description: |
 *           Predefined label to support billing location restriction.
 *       - key: city
 *         description: |
 *           Custom label to define the city where the library branch is located
 *           in.
 *       - key: name
 *         description: Custom label to define the name of the library branch.
 *     metrics:
 *     - name: library.googleapis.com/book/borrowed_count
 *       metric_kind: DELTA
 *       value_type: INT64
 *       unit: "1"
 *     billing:
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/billing_branch
 *         metrics:
 *         - library.googleapis.com/book/borrowed_count
 */
export interface Billing {
    /**
     * Billing configurations for sending metrics to the consumer project.
     * There can be multiple consumer destinations per service, each one must have
     * a different monitored resource type. A metric can be used in at most
     * one consumer destination.
     */
    consumerDestinations: Billing_BillingDestination[];
}
export interface BillingProtoMsg {
    typeUrl: "/google.api.Billing";
    value: Uint8Array;
}
/**
 * Billing related configuration of the service.
 *
 * The following example shows how to configure monitored resources and metrics
 * for billing, `consumer_destinations` is the only supported destination and
 * the monitored resources need at least one label key
 * `cloud.googleapis.com/location` to indicate the location of the billing
 * usage, using different monitored resources between monitoring and billing is
 * recommended so they can be evolved independently:
 *
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/billing_branch
 *       labels:
 *       - key: cloud.googleapis.com/location
 *         description: |
 *           Predefined label to support billing location restriction.
 *       - key: city
 *         description: |
 *           Custom label to define the city where the library branch is located
 *           in.
 *       - key: name
 *         description: Custom label to define the name of the library branch.
 *     metrics:
 *     - name: library.googleapis.com/book/borrowed_count
 *       metric_kind: DELTA
 *       value_type: INT64
 *       unit: "1"
 *     billing:
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/billing_branch
 *         metrics:
 *         - library.googleapis.com/book/borrowed_count
 */
export interface BillingAmino {
    /**
     * Billing configurations for sending metrics to the consumer project.
     * There can be multiple consumer destinations per service, each one must have
     * a different monitored resource type. A metric can be used in at most
     * one consumer destination.
     */
    consumer_destinations?: Billing_BillingDestinationAmino[];
}
export interface BillingAminoMsg {
    type: "/google.api.Billing";
    value: BillingAmino;
}
/**
 * Billing related configuration of the service.
 *
 * The following example shows how to configure monitored resources and metrics
 * for billing, `consumer_destinations` is the only supported destination and
 * the monitored resources need at least one label key
 * `cloud.googleapis.com/location` to indicate the location of the billing
 * usage, using different monitored resources between monitoring and billing is
 * recommended so they can be evolved independently:
 *
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/billing_branch
 *       labels:
 *       - key: cloud.googleapis.com/location
 *         description: |
 *           Predefined label to support billing location restriction.
 *       - key: city
 *         description: |
 *           Custom label to define the city where the library branch is located
 *           in.
 *       - key: name
 *         description: Custom label to define the name of the library branch.
 *     metrics:
 *     - name: library.googleapis.com/book/borrowed_count
 *       metric_kind: DELTA
 *       value_type: INT64
 *       unit: "1"
 *     billing:
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/billing_branch
 *         metrics:
 *         - library.googleapis.com/book/borrowed_count
 */
export interface BillingSDKType {
    consumer_destinations: Billing_BillingDestinationSDKType[];
}
/**
 * Configuration of a specific billing destination (Currently only support
 * bill against consumer project).
 */
export interface Billing_BillingDestination {
    /**
     * The monitored resource type. The type must be defined in
     * [Service.monitored_resources][google.api.Service.monitored_resources] section.
     */
    monitoredResource: string;
    /**
     * Names of the metrics to report to this billing destination.
     * Each name must be defined in [Service.metrics][google.api.Service.metrics] section.
     */
    metrics: string[];
}
export interface Billing_BillingDestinationProtoMsg {
    typeUrl: "/google.api.BillingDestination";
    value: Uint8Array;
}
/**
 * Configuration of a specific billing destination (Currently only support
 * bill against consumer project).
 */
export interface Billing_BillingDestinationAmino {
    /**
     * The monitored resource type. The type must be defined in
     * [Service.monitored_resources][google.api.Service.monitored_resources] section.
     */
    monitored_resource?: string;
    /**
     * Names of the metrics to report to this billing destination.
     * Each name must be defined in [Service.metrics][google.api.Service.metrics] section.
     */
    metrics?: string[];
}
export interface Billing_BillingDestinationAminoMsg {
    type: "/google.api.BillingDestination";
    value: Billing_BillingDestinationAmino;
}
/**
 * Configuration of a specific billing destination (Currently only support
 * bill against consumer project).
 */
export interface Billing_BillingDestinationSDKType {
    monitored_resource: string;
    metrics: string[];
}
export declare const Billing: {
    typeUrl: string;
    is(o: any): o is Billing;
    isSDK(o: any): o is BillingSDKType;
    isAmino(o: any): o is BillingAmino;
    encode(message: Billing, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Billing;
    fromJSON(object: any): Billing;
    toJSON(message: Billing): JsonSafe<Billing>;
    fromPartial(object: DeepPartial<Billing>): Billing;
    fromSDK(object: BillingSDKType): Billing;
    fromSDKJSON(object: any): BillingSDKType;
    toSDK(message: Billing): BillingSDKType;
    fromAmino(object: BillingAmino): Billing;
    toAmino(message: Billing): BillingAmino;
    fromAminoMsg(object: BillingAminoMsg): Billing;
    fromProtoMsg(message: BillingProtoMsg): Billing;
    toProto(message: Billing): Uint8Array;
    toProtoMsg(message: Billing): BillingProtoMsg;
    registerTypeUrl(): void;
};
export declare const Billing_BillingDestination: {
    typeUrl: string;
    is(o: any): o is Billing_BillingDestination;
    isSDK(o: any): o is Billing_BillingDestinationSDKType;
    isAmino(o: any): o is Billing_BillingDestinationAmino;
    encode(message: Billing_BillingDestination, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Billing_BillingDestination;
    fromJSON(object: any): Billing_BillingDestination;
    toJSON(message: Billing_BillingDestination): JsonSafe<Billing_BillingDestination>;
    fromPartial(object: DeepPartial<Billing_BillingDestination>): Billing_BillingDestination;
    fromSDK(object: Billing_BillingDestinationSDKType): Billing_BillingDestination;
    fromSDKJSON(object: any): Billing_BillingDestinationSDKType;
    toSDK(message: Billing_BillingDestination): Billing_BillingDestinationSDKType;
    fromAmino(object: Billing_BillingDestinationAmino): Billing_BillingDestination;
    toAmino(message: Billing_BillingDestination): Billing_BillingDestinationAmino;
    fromAminoMsg(object: Billing_BillingDestinationAminoMsg): Billing_BillingDestination;
    fromProtoMsg(message: Billing_BillingDestinationProtoMsg): Billing_BillingDestination;
    toProto(message: Billing_BillingDestination): Uint8Array;
    toProtoMsg(message: Billing_BillingDestination): Billing_BillingDestinationProtoMsg;
    registerTypeUrl(): void;
};
