import { isSet } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
export const protobufPackage = "google.api";
/**
 * Classifies set of possible modifications to an object in the service
 * configuration.
 */
export var ChangeType;
(function (ChangeType) {
    /** CHANGE_TYPE_UNSPECIFIED - No value was provided. */
    ChangeType[ChangeType["CHANGE_TYPE_UNSPECIFIED"] = 0] = "CHANGE_TYPE_UNSPECIFIED";
    /**
     * ADDED - The changed object exists in the 'new' service configuration, but not
     * in the 'old' service configuration.
     */
    ChangeType[ChangeType["ADDED"] = 1] = "ADDED";
    /**
     * REMOVED - The changed object exists in the 'old' service configuration, but not
     * in the 'new' service configuration.
     */
    ChangeType[ChangeType["REMOVED"] = 2] = "REMOVED";
    /**
     * MODIFIED - The changed object exists in both service configurations, but its value
     * is different.
     */
    ChangeType[ChangeType["MODIFIED"] = 3] = "MODIFIED";
    ChangeType[ChangeType["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(ChangeType || (ChangeType = {}));
export const ChangeTypeSDKType = ChangeType;
export const ChangeTypeAmino = ChangeType;
export function changeTypeFromJSON(object) {
    switch (object) {
        case 0:
        case "CHANGE_TYPE_UNSPECIFIED":
            return ChangeType.CHANGE_TYPE_UNSPECIFIED;
        case 1:
        case "ADDED":
            return ChangeType.ADDED;
        case 2:
        case "REMOVED":
            return ChangeType.REMOVED;
        case 3:
        case "MODIFIED":
            return ChangeType.MODIFIED;
        case -1:
        case "UNRECOGNIZED":
        default:
            return ChangeType.UNRECOGNIZED;
    }
}
export function changeTypeToJSON(object) {
    switch (object) {
        case ChangeType.CHANGE_TYPE_UNSPECIFIED:
            return "CHANGE_TYPE_UNSPECIFIED";
        case ChangeType.ADDED:
            return "ADDED";
        case ChangeType.REMOVED:
            return "REMOVED";
        case ChangeType.MODIFIED:
            return "MODIFIED";
        case ChangeType.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseConfigChange() {
    return {
        element: "",
        oldValue: "",
        newValue: "",
        changeType: 0,
        advices: []
    };
}
export const ConfigChange = {
    typeUrl: "/google.api.ConfigChange",
    is(o) {
        return o && (o.$typeUrl === ConfigChange.typeUrl || typeof o.element === "string" && typeof o.oldValue === "string" && typeof o.newValue === "string" && isSet(o.changeType) && Array.isArray(o.advices) && (!o.advices.length || Advice.is(o.advices[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ConfigChange.typeUrl || typeof o.element === "string" && typeof o.old_value === "string" && typeof o.new_value === "string" && isSet(o.change_type) && Array.isArray(o.advices) && (!o.advices.length || Advice.isSDK(o.advices[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ConfigChange.typeUrl || typeof o.element === "string" && typeof o.old_value === "string" && typeof o.new_value === "string" && isSet(o.change_type) && Array.isArray(o.advices) && (!o.advices.length || Advice.isAmino(o.advices[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.element !== undefined) {
            writer.uint32(10).string(message.element);
        }
        if (message.oldValue !== undefined) {
            writer.uint32(18).string(message.oldValue);
        }
        if (message.newValue !== undefined) {
            writer.uint32(26).string(message.newValue);
        }
        if (message.changeType !== 0) {
            writer.uint32(32).int32(message.changeType);
        }
        for (const v of message.advices) {
            Advice.encode(v, writer.uint32(42).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseConfigChange();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.element = reader.string();
                    break;
                case 2:
                    message.oldValue = reader.string();
                    break;
                case 3:
                    message.newValue = reader.string();
                    break;
                case 4:
                    message.changeType = reader.int32();
                    break;
                case 5:
                    message.advices.push(Advice.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseConfigChange();
        if (isSet(object.element))
            obj.element = String(object.element);
        if (isSet(object.oldValue))
            obj.oldValue = String(object.oldValue);
        if (isSet(object.newValue))
            obj.newValue = String(object.newValue);
        if (isSet(object.changeType))
            obj.changeType = changeTypeFromJSON(object.changeType);
        if (Array.isArray(object?.advices))
            obj.advices = object.advices.map((e) => Advice.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.element !== undefined && (obj.element = message.element);
        message.oldValue !== undefined && (obj.oldValue = message.oldValue);
        message.newValue !== undefined && (obj.newValue = message.newValue);
        message.changeType !== undefined && (obj.changeType = changeTypeToJSON(message.changeType));
        if (message.advices) {
            obj.advices = message.advices.map(e => e ? Advice.toJSON(e) : undefined);
        }
        else {
            obj.advices = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseConfigChange();
        message.element = object.element ?? "";
        message.oldValue = object.oldValue ?? "";
        message.newValue = object.newValue ?? "";
        message.changeType = object.changeType ?? 0;
        message.advices = object.advices?.map(e => Advice.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            element: object?.element,
            oldValue: object?.old_value,
            newValue: object?.new_value,
            changeType: isSet(object.change_type) ? changeTypeFromJSON(object.change_type) : -1,
            advices: Array.isArray(object?.advices) ? object.advices.map((e) => Advice.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            element: isSet(object.element) ? String(object.element) : "",
            old_value: isSet(object.old_value) ? String(object.old_value) : "",
            new_value: isSet(object.new_value) ? String(object.new_value) : "",
            change_type: isSet(object.change_type) ? changeTypeFromJSON(object.change_type) : -1,
            advices: Array.isArray(object?.advices) ? object.advices.map((e) => Advice.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        obj.element = message.element;
        obj.old_value = message.oldValue;
        obj.new_value = message.newValue;
        message.changeType !== undefined && (obj.change_type = changeTypeToJSON(message.changeType));
        if (message.advices) {
            obj.advices = message.advices.map(e => e ? Advice.toSDK(e) : undefined);
        }
        else {
            obj.advices = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseConfigChange();
        if (object.element !== undefined && object.element !== null) {
            message.element = object.element;
        }
        if (object.old_value !== undefined && object.old_value !== null) {
            message.oldValue = object.old_value;
        }
        if (object.new_value !== undefined && object.new_value !== null) {
            message.newValue = object.new_value;
        }
        if (object.change_type !== undefined && object.change_type !== null) {
            message.changeType = object.change_type;
        }
        message.advices = object.advices?.map(e => Advice.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.element = message.element === "" ? undefined : message.element;
        obj.old_value = message.oldValue === "" ? undefined : message.oldValue;
        obj.new_value = message.newValue === "" ? undefined : message.newValue;
        obj.change_type = message.changeType === 0 ? undefined : message.changeType;
        if (message.advices) {
            obj.advices = message.advices.map(e => e ? Advice.toAmino(e) : undefined);
        }
        else {
            obj.advices = message.advices;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ConfigChange.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ConfigChange.decode(message.value);
    },
    toProto(message) {
        return ConfigChange.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.ConfigChange",
            value: ConfigChange.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Advice.registerTypeUrl();
    }
};
function createBaseAdvice() {
    return {
        description: ""
    };
}
export const Advice = {
    typeUrl: "/google.api.Advice",
    is(o) {
        return o && (o.$typeUrl === Advice.typeUrl || typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Advice.typeUrl || typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Advice.typeUrl || typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseAdvice();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 2:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseAdvice();
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseAdvice();
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseAdvice();
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return Advice.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Advice.decode(message.value);
    },
    toProto(message) {
        return Advice.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.Advice",
            value: Advice.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
