import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/** Supported data type of the property values */
export declare enum Property_PropertyType {
    /** UNSPECIFIED - The type is unspecified, and will result in an error. */
    UNSPECIFIED = 0,
    /** INT64 - The type is `int64`. */
    INT64 = 1,
    /** BOOL - The type is `bool`. */
    BOOL = 2,
    /** STRING - The type is `string`. */
    STRING = 3,
    /** DOUBLE - The type is 'double'. */
    DOUBLE = 4,
    UNRECOGNIZED = -1
}
export declare const Property_PropertyTypeSDKType: typeof Property_PropertyType;
export declare const Property_PropertyTypeAmino: typeof Property_PropertyType;
export declare function property_PropertyTypeFromJSON(object: any): Property_PropertyType;
export declare function property_PropertyTypeToJSON(object: Property_PropertyType): string;
/**
 * A descriptor for defining project properties for a service. One service may
 * have many consumer projects, and the service may want to behave differently
 * depending on some properties on the project. For example, a project may be
 * associated with a school, or a business, or a government agency, a business
 * type property on the project may affect how a service responds to the client.
 * This descriptor defines which properties are allowed to be set on a project.
 *
 * Example:
 *
 *    project_properties:
 *      properties:
 *      - name: NO_WATERMARK
 *        type: BOOL
 *        description: Allows usage of the API without watermarks.
 *      - name: EXTENDED_TILE_CACHE_PERIOD
 *        type: INT64
 */
export interface ProjectProperties {
    /** List of per consumer project-specific properties. */
    properties: Property[];
}
export interface ProjectPropertiesProtoMsg {
    typeUrl: "/google.api.ProjectProperties";
    value: Uint8Array;
}
/**
 * A descriptor for defining project properties for a service. One service may
 * have many consumer projects, and the service may want to behave differently
 * depending on some properties on the project. For example, a project may be
 * associated with a school, or a business, or a government agency, a business
 * type property on the project may affect how a service responds to the client.
 * This descriptor defines which properties are allowed to be set on a project.
 *
 * Example:
 *
 *    project_properties:
 *      properties:
 *      - name: NO_WATERMARK
 *        type: BOOL
 *        description: Allows usage of the API without watermarks.
 *      - name: EXTENDED_TILE_CACHE_PERIOD
 *        type: INT64
 */
export interface ProjectPropertiesAmino {
    /** List of per consumer project-specific properties. */
    properties?: PropertyAmino[];
}
export interface ProjectPropertiesAminoMsg {
    type: "/google.api.ProjectProperties";
    value: ProjectPropertiesAmino;
}
/**
 * A descriptor for defining project properties for a service. One service may
 * have many consumer projects, and the service may want to behave differently
 * depending on some properties on the project. For example, a project may be
 * associated with a school, or a business, or a government agency, a business
 * type property on the project may affect how a service responds to the client.
 * This descriptor defines which properties are allowed to be set on a project.
 *
 * Example:
 *
 *    project_properties:
 *      properties:
 *      - name: NO_WATERMARK
 *        type: BOOL
 *        description: Allows usage of the API without watermarks.
 *      - name: EXTENDED_TILE_CACHE_PERIOD
 *        type: INT64
 */
export interface ProjectPropertiesSDKType {
    properties: PropertySDKType[];
}
/**
 * Defines project properties.
 *
 * API services can define properties that can be assigned to consumer projects
 * so that backends can perform response customization without having to make
 * additional calls or maintain additional storage. For example, Maps API
 * defines properties that controls map tile cache period, or whether to embed a
 * watermark in a result.
 *
 * These values can be set via API producer console. Only API providers can
 * define and set these properties.
 */
export interface Property {
    /** The name of the property (a.k.a key). */
    name: string;
    /** The type of this property. */
    type: Property_PropertyType;
    /** The description of the property */
    description: string;
}
export interface PropertyProtoMsg {
    typeUrl: "/google.api.Property";
    value: Uint8Array;
}
/**
 * Defines project properties.
 *
 * API services can define properties that can be assigned to consumer projects
 * so that backends can perform response customization without having to make
 * additional calls or maintain additional storage. For example, Maps API
 * defines properties that controls map tile cache period, or whether to embed a
 * watermark in a result.
 *
 * These values can be set via API producer console. Only API providers can
 * define and set these properties.
 */
export interface PropertyAmino {
    /** The name of the property (a.k.a key). */
    name?: string;
    /** The type of this property. */
    type?: Property_PropertyType;
    /** The description of the property */
    description?: string;
}
export interface PropertyAminoMsg {
    type: "/google.api.Property";
    value: PropertyAmino;
}
/**
 * Defines project properties.
 *
 * API services can define properties that can be assigned to consumer projects
 * so that backends can perform response customization without having to make
 * additional calls or maintain additional storage. For example, Maps API
 * defines properties that controls map tile cache period, or whether to embed a
 * watermark in a result.
 *
 * These values can be set via API producer console. Only API providers can
 * define and set these properties.
 */
export interface PropertySDKType {
    name: string;
    type: Property_PropertyType;
    description: string;
}
export declare const ProjectProperties: {
    typeUrl: string;
    is(o: any): o is ProjectProperties;
    isSDK(o: any): o is ProjectPropertiesSDKType;
    isAmino(o: any): o is ProjectPropertiesAmino;
    encode(message: ProjectProperties, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ProjectProperties;
    fromJSON(object: any): ProjectProperties;
    toJSON(message: ProjectProperties): JsonSafe<ProjectProperties>;
    fromPartial(object: DeepPartial<ProjectProperties>): ProjectProperties;
    fromSDK(object: ProjectPropertiesSDKType): ProjectProperties;
    fromSDKJSON(object: any): ProjectPropertiesSDKType;
    toSDK(message: ProjectProperties): ProjectPropertiesSDKType;
    fromAmino(object: ProjectPropertiesAmino): ProjectProperties;
    toAmino(message: ProjectProperties): ProjectPropertiesAmino;
    fromAminoMsg(object: ProjectPropertiesAminoMsg): ProjectProperties;
    fromProtoMsg(message: ProjectPropertiesProtoMsg): ProjectProperties;
    toProto(message: ProjectProperties): Uint8Array;
    toProtoMsg(message: ProjectProperties): ProjectPropertiesProtoMsg;
    registerTypeUrl(): void;
};
export declare const Property: {
    typeUrl: string;
    is(o: any): o is Property;
    isSDK(o: any): o is PropertySDKType;
    isAmino(o: any): o is PropertyAmino;
    encode(message: Property, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Property;
    fromJSON(object: any): Property;
    toJSON(message: Property): JsonSafe<Property>;
    fromPartial(object: DeepPartial<Property>): Property;
    fromSDK(object: PropertySDKType): Property;
    fromSDKJSON(object: any): PropertySDKType;
    toSDK(message: Property): PropertySDKType;
    fromAmino(object: PropertyAmino): Property;
    toAmino(message: Property): PropertyAmino;
    fromAminoMsg(object: PropertyAminoMsg): Property;
    fromProtoMsg(message: PropertyProtoMsg): Property;
    toProto(message: Property): Uint8Array;
    toProtoMsg(message: Property): PropertyProtoMsg;
    registerTypeUrl(): void;
};
