import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet } from "../../helpers";
export const protobufPackage = "google.api";
/** Supported data type of the property values */
export var Property_PropertyType;
(function (Property_PropertyType) {
    /** UNSPECIFIED - The type is unspecified, and will result in an error. */
    Property_PropertyType[Property_PropertyType["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /** INT64 - The type is `int64`. */
    Property_PropertyType[Property_PropertyType["INT64"] = 1] = "INT64";
    /** BOOL - The type is `bool`. */
    Property_PropertyType[Property_PropertyType["BOOL"] = 2] = "BOOL";
    /** STRING - The type is `string`. */
    Property_PropertyType[Property_PropertyType["STRING"] = 3] = "STRING";
    /** DOUBLE - The type is 'double'. */
    Property_PropertyType[Property_PropertyType["DOUBLE"] = 4] = "DOUBLE";
    Property_PropertyType[Property_PropertyType["UNRECOGNIZED"] = -1] = "UNRECOGNIZED";
})(Property_PropertyType || (Property_PropertyType = {}));
export const Property_PropertyTypeSDKType = Property_PropertyType;
export const Property_PropertyTypeAmino = Property_PropertyType;
export function property_PropertyTypeFromJSON(object) {
    switch (object) {
        case 0:
        case "UNSPECIFIED":
            return Property_PropertyType.UNSPECIFIED;
        case 1:
        case "INT64":
            return Property_PropertyType.INT64;
        case 2:
        case "BOOL":
            return Property_PropertyType.BOOL;
        case 3:
        case "STRING":
            return Property_PropertyType.STRING;
        case 4:
        case "DOUBLE":
            return Property_PropertyType.DOUBLE;
        case -1:
        case "UNRECOGNIZED":
        default:
            return Property_PropertyType.UNRECOGNIZED;
    }
}
export function property_PropertyTypeToJSON(object) {
    switch (object) {
        case Property_PropertyType.UNSPECIFIED:
            return "UNSPECIFIED";
        case Property_PropertyType.INT64:
            return "INT64";
        case Property_PropertyType.BOOL:
            return "BOOL";
        case Property_PropertyType.STRING:
            return "STRING";
        case Property_PropertyType.DOUBLE:
            return "DOUBLE";
        case Property_PropertyType.UNRECOGNIZED:
        default:
            return "UNRECOGNIZED";
    }
}
function createBaseProjectProperties() {
    return {
        properties: []
    };
}
export const ProjectProperties = {
    typeUrl: "/google.api.ProjectProperties",
    is(o) {
        return o && (o.$typeUrl === ProjectProperties.typeUrl || Array.isArray(o.properties) && (!o.properties.length || Property.is(o.properties[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ProjectProperties.typeUrl || Array.isArray(o.properties) && (!o.properties.length || Property.isSDK(o.properties[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ProjectProperties.typeUrl || Array.isArray(o.properties) && (!o.properties.length || Property.isAmino(o.properties[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.properties) {
            Property.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseProjectProperties();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.properties.push(Property.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseProjectProperties();
        if (Array.isArray(object?.properties))
            obj.properties = object.properties.map((e) => Property.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.properties) {
            obj.properties = message.properties.map(e => e ? Property.toJSON(e) : undefined);
        }
        else {
            obj.properties = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseProjectProperties();
        message.properties = object.properties?.map(e => Property.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            properties: Array.isArray(object?.properties) ? object.properties.map((e) => Property.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            properties: Array.isArray(object?.properties) ? object.properties.map((e) => Property.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.properties) {
            obj.properties = message.properties.map(e => e ? Property.toSDK(e) : undefined);
        }
        else {
            obj.properties = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseProjectProperties();
        message.properties = object.properties?.map(e => Property.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.properties) {
            obj.properties = message.properties.map(e => e ? Property.toAmino(e) : undefined);
        }
        else {
            obj.properties = message.properties;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ProjectProperties.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ProjectProperties.decode(message.value);
    },
    toProto(message) {
        return ProjectProperties.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.ProjectProperties",
            value: ProjectProperties.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Property.registerTypeUrl();
    }
};
function createBaseProperty() {
    return {
        name: "",
        type: 0,
        description: ""
    };
}
export const Property = {
    typeUrl: "/google.api.Property",
    is(o) {
        return o && (o.$typeUrl === Property.typeUrl || typeof o.name === "string" && isSet(o.type) && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Property.typeUrl || typeof o.name === "string" && isSet(o.type) && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Property.typeUrl || typeof o.name === "string" && isSet(o.type) && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.name !== undefined) {
            writer.uint32(10).string(message.name);
        }
        if (message.type !== 0) {
            writer.uint32(16).int32(message.type);
        }
        if (message.description !== undefined) {
            writer.uint32(26).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseProperty();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.name = reader.string();
                    break;
                case 2:
                    message.type = reader.int32();
                    break;
                case 3:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseProperty();
        if (isSet(object.name))
            obj.name = String(object.name);
        if (isSet(object.type))
            obj.type = property_PropertyTypeFromJSON(object.type);
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.name !== undefined && (obj.name = message.name);
        message.type !== undefined && (obj.type = property_PropertyTypeToJSON(message.type));
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseProperty();
        message.name = object.name ?? "";
        message.type = object.type ?? 0;
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            name: object?.name,
            type: isSet(object.type) ? property_PropertyTypeFromJSON(object.type) : -1,
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            name: isSet(object.name) ? String(object.name) : "",
            type: isSet(object.type) ? property_PropertyTypeFromJSON(object.type) : -1,
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.name = message.name;
        message.type !== undefined && (obj.type = property_PropertyTypeToJSON(message.type));
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseProperty();
        if (object.name !== undefined && object.name !== null) {
            message.name = object.name;
        }
        if (object.type !== undefined && object.type !== null) {
            message.type = object.type;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.name = message.name === "" ? undefined : message.name;
        obj.type = message.type === 0 ? undefined : message.type;
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return Property.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Property.decode(message.value);
    },
    toProto(message) {
        return Property.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.api.Property",
            value: Property.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
