import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * `Context` defines which contexts an API requests.
 *
 * Example:
 *
 *     context:
 *       rules:
 *       - selector: "*"
 *         requested:
 *         - google.rpc.context.ProjectContext
 *         - google.rpc.context.OriginContext
 *
 * The above specifies that all methods in the API request
 * `google.rpc.context.ProjectContext` and
 * `google.rpc.context.OriginContext`.
 *
 * Available context types are defined in package
 * `google.rpc.context`.
 *
 * This also provides mechanism to allowlist any protobuf message extension that
 * can be sent in grpc metadata using “x-goog-ext-<extension_id>-bin” and
 * “x-goog-ext-<extension_id>-jspb” format. For example, list any service
 * specific protobuf types that can appear in grpc metadata as follows in your
 * yaml file:
 *
 * Example:
 *
 *     context:
 *       rules:
 *        - selector: "google.example.library.v1.LibraryService.CreateBook"
 *          allowed_request_extensions:
 *          - google.foo.v1.NewExtension
 *          allowed_response_extensions:
 *          - google.foo.v1.NewExtension
 *
 * You can also specify extension ID instead of fully qualified extension name
 * here.
 */
export interface Context {
    /**
     * A list of RPC context rules that apply to individual API methods.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules: ContextRule[];
}
export interface ContextProtoMsg {
    typeUrl: "/google.api.Context";
    value: Uint8Array;
}
/**
 * `Context` defines which contexts an API requests.
 *
 * Example:
 *
 *     context:
 *       rules:
 *       - selector: "*"
 *         requested:
 *         - google.rpc.context.ProjectContext
 *         - google.rpc.context.OriginContext
 *
 * The above specifies that all methods in the API request
 * `google.rpc.context.ProjectContext` and
 * `google.rpc.context.OriginContext`.
 *
 * Available context types are defined in package
 * `google.rpc.context`.
 *
 * This also provides mechanism to allowlist any protobuf message extension that
 * can be sent in grpc metadata using “x-goog-ext-<extension_id>-bin” and
 * “x-goog-ext-<extension_id>-jspb” format. For example, list any service
 * specific protobuf types that can appear in grpc metadata as follows in your
 * yaml file:
 *
 * Example:
 *
 *     context:
 *       rules:
 *        - selector: "google.example.library.v1.LibraryService.CreateBook"
 *          allowed_request_extensions:
 *          - google.foo.v1.NewExtension
 *          allowed_response_extensions:
 *          - google.foo.v1.NewExtension
 *
 * You can also specify extension ID instead of fully qualified extension name
 * here.
 */
export interface ContextAmino {
    /**
     * A list of RPC context rules that apply to individual API methods.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules?: ContextRuleAmino[];
}
export interface ContextAminoMsg {
    type: "/google.api.Context";
    value: ContextAmino;
}
/**
 * `Context` defines which contexts an API requests.
 *
 * Example:
 *
 *     context:
 *       rules:
 *       - selector: "*"
 *         requested:
 *         - google.rpc.context.ProjectContext
 *         - google.rpc.context.OriginContext
 *
 * The above specifies that all methods in the API request
 * `google.rpc.context.ProjectContext` and
 * `google.rpc.context.OriginContext`.
 *
 * Available context types are defined in package
 * `google.rpc.context`.
 *
 * This also provides mechanism to allowlist any protobuf message extension that
 * can be sent in grpc metadata using “x-goog-ext-<extension_id>-bin” and
 * “x-goog-ext-<extension_id>-jspb” format. For example, list any service
 * specific protobuf types that can appear in grpc metadata as follows in your
 * yaml file:
 *
 * Example:
 *
 *     context:
 *       rules:
 *        - selector: "google.example.library.v1.LibraryService.CreateBook"
 *          allowed_request_extensions:
 *          - google.foo.v1.NewExtension
 *          allowed_response_extensions:
 *          - google.foo.v1.NewExtension
 *
 * You can also specify extension ID instead of fully qualified extension name
 * here.
 */
export interface ContextSDKType {
    rules: ContextRuleSDKType[];
}
/**
 * A context rule provides information about the context for an individual API
 * element.
 */
export interface ContextRule {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector: string;
    /** A list of full type names of requested contexts. */
    requested: string[];
    /** A list of full type names of provided contexts. */
    provided: string[];
    /**
     * A list of full type names or extension IDs of extensions allowed in grpc
     * side channel from client to backend.
     */
    allowedRequestExtensions: string[];
    /**
     * A list of full type names or extension IDs of extensions allowed in grpc
     * side channel from backend to client.
     */
    allowedResponseExtensions: string[];
}
export interface ContextRuleProtoMsg {
    typeUrl: "/google.api.ContextRule";
    value: Uint8Array;
}
/**
 * A context rule provides information about the context for an individual API
 * element.
 */
export interface ContextRuleAmino {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector?: string;
    /** A list of full type names of requested contexts. */
    requested?: string[];
    /** A list of full type names of provided contexts. */
    provided?: string[];
    /**
     * A list of full type names or extension IDs of extensions allowed in grpc
     * side channel from client to backend.
     */
    allowed_request_extensions?: string[];
    /**
     * A list of full type names or extension IDs of extensions allowed in grpc
     * side channel from backend to client.
     */
    allowed_response_extensions?: string[];
}
export interface ContextRuleAminoMsg {
    type: "/google.api.ContextRule";
    value: ContextRuleAmino;
}
/**
 * A context rule provides information about the context for an individual API
 * element.
 */
export interface ContextRuleSDKType {
    selector: string;
    requested: string[];
    provided: string[];
    allowed_request_extensions: string[];
    allowed_response_extensions: string[];
}
export declare const Context: {
    typeUrl: string;
    is(o: any): o is Context;
    isSDK(o: any): o is ContextSDKType;
    isAmino(o: any): o is ContextAmino;
    encode(message: Context, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Context;
    fromJSON(object: any): Context;
    toJSON(message: Context): JsonSafe<Context>;
    fromPartial(object: DeepPartial<Context>): Context;
    fromSDK(object: ContextSDKType): Context;
    fromSDKJSON(object: any): ContextSDKType;
    toSDK(message: Context): ContextSDKType;
    fromAmino(object: ContextAmino): Context;
    toAmino(message: Context): ContextAmino;
    fromAminoMsg(object: ContextAminoMsg): Context;
    fromProtoMsg(message: ContextProtoMsg): Context;
    toProto(message: Context): Uint8Array;
    toProtoMsg(message: Context): ContextProtoMsg;
    registerTypeUrl(): void;
};
export declare const ContextRule: {
    typeUrl: string;
    is(o: any): o is ContextRule;
    isSDK(o: any): o is ContextRuleSDKType;
    isAmino(o: any): o is ContextRuleAmino;
    encode(message: ContextRule, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ContextRule;
    fromJSON(object: any): ContextRule;
    toJSON(message: ContextRule): JsonSafe<ContextRule>;
    fromPartial(object: DeepPartial<ContextRule>): ContextRule;
    fromSDK(object: ContextRuleSDKType): ContextRule;
    fromSDKJSON(object: any): ContextRuleSDKType;
    toSDK(message: ContextRule): ContextRuleSDKType;
    fromAmino(object: ContextRuleAmino): ContextRule;
    toAmino(message: ContextRule): ContextRuleAmino;
    fromAminoMsg(object: ContextRuleAminoMsg): ContextRule;
    fromProtoMsg(message: ContextRuleProtoMsg): ContextRule;
    toProto(message: ContextRule): Uint8Array;
    toProtoMsg(message: ContextRule): ContextRuleProtoMsg;
    registerTypeUrl(): void;
};
