import { ParsedExpr, ParsedExprAmino, ParsedExprSDKType, SourcePosition, SourcePositionAmino, SourcePositionSDKType } from "../../v1alpha1/syntax";
import { Decl, DeclAmino, DeclSDKType, CheckedExpr, CheckedExprAmino, CheckedExprSDKType } from "../../v1alpha1/checked";
import { ExprValue, ExprValueAmino, ExprValueSDKType } from "../../v1alpha1/eval";
import { Status, StatusAmino, StatusSDKType } from "../../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../../binary";
import { DeepPartial } from "../../../../../helpers";
import { JsonSafe } from "../../../../../json-safe";
export declare const protobufPackage = "google.api.expr.conformance.v1alpha1";
/** Severities of issues. */
export declare enum IssueDetails_Severity {
    /** SEVERITY_UNSPECIFIED - An unspecified severity. */
    SEVERITY_UNSPECIFIED = 0,
    /**
     * DEPRECATION - Deprecation issue for statements and method that may no longer be
     * supported or maintained.
     */
    DEPRECATION = 1,
    /** WARNING - Warnings such as: unused variables. */
    WARNING = 2,
    /** ERROR - Errors such as: unmatched curly braces or variable redefinition. */
    ERROR = 3,
    UNRECOGNIZED = -1
}
export declare const IssueDetails_SeveritySDKType: typeof IssueDetails_Severity;
export declare const IssueDetails_SeverityAmino: typeof IssueDetails_Severity;
export declare function issueDetails_SeverityFromJSON(object: any): IssueDetails_Severity;
export declare function issueDetails_SeverityToJSON(object: IssueDetails_Severity): string;
/** Request message for the Parse method. */
export interface ParseRequest {
    /** Required. Source text in CEL syntax. */
    celSource: string;
    /** Tag for version of CEL syntax, for future use. */
    syntaxVersion: string;
    /** File or resource for source text, used in [SourceInfo][google.api.SourceInfo]. */
    sourceLocation: string;
    /** Prevent macro expansion.  See "Macros" in Language Defiinition. */
    disableMacros: boolean;
}
export interface ParseRequestProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.ParseRequest";
    value: Uint8Array;
}
/** Request message for the Parse method. */
export interface ParseRequestAmino {
    /** Required. Source text in CEL syntax. */
    cel_source?: string;
    /** Tag for version of CEL syntax, for future use. */
    syntax_version?: string;
    /** File or resource for source text, used in [SourceInfo][google.api.SourceInfo]. */
    source_location?: string;
    /** Prevent macro expansion.  See "Macros" in Language Defiinition. */
    disable_macros?: boolean;
}
export interface ParseRequestAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.ParseRequest";
    value: ParseRequestAmino;
}
/** Request message for the Parse method. */
export interface ParseRequestSDKType {
    cel_source: string;
    syntax_version: string;
    source_location: string;
    disable_macros: boolean;
}
/** Response message for the Parse method. */
export interface ParseResponse {
    /** The parsed representation, or unset if parsing failed. */
    parsedExpr?: ParsedExpr;
    /** Any number of issues with [StatusDetails][] as the details. */
    issues: Status[];
}
export interface ParseResponseProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.ParseResponse";
    value: Uint8Array;
}
/** Response message for the Parse method. */
export interface ParseResponseAmino {
    /** The parsed representation, or unset if parsing failed. */
    parsed_expr?: ParsedExprAmino;
    /** Any number of issues with [StatusDetails][] as the details. */
    issues?: StatusAmino[];
}
export interface ParseResponseAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.ParseResponse";
    value: ParseResponseAmino;
}
/** Response message for the Parse method. */
export interface ParseResponseSDKType {
    parsed_expr?: ParsedExprSDKType;
    issues: StatusSDKType[];
}
/** Request message for the Check method. */
export interface CheckRequest {
    /** Required. The parsed representation of the CEL program. */
    parsedExpr?: ParsedExpr;
    /**
     * Declarations of types for external variables and functions.
     * Required if program uses external variables or functions
     * not in the default environment.
     */
    typeEnv: Decl[];
    /**
     * The protocol buffer context.  See "Name Resolution" in the
     * Language Definition.
     */
    container: string;
    /**
     * If true, use only the declarations in [type_env][google.api.expr.conformance.v1alpha1.CheckRequest.type_env].  If false (default),
     * add declarations for the standard definitions to the type environment.  See
     * "Standard Definitions" in the Language Definition.
     */
    noStdEnv: boolean;
}
export interface CheckRequestProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.CheckRequest";
    value: Uint8Array;
}
/** Request message for the Check method. */
export interface CheckRequestAmino {
    /** Required. The parsed representation of the CEL program. */
    parsed_expr?: ParsedExprAmino;
    /**
     * Declarations of types for external variables and functions.
     * Required if program uses external variables or functions
     * not in the default environment.
     */
    type_env?: DeclAmino[];
    /**
     * The protocol buffer context.  See "Name Resolution" in the
     * Language Definition.
     */
    container?: string;
    /**
     * If true, use only the declarations in [type_env][google.api.expr.conformance.v1alpha1.CheckRequest.type_env].  If false (default),
     * add declarations for the standard definitions to the type environment.  See
     * "Standard Definitions" in the Language Definition.
     */
    no_std_env?: boolean;
}
export interface CheckRequestAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.CheckRequest";
    value: CheckRequestAmino;
}
/** Request message for the Check method. */
export interface CheckRequestSDKType {
    parsed_expr?: ParsedExprSDKType;
    type_env: DeclSDKType[];
    container: string;
    no_std_env: boolean;
}
/** Response message for the Check method. */
export interface CheckResponse {
    /** The annotated representation, or unset if checking failed. */
    checkedExpr?: CheckedExpr;
    /** Any number of issues with [StatusDetails][] as the details. */
    issues: Status[];
}
export interface CheckResponseProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.CheckResponse";
    value: Uint8Array;
}
/** Response message for the Check method. */
export interface CheckResponseAmino {
    /** The annotated representation, or unset if checking failed. */
    checked_expr?: CheckedExprAmino;
    /** Any number of issues with [StatusDetails][] as the details. */
    issues?: StatusAmino[];
}
export interface CheckResponseAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.CheckResponse";
    value: CheckResponseAmino;
}
/** Response message for the Check method. */
export interface CheckResponseSDKType {
    checked_expr?: CheckedExprSDKType;
    issues: StatusSDKType[];
}
export interface EvalRequest_BindingsEntry {
    key: string;
    value?: ExprValue;
}
export interface EvalRequest_BindingsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface EvalRequest_BindingsEntryAmino {
    key?: string;
    value?: ExprValueAmino;
}
export interface EvalRequest_BindingsEntryAminoMsg {
    type: string;
    value: EvalRequest_BindingsEntryAmino;
}
export interface EvalRequest_BindingsEntrySDKType {
    key: string;
    value?: ExprValueSDKType;
}
/** Request message for the Eval method. */
export interface EvalRequest {
    /** Evaluate based on the parsed representation. */
    parsedExpr?: ParsedExpr;
    /** Evaluate based on the checked representation. */
    checkedExpr?: CheckedExpr;
    /**
     * Bindings for the external variables.  The types SHOULD be compatible
     * with the type environment in [CheckRequest][google.api.expr.conformance.v1alpha1.CheckRequest], if checked.
     */
    bindings: {
        [key: string]: ExprValue;
    };
    /** SHOULD be the same container as used in [CheckRequest][google.api.expr.conformance.v1alpha1.CheckRequest], if checked. */
    container: string;
}
export interface EvalRequestProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.EvalRequest";
    value: Uint8Array;
}
/** Request message for the Eval method. */
export interface EvalRequestAmino {
    /** Evaluate based on the parsed representation. */
    parsed_expr?: ParsedExprAmino;
    /** Evaluate based on the checked representation. */
    checked_expr?: CheckedExprAmino;
    /**
     * Bindings for the external variables.  The types SHOULD be compatible
     * with the type environment in [CheckRequest][google.api.expr.conformance.v1alpha1.CheckRequest], if checked.
     */
    bindings?: {
        [key: string]: ExprValueAmino;
    };
    /** SHOULD be the same container as used in [CheckRequest][google.api.expr.conformance.v1alpha1.CheckRequest], if checked. */
    container?: string;
}
export interface EvalRequestAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.EvalRequest";
    value: EvalRequestAmino;
}
/** Request message for the Eval method. */
export interface EvalRequestSDKType {
    parsed_expr?: ParsedExprSDKType;
    checked_expr?: CheckedExprSDKType;
    bindings: {
        [key: string]: ExprValueSDKType;
    };
    container: string;
}
/** Response message for the Eval method. */
export interface EvalResponse {
    /** The execution result, or unset if execution couldn't start. */
    result?: ExprValue;
    /**
     * Any number of issues with [StatusDetails][] as the details.
     * Note that CEL execution errors are reified into [ExprValue][].
     * Nevertheless, we'll allow out-of-band issues to be raised,
     * which also makes the replies more regular.
     */
    issues: Status[];
}
export interface EvalResponseProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.EvalResponse";
    value: Uint8Array;
}
/** Response message for the Eval method. */
export interface EvalResponseAmino {
    /** The execution result, or unset if execution couldn't start. */
    result?: ExprValueAmino;
    /**
     * Any number of issues with [StatusDetails][] as the details.
     * Note that CEL execution errors are reified into [ExprValue][].
     * Nevertheless, we'll allow out-of-band issues to be raised,
     * which also makes the replies more regular.
     */
    issues?: StatusAmino[];
}
export interface EvalResponseAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.EvalResponse";
    value: EvalResponseAmino;
}
/** Response message for the Eval method. */
export interface EvalResponseSDKType {
    result?: ExprValueSDKType;
    issues: StatusSDKType[];
}
/**
 * Warnings or errors in service execution are represented by
 * [google.rpc.Status][google.rpc.Status] messages, with the following message
 * in the details field.
 */
export interface IssueDetails {
    /** The severity of the issue. */
    severity: IssueDetails_Severity;
    /** Position in the source, if known. */
    position?: SourcePosition;
    /** Expression ID from [Expr][], 0 if unknown. */
    id: bigint;
}
export interface IssueDetailsProtoMsg {
    typeUrl: "/google.api.expr.conformance.v1alpha1.IssueDetails";
    value: Uint8Array;
}
/**
 * Warnings or errors in service execution are represented by
 * [google.rpc.Status][google.rpc.Status] messages, with the following message
 * in the details field.
 */
export interface IssueDetailsAmino {
    /** The severity of the issue. */
    severity?: IssueDetails_Severity;
    /** Position in the source, if known. */
    position?: SourcePositionAmino;
    /** Expression ID from [Expr][], 0 if unknown. */
    id?: string;
}
export interface IssueDetailsAminoMsg {
    type: "/google.api.expr.conformance.v1alpha1.IssueDetails";
    value: IssueDetailsAmino;
}
/**
 * Warnings or errors in service execution are represented by
 * [google.rpc.Status][google.rpc.Status] messages, with the following message
 * in the details field.
 */
export interface IssueDetailsSDKType {
    severity: IssueDetails_Severity;
    position?: SourcePositionSDKType;
    id: bigint;
}
export declare const ParseRequest: {
    typeUrl: string;
    is(o: any): o is ParseRequest;
    isSDK(o: any): o is ParseRequestSDKType;
    isAmino(o: any): o is ParseRequestAmino;
    encode(message: ParseRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ParseRequest;
    fromJSON(object: any): ParseRequest;
    toJSON(message: ParseRequest): JsonSafe<ParseRequest>;
    fromPartial(object: DeepPartial<ParseRequest>): ParseRequest;
    fromSDK(object: ParseRequestSDKType): ParseRequest;
    fromSDKJSON(object: any): ParseRequestSDKType;
    toSDK(message: ParseRequest): ParseRequestSDKType;
    fromAmino(object: ParseRequestAmino): ParseRequest;
    toAmino(message: ParseRequest): ParseRequestAmino;
    fromAminoMsg(object: ParseRequestAminoMsg): ParseRequest;
    fromProtoMsg(message: ParseRequestProtoMsg): ParseRequest;
    toProto(message: ParseRequest): Uint8Array;
    toProtoMsg(message: ParseRequest): ParseRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ParseResponse: {
    typeUrl: string;
    is(o: any): o is ParseResponse;
    isSDK(o: any): o is ParseResponseSDKType;
    isAmino(o: any): o is ParseResponseAmino;
    encode(message: ParseResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ParseResponse;
    fromJSON(object: any): ParseResponse;
    toJSON(message: ParseResponse): JsonSafe<ParseResponse>;
    fromPartial(object: DeepPartial<ParseResponse>): ParseResponse;
    fromSDK(object: ParseResponseSDKType): ParseResponse;
    fromSDKJSON(object: any): ParseResponseSDKType;
    toSDK(message: ParseResponse): ParseResponseSDKType;
    fromAmino(object: ParseResponseAmino): ParseResponse;
    toAmino(message: ParseResponse): ParseResponseAmino;
    fromAminoMsg(object: ParseResponseAminoMsg): ParseResponse;
    fromProtoMsg(message: ParseResponseProtoMsg): ParseResponse;
    toProto(message: ParseResponse): Uint8Array;
    toProtoMsg(message: ParseResponse): ParseResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckRequest: {
    typeUrl: string;
    is(o: any): o is CheckRequest;
    isSDK(o: any): o is CheckRequestSDKType;
    isAmino(o: any): o is CheckRequestAmino;
    encode(message: CheckRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckRequest;
    fromJSON(object: any): CheckRequest;
    toJSON(message: CheckRequest): JsonSafe<CheckRequest>;
    fromPartial(object: DeepPartial<CheckRequest>): CheckRequest;
    fromSDK(object: CheckRequestSDKType): CheckRequest;
    fromSDKJSON(object: any): CheckRequestSDKType;
    toSDK(message: CheckRequest): CheckRequestSDKType;
    fromAmino(object: CheckRequestAmino): CheckRequest;
    toAmino(message: CheckRequest): CheckRequestAmino;
    fromAminoMsg(object: CheckRequestAminoMsg): CheckRequest;
    fromProtoMsg(message: CheckRequestProtoMsg): CheckRequest;
    toProto(message: CheckRequest): Uint8Array;
    toProtoMsg(message: CheckRequest): CheckRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckResponse: {
    typeUrl: string;
    is(o: any): o is CheckResponse;
    isSDK(o: any): o is CheckResponseSDKType;
    isAmino(o: any): o is CheckResponseAmino;
    encode(message: CheckResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse;
    fromJSON(object: any): CheckResponse;
    toJSON(message: CheckResponse): JsonSafe<CheckResponse>;
    fromPartial(object: DeepPartial<CheckResponse>): CheckResponse;
    fromSDK(object: CheckResponseSDKType): CheckResponse;
    fromSDKJSON(object: any): CheckResponseSDKType;
    toSDK(message: CheckResponse): CheckResponseSDKType;
    fromAmino(object: CheckResponseAmino): CheckResponse;
    toAmino(message: CheckResponse): CheckResponseAmino;
    fromAminoMsg(object: CheckResponseAminoMsg): CheckResponse;
    fromProtoMsg(message: CheckResponseProtoMsg): CheckResponse;
    toProto(message: CheckResponse): Uint8Array;
    toProtoMsg(message: CheckResponse): CheckResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const EvalRequest_BindingsEntry: {
    encode(message: EvalRequest_BindingsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvalRequest_BindingsEntry;
    fromJSON(object: any): EvalRequest_BindingsEntry;
    toJSON(message: EvalRequest_BindingsEntry): JsonSafe<EvalRequest_BindingsEntry>;
    fromPartial(object: DeepPartial<EvalRequest_BindingsEntry>): EvalRequest_BindingsEntry;
    fromSDK(object: EvalRequest_BindingsEntrySDKType): EvalRequest_BindingsEntry;
    fromSDKJSON(object: any): EvalRequest_BindingsEntrySDKType;
    toSDK(message: EvalRequest_BindingsEntry): EvalRequest_BindingsEntrySDKType;
    fromAmino(object: EvalRequest_BindingsEntryAmino): EvalRequest_BindingsEntry;
    toAmino(message: EvalRequest_BindingsEntry): EvalRequest_BindingsEntryAmino;
    fromAminoMsg(object: EvalRequest_BindingsEntryAminoMsg): EvalRequest_BindingsEntry;
    fromProtoMsg(message: EvalRequest_BindingsEntryProtoMsg): EvalRequest_BindingsEntry;
    toProto(message: EvalRequest_BindingsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const EvalRequest: {
    typeUrl: string;
    is(o: any): o is EvalRequest;
    isSDK(o: any): o is EvalRequestSDKType;
    isAmino(o: any): o is EvalRequestAmino;
    encode(message: EvalRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvalRequest;
    fromJSON(object: any): EvalRequest;
    toJSON(message: EvalRequest): JsonSafe<EvalRequest>;
    fromPartial(object: DeepPartial<EvalRequest>): EvalRequest;
    fromSDK(object: EvalRequestSDKType): EvalRequest;
    fromSDKJSON(object: any): EvalRequestSDKType;
    toSDK(message: EvalRequest): EvalRequestSDKType;
    fromAmino(object: EvalRequestAmino): EvalRequest;
    toAmino(message: EvalRequest): EvalRequestAmino;
    fromAminoMsg(object: EvalRequestAminoMsg): EvalRequest;
    fromProtoMsg(message: EvalRequestProtoMsg): EvalRequest;
    toProto(message: EvalRequest): Uint8Array;
    toProtoMsg(message: EvalRequest): EvalRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const EvalResponse: {
    typeUrl: string;
    is(o: any): o is EvalResponse;
    isSDK(o: any): o is EvalResponseSDKType;
    isAmino(o: any): o is EvalResponseAmino;
    encode(message: EvalResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvalResponse;
    fromJSON(object: any): EvalResponse;
    toJSON(message: EvalResponse): JsonSafe<EvalResponse>;
    fromPartial(object: DeepPartial<EvalResponse>): EvalResponse;
    fromSDK(object: EvalResponseSDKType): EvalResponse;
    fromSDKJSON(object: any): EvalResponseSDKType;
    toSDK(message: EvalResponse): EvalResponseSDKType;
    fromAmino(object: EvalResponseAmino): EvalResponse;
    toAmino(message: EvalResponse): EvalResponseAmino;
    fromAminoMsg(object: EvalResponseAminoMsg): EvalResponse;
    fromProtoMsg(message: EvalResponseProtoMsg): EvalResponse;
    toProto(message: EvalResponse): Uint8Array;
    toProtoMsg(message: EvalResponse): EvalResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const IssueDetails: {
    typeUrl: string;
    is(o: any): o is IssueDetails;
    isSDK(o: any): o is IssueDetailsSDKType;
    isAmino(o: any): o is IssueDetailsAmino;
    encode(message: IssueDetails, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): IssueDetails;
    fromJSON(object: any): IssueDetails;
    toJSON(message: IssueDetails): JsonSafe<IssueDetails>;
    fromPartial(object: DeepPartial<IssueDetails>): IssueDetails;
    fromSDK(object: IssueDetailsSDKType): IssueDetails;
    fromSDKJSON(object: any): IssueDetailsSDKType;
    toSDK(message: IssueDetails): IssueDetailsSDKType;
    fromAmino(object: IssueDetailsAmino): IssueDetails;
    toAmino(message: IssueDetails): IssueDetailsAmino;
    fromAminoMsg(object: IssueDetailsAminoMsg): IssueDetails;
    fromProtoMsg(message: IssueDetailsProtoMsg): IssueDetails;
    toProto(message: IssueDetails): Uint8Array;
    toProtoMsg(message: IssueDetails): IssueDetailsProtoMsg;
    registerTypeUrl(): void;
};
