import { Value, ValueAmino, ValueSDKType } from "./value";
import { Status, StatusAmino, StatusSDKType } from "../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { JsonSafe } from "../../../../json-safe";
import { DeepPartial } from "../../../../helpers";
export declare const protobufPackage = "google.api.expr.v1alpha1";
/**
 * The state of an evaluation.
 *
 * Can represent an inital, partial, or completed state of evaluation.
 */
export interface EvalState {
    /** The unique values referenced in this message. */
    values: ExprValue[];
    /**
     * An ordered list of results.
     *
     * Tracks the flow of evaluation through the expression.
     * May be sparse.
     */
    results: EvalState_Result[];
}
export interface EvalStateProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.EvalState";
    value: Uint8Array;
}
/**
 * The state of an evaluation.
 *
 * Can represent an inital, partial, or completed state of evaluation.
 */
export interface EvalStateAmino {
    /** The unique values referenced in this message. */
    values?: ExprValueAmino[];
    /**
     * An ordered list of results.
     *
     * Tracks the flow of evaluation through the expression.
     * May be sparse.
     */
    results?: EvalState_ResultAmino[];
}
export interface EvalStateAminoMsg {
    type: "/google.api.expr.v1alpha1.EvalState";
    value: EvalStateAmino;
}
/**
 * The state of an evaluation.
 *
 * Can represent an inital, partial, or completed state of evaluation.
 */
export interface EvalStateSDKType {
    values: ExprValueSDKType[];
    results: EvalState_ResultSDKType[];
}
/** A single evalution result. */
export interface EvalState_Result {
    /** The id of the expression this result if for. */
    expr: bigint;
    /** The index in `values` of the resulting value. */
    value: bigint;
}
export interface EvalState_ResultProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Result";
    value: Uint8Array;
}
/** A single evalution result. */
export interface EvalState_ResultAmino {
    /** The id of the expression this result if for. */
    expr?: string;
    /** The index in `values` of the resulting value. */
    value?: string;
}
export interface EvalState_ResultAminoMsg {
    type: "/google.api.expr.v1alpha1.Result";
    value: EvalState_ResultAmino;
}
/** A single evalution result. */
export interface EvalState_ResultSDKType {
    expr: bigint;
    value: bigint;
}
/** The value of an evaluated expression. */
export interface ExprValue {
    /** A concrete value. */
    value?: Value;
    /**
     * The set of errors in the critical path of evalution.
     *
     * Only errors in the critical path are included. For example,
     * `(<error1> || true) && <error2>` will only result in `<error2>`,
     * while `<error1> || <error2>` will result in both `<error1>` and
     * `<error2>`.
     *
     * Errors cause by the presence of other errors are not included in the
     * set. For example `<error1>.foo`, `foo(<error1>)`, and `<error1> + 1` will
     * only result in `<error1>`.
     *
     * Multiple errors *might* be included when evaluation could result
     * in different errors. For example `<error1> + <error2>` and
     * `foo(<error1>, <error2>)` may result in `<error1>`, `<error2>` or both.
     * The exact subset of errors included for this case is unspecified and
     * depends on the implementation details of the evaluator.
     */
    error?: ErrorSet;
    /**
     * The set of unknowns in the critical path of evaluation.
     *
     * Unknown behaves identically to Error with regards to propagation.
     * Specifically, only unknowns in the critical path are included, unknowns
     * caused by the presence of other unknowns are not included, and multiple
     * unknowns *might* be included included when evaluation could result in
     * different unknowns. For example:
     *
     *     (<unknown[1]> || true) && <unknown[2]> -> <unknown[2]>
     *     <unknown[1]> || <unknown[2]> -> <unknown[1,2]>
     *     <unknown[1]>.foo -> <unknown[1]>
     *     foo(<unknown[1]>) -> <unknown[1]>
     *     <unknown[1]> + <unknown[2]> -> <unknown[1]> or <unknown[2[>
     *
     * Unknown takes precidence over Error in cases where a `Value` can short
     * circuit the result:
     *
     *     <error> || <unknown> -> <unknown>
     *     <error> && <unknown> -> <unknown>
     *
     * Errors take precidence in all other cases:
     *
     *     <unknown> + <error> -> <error>
     *     foo(<unknown>, <error>) -> <error>
     */
    unknown?: UnknownSet;
}
export interface ExprValueProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.ExprValue";
    value: Uint8Array;
}
/** The value of an evaluated expression. */
export interface ExprValueAmino {
    /** A concrete value. */
    value?: ValueAmino;
    /**
     * The set of errors in the critical path of evalution.
     *
     * Only errors in the critical path are included. For example,
     * `(<error1> || true) && <error2>` will only result in `<error2>`,
     * while `<error1> || <error2>` will result in both `<error1>` and
     * `<error2>`.
     *
     * Errors cause by the presence of other errors are not included in the
     * set. For example `<error1>.foo`, `foo(<error1>)`, and `<error1> + 1` will
     * only result in `<error1>`.
     *
     * Multiple errors *might* be included when evaluation could result
     * in different errors. For example `<error1> + <error2>` and
     * `foo(<error1>, <error2>)` may result in `<error1>`, `<error2>` or both.
     * The exact subset of errors included for this case is unspecified and
     * depends on the implementation details of the evaluator.
     */
    error?: ErrorSetAmino;
    /**
     * The set of unknowns in the critical path of evaluation.
     *
     * Unknown behaves identically to Error with regards to propagation.
     * Specifically, only unknowns in the critical path are included, unknowns
     * caused by the presence of other unknowns are not included, and multiple
     * unknowns *might* be included included when evaluation could result in
     * different unknowns. For example:
     *
     *     (<unknown[1]> || true) && <unknown[2]> -> <unknown[2]>
     *     <unknown[1]> || <unknown[2]> -> <unknown[1,2]>
     *     <unknown[1]>.foo -> <unknown[1]>
     *     foo(<unknown[1]>) -> <unknown[1]>
     *     <unknown[1]> + <unknown[2]> -> <unknown[1]> or <unknown[2[>
     *
     * Unknown takes precidence over Error in cases where a `Value` can short
     * circuit the result:
     *
     *     <error> || <unknown> -> <unknown>
     *     <error> && <unknown> -> <unknown>
     *
     * Errors take precidence in all other cases:
     *
     *     <unknown> + <error> -> <error>
     *     foo(<unknown>, <error>) -> <error>
     */
    unknown?: UnknownSetAmino;
}
export interface ExprValueAminoMsg {
    type: "/google.api.expr.v1alpha1.ExprValue";
    value: ExprValueAmino;
}
/** The value of an evaluated expression. */
export interface ExprValueSDKType {
    value?: ValueSDKType;
    error?: ErrorSetSDKType;
    unknown?: UnknownSetSDKType;
}
/**
 * A set of errors.
 *
 * The errors included depend on the context. See `ExprValue.error`.
 */
export interface ErrorSet {
    /** The errors in the set. */
    errors: Status[];
}
export interface ErrorSetProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.ErrorSet";
    value: Uint8Array;
}
/**
 * A set of errors.
 *
 * The errors included depend on the context. See `ExprValue.error`.
 */
export interface ErrorSetAmino {
    /** The errors in the set. */
    errors?: StatusAmino[];
}
export interface ErrorSetAminoMsg {
    type: "/google.api.expr.v1alpha1.ErrorSet";
    value: ErrorSetAmino;
}
/**
 * A set of errors.
 *
 * The errors included depend on the context. See `ExprValue.error`.
 */
export interface ErrorSetSDKType {
    errors: StatusSDKType[];
}
/**
 * A set of expressions for which the value is unknown.
 *
 * The unknowns included depend on the context. See `ExprValue.unknown`.
 */
export interface UnknownSet {
    /** The ids of the expressions with unknown values. */
    exprs: bigint[];
}
export interface UnknownSetProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.UnknownSet";
    value: Uint8Array;
}
/**
 * A set of expressions for which the value is unknown.
 *
 * The unknowns included depend on the context. See `ExprValue.unknown`.
 */
export interface UnknownSetAmino {
    /** The ids of the expressions with unknown values. */
    exprs?: string[];
}
export interface UnknownSetAminoMsg {
    type: "/google.api.expr.v1alpha1.UnknownSet";
    value: UnknownSetAmino;
}
/**
 * A set of expressions for which the value is unknown.
 *
 * The unknowns included depend on the context. See `ExprValue.unknown`.
 */
export interface UnknownSetSDKType {
    exprs: bigint[];
}
export declare const EvalState: {
    typeUrl: string;
    is(o: any): o is EvalState;
    isSDK(o: any): o is EvalStateSDKType;
    isAmino(o: any): o is EvalStateAmino;
    encode(message: EvalState, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvalState;
    fromJSON(object: any): EvalState;
    toJSON(message: EvalState): JsonSafe<EvalState>;
    fromPartial(object: DeepPartial<EvalState>): EvalState;
    fromSDK(object: EvalStateSDKType): EvalState;
    fromSDKJSON(object: any): EvalStateSDKType;
    toSDK(message: EvalState): EvalStateSDKType;
    fromAmino(object: EvalStateAmino): EvalState;
    toAmino(message: EvalState): EvalStateAmino;
    fromAminoMsg(object: EvalStateAminoMsg): EvalState;
    fromProtoMsg(message: EvalStateProtoMsg): EvalState;
    toProto(message: EvalState): Uint8Array;
    toProtoMsg(message: EvalState): EvalStateProtoMsg;
    registerTypeUrl(): void;
};
export declare const EvalState_Result: {
    typeUrl: string;
    is(o: any): o is EvalState_Result;
    isSDK(o: any): o is EvalState_ResultSDKType;
    isAmino(o: any): o is EvalState_ResultAmino;
    encode(message: EvalState_Result, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvalState_Result;
    fromJSON(object: any): EvalState_Result;
    toJSON(message: EvalState_Result): JsonSafe<EvalState_Result>;
    fromPartial(object: DeepPartial<EvalState_Result>): EvalState_Result;
    fromSDK(object: EvalState_ResultSDKType): EvalState_Result;
    fromSDKJSON(object: any): EvalState_ResultSDKType;
    toSDK(message: EvalState_Result): EvalState_ResultSDKType;
    fromAmino(object: EvalState_ResultAmino): EvalState_Result;
    toAmino(message: EvalState_Result): EvalState_ResultAmino;
    fromAminoMsg(object: EvalState_ResultAminoMsg): EvalState_Result;
    fromProtoMsg(message: EvalState_ResultProtoMsg): EvalState_Result;
    toProto(message: EvalState_Result): Uint8Array;
    toProtoMsg(message: EvalState_Result): EvalState_ResultProtoMsg;
    registerTypeUrl(): void;
};
export declare const ExprValue: {
    typeUrl: string;
    is(o: any): o is ExprValue;
    isSDK(o: any): o is ExprValueSDKType;
    isAmino(o: any): o is ExprValueAmino;
    encode(message: ExprValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ExprValue;
    fromJSON(object: any): ExprValue;
    toJSON(message: ExprValue): JsonSafe<ExprValue>;
    fromPartial(object: DeepPartial<ExprValue>): ExprValue;
    fromSDK(object: ExprValueSDKType): ExprValue;
    fromSDKJSON(object: any): ExprValueSDKType;
    toSDK(message: ExprValue): ExprValueSDKType;
    fromAmino(object: ExprValueAmino): ExprValue;
    toAmino(message: ExprValue): ExprValueAmino;
    fromAminoMsg(object: ExprValueAminoMsg): ExprValue;
    fromProtoMsg(message: ExprValueProtoMsg): ExprValue;
    toProto(message: ExprValue): Uint8Array;
    toProtoMsg(message: ExprValue): ExprValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const ErrorSet: {
    typeUrl: string;
    is(o: any): o is ErrorSet;
    isSDK(o: any): o is ErrorSetSDKType;
    isAmino(o: any): o is ErrorSetAmino;
    encode(message: ErrorSet, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ErrorSet;
    fromJSON(object: any): ErrorSet;
    toJSON(message: ErrorSet): JsonSafe<ErrorSet>;
    fromPartial(object: DeepPartial<ErrorSet>): ErrorSet;
    fromSDK(object: ErrorSetSDKType): ErrorSet;
    fromSDKJSON(object: any): ErrorSetSDKType;
    toSDK(message: ErrorSet): ErrorSetSDKType;
    fromAmino(object: ErrorSetAmino): ErrorSet;
    toAmino(message: ErrorSet): ErrorSetAmino;
    fromAminoMsg(object: ErrorSetAminoMsg): ErrorSet;
    fromProtoMsg(message: ErrorSetProtoMsg): ErrorSet;
    toProto(message: ErrorSet): Uint8Array;
    toProtoMsg(message: ErrorSet): ErrorSetProtoMsg;
    registerTypeUrl(): void;
};
export declare const UnknownSet: {
    typeUrl: string;
    is(o: any): o is UnknownSet;
    isSDK(o: any): o is UnknownSetSDKType;
    isAmino(o: any): o is UnknownSetAmino;
    encode(message: UnknownSet, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UnknownSet;
    fromJSON(object: any): UnknownSet;
    toJSON(message: UnknownSet): JsonSafe<UnknownSet>;
    fromPartial(object: DeepPartial<UnknownSet>): UnknownSet;
    fromSDK(object: UnknownSetSDKType): UnknownSet;
    fromSDKJSON(object: any): UnknownSetSDKType;
    toSDK(message: UnknownSet): UnknownSetSDKType;
    fromAmino(object: UnknownSetAmino): UnknownSet;
    toAmino(message: UnknownSet): UnknownSetAmino;
    fromAminoMsg(object: UnknownSetAminoMsg): UnknownSet;
    fromProtoMsg(message: UnknownSetProtoMsg): UnknownSet;
    toProto(message: UnknownSet): Uint8Array;
    toProtoMsg(message: UnknownSet): UnknownSetProtoMsg;
    registerTypeUrl(): void;
};
