import { NullValue } from "../../../protobuf/struct";
import { Duration, DurationAmino, DurationSDKType } from "../../../protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.expr.v1alpha1";
/** An expression together with source information as returned by the parser. */
export interface ParsedExpr {
    /** The parsed expression. */
    expr?: Expr;
    /** The source info derived from input that generated the parsed `expr`. */
    sourceInfo?: SourceInfo;
}
export interface ParsedExprProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.ParsedExpr";
    value: Uint8Array;
}
/** An expression together with source information as returned by the parser. */
export interface ParsedExprAmino {
    /** The parsed expression. */
    expr?: ExprAmino;
    /** The source info derived from input that generated the parsed `expr`. */
    source_info?: SourceInfoAmino;
}
export interface ParsedExprAminoMsg {
    type: "/google.api.expr.v1alpha1.ParsedExpr";
    value: ParsedExprAmino;
}
/** An expression together with source information as returned by the parser. */
export interface ParsedExprSDKType {
    expr?: ExprSDKType;
    source_info?: SourceInfoSDKType;
}
/**
 * An abstract representation of a common expression.
 *
 * Expressions are abstractly represented as a collection of identifiers,
 * select statements, function calls, literals, and comprehensions. All
 * operators with the exception of the '.' operator are modelled as function
 * calls. This makes it easy to represent new operators into the existing AST.
 *
 * All references within expressions must resolve to a [Decl][google.api.expr.v1alpha1.Decl] provided at
 * type-check for an expression to be valid. A reference may either be a bare
 * identifier `name` or a qualified identifier `google.api.name`. References
 * may either refer to a value or a function declaration.
 *
 * For example, the expression `google.api.name.startsWith('expr')` references
 * the declaration `google.api.name` within a [Expr.Select][google.api.expr.v1alpha1.Expr.Select] expression, and
 * the function declaration `startsWith`.
 */
export interface Expr {
    /**
     * Required. An id assigned to this node by the parser which is unique in a
     * given expression tree. This is used to associate type information and other
     * attributes to a node in the parse tree.
     */
    id: bigint;
    /** A literal expression. */
    constExpr?: Constant;
    /** An identifier expression. */
    identExpr?: Expr_Ident;
    /** A field selection expression, e.g. `request.auth`. */
    selectExpr?: Expr_Select;
    /** A call expression, including calls to predefined functions and operators. */
    callExpr?: Expr_Call;
    /** A list creation expression. */
    listExpr?: Expr_CreateList;
    /** A map or message creation expression. */
    structExpr?: Expr_CreateStruct;
    /** A comprehension expression. */
    comprehensionExpr?: Expr_Comprehension;
}
export interface ExprProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Expr";
    value: Uint8Array;
}
/**
 * An abstract representation of a common expression.
 *
 * Expressions are abstractly represented as a collection of identifiers,
 * select statements, function calls, literals, and comprehensions. All
 * operators with the exception of the '.' operator are modelled as function
 * calls. This makes it easy to represent new operators into the existing AST.
 *
 * All references within expressions must resolve to a [Decl][google.api.expr.v1alpha1.Decl] provided at
 * type-check for an expression to be valid. A reference may either be a bare
 * identifier `name` or a qualified identifier `google.api.name`. References
 * may either refer to a value or a function declaration.
 *
 * For example, the expression `google.api.name.startsWith('expr')` references
 * the declaration `google.api.name` within a [Expr.Select][google.api.expr.v1alpha1.Expr.Select] expression, and
 * the function declaration `startsWith`.
 */
export interface ExprAmino {
    /**
     * Required. An id assigned to this node by the parser which is unique in a
     * given expression tree. This is used to associate type information and other
     * attributes to a node in the parse tree.
     */
    id?: string;
    /** A literal expression. */
    const_expr?: ConstantAmino;
    /** An identifier expression. */
    ident_expr?: Expr_IdentAmino;
    /** A field selection expression, e.g. `request.auth`. */
    select_expr?: Expr_SelectAmino;
    /** A call expression, including calls to predefined functions and operators. */
    call_expr?: Expr_CallAmino;
    /** A list creation expression. */
    list_expr?: Expr_CreateListAmino;
    /** A map or message creation expression. */
    struct_expr?: Expr_CreateStructAmino;
    /** A comprehension expression. */
    comprehension_expr?: Expr_ComprehensionAmino;
}
export interface ExprAminoMsg {
    type: "/google.api.expr.v1alpha1.Expr";
    value: ExprAmino;
}
/**
 * An abstract representation of a common expression.
 *
 * Expressions are abstractly represented as a collection of identifiers,
 * select statements, function calls, literals, and comprehensions. All
 * operators with the exception of the '.' operator are modelled as function
 * calls. This makes it easy to represent new operators into the existing AST.
 *
 * All references within expressions must resolve to a [Decl][google.api.expr.v1alpha1.Decl] provided at
 * type-check for an expression to be valid. A reference may either be a bare
 * identifier `name` or a qualified identifier `google.api.name`. References
 * may either refer to a value or a function declaration.
 *
 * For example, the expression `google.api.name.startsWith('expr')` references
 * the declaration `google.api.name` within a [Expr.Select][google.api.expr.v1alpha1.Expr.Select] expression, and
 * the function declaration `startsWith`.
 */
export interface ExprSDKType {
    id: bigint;
    const_expr?: ConstantSDKType;
    ident_expr?: Expr_IdentSDKType;
    select_expr?: Expr_SelectSDKType;
    call_expr?: Expr_CallSDKType;
    list_expr?: Expr_CreateListSDKType;
    struct_expr?: Expr_CreateStructSDKType;
    comprehension_expr?: Expr_ComprehensionSDKType;
}
/** An identifier expression. e.g. `request`. */
export interface Expr_Ident {
    /**
     * Required. Holds a single, unqualified identifier, possibly preceded by a
     * '.'.
     *
     * Qualified names are represented by the [Expr.Select][google.api.expr.v1alpha1.Expr.Select] expression.
     */
    name: string;
}
export interface Expr_IdentProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Ident";
    value: Uint8Array;
}
/** An identifier expression. e.g. `request`. */
export interface Expr_IdentAmino {
    /**
     * Required. Holds a single, unqualified identifier, possibly preceded by a
     * '.'.
     *
     * Qualified names are represented by the [Expr.Select][google.api.expr.v1alpha1.Expr.Select] expression.
     */
    name?: string;
}
export interface Expr_IdentAminoMsg {
    type: "/google.api.expr.v1alpha1.Ident";
    value: Expr_IdentAmino;
}
/** An identifier expression. e.g. `request`. */
export interface Expr_IdentSDKType {
    name: string;
}
/** A field selection expression. e.g. `request.auth`. */
export interface Expr_Select {
    /**
     * Required. The target of the selection expression.
     *
     * For example, in the select expression `request.auth`, the `request`
     * portion of the expression is the `operand`.
     */
    operand?: Expr;
    /**
     * Required. The name of the field to select.
     *
     * For example, in the select expression `request.auth`, the `auth` portion
     * of the expression would be the `field`.
     */
    field: string;
    /**
     * Whether the select is to be interpreted as a field presence test.
     *
     * This results from the macro `has(request.auth)`.
     */
    testOnly: boolean;
}
export interface Expr_SelectProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Select";
    value: Uint8Array;
}
/** A field selection expression. e.g. `request.auth`. */
export interface Expr_SelectAmino {
    /**
     * Required. The target of the selection expression.
     *
     * For example, in the select expression `request.auth`, the `request`
     * portion of the expression is the `operand`.
     */
    operand?: ExprAmino;
    /**
     * Required. The name of the field to select.
     *
     * For example, in the select expression `request.auth`, the `auth` portion
     * of the expression would be the `field`.
     */
    field?: string;
    /**
     * Whether the select is to be interpreted as a field presence test.
     *
     * This results from the macro `has(request.auth)`.
     */
    test_only?: boolean;
}
export interface Expr_SelectAminoMsg {
    type: "/google.api.expr.v1alpha1.Select";
    value: Expr_SelectAmino;
}
/** A field selection expression. e.g. `request.auth`. */
export interface Expr_SelectSDKType {
    operand?: ExprSDKType;
    field: string;
    test_only: boolean;
}
/**
 * A call expression, including calls to predefined functions and operators.
 *
 * For example, `value == 10`, `size(map_value)`.
 */
export interface Expr_Call {
    /**
     * The target of an method call-style expression. For example, `x` in
     * `x.f()`.
     */
    target?: Expr;
    /** Required. The name of the function or method being called. */
    function: string;
    /** The arguments. */
    args: Expr[];
}
export interface Expr_CallProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Call";
    value: Uint8Array;
}
/**
 * A call expression, including calls to predefined functions and operators.
 *
 * For example, `value == 10`, `size(map_value)`.
 */
export interface Expr_CallAmino {
    /**
     * The target of an method call-style expression. For example, `x` in
     * `x.f()`.
     */
    target?: ExprAmino;
    /** Required. The name of the function or method being called. */
    function?: string;
    /** The arguments. */
    args?: ExprAmino[];
}
export interface Expr_CallAminoMsg {
    type: "/google.api.expr.v1alpha1.Call";
    value: Expr_CallAmino;
}
/**
 * A call expression, including calls to predefined functions and operators.
 *
 * For example, `value == 10`, `size(map_value)`.
 */
export interface Expr_CallSDKType {
    target?: ExprSDKType;
    function: string;
    args: ExprSDKType[];
}
/**
 * A list creation expression.
 *
 * Lists may either be homogenous, e.g. `[1, 2, 3]`, or heterogeneous, e.g.
 * `dyn([1, 'hello', 2.0])`
 */
export interface Expr_CreateList {
    /** The elements part of the list. */
    elements: Expr[];
}
export interface Expr_CreateListProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.CreateList";
    value: Uint8Array;
}
/**
 * A list creation expression.
 *
 * Lists may either be homogenous, e.g. `[1, 2, 3]`, or heterogeneous, e.g.
 * `dyn([1, 'hello', 2.0])`
 */
export interface Expr_CreateListAmino {
    /** The elements part of the list. */
    elements?: ExprAmino[];
}
export interface Expr_CreateListAminoMsg {
    type: "/google.api.expr.v1alpha1.CreateList";
    value: Expr_CreateListAmino;
}
/**
 * A list creation expression.
 *
 * Lists may either be homogenous, e.g. `[1, 2, 3]`, or heterogeneous, e.g.
 * `dyn([1, 'hello', 2.0])`
 */
export interface Expr_CreateListSDKType {
    elements: ExprSDKType[];
}
/**
 * A map or message creation expression.
 *
 * Maps are constructed as `{'key_name': 'value'}`. Message construction is
 * similar, but prefixed with a type name and composed of field ids:
 * `types.MyType{field_id: 'value'}`.
 */
export interface Expr_CreateStruct {
    /**
     * The type name of the message to be created, empty when creating map
     * literals.
     */
    messageName: string;
    /** The entries in the creation expression. */
    entries: Expr_CreateStruct_Entry[];
}
export interface Expr_CreateStructProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.CreateStruct";
    value: Uint8Array;
}
/**
 * A map or message creation expression.
 *
 * Maps are constructed as `{'key_name': 'value'}`. Message construction is
 * similar, but prefixed with a type name and composed of field ids:
 * `types.MyType{field_id: 'value'}`.
 */
export interface Expr_CreateStructAmino {
    /**
     * The type name of the message to be created, empty when creating map
     * literals.
     */
    message_name?: string;
    /** The entries in the creation expression. */
    entries?: Expr_CreateStruct_EntryAmino[];
}
export interface Expr_CreateStructAminoMsg {
    type: "/google.api.expr.v1alpha1.CreateStruct";
    value: Expr_CreateStructAmino;
}
/**
 * A map or message creation expression.
 *
 * Maps are constructed as `{'key_name': 'value'}`. Message construction is
 * similar, but prefixed with a type name and composed of field ids:
 * `types.MyType{field_id: 'value'}`.
 */
export interface Expr_CreateStructSDKType {
    message_name: string;
    entries: Expr_CreateStruct_EntrySDKType[];
}
/** Represents an entry. */
export interface Expr_CreateStruct_Entry {
    /**
     * Required. An id assigned to this node by the parser which is unique
     * in a given expression tree. This is used to associate type
     * information and other attributes to the node.
     */
    id: bigint;
    /** The field key for a message creator statement. */
    fieldKey?: string;
    /** The key expression for a map creation statement. */
    mapKey?: Expr;
    /** Required. The value assigned to the key. */
    value?: Expr;
}
export interface Expr_CreateStruct_EntryProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Entry";
    value: Uint8Array;
}
/** Represents an entry. */
export interface Expr_CreateStruct_EntryAmino {
    /**
     * Required. An id assigned to this node by the parser which is unique
     * in a given expression tree. This is used to associate type
     * information and other attributes to the node.
     */
    id?: string;
    /** The field key for a message creator statement. */
    field_key?: string;
    /** The key expression for a map creation statement. */
    map_key?: ExprAmino;
    /** Required. The value assigned to the key. */
    value?: ExprAmino;
}
export interface Expr_CreateStruct_EntryAminoMsg {
    type: "/google.api.expr.v1alpha1.Entry";
    value: Expr_CreateStruct_EntryAmino;
}
/** Represents an entry. */
export interface Expr_CreateStruct_EntrySDKType {
    id: bigint;
    field_key?: string;
    map_key?: ExprSDKType;
    value?: ExprSDKType;
}
/**
 * A comprehension expression applied to a list or map.
 *
 * Comprehensions are not part of the core syntax, but enabled with macros.
 * A macro matches a specific call signature within a parsed AST and replaces
 * the call with an alternate AST block. Macro expansion happens at parse
 * time.
 *
 * The following macros are supported within CEL:
 *
 * Aggregate type macros may be applied to all elements in a list or all keys
 * in a map:
 *
 * *  `all`, `exists`, `exists_one` -  test a predicate expression against
 *    the inputs and return `true` if the predicate is satisfied for all,
 *    any, or only one value `list.all(x, x < 10)`.
 * *  `filter` - test a predicate expression against the inputs and return
 *    the subset of elements which satisfy the predicate:
 *    `payments.filter(p, p > 1000)`.
 * *  `map` - apply an expression to all elements in the input and return the
 *    output aggregate type: `[1, 2, 3].map(i, i * i)`.
 *
 * The `has(m.x)` macro tests whether the property `x` is present in struct
 * `m`. The semantics of this macro depend on the type of `m`. For proto2
 * messages `has(m.x)` is defined as 'defined, but not set`. For proto3, the
 * macro tests whether the property is set to its default. For map and struct
 * types, the macro tests whether the property `x` is defined on `m`.
 */
export interface Expr_Comprehension {
    /** The name of the iteration variable. */
    iterVar: string;
    /** The range over which var iterates. */
    iterRange?: Expr;
    /** The name of the variable used for accumulation of the result. */
    accuVar: string;
    /** The initial value of the accumulator. */
    accuInit?: Expr;
    /**
     * An expression which can contain iter_var and accu_var.
     *
     * Returns false when the result has been computed and may be used as
     * a hint to short-circuit the remainder of the comprehension.
     */
    loopCondition?: Expr;
    /**
     * An expression which can contain iter_var and accu_var.
     *
     * Computes the next value of accu_var.
     */
    loopStep?: Expr;
    /**
     * An expression which can contain accu_var.
     *
     * Computes the result.
     */
    result?: Expr;
}
export interface Expr_ComprehensionProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Comprehension";
    value: Uint8Array;
}
/**
 * A comprehension expression applied to a list or map.
 *
 * Comprehensions are not part of the core syntax, but enabled with macros.
 * A macro matches a specific call signature within a parsed AST and replaces
 * the call with an alternate AST block. Macro expansion happens at parse
 * time.
 *
 * The following macros are supported within CEL:
 *
 * Aggregate type macros may be applied to all elements in a list or all keys
 * in a map:
 *
 * *  `all`, `exists`, `exists_one` -  test a predicate expression against
 *    the inputs and return `true` if the predicate is satisfied for all,
 *    any, or only one value `list.all(x, x < 10)`.
 * *  `filter` - test a predicate expression against the inputs and return
 *    the subset of elements which satisfy the predicate:
 *    `payments.filter(p, p > 1000)`.
 * *  `map` - apply an expression to all elements in the input and return the
 *    output aggregate type: `[1, 2, 3].map(i, i * i)`.
 *
 * The `has(m.x)` macro tests whether the property `x` is present in struct
 * `m`. The semantics of this macro depend on the type of `m`. For proto2
 * messages `has(m.x)` is defined as 'defined, but not set`. For proto3, the
 * macro tests whether the property is set to its default. For map and struct
 * types, the macro tests whether the property `x` is defined on `m`.
 */
export interface Expr_ComprehensionAmino {
    /** The name of the iteration variable. */
    iter_var?: string;
    /** The range over which var iterates. */
    iter_range?: ExprAmino;
    /** The name of the variable used for accumulation of the result. */
    accu_var?: string;
    /** The initial value of the accumulator. */
    accu_init?: ExprAmino;
    /**
     * An expression which can contain iter_var and accu_var.
     *
     * Returns false when the result has been computed and may be used as
     * a hint to short-circuit the remainder of the comprehension.
     */
    loop_condition?: ExprAmino;
    /**
     * An expression which can contain iter_var and accu_var.
     *
     * Computes the next value of accu_var.
     */
    loop_step?: ExprAmino;
    /**
     * An expression which can contain accu_var.
     *
     * Computes the result.
     */
    result?: ExprAmino;
}
export interface Expr_ComprehensionAminoMsg {
    type: "/google.api.expr.v1alpha1.Comprehension";
    value: Expr_ComprehensionAmino;
}
/**
 * A comprehension expression applied to a list or map.
 *
 * Comprehensions are not part of the core syntax, but enabled with macros.
 * A macro matches a specific call signature within a parsed AST and replaces
 * the call with an alternate AST block. Macro expansion happens at parse
 * time.
 *
 * The following macros are supported within CEL:
 *
 * Aggregate type macros may be applied to all elements in a list or all keys
 * in a map:
 *
 * *  `all`, `exists`, `exists_one` -  test a predicate expression against
 *    the inputs and return `true` if the predicate is satisfied for all,
 *    any, or only one value `list.all(x, x < 10)`.
 * *  `filter` - test a predicate expression against the inputs and return
 *    the subset of elements which satisfy the predicate:
 *    `payments.filter(p, p > 1000)`.
 * *  `map` - apply an expression to all elements in the input and return the
 *    output aggregate type: `[1, 2, 3].map(i, i * i)`.
 *
 * The `has(m.x)` macro tests whether the property `x` is present in struct
 * `m`. The semantics of this macro depend on the type of `m`. For proto2
 * messages `has(m.x)` is defined as 'defined, but not set`. For proto3, the
 * macro tests whether the property is set to its default. For map and struct
 * types, the macro tests whether the property `x` is defined on `m`.
 */
export interface Expr_ComprehensionSDKType {
    iter_var: string;
    iter_range?: ExprSDKType;
    accu_var: string;
    accu_init?: ExprSDKType;
    loop_condition?: ExprSDKType;
    loop_step?: ExprSDKType;
    result?: ExprSDKType;
}
/**
 * Represents a primitive literal.
 *
 * Named 'Constant' here for backwards compatibility.
 *
 * This is similar as the primitives supported in the well-known type
 * `google.protobuf.Value`, but richer so it can represent CEL's full range of
 * primitives.
 *
 * Lists and structs are not included as constants as these aggregate types may
 * contain [Expr][google.api.expr.v1alpha1.Expr] elements which require evaluation and are thus not constant.
 *
 * Examples of literals include: `"hello"`, `b'bytes'`, `1u`, `4.2`, `-2`,
 * `true`, `null`.
 */
export interface Constant {
    /** null value. */
    nullValue?: NullValue;
    /** boolean value. */
    boolValue?: boolean;
    /** int64 value. */
    int64Value?: bigint;
    /** uint64 value. */
    uint64Value?: bigint;
    /** double value. */
    doubleValue?: number;
    /** string value. */
    stringValue?: string;
    /** bytes value. */
    bytesValue?: Uint8Array;
    /**
     * protobuf.Duration value.
     *
     * Deprecated: duration is no longer considered a builtin cel type.
     */
    /** @deprecated */
    durationValue?: Duration;
    /**
     * protobuf.Timestamp value.
     *
     * Deprecated: timestamp is no longer considered a builtin cel type.
     */
    /** @deprecated */
    timestampValue?: Date;
}
export interface ConstantProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Constant";
    value: Uint8Array;
}
/**
 * Represents a primitive literal.
 *
 * Named 'Constant' here for backwards compatibility.
 *
 * This is similar as the primitives supported in the well-known type
 * `google.protobuf.Value`, but richer so it can represent CEL's full range of
 * primitives.
 *
 * Lists and structs are not included as constants as these aggregate types may
 * contain [Expr][google.api.expr.v1alpha1.Expr] elements which require evaluation and are thus not constant.
 *
 * Examples of literals include: `"hello"`, `b'bytes'`, `1u`, `4.2`, `-2`,
 * `true`, `null`.
 */
export interface ConstantAmino {
    /** null value. */
    null_value?: NullValue;
    /** boolean value. */
    bool_value?: boolean;
    /** int64 value. */
    int64_value?: string;
    /** uint64 value. */
    uint64_value?: string;
    /** double value. */
    double_value?: number;
    /** string value. */
    string_value?: string;
    /** bytes value. */
    bytes_value?: string;
    /**
     * protobuf.Duration value.
     *
     * Deprecated: duration is no longer considered a builtin cel type.
     */
    /** @deprecated */
    duration_value?: DurationAmino;
    /**
     * protobuf.Timestamp value.
     *
     * Deprecated: timestamp is no longer considered a builtin cel type.
     */
    /** @deprecated */
    timestamp_value?: string;
}
export interface ConstantAminoMsg {
    type: "/google.api.expr.v1alpha1.Constant";
    value: ConstantAmino;
}
/**
 * Represents a primitive literal.
 *
 * Named 'Constant' here for backwards compatibility.
 *
 * This is similar as the primitives supported in the well-known type
 * `google.protobuf.Value`, but richer so it can represent CEL's full range of
 * primitives.
 *
 * Lists and structs are not included as constants as these aggregate types may
 * contain [Expr][google.api.expr.v1alpha1.Expr] elements which require evaluation and are thus not constant.
 *
 * Examples of literals include: `"hello"`, `b'bytes'`, `1u`, `4.2`, `-2`,
 * `true`, `null`.
 */
export interface ConstantSDKType {
    null_value?: NullValue;
    bool_value?: boolean;
    int64_value?: bigint;
    uint64_value?: bigint;
    double_value?: number;
    string_value?: string;
    bytes_value?: Uint8Array;
    /** @deprecated */
    duration_value?: DurationSDKType;
    /** @deprecated */
    timestamp_value?: Date;
}
export interface SourceInfo_PositionsEntry {
    key: bigint;
    value: number;
}
export interface SourceInfo_PositionsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface SourceInfo_PositionsEntryAmino {
    key?: string;
    value?: number;
}
export interface SourceInfo_PositionsEntryAminoMsg {
    type: string;
    value: SourceInfo_PositionsEntryAmino;
}
export interface SourceInfo_PositionsEntrySDKType {
    key: bigint;
    value: number;
}
export interface SourceInfo_MacroCallsEntry {
    key: bigint;
    value?: Expr;
}
export interface SourceInfo_MacroCallsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface SourceInfo_MacroCallsEntryAmino {
    key?: string;
    value?: ExprAmino;
}
export interface SourceInfo_MacroCallsEntryAminoMsg {
    type: string;
    value: SourceInfo_MacroCallsEntryAmino;
}
export interface SourceInfo_MacroCallsEntrySDKType {
    key: bigint;
    value?: ExprSDKType;
}
/** Source information collected at parse time. */
export interface SourceInfo {
    /** The syntax version of the source, e.g. `cel1`. */
    syntaxVersion: string;
    /**
     * The location name. All position information attached to an expression is
     * relative to this location.
     *
     * The location could be a file, UI element, or similar. For example,
     * `acme/app/AnvilPolicy.cel`.
     */
    location: string;
    /**
     * Monotonically increasing list of code point offsets where newlines
     * `\n` appear.
     *
     * The line number of a given position is the index `i` where for a given
     * `id` the `line_offsets[i] < id_positions[id] < line_offsets[i+1]`. The
     * column may be derivd from `id_positions[id] - line_offsets[i]`.
     */
    lineOffsets: number[];
    /**
     * A map from the parse node id (e.g. `Expr.id`) to the code point offset
     * within the source.
     */
    positions: {
        [key: bigint]: number;
    };
    /**
     * A map from the parse node id where a macro replacement was made to the
     * call `Expr` that resulted in a macro expansion.
     *
     * For example, `has(value.field)` is a function call that is replaced by a
     * `test_only` field selection in the AST. Likewise, the call
     * `list.exists(e, e > 10)` translates to a comprehension expression. The key
     * in the map corresponds to the expression id of the expanded macro, and the
     * value is the call `Expr` that was replaced.
     */
    macroCalls: {
        [key: bigint]: Expr;
    };
}
export interface SourceInfoProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.SourceInfo";
    value: Uint8Array;
}
/** Source information collected at parse time. */
export interface SourceInfoAmino {
    /** The syntax version of the source, e.g. `cel1`. */
    syntax_version?: string;
    /**
     * The location name. All position information attached to an expression is
     * relative to this location.
     *
     * The location could be a file, UI element, or similar. For example,
     * `acme/app/AnvilPolicy.cel`.
     */
    location?: string;
    /**
     * Monotonically increasing list of code point offsets where newlines
     * `\n` appear.
     *
     * The line number of a given position is the index `i` where for a given
     * `id` the `line_offsets[i] < id_positions[id] < line_offsets[i+1]`. The
     * column may be derivd from `id_positions[id] - line_offsets[i]`.
     */
    line_offsets?: number[];
    /**
     * A map from the parse node id (e.g. `Expr.id`) to the code point offset
     * within the source.
     */
    positions?: {
        [key: string]: number;
    };
    /**
     * A map from the parse node id where a macro replacement was made to the
     * call `Expr` that resulted in a macro expansion.
     *
     * For example, `has(value.field)` is a function call that is replaced by a
     * `test_only` field selection in the AST. Likewise, the call
     * `list.exists(e, e > 10)` translates to a comprehension expression. The key
     * in the map corresponds to the expression id of the expanded macro, and the
     * value is the call `Expr` that was replaced.
     */
    macro_calls?: {
        [key: string]: ExprAmino;
    };
}
export interface SourceInfoAminoMsg {
    type: "/google.api.expr.v1alpha1.SourceInfo";
    value: SourceInfoAmino;
}
/** Source information collected at parse time. */
export interface SourceInfoSDKType {
    syntax_version: string;
    location: string;
    line_offsets: number[];
    positions: {
        [key: bigint]: number;
    };
    macro_calls: {
        [key: bigint]: ExprSDKType;
    };
}
/** A specific position in source. */
export interface SourcePosition {
    /** The soucre location name (e.g. file name). */
    location: string;
    /** The UTF-8 code unit offset. */
    offset: number;
    /**
     * The 1-based index of the starting line in the source text
     * where the issue occurs, or 0 if unknown.
     */
    line: number;
    /**
     * The 0-based index of the starting position within the line of source text
     * where the issue occurs.  Only meaningful if line is nonzero.
     */
    column: number;
}
export interface SourcePositionProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.SourcePosition";
    value: Uint8Array;
}
/** A specific position in source. */
export interface SourcePositionAmino {
    /** The soucre location name (e.g. file name). */
    location?: string;
    /** The UTF-8 code unit offset. */
    offset?: number;
    /**
     * The 1-based index of the starting line in the source text
     * where the issue occurs, or 0 if unknown.
     */
    line?: number;
    /**
     * The 0-based index of the starting position within the line of source text
     * where the issue occurs.  Only meaningful if line is nonzero.
     */
    column?: number;
}
export interface SourcePositionAminoMsg {
    type: "/google.api.expr.v1alpha1.SourcePosition";
    value: SourcePositionAmino;
}
/** A specific position in source. */
export interface SourcePositionSDKType {
    location: string;
    offset: number;
    line: number;
    column: number;
}
export declare const ParsedExpr: {
    typeUrl: string;
    is(o: any): o is ParsedExpr;
    isSDK(o: any): o is ParsedExprSDKType;
    isAmino(o: any): o is ParsedExprAmino;
    encode(message: ParsedExpr, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ParsedExpr;
    fromJSON(object: any): ParsedExpr;
    toJSON(message: ParsedExpr): JsonSafe<ParsedExpr>;
    fromPartial(object: DeepPartial<ParsedExpr>): ParsedExpr;
    fromSDK(object: ParsedExprSDKType): ParsedExpr;
    fromSDKJSON(object: any): ParsedExprSDKType;
    toSDK(message: ParsedExpr): ParsedExprSDKType;
    fromAmino(object: ParsedExprAmino): ParsedExpr;
    toAmino(message: ParsedExpr): ParsedExprAmino;
    fromAminoMsg(object: ParsedExprAminoMsg): ParsedExpr;
    fromProtoMsg(message: ParsedExprProtoMsg): ParsedExpr;
    toProto(message: ParsedExpr): Uint8Array;
    toProtoMsg(message: ParsedExpr): ParsedExprProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr: {
    typeUrl: string;
    is(o: any): o is Expr;
    isSDK(o: any): o is ExprSDKType;
    isAmino(o: any): o is ExprAmino;
    encode(message: Expr, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr;
    fromJSON(object: any): Expr;
    toJSON(message: Expr): JsonSafe<Expr>;
    fromPartial(object: DeepPartial<Expr>): Expr;
    fromSDK(object: ExprSDKType): Expr;
    fromSDKJSON(object: any): ExprSDKType;
    toSDK(message: Expr): ExprSDKType;
    fromAmino(object: ExprAmino): Expr;
    toAmino(message: Expr): ExprAmino;
    fromAminoMsg(object: ExprAminoMsg): Expr;
    fromProtoMsg(message: ExprProtoMsg): Expr;
    toProto(message: Expr): Uint8Array;
    toProtoMsg(message: Expr): ExprProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_Ident: {
    typeUrl: string;
    is(o: any): o is Expr_Ident;
    isSDK(o: any): o is Expr_IdentSDKType;
    isAmino(o: any): o is Expr_IdentAmino;
    encode(message: Expr_Ident, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_Ident;
    fromJSON(object: any): Expr_Ident;
    toJSON(message: Expr_Ident): JsonSafe<Expr_Ident>;
    fromPartial(object: DeepPartial<Expr_Ident>): Expr_Ident;
    fromSDK(object: Expr_IdentSDKType): Expr_Ident;
    fromSDKJSON(object: any): Expr_IdentSDKType;
    toSDK(message: Expr_Ident): Expr_IdentSDKType;
    fromAmino(object: Expr_IdentAmino): Expr_Ident;
    toAmino(message: Expr_Ident): Expr_IdentAmino;
    fromAminoMsg(object: Expr_IdentAminoMsg): Expr_Ident;
    fromProtoMsg(message: Expr_IdentProtoMsg): Expr_Ident;
    toProto(message: Expr_Ident): Uint8Array;
    toProtoMsg(message: Expr_Ident): Expr_IdentProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_Select: {
    typeUrl: string;
    is(o: any): o is Expr_Select;
    isSDK(o: any): o is Expr_SelectSDKType;
    isAmino(o: any): o is Expr_SelectAmino;
    encode(message: Expr_Select, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_Select;
    fromJSON(object: any): Expr_Select;
    toJSON(message: Expr_Select): JsonSafe<Expr_Select>;
    fromPartial(object: DeepPartial<Expr_Select>): Expr_Select;
    fromSDK(object: Expr_SelectSDKType): Expr_Select;
    fromSDKJSON(object: any): Expr_SelectSDKType;
    toSDK(message: Expr_Select): Expr_SelectSDKType;
    fromAmino(object: Expr_SelectAmino): Expr_Select;
    toAmino(message: Expr_Select): Expr_SelectAmino;
    fromAminoMsg(object: Expr_SelectAminoMsg): Expr_Select;
    fromProtoMsg(message: Expr_SelectProtoMsg): Expr_Select;
    toProto(message: Expr_Select): Uint8Array;
    toProtoMsg(message: Expr_Select): Expr_SelectProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_Call: {
    typeUrl: string;
    is(o: any): o is Expr_Call;
    isSDK(o: any): o is Expr_CallSDKType;
    isAmino(o: any): o is Expr_CallAmino;
    encode(message: Expr_Call, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_Call;
    fromJSON(object: any): Expr_Call;
    toJSON(message: Expr_Call): JsonSafe<Expr_Call>;
    fromPartial(object: DeepPartial<Expr_Call>): Expr_Call;
    fromSDK(object: Expr_CallSDKType): Expr_Call;
    fromSDKJSON(object: any): Expr_CallSDKType;
    toSDK(message: Expr_Call): Expr_CallSDKType;
    fromAmino(object: Expr_CallAmino): Expr_Call;
    toAmino(message: Expr_Call): Expr_CallAmino;
    fromAminoMsg(object: Expr_CallAminoMsg): Expr_Call;
    fromProtoMsg(message: Expr_CallProtoMsg): Expr_Call;
    toProto(message: Expr_Call): Uint8Array;
    toProtoMsg(message: Expr_Call): Expr_CallProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_CreateList: {
    typeUrl: string;
    is(o: any): o is Expr_CreateList;
    isSDK(o: any): o is Expr_CreateListSDKType;
    isAmino(o: any): o is Expr_CreateListAmino;
    encode(message: Expr_CreateList, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_CreateList;
    fromJSON(object: any): Expr_CreateList;
    toJSON(message: Expr_CreateList): JsonSafe<Expr_CreateList>;
    fromPartial(object: DeepPartial<Expr_CreateList>): Expr_CreateList;
    fromSDK(object: Expr_CreateListSDKType): Expr_CreateList;
    fromSDKJSON(object: any): Expr_CreateListSDKType;
    toSDK(message: Expr_CreateList): Expr_CreateListSDKType;
    fromAmino(object: Expr_CreateListAmino): Expr_CreateList;
    toAmino(message: Expr_CreateList): Expr_CreateListAmino;
    fromAminoMsg(object: Expr_CreateListAminoMsg): Expr_CreateList;
    fromProtoMsg(message: Expr_CreateListProtoMsg): Expr_CreateList;
    toProto(message: Expr_CreateList): Uint8Array;
    toProtoMsg(message: Expr_CreateList): Expr_CreateListProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_CreateStruct: {
    typeUrl: string;
    is(o: any): o is Expr_CreateStruct;
    isSDK(o: any): o is Expr_CreateStructSDKType;
    isAmino(o: any): o is Expr_CreateStructAmino;
    encode(message: Expr_CreateStruct, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_CreateStruct;
    fromJSON(object: any): Expr_CreateStruct;
    toJSON(message: Expr_CreateStruct): JsonSafe<Expr_CreateStruct>;
    fromPartial(object: DeepPartial<Expr_CreateStruct>): Expr_CreateStruct;
    fromSDK(object: Expr_CreateStructSDKType): Expr_CreateStruct;
    fromSDKJSON(object: any): Expr_CreateStructSDKType;
    toSDK(message: Expr_CreateStruct): Expr_CreateStructSDKType;
    fromAmino(object: Expr_CreateStructAmino): Expr_CreateStruct;
    toAmino(message: Expr_CreateStruct): Expr_CreateStructAmino;
    fromAminoMsg(object: Expr_CreateStructAminoMsg): Expr_CreateStruct;
    fromProtoMsg(message: Expr_CreateStructProtoMsg): Expr_CreateStruct;
    toProto(message: Expr_CreateStruct): Uint8Array;
    toProtoMsg(message: Expr_CreateStruct): Expr_CreateStructProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_CreateStruct_Entry: {
    typeUrl: string;
    is(o: any): o is Expr_CreateStruct_Entry;
    isSDK(o: any): o is Expr_CreateStruct_EntrySDKType;
    isAmino(o: any): o is Expr_CreateStruct_EntryAmino;
    encode(message: Expr_CreateStruct_Entry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_CreateStruct_Entry;
    fromJSON(object: any): Expr_CreateStruct_Entry;
    toJSON(message: Expr_CreateStruct_Entry): JsonSafe<Expr_CreateStruct_Entry>;
    fromPartial(object: DeepPartial<Expr_CreateStruct_Entry>): Expr_CreateStruct_Entry;
    fromSDK(object: Expr_CreateStruct_EntrySDKType): Expr_CreateStruct_Entry;
    fromSDKJSON(object: any): Expr_CreateStruct_EntrySDKType;
    toSDK(message: Expr_CreateStruct_Entry): Expr_CreateStruct_EntrySDKType;
    fromAmino(object: Expr_CreateStruct_EntryAmino): Expr_CreateStruct_Entry;
    toAmino(message: Expr_CreateStruct_Entry): Expr_CreateStruct_EntryAmino;
    fromAminoMsg(object: Expr_CreateStruct_EntryAminoMsg): Expr_CreateStruct_Entry;
    fromProtoMsg(message: Expr_CreateStruct_EntryProtoMsg): Expr_CreateStruct_Entry;
    toProto(message: Expr_CreateStruct_Entry): Uint8Array;
    toProtoMsg(message: Expr_CreateStruct_Entry): Expr_CreateStruct_EntryProtoMsg;
    registerTypeUrl(): void;
};
export declare const Expr_Comprehension: {
    typeUrl: string;
    is(o: any): o is Expr_Comprehension;
    isSDK(o: any): o is Expr_ComprehensionSDKType;
    isAmino(o: any): o is Expr_ComprehensionAmino;
    encode(message: Expr_Comprehension, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Expr_Comprehension;
    fromJSON(object: any): Expr_Comprehension;
    toJSON(message: Expr_Comprehension): JsonSafe<Expr_Comprehension>;
    fromPartial(object: DeepPartial<Expr_Comprehension>): Expr_Comprehension;
    fromSDK(object: Expr_ComprehensionSDKType): Expr_Comprehension;
    fromSDKJSON(object: any): Expr_ComprehensionSDKType;
    toSDK(message: Expr_Comprehension): Expr_ComprehensionSDKType;
    fromAmino(object: Expr_ComprehensionAmino): Expr_Comprehension;
    toAmino(message: Expr_Comprehension): Expr_ComprehensionAmino;
    fromAminoMsg(object: Expr_ComprehensionAminoMsg): Expr_Comprehension;
    fromProtoMsg(message: Expr_ComprehensionProtoMsg): Expr_Comprehension;
    toProto(message: Expr_Comprehension): Uint8Array;
    toProtoMsg(message: Expr_Comprehension): Expr_ComprehensionProtoMsg;
    registerTypeUrl(): void;
};
export declare const Constant: {
    typeUrl: string;
    is(o: any): o is Constant;
    isSDK(o: any): o is ConstantSDKType;
    isAmino(o: any): o is ConstantAmino;
    encode(message: Constant, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Constant;
    fromJSON(object: any): Constant;
    toJSON(message: Constant): JsonSafe<Constant>;
    fromPartial(object: DeepPartial<Constant>): Constant;
    fromSDK(object: ConstantSDKType): Constant;
    fromSDKJSON(object: any): ConstantSDKType;
    toSDK(message: Constant): ConstantSDKType;
    fromAmino(object: ConstantAmino): Constant;
    toAmino(message: Constant): ConstantAmino;
    fromAminoMsg(object: ConstantAminoMsg): Constant;
    fromProtoMsg(message: ConstantProtoMsg): Constant;
    toProto(message: Constant): Uint8Array;
    toProtoMsg(message: Constant): ConstantProtoMsg;
    registerTypeUrl(): void;
};
export declare const SourceInfo_PositionsEntry: {
    encode(message: SourceInfo_PositionsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourceInfo_PositionsEntry;
    fromJSON(object: any): SourceInfo_PositionsEntry;
    toJSON(message: SourceInfo_PositionsEntry): JsonSafe<SourceInfo_PositionsEntry>;
    fromPartial(object: DeepPartial<SourceInfo_PositionsEntry>): SourceInfo_PositionsEntry;
    fromSDK(object: SourceInfo_PositionsEntrySDKType): SourceInfo_PositionsEntry;
    fromSDKJSON(object: any): SourceInfo_PositionsEntrySDKType;
    toSDK(message: SourceInfo_PositionsEntry): SourceInfo_PositionsEntrySDKType;
    fromAmino(object: SourceInfo_PositionsEntryAmino): SourceInfo_PositionsEntry;
    toAmino(message: SourceInfo_PositionsEntry): SourceInfo_PositionsEntryAmino;
    fromAminoMsg(object: SourceInfo_PositionsEntryAminoMsg): SourceInfo_PositionsEntry;
    fromProtoMsg(message: SourceInfo_PositionsEntryProtoMsg): SourceInfo_PositionsEntry;
    toProto(message: SourceInfo_PositionsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const SourceInfo_MacroCallsEntry: {
    encode(message: SourceInfo_MacroCallsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourceInfo_MacroCallsEntry;
    fromJSON(object: any): SourceInfo_MacroCallsEntry;
    toJSON(message: SourceInfo_MacroCallsEntry): JsonSafe<SourceInfo_MacroCallsEntry>;
    fromPartial(object: DeepPartial<SourceInfo_MacroCallsEntry>): SourceInfo_MacroCallsEntry;
    fromSDK(object: SourceInfo_MacroCallsEntrySDKType): SourceInfo_MacroCallsEntry;
    fromSDKJSON(object: any): SourceInfo_MacroCallsEntrySDKType;
    toSDK(message: SourceInfo_MacroCallsEntry): SourceInfo_MacroCallsEntrySDKType;
    fromAmino(object: SourceInfo_MacroCallsEntryAmino): SourceInfo_MacroCallsEntry;
    toAmino(message: SourceInfo_MacroCallsEntry): SourceInfo_MacroCallsEntryAmino;
    fromAminoMsg(object: SourceInfo_MacroCallsEntryAminoMsg): SourceInfo_MacroCallsEntry;
    fromProtoMsg(message: SourceInfo_MacroCallsEntryProtoMsg): SourceInfo_MacroCallsEntry;
    toProto(message: SourceInfo_MacroCallsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const SourceInfo: {
    typeUrl: string;
    is(o: any): o is SourceInfo;
    isSDK(o: any): o is SourceInfoSDKType;
    isAmino(o: any): o is SourceInfoAmino;
    encode(message: SourceInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourceInfo;
    fromJSON(object: any): SourceInfo;
    toJSON(message: SourceInfo): JsonSafe<SourceInfo>;
    fromPartial(object: DeepPartial<SourceInfo>): SourceInfo;
    fromSDK(object: SourceInfoSDKType): SourceInfo;
    fromSDKJSON(object: any): SourceInfoSDKType;
    toSDK(message: SourceInfo): SourceInfoSDKType;
    fromAmino(object: SourceInfoAmino): SourceInfo;
    toAmino(message: SourceInfo): SourceInfoAmino;
    fromAminoMsg(object: SourceInfoAminoMsg): SourceInfo;
    fromProtoMsg(message: SourceInfoProtoMsg): SourceInfo;
    toProto(message: SourceInfo): Uint8Array;
    toProtoMsg(message: SourceInfo): SourceInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const SourcePosition: {
    typeUrl: string;
    is(o: any): o is SourcePosition;
    isSDK(o: any): o is SourcePositionSDKType;
    isAmino(o: any): o is SourcePositionAmino;
    encode(message: SourcePosition, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourcePosition;
    fromJSON(object: any): SourcePosition;
    toJSON(message: SourcePosition): JsonSafe<SourcePosition>;
    fromPartial(object: DeepPartial<SourcePosition>): SourcePosition;
    fromSDK(object: SourcePositionSDKType): SourcePosition;
    fromSDKJSON(object: any): SourcePositionSDKType;
    toSDK(message: SourcePosition): SourcePositionSDKType;
    fromAmino(object: SourcePositionAmino): SourcePosition;
    toAmino(message: SourcePosition): SourcePositionAmino;
    fromAminoMsg(object: SourcePositionAminoMsg): SourcePosition;
    fromProtoMsg(message: SourcePositionProtoMsg): SourcePosition;
    toProto(message: SourcePosition): Uint8Array;
    toProtoMsg(message: SourcePosition): SourcePositionProtoMsg;
    registerTypeUrl(): void;
};
