import { NullValue } from "../../../protobuf/struct";
import { Any, AnyAmino, AnySDKType } from "../../../protobuf/any";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.expr.v1alpha1";
/**
 * Represents a CEL value.
 *
 * This is similar to `google.protobuf.Value`, but can represent CEL's full
 * range of values.
 */
export interface Value {
    /** Null value. */
    nullValue?: NullValue;
    /** Boolean value. */
    boolValue?: boolean;
    /** Signed integer value. */
    int64Value?: bigint;
    /** Unsigned integer value. */
    uint64Value?: bigint;
    /** Floating point value. */
    doubleValue?: number;
    /** UTF-8 string value. */
    stringValue?: string;
    /** Byte string value. */
    bytesValue?: Uint8Array;
    /** An enum value. */
    enumValue?: EnumValue;
    /** The proto message backing an object value. */
    objectValue?: Any;
    /** Map value. */
    mapValue?: MapValue;
    /** List value. */
    listValue?: ListValue;
    /** Type value. */
    typeValue?: string;
}
export interface ValueProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Value";
    value: Uint8Array;
}
/**
 * Represents a CEL value.
 *
 * This is similar to `google.protobuf.Value`, but can represent CEL's full
 * range of values.
 */
export interface ValueAmino {
    /** Null value. */
    null_value?: NullValue;
    /** Boolean value. */
    bool_value?: boolean;
    /** Signed integer value. */
    int64_value?: string;
    /** Unsigned integer value. */
    uint64_value?: string;
    /** Floating point value. */
    double_value?: number;
    /** UTF-8 string value. */
    string_value?: string;
    /** Byte string value. */
    bytes_value?: string;
    /** An enum value. */
    enum_value?: EnumValueAmino;
    /** The proto message backing an object value. */
    object_value?: AnyAmino;
    /** Map value. */
    map_value?: MapValueAmino;
    /** List value. */
    list_value?: ListValueAmino;
    /** Type value. */
    type_value?: string;
}
export interface ValueAminoMsg {
    type: "/google.api.expr.v1alpha1.Value";
    value: ValueAmino;
}
/**
 * Represents a CEL value.
 *
 * This is similar to `google.protobuf.Value`, but can represent CEL's full
 * range of values.
 */
export interface ValueSDKType {
    null_value?: NullValue;
    bool_value?: boolean;
    int64_value?: bigint;
    uint64_value?: bigint;
    double_value?: number;
    string_value?: string;
    bytes_value?: Uint8Array;
    enum_value?: EnumValueSDKType;
    object_value?: AnySDKType;
    map_value?: MapValueSDKType;
    list_value?: ListValueSDKType;
    type_value?: string;
}
/** An enum value. */
export interface EnumValue {
    /** The fully qualified name of the enum type. */
    type: string;
    /** The value of the enum. */
    value: number;
}
export interface EnumValueProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.EnumValue";
    value: Uint8Array;
}
/** An enum value. */
export interface EnumValueAmino {
    /** The fully qualified name of the enum type. */
    type?: string;
    /** The value of the enum. */
    value?: number;
}
export interface EnumValueAminoMsg {
    type: "/google.api.expr.v1alpha1.EnumValue";
    value: EnumValueAmino;
}
/** An enum value. */
export interface EnumValueSDKType {
    type: string;
    value: number;
}
/**
 * A list.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface ListValue {
    /** The ordered values in the list. */
    values: Value[];
}
export interface ListValueProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.ListValue";
    value: Uint8Array;
}
/**
 * A list.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface ListValueAmino {
    /** The ordered values in the list. */
    values?: ValueAmino[];
}
export interface ListValueAminoMsg {
    type: "/google.api.expr.v1alpha1.ListValue";
    value: ListValueAmino;
}
/**
 * A list.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface ListValueSDKType {
    values: ValueSDKType[];
}
/**
 * A map.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface MapValue {
    /**
     * The set of map entries.
     *
     * CEL has fewer restrictions on keys, so a protobuf map represenation
     * cannot be used.
     */
    entries: MapValue_Entry[];
}
export interface MapValueProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.MapValue";
    value: Uint8Array;
}
/**
 * A map.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface MapValueAmino {
    /**
     * The set of map entries.
     *
     * CEL has fewer restrictions on keys, so a protobuf map represenation
     * cannot be used.
     */
    entries?: MapValue_EntryAmino[];
}
export interface MapValueAminoMsg {
    type: "/google.api.expr.v1alpha1.MapValue";
    value: MapValueAmino;
}
/**
 * A map.
 *
 * Wrapped in a message so 'not set' and empty can be differentiated, which is
 * required for use in a 'oneof'.
 */
export interface MapValueSDKType {
    entries: MapValue_EntrySDKType[];
}
/** An entry in the map. */
export interface MapValue_Entry {
    /**
     * The key.
     *
     * Must be unique with in the map.
     * Currently only boolean, int, uint, and string values can be keys.
     */
    key?: Value;
    /** The value. */
    value?: Value;
}
export interface MapValue_EntryProtoMsg {
    typeUrl: "/google.api.expr.v1alpha1.Entry";
    value: Uint8Array;
}
/** An entry in the map. */
export interface MapValue_EntryAmino {
    /**
     * The key.
     *
     * Must be unique with in the map.
     * Currently only boolean, int, uint, and string values can be keys.
     */
    key?: ValueAmino;
    /** The value. */
    value?: ValueAmino;
}
export interface MapValue_EntryAminoMsg {
    type: "/google.api.expr.v1alpha1.Entry";
    value: MapValue_EntryAmino;
}
/** An entry in the map. */
export interface MapValue_EntrySDKType {
    key?: ValueSDKType;
    value?: ValueSDKType;
}
export declare const Value: {
    typeUrl: string;
    is(o: any): o is Value;
    isSDK(o: any): o is ValueSDKType;
    isAmino(o: any): o is ValueAmino;
    encode(message: Value, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Value;
    fromJSON(object: any): Value;
    toJSON(message: Value): JsonSafe<Value>;
    fromPartial(object: DeepPartial<Value>): Value;
    fromSDK(object: ValueSDKType): Value;
    fromSDKJSON(object: any): ValueSDKType;
    toSDK(message: Value): ValueSDKType;
    fromAmino(object: ValueAmino): Value;
    toAmino(message: Value): ValueAmino;
    fromAminoMsg(object: ValueAminoMsg): Value;
    fromProtoMsg(message: ValueProtoMsg): Value;
    toProto(message: Value): Uint8Array;
    toProtoMsg(message: Value): ValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const EnumValue: {
    typeUrl: string;
    is(o: any): o is EnumValue;
    isSDK(o: any): o is EnumValueSDKType;
    isAmino(o: any): o is EnumValueAmino;
    encode(message: EnumValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EnumValue;
    fromJSON(object: any): EnumValue;
    toJSON(message: EnumValue): JsonSafe<EnumValue>;
    fromPartial(object: DeepPartial<EnumValue>): EnumValue;
    fromSDK(object: EnumValueSDKType): EnumValue;
    fromSDKJSON(object: any): EnumValueSDKType;
    toSDK(message: EnumValue): EnumValueSDKType;
    fromAmino(object: EnumValueAmino): EnumValue;
    toAmino(message: EnumValue): EnumValueAmino;
    fromAminoMsg(object: EnumValueAminoMsg): EnumValue;
    fromProtoMsg(message: EnumValueProtoMsg): EnumValue;
    toProto(message: EnumValue): Uint8Array;
    toProtoMsg(message: EnumValue): EnumValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListValue: {
    typeUrl: string;
    is(o: any): o is ListValue;
    isSDK(o: any): o is ListValueSDKType;
    isAmino(o: any): o is ListValueAmino;
    encode(message: ListValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListValue;
    fromJSON(object: any): ListValue;
    toJSON(message: ListValue): JsonSafe<ListValue>;
    fromPartial(object: DeepPartial<ListValue>): ListValue;
    fromSDK(object: ListValueSDKType): ListValue;
    fromSDKJSON(object: any): ListValueSDKType;
    toSDK(message: ListValue): ListValueSDKType;
    fromAmino(object: ListValueAmino): ListValue;
    toAmino(message: ListValue): ListValueAmino;
    fromAminoMsg(object: ListValueAminoMsg): ListValue;
    fromProtoMsg(message: ListValueProtoMsg): ListValue;
    toProto(message: ListValue): Uint8Array;
    toProtoMsg(message: ListValue): ListValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const MapValue: {
    typeUrl: string;
    is(o: any): o is MapValue;
    isSDK(o: any): o is MapValueSDKType;
    isAmino(o: any): o is MapValueAmino;
    encode(message: MapValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MapValue;
    fromJSON(object: any): MapValue;
    toJSON(message: MapValue): JsonSafe<MapValue>;
    fromPartial(object: DeepPartial<MapValue>): MapValue;
    fromSDK(object: MapValueSDKType): MapValue;
    fromSDKJSON(object: any): MapValueSDKType;
    toSDK(message: MapValue): MapValueSDKType;
    fromAmino(object: MapValueAmino): MapValue;
    toAmino(message: MapValue): MapValueAmino;
    fromAminoMsg(object: MapValueAminoMsg): MapValue;
    fromProtoMsg(message: MapValueProtoMsg): MapValue;
    toProto(message: MapValue): Uint8Array;
    toProtoMsg(message: MapValue): MapValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const MapValue_Entry: {
    typeUrl: string;
    is(o: any): o is MapValue_Entry;
    isSDK(o: any): o is MapValue_EntrySDKType;
    isAmino(o: any): o is MapValue_EntryAmino;
    encode(message: MapValue_Entry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MapValue_Entry;
    fromJSON(object: any): MapValue_Entry;
    toJSON(message: MapValue_Entry): JsonSafe<MapValue_Entry>;
    fromPartial(object: DeepPartial<MapValue_Entry>): MapValue_Entry;
    fromSDK(object: MapValue_EntrySDKType): MapValue_Entry;
    fromSDKJSON(object: any): MapValue_EntrySDKType;
    toSDK(message: MapValue_Entry): MapValue_EntrySDKType;
    fromAmino(object: MapValue_EntryAmino): MapValue_Entry;
    toAmino(message: MapValue_Entry): MapValue_EntryAmino;
    fromAminoMsg(object: MapValue_EntryAminoMsg): MapValue_Entry;
    fromProtoMsg(message: MapValue_EntryProtoMsg): MapValue_Entry;
    toProto(message: MapValue_Entry): Uint8Array;
    toProtoMsg(message: MapValue_Entry): MapValue_EntryProtoMsg;
    registerTypeUrl(): void;
};
