import { Expr, ExprAmino, ExprSDKType } from "./expr";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.expr.v1beta1";
/** A declaration. */
export interface Decl {
    /** The id of the declaration. */
    id: number;
    /** The name of the declaration. */
    name: string;
    /** The documentation string for the declaration. */
    doc: string;
    /** An identifier declaration. */
    ident?: IdentDecl;
    /** A function declaration. */
    function?: FunctionDecl;
}
export interface DeclProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.Decl";
    value: Uint8Array;
}
/** A declaration. */
export interface DeclAmino {
    /** The id of the declaration. */
    id?: number;
    /** The name of the declaration. */
    name?: string;
    /** The documentation string for the declaration. */
    doc?: string;
    /** An identifier declaration. */
    ident?: IdentDeclAmino;
    /** A function declaration. */
    function?: FunctionDeclAmino;
}
export interface DeclAminoMsg {
    type: "/google.api.expr.v1beta1.Decl";
    value: DeclAmino;
}
/** A declaration. */
export interface DeclSDKType {
    id: number;
    name: string;
    doc: string;
    ident?: IdentDeclSDKType;
    function?: FunctionDeclSDKType;
}
/**
 * The declared type of a variable.
 *
 * Extends runtime type values with extra information used for type checking
 * and dispatching.
 */
export interface DeclType {
    /** The expression id of the declared type, if applicable. */
    id: number;
    /** The type name, e.g. 'int', 'my.type.Type' or 'T' */
    type: string;
    /**
     * An ordered list of type parameters, e.g. `<string, int>`.
     * Only applies to a subset of types, e.g. `map`, `list`.
     */
    typeParams: DeclType[];
}
export interface DeclTypeProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.DeclType";
    value: Uint8Array;
}
/**
 * The declared type of a variable.
 *
 * Extends runtime type values with extra information used for type checking
 * and dispatching.
 */
export interface DeclTypeAmino {
    /** The expression id of the declared type, if applicable. */
    id?: number;
    /** The type name, e.g. 'int', 'my.type.Type' or 'T' */
    type?: string;
    /**
     * An ordered list of type parameters, e.g. `<string, int>`.
     * Only applies to a subset of types, e.g. `map`, `list`.
     */
    type_params?: DeclTypeAmino[];
}
export interface DeclTypeAminoMsg {
    type: "/google.api.expr.v1beta1.DeclType";
    value: DeclTypeAmino;
}
/**
 * The declared type of a variable.
 *
 * Extends runtime type values with extra information used for type checking
 * and dispatching.
 */
export interface DeclTypeSDKType {
    id: number;
    type: string;
    type_params: DeclTypeSDKType[];
}
/** An identifier declaration. */
export interface IdentDecl {
    /** Optional type of the identifier. */
    type?: DeclType;
    /** Optional value of the identifier. */
    value?: Expr;
}
export interface IdentDeclProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.IdentDecl";
    value: Uint8Array;
}
/** An identifier declaration. */
export interface IdentDeclAmino {
    /** Optional type of the identifier. */
    type?: DeclTypeAmino;
    /** Optional value of the identifier. */
    value?: ExprAmino;
}
export interface IdentDeclAminoMsg {
    type: "/google.api.expr.v1beta1.IdentDecl";
    value: IdentDeclAmino;
}
/** An identifier declaration. */
export interface IdentDeclSDKType {
    type?: DeclTypeSDKType;
    value?: ExprSDKType;
}
/** A function declaration. */
export interface FunctionDecl {
    /** The function arguments. */
    args: IdentDecl[];
    /** Optional declared return type. */
    returnType?: DeclType;
    /** If the first argument of the function is the receiver. */
    receiverFunction: boolean;
}
export interface FunctionDeclProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.FunctionDecl";
    value: Uint8Array;
}
/** A function declaration. */
export interface FunctionDeclAmino {
    /** The function arguments. */
    args?: IdentDeclAmino[];
    /** Optional declared return type. */
    return_type?: DeclTypeAmino;
    /** If the first argument of the function is the receiver. */
    receiver_function?: boolean;
}
export interface FunctionDeclAminoMsg {
    type: "/google.api.expr.v1beta1.FunctionDecl";
    value: FunctionDeclAmino;
}
/** A function declaration. */
export interface FunctionDeclSDKType {
    args: IdentDeclSDKType[];
    return_type?: DeclTypeSDKType;
    receiver_function: boolean;
}
export declare const Decl: {
    typeUrl: string;
    is(o: any): o is Decl;
    isSDK(o: any): o is DeclSDKType;
    isAmino(o: any): o is DeclAmino;
    encode(message: Decl, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Decl;
    fromJSON(object: any): Decl;
    toJSON(message: Decl): JsonSafe<Decl>;
    fromPartial(object: DeepPartial<Decl>): Decl;
    fromSDK(object: DeclSDKType): Decl;
    fromSDKJSON(object: any): DeclSDKType;
    toSDK(message: Decl): DeclSDKType;
    fromAmino(object: DeclAmino): Decl;
    toAmino(message: Decl): DeclAmino;
    fromAminoMsg(object: DeclAminoMsg): Decl;
    fromProtoMsg(message: DeclProtoMsg): Decl;
    toProto(message: Decl): Uint8Array;
    toProtoMsg(message: Decl): DeclProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeclType: {
    typeUrl: string;
    is(o: any): o is DeclType;
    isSDK(o: any): o is DeclTypeSDKType;
    isAmino(o: any): o is DeclTypeAmino;
    encode(message: DeclType, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeclType;
    fromJSON(object: any): DeclType;
    toJSON(message: DeclType): JsonSafe<DeclType>;
    fromPartial(object: DeepPartial<DeclType>): DeclType;
    fromSDK(object: DeclTypeSDKType): DeclType;
    fromSDKJSON(object: any): DeclTypeSDKType;
    toSDK(message: DeclType): DeclTypeSDKType;
    fromAmino(object: DeclTypeAmino): DeclType;
    toAmino(message: DeclType): DeclTypeAmino;
    fromAminoMsg(object: DeclTypeAminoMsg): DeclType;
    fromProtoMsg(message: DeclTypeProtoMsg): DeclType;
    toProto(message: DeclType): Uint8Array;
    toProtoMsg(message: DeclType): DeclTypeProtoMsg;
    registerTypeUrl(): void;
};
export declare const IdentDecl: {
    typeUrl: string;
    is(o: any): o is IdentDecl;
    isSDK(o: any): o is IdentDeclSDKType;
    isAmino(o: any): o is IdentDeclAmino;
    encode(message: IdentDecl, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): IdentDecl;
    fromJSON(object: any): IdentDecl;
    toJSON(message: IdentDecl): JsonSafe<IdentDecl>;
    fromPartial(object: DeepPartial<IdentDecl>): IdentDecl;
    fromSDK(object: IdentDeclSDKType): IdentDecl;
    fromSDKJSON(object: any): IdentDeclSDKType;
    toSDK(message: IdentDecl): IdentDeclSDKType;
    fromAmino(object: IdentDeclAmino): IdentDecl;
    toAmino(message: IdentDecl): IdentDeclAmino;
    fromAminoMsg(object: IdentDeclAminoMsg): IdentDecl;
    fromProtoMsg(message: IdentDeclProtoMsg): IdentDecl;
    toProto(message: IdentDecl): Uint8Array;
    toProtoMsg(message: IdentDecl): IdentDeclProtoMsg;
    registerTypeUrl(): void;
};
export declare const FunctionDecl: {
    typeUrl: string;
    is(o: any): o is FunctionDecl;
    isSDK(o: any): o is FunctionDeclSDKType;
    isAmino(o: any): o is FunctionDeclAmino;
    encode(message: FunctionDecl, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): FunctionDecl;
    fromJSON(object: any): FunctionDecl;
    toJSON(message: FunctionDecl): JsonSafe<FunctionDecl>;
    fromPartial(object: DeepPartial<FunctionDecl>): FunctionDecl;
    fromSDK(object: FunctionDeclSDKType): FunctionDecl;
    fromSDKJSON(object: any): FunctionDeclSDKType;
    toSDK(message: FunctionDecl): FunctionDeclSDKType;
    fromAmino(object: FunctionDeclAmino): FunctionDecl;
    toAmino(message: FunctionDecl): FunctionDeclAmino;
    fromAminoMsg(object: FunctionDeclAminoMsg): FunctionDecl;
    fromProtoMsg(message: FunctionDeclProtoMsg): FunctionDecl;
    toProto(message: FunctionDecl): Uint8Array;
    toProtoMsg(message: FunctionDecl): FunctionDeclProtoMsg;
    registerTypeUrl(): void;
};
