import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.expr.v1beta1";
export interface SourceInfo_PositionsEntry {
    key: number;
    value: number;
}
export interface SourceInfo_PositionsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface SourceInfo_PositionsEntryAmino {
    key?: number;
    value?: number;
}
export interface SourceInfo_PositionsEntryAminoMsg {
    type: string;
    value: SourceInfo_PositionsEntryAmino;
}
export interface SourceInfo_PositionsEntrySDKType {
    key: number;
    value: number;
}
/** Source information collected at parse time. */
export interface SourceInfo {
    /**
     * The location name. All position information attached to an expression is
     * relative to this location.
     *
     * The location could be a file, UI element, or similar. For example,
     * `acme/app/AnvilPolicy.cel`.
     */
    location: string;
    /**
     * Monotonically increasing list of character offsets where newlines appear.
     *
     * The line number of a given position is the index `i` where for a given
     * `id` the `line_offsets[i] < id_positions[id] < line_offsets[i+1]`. The
     * column may be derivd from `id_positions[id] - line_offsets[i]`.
     */
    lineOffsets: number[];
    /**
     * A map from the parse node id (e.g. `Expr.id`) to the character offset
     * within source.
     */
    positions: {
        [key: number]: number;
    };
}
export interface SourceInfoProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.SourceInfo";
    value: Uint8Array;
}
/** Source information collected at parse time. */
export interface SourceInfoAmino {
    /**
     * The location name. All position information attached to an expression is
     * relative to this location.
     *
     * The location could be a file, UI element, or similar. For example,
     * `acme/app/AnvilPolicy.cel`.
     */
    location?: string;
    /**
     * Monotonically increasing list of character offsets where newlines appear.
     *
     * The line number of a given position is the index `i` where for a given
     * `id` the `line_offsets[i] < id_positions[id] < line_offsets[i+1]`. The
     * column may be derivd from `id_positions[id] - line_offsets[i]`.
     */
    line_offsets?: number[];
    /**
     * A map from the parse node id (e.g. `Expr.id`) to the character offset
     * within source.
     */
    positions?: {
        [key: number]: number;
    };
}
export interface SourceInfoAminoMsg {
    type: "/google.api.expr.v1beta1.SourceInfo";
    value: SourceInfoAmino;
}
/** Source information collected at parse time. */
export interface SourceInfoSDKType {
    location: string;
    line_offsets: number[];
    positions: {
        [key: number]: number;
    };
}
/** A specific position in source. */
export interface SourcePosition {
    /** The soucre location name (e.g. file name). */
    location: string;
    /** The character offset. */
    offset: number;
    /**
     * The 1-based index of the starting line in the source text
     * where the issue occurs, or 0 if unknown.
     */
    line: number;
    /**
     * The 0-based index of the starting position within the line of source text
     * where the issue occurs.  Only meaningful if line is nonzer..
     */
    column: number;
}
export interface SourcePositionProtoMsg {
    typeUrl: "/google.api.expr.v1beta1.SourcePosition";
    value: Uint8Array;
}
/** A specific position in source. */
export interface SourcePositionAmino {
    /** The soucre location name (e.g. file name). */
    location?: string;
    /** The character offset. */
    offset?: number;
    /**
     * The 1-based index of the starting line in the source text
     * where the issue occurs, or 0 if unknown.
     */
    line?: number;
    /**
     * The 0-based index of the starting position within the line of source text
     * where the issue occurs.  Only meaningful if line is nonzer..
     */
    column?: number;
}
export interface SourcePositionAminoMsg {
    type: "/google.api.expr.v1beta1.SourcePosition";
    value: SourcePositionAmino;
}
/** A specific position in source. */
export interface SourcePositionSDKType {
    location: string;
    offset: number;
    line: number;
    column: number;
}
export declare const SourceInfo_PositionsEntry: {
    encode(message: SourceInfo_PositionsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourceInfo_PositionsEntry;
    fromJSON(object: any): SourceInfo_PositionsEntry;
    toJSON(message: SourceInfo_PositionsEntry): JsonSafe<SourceInfo_PositionsEntry>;
    fromPartial(object: DeepPartial<SourceInfo_PositionsEntry>): SourceInfo_PositionsEntry;
    fromSDK(object: SourceInfo_PositionsEntrySDKType): SourceInfo_PositionsEntry;
    fromSDKJSON(object: any): SourceInfo_PositionsEntrySDKType;
    toSDK(message: SourceInfo_PositionsEntry): SourceInfo_PositionsEntrySDKType;
    fromAmino(object: SourceInfo_PositionsEntryAmino): SourceInfo_PositionsEntry;
    toAmino(message: SourceInfo_PositionsEntry): SourceInfo_PositionsEntryAmino;
    fromAminoMsg(object: SourceInfo_PositionsEntryAminoMsg): SourceInfo_PositionsEntry;
    fromProtoMsg(message: SourceInfo_PositionsEntryProtoMsg): SourceInfo_PositionsEntry;
    toProto(message: SourceInfo_PositionsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const SourceInfo: {
    typeUrl: string;
    is(o: any): o is SourceInfo;
    isSDK(o: any): o is SourceInfoSDKType;
    isAmino(o: any): o is SourceInfoAmino;
    encode(message: SourceInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourceInfo;
    fromJSON(object: any): SourceInfo;
    toJSON(message: SourceInfo): JsonSafe<SourceInfo>;
    fromPartial(object: DeepPartial<SourceInfo>): SourceInfo;
    fromSDK(object: SourceInfoSDKType): SourceInfo;
    fromSDKJSON(object: any): SourceInfoSDKType;
    toSDK(message: SourceInfo): SourceInfoSDKType;
    fromAmino(object: SourceInfoAmino): SourceInfo;
    toAmino(message: SourceInfo): SourceInfoAmino;
    fromAminoMsg(object: SourceInfoAminoMsg): SourceInfo;
    fromProtoMsg(message: SourceInfoProtoMsg): SourceInfo;
    toProto(message: SourceInfo): Uint8Array;
    toProtoMsg(message: SourceInfo): SourceInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const SourcePosition: {
    typeUrl: string;
    is(o: any): o is SourcePosition;
    isSDK(o: any): o is SourcePositionSDKType;
    isAmino(o: any): o is SourcePositionAmino;
    encode(message: SourcePosition, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SourcePosition;
    fromJSON(object: any): SourcePosition;
    toJSON(message: SourcePosition): JsonSafe<SourcePosition>;
    fromPartial(object: DeepPartial<SourcePosition>): SourcePosition;
    fromSDK(object: SourcePositionSDKType): SourcePosition;
    fromSDKJSON(object: any): SourcePositionSDKType;
    toSDK(message: SourcePosition): SourcePositionSDKType;
    fromAmino(object: SourcePositionAmino): SourcePosition;
    toAmino(message: SourcePosition): SourcePositionAmino;
    fromAminoMsg(object: SourcePositionAminoMsg): SourcePosition;
    fromProtoMsg(message: SourcePositionProtoMsg): SourcePosition;
    toProto(message: SourcePosition): Uint8Array;
    toProtoMsg(message: SourcePosition): SourcePositionProtoMsg;
    registerTypeUrl(): void;
};
