import { LabelDescriptor, LabelDescriptorAmino, LabelDescriptorSDKType } from "./label";
import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.api";
/**
 * A description of a log type. Example in YAML format:
 *
 *     - name: library.googleapis.com/activity_history
 *       description: The history of borrowing and returning library items.
 *       display_name: Activity
 *       labels:
 *       - key: /customer_id
 *         description: Identifier of a library customer
 */
export interface LogDescriptor {
    /**
     * The name of the log. It must be less than 512 characters long and can
     * include the following characters: upper- and lower-case alphanumeric
     * characters [A-Za-z0-9], and punctuation characters including
     * slash, underscore, hyphen, period [/_-.].
     */
    name: string;
    /**
     * The set of labels that are available to describe a specific log entry.
     * Runtime requests that contain labels not specified here are
     * considered invalid.
     */
    labels: LabelDescriptor[];
    /**
     * A human-readable description of this log. This information appears in
     * the documentation and can contain details.
     */
    description: string;
    /**
     * The human-readable name for this log. This information appears on
     * the user interface and should be concise.
     */
    displayName: string;
}
export interface LogDescriptorProtoMsg {
    typeUrl: "/google.api.LogDescriptor";
    value: Uint8Array;
}
/**
 * A description of a log type. Example in YAML format:
 *
 *     - name: library.googleapis.com/activity_history
 *       description: The history of borrowing and returning library items.
 *       display_name: Activity
 *       labels:
 *       - key: /customer_id
 *         description: Identifier of a library customer
 */
export interface LogDescriptorAmino {
    /**
     * The name of the log. It must be less than 512 characters long and can
     * include the following characters: upper- and lower-case alphanumeric
     * characters [A-Za-z0-9], and punctuation characters including
     * slash, underscore, hyphen, period [/_-.].
     */
    name?: string;
    /**
     * The set of labels that are available to describe a specific log entry.
     * Runtime requests that contain labels not specified here are
     * considered invalid.
     */
    labels?: LabelDescriptorAmino[];
    /**
     * A human-readable description of this log. This information appears in
     * the documentation and can contain details.
     */
    description?: string;
    /**
     * The human-readable name for this log. This information appears on
     * the user interface and should be concise.
     */
    display_name?: string;
}
export interface LogDescriptorAminoMsg {
    type: "/google.api.LogDescriptor";
    value: LogDescriptorAmino;
}
/**
 * A description of a log type. Example in YAML format:
 *
 *     - name: library.googleapis.com/activity_history
 *       description: The history of borrowing and returning library items.
 *       display_name: Activity
 *       labels:
 *       - key: /customer_id
 *         description: Identifier of a library customer
 */
export interface LogDescriptorSDKType {
    name: string;
    labels: LabelDescriptorSDKType[];
    description: string;
    display_name: string;
}
export declare const LogDescriptor: {
    typeUrl: string;
    is(o: any): o is LogDescriptor;
    isSDK(o: any): o is LogDescriptorSDKType;
    isAmino(o: any): o is LogDescriptorAmino;
    encode(message: LogDescriptor, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogDescriptor;
    fromJSON(object: any): LogDescriptor;
    toJSON(message: LogDescriptor): JsonSafe<LogDescriptor>;
    fromPartial(object: DeepPartial<LogDescriptor>): LogDescriptor;
    fromSDK(object: LogDescriptorSDKType): LogDescriptor;
    fromSDKJSON(object: any): LogDescriptorSDKType;
    toSDK(message: LogDescriptor): LogDescriptorSDKType;
    fromAmino(object: LogDescriptorAmino): LogDescriptor;
    toAmino(message: LogDescriptor): LogDescriptorAmino;
    fromAminoMsg(object: LogDescriptorAminoMsg): LogDescriptor;
    fromProtoMsg(message: LogDescriptorProtoMsg): LogDescriptor;
    toProto(message: LogDescriptor): Uint8Array;
    toProtoMsg(message: LogDescriptor): LogDescriptorProtoMsg;
    registerTypeUrl(): void;
};
