import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * Logging configuration of the service.
 *
 * The following example shows how to configure logs to be sent to the
 * producer and consumer projects. In the example, the `activity_history`
 * log is sent to both the producer and consumer projects, whereas the
 * `purchase_history` log is only sent to the producer project.
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/branch
 *       labels:
 *       - key: /city
 *         description: The city where the library branch is located in.
 *       - key: /name
 *         description: The name of the branch.
 *     logs:
 *     - name: activity_history
 *       labels:
 *       - key: /customer_id
 *     - name: purchase_history
 *     logging:
 *       producer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 *         - purchase_history
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 */
export interface Logging {
    /**
     * Logging configurations for sending logs to the producer project.
     * There can be multiple producer destinations, each one must have a
     * different monitored resource type. A log can be used in at most
     * one producer destination.
     */
    producerDestinations: Logging_LoggingDestination[];
    /**
     * Logging configurations for sending logs to the consumer project.
     * There can be multiple consumer destinations, each one must have a
     * different monitored resource type. A log can be used in at most
     * one consumer destination.
     */
    consumerDestinations: Logging_LoggingDestination[];
}
export interface LoggingProtoMsg {
    typeUrl: "/google.api.Logging";
    value: Uint8Array;
}
/**
 * Logging configuration of the service.
 *
 * The following example shows how to configure logs to be sent to the
 * producer and consumer projects. In the example, the `activity_history`
 * log is sent to both the producer and consumer projects, whereas the
 * `purchase_history` log is only sent to the producer project.
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/branch
 *       labels:
 *       - key: /city
 *         description: The city where the library branch is located in.
 *       - key: /name
 *         description: The name of the branch.
 *     logs:
 *     - name: activity_history
 *       labels:
 *       - key: /customer_id
 *     - name: purchase_history
 *     logging:
 *       producer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 *         - purchase_history
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 */
export interface LoggingAmino {
    /**
     * Logging configurations for sending logs to the producer project.
     * There can be multiple producer destinations, each one must have a
     * different monitored resource type. A log can be used in at most
     * one producer destination.
     */
    producer_destinations?: Logging_LoggingDestinationAmino[];
    /**
     * Logging configurations for sending logs to the consumer project.
     * There can be multiple consumer destinations, each one must have a
     * different monitored resource type. A log can be used in at most
     * one consumer destination.
     */
    consumer_destinations?: Logging_LoggingDestinationAmino[];
}
export interface LoggingAminoMsg {
    type: "/google.api.Logging";
    value: LoggingAmino;
}
/**
 * Logging configuration of the service.
 *
 * The following example shows how to configure logs to be sent to the
 * producer and consumer projects. In the example, the `activity_history`
 * log is sent to both the producer and consumer projects, whereas the
 * `purchase_history` log is only sent to the producer project.
 *
 *     monitored_resources:
 *     - type: library.googleapis.com/branch
 *       labels:
 *       - key: /city
 *         description: The city where the library branch is located in.
 *       - key: /name
 *         description: The name of the branch.
 *     logs:
 *     - name: activity_history
 *       labels:
 *       - key: /customer_id
 *     - name: purchase_history
 *     logging:
 *       producer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 *         - purchase_history
 *       consumer_destinations:
 *       - monitored_resource: library.googleapis.com/branch
 *         logs:
 *         - activity_history
 */
export interface LoggingSDKType {
    producer_destinations: Logging_LoggingDestinationSDKType[];
    consumer_destinations: Logging_LoggingDestinationSDKType[];
}
/**
 * Configuration of a specific logging destination (the producer project
 * or the consumer project).
 */
export interface Logging_LoggingDestination {
    /**
     * The monitored resource type. The type must be defined in the
     * [Service.monitored_resources][google.api.Service.monitored_resources] section.
     */
    monitoredResource: string;
    /**
     * Names of the logs to be sent to this destination. Each name must
     * be defined in the [Service.logs][google.api.Service.logs] section. If the log name is
     * not a domain scoped name, it will be automatically prefixed with
     * the service name followed by "/".
     */
    logs: string[];
}
export interface Logging_LoggingDestinationProtoMsg {
    typeUrl: "/google.api.LoggingDestination";
    value: Uint8Array;
}
/**
 * Configuration of a specific logging destination (the producer project
 * or the consumer project).
 */
export interface Logging_LoggingDestinationAmino {
    /**
     * The monitored resource type. The type must be defined in the
     * [Service.monitored_resources][google.api.Service.monitored_resources] section.
     */
    monitored_resource?: string;
    /**
     * Names of the logs to be sent to this destination. Each name must
     * be defined in the [Service.logs][google.api.Service.logs] section. If the log name is
     * not a domain scoped name, it will be automatically prefixed with
     * the service name followed by "/".
     */
    logs?: string[];
}
export interface Logging_LoggingDestinationAminoMsg {
    type: "/google.api.LoggingDestination";
    value: Logging_LoggingDestinationAmino;
}
/**
 * Configuration of a specific logging destination (the producer project
 * or the consumer project).
 */
export interface Logging_LoggingDestinationSDKType {
    monitored_resource: string;
    logs: string[];
}
export declare const Logging: {
    typeUrl: string;
    is(o: any): o is Logging;
    isSDK(o: any): o is LoggingSDKType;
    isAmino(o: any): o is LoggingAmino;
    encode(message: Logging, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Logging;
    fromJSON(object: any): Logging;
    toJSON(message: Logging): JsonSafe<Logging>;
    fromPartial(object: DeepPartial<Logging>): Logging;
    fromSDK(object: LoggingSDKType): Logging;
    fromSDKJSON(object: any): LoggingSDKType;
    toSDK(message: Logging): LoggingSDKType;
    fromAmino(object: LoggingAmino): Logging;
    toAmino(message: Logging): LoggingAmino;
    fromAminoMsg(object: LoggingAminoMsg): Logging;
    fromProtoMsg(message: LoggingProtoMsg): Logging;
    toProto(message: Logging): Uint8Array;
    toProtoMsg(message: Logging): LoggingProtoMsg;
    registerTypeUrl(): void;
};
export declare const Logging_LoggingDestination: {
    typeUrl: string;
    is(o: any): o is Logging_LoggingDestination;
    isSDK(o: any): o is Logging_LoggingDestinationSDKType;
    isAmino(o: any): o is Logging_LoggingDestinationAmino;
    encode(message: Logging_LoggingDestination, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Logging_LoggingDestination;
    fromJSON(object: any): Logging_LoggingDestination;
    toJSON(message: Logging_LoggingDestination): JsonSafe<Logging_LoggingDestination>;
    fromPartial(object: DeepPartial<Logging_LoggingDestination>): Logging_LoggingDestination;
    fromSDK(object: Logging_LoggingDestinationSDKType): Logging_LoggingDestination;
    fromSDKJSON(object: any): Logging_LoggingDestinationSDKType;
    toSDK(message: Logging_LoggingDestination): Logging_LoggingDestinationSDKType;
    fromAmino(object: Logging_LoggingDestinationAmino): Logging_LoggingDestination;
    toAmino(message: Logging_LoggingDestination): Logging_LoggingDestinationAmino;
    fromAminoMsg(object: Logging_LoggingDestinationAminoMsg): Logging_LoggingDestination;
    fromProtoMsg(message: Logging_LoggingDestinationProtoMsg): Logging_LoggingDestination;
    toProto(message: Logging_LoggingDestination): Uint8Array;
    toProtoMsg(message: Logging_LoggingDestination): Logging_LoggingDestinationProtoMsg;
    registerTypeUrl(): void;
};
