import { LaunchStage } from "./launch_stage";
import { Duration, DurationAmino, DurationSDKType } from "../protobuf/duration";
import { LabelDescriptor, LabelDescriptorAmino, LabelDescriptorSDKType } from "./label";
import { DeepPartial } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.api";
/**
 * The kind of measurement. It describes how the data is reported.
 * For information on setting the start time and end time based on
 * the MetricKind, see [TimeInterval][google.monitoring.v3.TimeInterval].
 */
export declare enum MetricDescriptor_MetricKind {
    /** METRIC_KIND_UNSPECIFIED - Do not use this default value. */
    METRIC_KIND_UNSPECIFIED = 0,
    /** GAUGE - An instantaneous measurement of a value. */
    GAUGE = 1,
    /** DELTA - The change in a value during a time interval. */
    DELTA = 2,
    /**
     * CUMULATIVE - A value accumulated over a time interval.  Cumulative
     * measurements in a time series should have the same start time
     * and increasing end times, until an event resets the cumulative
     * value to zero and sets a new start time for the following
     * points.
     */
    CUMULATIVE = 3,
    UNRECOGNIZED = -1
}
export declare const MetricDescriptor_MetricKindSDKType: typeof MetricDescriptor_MetricKind;
export declare const MetricDescriptor_MetricKindAmino: typeof MetricDescriptor_MetricKind;
export declare function metricDescriptor_MetricKindFromJSON(object: any): MetricDescriptor_MetricKind;
export declare function metricDescriptor_MetricKindToJSON(object: MetricDescriptor_MetricKind): string;
/** The value type of a metric. */
export declare enum MetricDescriptor_ValueType {
    /** VALUE_TYPE_UNSPECIFIED - Do not use this default value. */
    VALUE_TYPE_UNSPECIFIED = 0,
    /**
     * BOOL - The value is a boolean.
     * This value type can be used only if the metric kind is `GAUGE`.
     */
    BOOL = 1,
    /** INT64 - The value is a signed 64-bit integer. */
    INT64 = 2,
    /** DOUBLE - The value is a double precision floating point number. */
    DOUBLE = 3,
    /**
     * STRING - The value is a text string.
     * This value type can be used only if the metric kind is `GAUGE`.
     */
    STRING = 4,
    /** DISTRIBUTION - The value is a [`Distribution`][google.api.Distribution]. */
    DISTRIBUTION = 5,
    /** MONEY - The value is money. */
    MONEY = 6,
    UNRECOGNIZED = -1
}
export declare const MetricDescriptor_ValueTypeSDKType: typeof MetricDescriptor_ValueType;
export declare const MetricDescriptor_ValueTypeAmino: typeof MetricDescriptor_ValueType;
export declare function metricDescriptor_ValueTypeFromJSON(object: any): MetricDescriptor_ValueType;
export declare function metricDescriptor_ValueTypeToJSON(object: MetricDescriptor_ValueType): string;
/**
 * Defines a metric type and its schema. Once a metric descriptor is created,
 * deleting or altering it stops data collection and makes the metric type's
 * existing data unusable.
 */
export interface MetricDescriptor {
    /** The resource name of the metric descriptor. */
    name: string;
    /**
     * The metric type, including its DNS name prefix. The type is not
     * URL-encoded. All user-defined metric types have the DNS name
     * `custom.googleapis.com` or `external.googleapis.com`. Metric types should
     * use a natural hierarchical grouping. For example:
     *
     *     "custom.googleapis.com/invoice/paid/amount"
     *     "external.googleapis.com/prometheus/up"
     *     "appengine.googleapis.com/http/server/response_latencies"
     */
    type: string;
    /**
     * The set of labels that can be used to describe a specific
     * instance of this metric type. For example, the
     * `appengine.googleapis.com/http/server/response_latencies` metric
     * type has a label for the HTTP response code, `response_code`, so
     * you can look at latencies for successful responses or just
     * for responses that failed.
     */
    labels: LabelDescriptor[];
    /**
     * Whether the metric records instantaneous values, changes to a value, etc.
     * Some combinations of `metric_kind` and `value_type` might not be supported.
     */
    metricKind: MetricDescriptor_MetricKind;
    /**
     * Whether the measurement is an integer, a floating-point number, etc.
     * Some combinations of `metric_kind` and `value_type` might not be supported.
     */
    valueType: MetricDescriptor_ValueType;
    /**
     * The units in which the metric value is reported. It is only applicable
     * if the `value_type` is `INT64`, `DOUBLE`, or `DISTRIBUTION`. The `unit`
     * defines the representation of the stored metric values.
     *
     * Different systems might scale the values to be more easily displayed (so a
     * value of `0.02kBy` _might_ be displayed as `20By`, and a value of
     * `3523kBy` _might_ be displayed as `3.5MBy`). However, if the `unit` is
     * `kBy`, then the value of the metric is always in thousands of bytes, no
     * matter how it might be displayed.
     *
     * If you want a custom metric to record the exact number of CPU-seconds used
     * by a job, you can create an `INT64 CUMULATIVE` metric whose `unit` is
     * `s{CPU}` (or equivalently `1s{CPU}` or just `s`). If the job uses 12,005
     * CPU-seconds, then the value is written as `12005`.
     *
     * Alternatively, if you want a custom metric to record data in a more
     * granular way, you can create a `DOUBLE CUMULATIVE` metric whose `unit` is
     * `ks{CPU}`, and then write the value `12.005` (which is `12005/1000`),
     * or use `Kis{CPU}` and write `11.723` (which is `12005/1024`).
     *
     * The supported units are a subset of [The Unified Code for Units of
     * Measure](https://unitsofmeasure.org/ucum.html) standard:
     *
     * **Basic units (UNIT)**
     *
     * * `bit`   bit
     * * `By`    byte
     * * `s`     second
     * * `min`   minute
     * * `h`     hour
     * * `d`     day
     * * `1`     dimensionless
     *
     * **Prefixes (PREFIX)**
     *
     * * `k`     kilo    (10^3)
     * * `M`     mega    (10^6)
     * * `G`     giga    (10^9)
     * * `T`     tera    (10^12)
     * * `P`     peta    (10^15)
     * * `E`     exa     (10^18)
     * * `Z`     zetta   (10^21)
     * * `Y`     yotta   (10^24)
     *
     * * `m`     milli   (10^-3)
     * * `u`     micro   (10^-6)
     * * `n`     nano    (10^-9)
     * * `p`     pico    (10^-12)
     * * `f`     femto   (10^-15)
     * * `a`     atto    (10^-18)
     * * `z`     zepto   (10^-21)
     * * `y`     yocto   (10^-24)
     *
     * * `Ki`    kibi    (2^10)
     * * `Mi`    mebi    (2^20)
     * * `Gi`    gibi    (2^30)
     * * `Ti`    tebi    (2^40)
     * * `Pi`    pebi    (2^50)
     *
     * **Grammar**
     *
     * The grammar also includes these connectors:
     *
     * * `/`    division or ratio (as an infix operator). For examples,
     *          `kBy/{email}` or `MiBy/10ms` (although you should almost never
     *          have `/s` in a metric `unit`; rates should always be computed at
     *          query time from the underlying cumulative or delta value).
     * * `.`    multiplication or composition (as an infix operator). For
     *          examples, `GBy.d` or `k{watt}.h`.
     *
     * The grammar for a unit is as follows:
     *
     *     Expression = Component { "." Component } { "/" Component } ;
     *
     *     Component = ( [ PREFIX ] UNIT | "%" ) [ Annotation ]
     *               | Annotation
     *               | "1"
     *               ;
     *
     *     Annotation = "{" NAME "}" ;
     *
     * Notes:
     *
     * * `Annotation` is just a comment if it follows a `UNIT`. If the annotation
     *    is used alone, then the unit is equivalent to `1`. For examples,
     *    `{request}/s == 1/s`, `By{transmitted}/s == By/s`.
     * * `NAME` is a sequence of non-blank printable ASCII characters not
     *    containing `{` or `}`.
     * * `1` represents a unitary [dimensionless
     *    unit](https://en.wikipedia.org/wiki/Dimensionless_quantity) of 1, such
     *    as in `1/s`. It is typically used when none of the basic units are
     *    appropriate. For example, "new users per day" can be represented as
     *    `1/d` or `{new-users}/d` (and a metric value `5` would mean "5 new
     *    users). Alternatively, "thousands of page views per day" would be
     *    represented as `1000/d` or `k1/d` or `k{page_views}/d` (and a metric
     *    value of `5.3` would mean "5300 page views per day").
     * * `%` represents dimensionless value of 1/100, and annotates values giving
     *    a percentage (so the metric values are typically in the range of 0..100,
     *    and a metric value `3` means "3 percent").
     * * `10^2.%` indicates a metric contains a ratio, typically in the range
     *    0..1, that will be multiplied by 100 and displayed as a percentage
     *    (so a metric value `0.03` means "3 percent").
     */
    unit: string;
    /** A detailed description of the metric, which can be used in documentation. */
    description: string;
    /**
     * A concise name for the metric, which can be displayed in user interfaces.
     * Use sentence case without an ending period, for example "Request count".
     * This field is optional but it is recommended to be set for any metrics
     * associated with user-visible concepts, such as Quota.
     */
    displayName: string;
    /** Optional. Metadata which can be used to guide usage of the metric. */
    metadata?: MetricDescriptor_MetricDescriptorMetadata;
    /** Optional. The launch stage of the metric definition. */
    launchStage: LaunchStage;
    /**
     * Read-only. If present, then a [time
     * series][google.monitoring.v3.TimeSeries], which is identified partially by
     * a metric type and a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor], that is associated
     * with this metric type can only be associated with one of the monitored
     * resource types listed here.
     */
    monitoredResourceTypes: string[];
}
export interface MetricDescriptorProtoMsg {
    typeUrl: "/google.api.MetricDescriptor";
    value: Uint8Array;
}
/**
 * Defines a metric type and its schema. Once a metric descriptor is created,
 * deleting or altering it stops data collection and makes the metric type's
 * existing data unusable.
 */
export interface MetricDescriptorAmino {
    /** The resource name of the metric descriptor. */
    name?: string;
    /**
     * The metric type, including its DNS name prefix. The type is not
     * URL-encoded. All user-defined metric types have the DNS name
     * `custom.googleapis.com` or `external.googleapis.com`. Metric types should
     * use a natural hierarchical grouping. For example:
     *
     *     "custom.googleapis.com/invoice/paid/amount"
     *     "external.googleapis.com/prometheus/up"
     *     "appengine.googleapis.com/http/server/response_latencies"
     */
    type?: string;
    /**
     * The set of labels that can be used to describe a specific
     * instance of this metric type. For example, the
     * `appengine.googleapis.com/http/server/response_latencies` metric
     * type has a label for the HTTP response code, `response_code`, so
     * you can look at latencies for successful responses or just
     * for responses that failed.
     */
    labels?: LabelDescriptorAmino[];
    /**
     * Whether the metric records instantaneous values, changes to a value, etc.
     * Some combinations of `metric_kind` and `value_type` might not be supported.
     */
    metric_kind?: MetricDescriptor_MetricKind;
    /**
     * Whether the measurement is an integer, a floating-point number, etc.
     * Some combinations of `metric_kind` and `value_type` might not be supported.
     */
    value_type?: MetricDescriptor_ValueType;
    /**
     * The units in which the metric value is reported. It is only applicable
     * if the `value_type` is `INT64`, `DOUBLE`, or `DISTRIBUTION`. The `unit`
     * defines the representation of the stored metric values.
     *
     * Different systems might scale the values to be more easily displayed (so a
     * value of `0.02kBy` _might_ be displayed as `20By`, and a value of
     * `3523kBy` _might_ be displayed as `3.5MBy`). However, if the `unit` is
     * `kBy`, then the value of the metric is always in thousands of bytes, no
     * matter how it might be displayed.
     *
     * If you want a custom metric to record the exact number of CPU-seconds used
     * by a job, you can create an `INT64 CUMULATIVE` metric whose `unit` is
     * `s{CPU}` (or equivalently `1s{CPU}` or just `s`). If the job uses 12,005
     * CPU-seconds, then the value is written as `12005`.
     *
     * Alternatively, if you want a custom metric to record data in a more
     * granular way, you can create a `DOUBLE CUMULATIVE` metric whose `unit` is
     * `ks{CPU}`, and then write the value `12.005` (which is `12005/1000`),
     * or use `Kis{CPU}` and write `11.723` (which is `12005/1024`).
     *
     * The supported units are a subset of [The Unified Code for Units of
     * Measure](https://unitsofmeasure.org/ucum.html) standard:
     *
     * **Basic units (UNIT)**
     *
     * * `bit`   bit
     * * `By`    byte
     * * `s`     second
     * * `min`   minute
     * * `h`     hour
     * * `d`     day
     * * `1`     dimensionless
     *
     * **Prefixes (PREFIX)**
     *
     * * `k`     kilo    (10^3)
     * * `M`     mega    (10^6)
     * * `G`     giga    (10^9)
     * * `T`     tera    (10^12)
     * * `P`     peta    (10^15)
     * * `E`     exa     (10^18)
     * * `Z`     zetta   (10^21)
     * * `Y`     yotta   (10^24)
     *
     * * `m`     milli   (10^-3)
     * * `u`     micro   (10^-6)
     * * `n`     nano    (10^-9)
     * * `p`     pico    (10^-12)
     * * `f`     femto   (10^-15)
     * * `a`     atto    (10^-18)
     * * `z`     zepto   (10^-21)
     * * `y`     yocto   (10^-24)
     *
     * * `Ki`    kibi    (2^10)
     * * `Mi`    mebi    (2^20)
     * * `Gi`    gibi    (2^30)
     * * `Ti`    tebi    (2^40)
     * * `Pi`    pebi    (2^50)
     *
     * **Grammar**
     *
     * The grammar also includes these connectors:
     *
     * * `/`    division or ratio (as an infix operator). For examples,
     *          `kBy/{email}` or `MiBy/10ms` (although you should almost never
     *          have `/s` in a metric `unit`; rates should always be computed at
     *          query time from the underlying cumulative or delta value).
     * * `.`    multiplication or composition (as an infix operator). For
     *          examples, `GBy.d` or `k{watt}.h`.
     *
     * The grammar for a unit is as follows:
     *
     *     Expression = Component { "." Component } { "/" Component } ;
     *
     *     Component = ( [ PREFIX ] UNIT | "%" ) [ Annotation ]
     *               | Annotation
     *               | "1"
     *               ;
     *
     *     Annotation = "{" NAME "}" ;
     *
     * Notes:
     *
     * * `Annotation` is just a comment if it follows a `UNIT`. If the annotation
     *    is used alone, then the unit is equivalent to `1`. For examples,
     *    `{request}/s == 1/s`, `By{transmitted}/s == By/s`.
     * * `NAME` is a sequence of non-blank printable ASCII characters not
     *    containing `{` or `}`.
     * * `1` represents a unitary [dimensionless
     *    unit](https://en.wikipedia.org/wiki/Dimensionless_quantity) of 1, such
     *    as in `1/s`. It is typically used when none of the basic units are
     *    appropriate. For example, "new users per day" can be represented as
     *    `1/d` or `{new-users}/d` (and a metric value `5` would mean "5 new
     *    users). Alternatively, "thousands of page views per day" would be
     *    represented as `1000/d` or `k1/d` or `k{page_views}/d` (and a metric
     *    value of `5.3` would mean "5300 page views per day").
     * * `%` represents dimensionless value of 1/100, and annotates values giving
     *    a percentage (so the metric values are typically in the range of 0..100,
     *    and a metric value `3` means "3 percent").
     * * `10^2.%` indicates a metric contains a ratio, typically in the range
     *    0..1, that will be multiplied by 100 and displayed as a percentage
     *    (so a metric value `0.03` means "3 percent").
     */
    unit?: string;
    /** A detailed description of the metric, which can be used in documentation. */
    description?: string;
    /**
     * A concise name for the metric, which can be displayed in user interfaces.
     * Use sentence case without an ending period, for example "Request count".
     * This field is optional but it is recommended to be set for any metrics
     * associated with user-visible concepts, such as Quota.
     */
    display_name?: string;
    /** Optional. Metadata which can be used to guide usage of the metric. */
    metadata?: MetricDescriptor_MetricDescriptorMetadataAmino;
    /** Optional. The launch stage of the metric definition. */
    launch_stage?: LaunchStage;
    /**
     * Read-only. If present, then a [time
     * series][google.monitoring.v3.TimeSeries], which is identified partially by
     * a metric type and a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor], that is associated
     * with this metric type can only be associated with one of the monitored
     * resource types listed here.
     */
    monitored_resource_types?: string[];
}
export interface MetricDescriptorAminoMsg {
    type: "/google.api.MetricDescriptor";
    value: MetricDescriptorAmino;
}
/**
 * Defines a metric type and its schema. Once a metric descriptor is created,
 * deleting or altering it stops data collection and makes the metric type's
 * existing data unusable.
 */
export interface MetricDescriptorSDKType {
    name: string;
    type: string;
    labels: LabelDescriptorSDKType[];
    metric_kind: MetricDescriptor_MetricKind;
    value_type: MetricDescriptor_ValueType;
    unit: string;
    description: string;
    display_name: string;
    metadata?: MetricDescriptor_MetricDescriptorMetadataSDKType;
    launch_stage: LaunchStage;
    monitored_resource_types: string[];
}
/** Additional annotations that can be used to guide the usage of a metric. */
export interface MetricDescriptor_MetricDescriptorMetadata {
    /** Deprecated. Must use the [MetricDescriptor.launch_stage][google.api.MetricDescriptor.launch_stage] instead. */
    /** @deprecated */
    launchStage: LaunchStage;
    /**
     * The sampling period of metric data points. For metrics which are written
     * periodically, consecutive data points are stored at this time interval,
     * excluding data loss due to errors. Metrics with a higher granularity have
     * a smaller sampling period.
     */
    samplePeriod?: Duration;
    /**
     * The delay of data points caused by ingestion. Data points older than this
     * age are guaranteed to be ingested and available to be read, excluding
     * data loss due to errors.
     */
    ingestDelay?: Duration;
}
export interface MetricDescriptor_MetricDescriptorMetadataProtoMsg {
    typeUrl: "/google.api.MetricDescriptorMetadata";
    value: Uint8Array;
}
/** Additional annotations that can be used to guide the usage of a metric. */
export interface MetricDescriptor_MetricDescriptorMetadataAmino {
    /** Deprecated. Must use the [MetricDescriptor.launch_stage][google.api.MetricDescriptor.launch_stage] instead. */
    /** @deprecated */
    launch_stage?: LaunchStage;
    /**
     * The sampling period of metric data points. For metrics which are written
     * periodically, consecutive data points are stored at this time interval,
     * excluding data loss due to errors. Metrics with a higher granularity have
     * a smaller sampling period.
     */
    sample_period?: DurationAmino;
    /**
     * The delay of data points caused by ingestion. Data points older than this
     * age are guaranteed to be ingested and available to be read, excluding
     * data loss due to errors.
     */
    ingest_delay?: DurationAmino;
}
export interface MetricDescriptor_MetricDescriptorMetadataAminoMsg {
    type: "/google.api.MetricDescriptorMetadata";
    value: MetricDescriptor_MetricDescriptorMetadataAmino;
}
/** Additional annotations that can be used to guide the usage of a metric. */
export interface MetricDescriptor_MetricDescriptorMetadataSDKType {
    /** @deprecated */
    launch_stage: LaunchStage;
    sample_period?: DurationSDKType;
    ingest_delay?: DurationSDKType;
}
export interface Metric_LabelsEntry {
    key: string;
    value: string;
}
export interface Metric_LabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface Metric_LabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface Metric_LabelsEntryAminoMsg {
    type: string;
    value: Metric_LabelsEntryAmino;
}
export interface Metric_LabelsEntrySDKType {
    key: string;
    value: string;
}
/**
 * A specific metric, identified by specifying values for all of the
 * labels of a [`MetricDescriptor`][google.api.MetricDescriptor].
 */
export interface Metric {
    /**
     * An existing metric type, see [google.api.MetricDescriptor][google.api.MetricDescriptor].
     * For example, `custom.googleapis.com/invoice/paid/amount`.
     */
    type: string;
    /**
     * The set of label values that uniquely identify this metric. All
     * labels listed in the `MetricDescriptor` must be assigned values.
     */
    labels: {
        [key: string]: string;
    };
}
export interface MetricProtoMsg {
    typeUrl: "/google.api.Metric";
    value: Uint8Array;
}
/**
 * A specific metric, identified by specifying values for all of the
 * labels of a [`MetricDescriptor`][google.api.MetricDescriptor].
 */
export interface MetricAmino {
    /**
     * An existing metric type, see [google.api.MetricDescriptor][google.api.MetricDescriptor].
     * For example, `custom.googleapis.com/invoice/paid/amount`.
     */
    type?: string;
    /**
     * The set of label values that uniquely identify this metric. All
     * labels listed in the `MetricDescriptor` must be assigned values.
     */
    labels?: {
        [key: string]: string;
    };
}
export interface MetricAminoMsg {
    type: "/google.api.Metric";
    value: MetricAmino;
}
/**
 * A specific metric, identified by specifying values for all of the
 * labels of a [`MetricDescriptor`][google.api.MetricDescriptor].
 */
export interface MetricSDKType {
    type: string;
    labels: {
        [key: string]: string;
    };
}
export declare const MetricDescriptor: {
    typeUrl: string;
    is(o: any): o is MetricDescriptor;
    isSDK(o: any): o is MetricDescriptorSDKType;
    isAmino(o: any): o is MetricDescriptorAmino;
    encode(message: MetricDescriptor, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricDescriptor;
    fromJSON(object: any): MetricDescriptor;
    toJSON(message: MetricDescriptor): JsonSafe<MetricDescriptor>;
    fromPartial(object: DeepPartial<MetricDescriptor>): MetricDescriptor;
    fromSDK(object: MetricDescriptorSDKType): MetricDescriptor;
    fromSDKJSON(object: any): MetricDescriptorSDKType;
    toSDK(message: MetricDescriptor): MetricDescriptorSDKType;
    fromAmino(object: MetricDescriptorAmino): MetricDescriptor;
    toAmino(message: MetricDescriptor): MetricDescriptorAmino;
    fromAminoMsg(object: MetricDescriptorAminoMsg): MetricDescriptor;
    fromProtoMsg(message: MetricDescriptorProtoMsg): MetricDescriptor;
    toProto(message: MetricDescriptor): Uint8Array;
    toProtoMsg(message: MetricDescriptor): MetricDescriptorProtoMsg;
    registerTypeUrl(): void;
};
export declare const MetricDescriptor_MetricDescriptorMetadata: {
    typeUrl: string;
    is(o: any): o is MetricDescriptor_MetricDescriptorMetadata;
    isSDK(o: any): o is MetricDescriptor_MetricDescriptorMetadataSDKType;
    isAmino(o: any): o is MetricDescriptor_MetricDescriptorMetadataAmino;
    encode(message: MetricDescriptor_MetricDescriptorMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricDescriptor_MetricDescriptorMetadata;
    fromJSON(object: any): MetricDescriptor_MetricDescriptorMetadata;
    toJSON(message: MetricDescriptor_MetricDescriptorMetadata): JsonSafe<MetricDescriptor_MetricDescriptorMetadata>;
    fromPartial(object: DeepPartial<MetricDescriptor_MetricDescriptorMetadata>): MetricDescriptor_MetricDescriptorMetadata;
    fromSDK(object: MetricDescriptor_MetricDescriptorMetadataSDKType): MetricDescriptor_MetricDescriptorMetadata;
    fromSDKJSON(object: any): MetricDescriptor_MetricDescriptorMetadataSDKType;
    toSDK(message: MetricDescriptor_MetricDescriptorMetadata): MetricDescriptor_MetricDescriptorMetadataSDKType;
    fromAmino(object: MetricDescriptor_MetricDescriptorMetadataAmino): MetricDescriptor_MetricDescriptorMetadata;
    toAmino(message: MetricDescriptor_MetricDescriptorMetadata): MetricDescriptor_MetricDescriptorMetadataAmino;
    fromAminoMsg(object: MetricDescriptor_MetricDescriptorMetadataAminoMsg): MetricDescriptor_MetricDescriptorMetadata;
    fromProtoMsg(message: MetricDescriptor_MetricDescriptorMetadataProtoMsg): MetricDescriptor_MetricDescriptorMetadata;
    toProto(message: MetricDescriptor_MetricDescriptorMetadata): Uint8Array;
    toProtoMsg(message: MetricDescriptor_MetricDescriptorMetadata): MetricDescriptor_MetricDescriptorMetadataProtoMsg;
    registerTypeUrl(): void;
};
export declare const Metric_LabelsEntry: {
    encode(message: Metric_LabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Metric_LabelsEntry;
    fromJSON(object: any): Metric_LabelsEntry;
    toJSON(message: Metric_LabelsEntry): JsonSafe<Metric_LabelsEntry>;
    fromPartial(object: DeepPartial<Metric_LabelsEntry>): Metric_LabelsEntry;
    fromSDK(object: Metric_LabelsEntrySDKType): Metric_LabelsEntry;
    fromSDKJSON(object: any): Metric_LabelsEntrySDKType;
    toSDK(message: Metric_LabelsEntry): Metric_LabelsEntrySDKType;
    fromAmino(object: Metric_LabelsEntryAmino): Metric_LabelsEntry;
    toAmino(message: Metric_LabelsEntry): Metric_LabelsEntryAmino;
    fromAminoMsg(object: Metric_LabelsEntryAminoMsg): Metric_LabelsEntry;
    fromProtoMsg(message: Metric_LabelsEntryProtoMsg): Metric_LabelsEntry;
    toProto(message: Metric_LabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const Metric: {
    typeUrl: string;
    is(o: any): o is Metric;
    isSDK(o: any): o is MetricSDKType;
    isAmino(o: any): o is MetricAmino;
    encode(message: Metric, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Metric;
    fromJSON(object: any): Metric;
    toJSON(message: Metric): JsonSafe<Metric>;
    fromPartial(object: DeepPartial<Metric>): Metric;
    fromSDK(object: MetricSDKType): Metric;
    fromSDKJSON(object: any): MetricSDKType;
    toSDK(message: Metric): MetricSDKType;
    fromAmino(object: MetricAmino): Metric;
    toAmino(message: Metric): MetricAmino;
    fromAminoMsg(object: MetricAminoMsg): Metric;
    fromProtoMsg(message: MetricProtoMsg): Metric;
    toProto(message: Metric): Uint8Array;
    toProtoMsg(message: Metric): MetricProtoMsg;
    registerTypeUrl(): void;
};
