import { LabelDescriptor, LabelDescriptorAmino, LabelDescriptorSDKType } from "./label";
import { LaunchStage } from "./launch_stage";
import { Struct, StructAmino, StructSDKType } from "../protobuf/struct";
import { DeepPartial } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.api";
/**
 * An object that describes the schema of a [MonitoredResource][google.api.MonitoredResource] object using a
 * type name and a set of labels.  For example, the monitored resource
 * descriptor for Google Compute Engine VM instances has a type of
 * `"gce_instance"` and specifies the use of the labels `"instance_id"` and
 * `"zone"` to identify particular VM instances.
 *
 * Different APIs can support different monitored resource types. APIs generally
 * provide a `list` method that returns the monitored resource descriptors used
 * by the API.
 */
export interface MonitoredResourceDescriptor {
    /**
     * Optional. The resource name of the monitored resource descriptor:
     * `"projects/{project_id}/monitoredResourceDescriptors/{type}"` where
     * {type} is the value of the `type` field in this object and
     * {project_id} is a project ID that provides API-specific context for
     * accessing the type.  APIs that do not use project information can use the
     * resource name format `"monitoredResourceDescriptors/{type}"`.
     */
    name: string;
    /**
     * Required. The monitored resource type. For example, the type
     * `"cloudsql_database"` represents databases in Google Cloud SQL.
     */
    type: string;
    /**
     * Optional. A concise name for the monitored resource type that might be
     * displayed in user interfaces. It should be a Title Cased Noun Phrase,
     * without any article or other determiners. For example,
     * `"Google Cloud SQL Database"`.
     */
    displayName: string;
    /**
     * Optional. A detailed description of the monitored resource type that might
     * be used in documentation.
     */
    description: string;
    /**
     * Required. A set of labels used to describe instances of this monitored
     * resource type. For example, an individual Google Cloud SQL database is
     * identified by values for the labels `"database_id"` and `"zone"`.
     */
    labels: LabelDescriptor[];
    /** Optional. The launch stage of the monitored resource definition. */
    launchStage: LaunchStage;
}
export interface MonitoredResourceDescriptorProtoMsg {
    typeUrl: "/google.api.MonitoredResourceDescriptor";
    value: Uint8Array;
}
/**
 * An object that describes the schema of a [MonitoredResource][google.api.MonitoredResource] object using a
 * type name and a set of labels.  For example, the monitored resource
 * descriptor for Google Compute Engine VM instances has a type of
 * `"gce_instance"` and specifies the use of the labels `"instance_id"` and
 * `"zone"` to identify particular VM instances.
 *
 * Different APIs can support different monitored resource types. APIs generally
 * provide a `list` method that returns the monitored resource descriptors used
 * by the API.
 */
export interface MonitoredResourceDescriptorAmino {
    /**
     * Optional. The resource name of the monitored resource descriptor:
     * `"projects/{project_id}/monitoredResourceDescriptors/{type}"` where
     * {type} is the value of the `type` field in this object and
     * {project_id} is a project ID that provides API-specific context for
     * accessing the type.  APIs that do not use project information can use the
     * resource name format `"monitoredResourceDescriptors/{type}"`.
     */
    name?: string;
    /**
     * Required. The monitored resource type. For example, the type
     * `"cloudsql_database"` represents databases in Google Cloud SQL.
     */
    type?: string;
    /**
     * Optional. A concise name for the monitored resource type that might be
     * displayed in user interfaces. It should be a Title Cased Noun Phrase,
     * without any article or other determiners. For example,
     * `"Google Cloud SQL Database"`.
     */
    display_name?: string;
    /**
     * Optional. A detailed description of the monitored resource type that might
     * be used in documentation.
     */
    description?: string;
    /**
     * Required. A set of labels used to describe instances of this monitored
     * resource type. For example, an individual Google Cloud SQL database is
     * identified by values for the labels `"database_id"` and `"zone"`.
     */
    labels?: LabelDescriptorAmino[];
    /** Optional. The launch stage of the monitored resource definition. */
    launch_stage?: LaunchStage;
}
export interface MonitoredResourceDescriptorAminoMsg {
    type: "/google.api.MonitoredResourceDescriptor";
    value: MonitoredResourceDescriptorAmino;
}
/**
 * An object that describes the schema of a [MonitoredResource][google.api.MonitoredResource] object using a
 * type name and a set of labels.  For example, the monitored resource
 * descriptor for Google Compute Engine VM instances has a type of
 * `"gce_instance"` and specifies the use of the labels `"instance_id"` and
 * `"zone"` to identify particular VM instances.
 *
 * Different APIs can support different monitored resource types. APIs generally
 * provide a `list` method that returns the monitored resource descriptors used
 * by the API.
 */
export interface MonitoredResourceDescriptorSDKType {
    name: string;
    type: string;
    display_name: string;
    description: string;
    labels: LabelDescriptorSDKType[];
    launch_stage: LaunchStage;
}
export interface MonitoredResource_LabelsEntry {
    key: string;
    value: string;
}
export interface MonitoredResource_LabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface MonitoredResource_LabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface MonitoredResource_LabelsEntryAminoMsg {
    type: string;
    value: MonitoredResource_LabelsEntryAmino;
}
export interface MonitoredResource_LabelsEntrySDKType {
    key: string;
    value: string;
}
/**
 * An object representing a resource that can be used for monitoring, logging,
 * billing, or other purposes. Examples include virtual machine instances,
 * databases, and storage devices such as disks. The `type` field identifies a
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object that describes the resource's
 * schema. Information in the `labels` field identifies the actual resource and
 * its attributes according to the schema. For example, a particular Compute
 * Engine VM instance could be represented by the following object, because the
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for `"gce_instance"` has labels
 * `"instance_id"` and `"zone"`:
 *
 *     { "type": "gce_instance",
 *       "labels": { "instance_id": "12345678901234",
 *                   "zone": "us-central1-a" }}
 */
export interface MonitoredResource {
    /**
     * Required. The monitored resource type. This field must match
     * the `type` field of a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object. For
     * example, the type of a Compute Engine VM instance is `gce_instance`.
     */
    type: string;
    /**
     * Required. Values for all of the labels listed in the associated monitored
     * resource descriptor. For example, Compute Engine VM instances use the
     * labels `"project_id"`, `"instance_id"`, and `"zone"`.
     */
    labels: {
        [key: string]: string;
    };
}
export interface MonitoredResourceProtoMsg {
    typeUrl: "/google.api.MonitoredResource";
    value: Uint8Array;
}
/**
 * An object representing a resource that can be used for monitoring, logging,
 * billing, or other purposes. Examples include virtual machine instances,
 * databases, and storage devices such as disks. The `type` field identifies a
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object that describes the resource's
 * schema. Information in the `labels` field identifies the actual resource and
 * its attributes according to the schema. For example, a particular Compute
 * Engine VM instance could be represented by the following object, because the
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for `"gce_instance"` has labels
 * `"instance_id"` and `"zone"`:
 *
 *     { "type": "gce_instance",
 *       "labels": { "instance_id": "12345678901234",
 *                   "zone": "us-central1-a" }}
 */
export interface MonitoredResourceAmino {
    /**
     * Required. The monitored resource type. This field must match
     * the `type` field of a [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object. For
     * example, the type of a Compute Engine VM instance is `gce_instance`.
     */
    type?: string;
    /**
     * Required. Values for all of the labels listed in the associated monitored
     * resource descriptor. For example, Compute Engine VM instances use the
     * labels `"project_id"`, `"instance_id"`, and `"zone"`.
     */
    labels?: {
        [key: string]: string;
    };
}
export interface MonitoredResourceAminoMsg {
    type: "/google.api.MonitoredResource";
    value: MonitoredResourceAmino;
}
/**
 * An object representing a resource that can be used for monitoring, logging,
 * billing, or other purposes. Examples include virtual machine instances,
 * databases, and storage devices such as disks. The `type` field identifies a
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] object that describes the resource's
 * schema. Information in the `labels` field identifies the actual resource and
 * its attributes according to the schema. For example, a particular Compute
 * Engine VM instance could be represented by the following object, because the
 * [MonitoredResourceDescriptor][google.api.MonitoredResourceDescriptor] for `"gce_instance"` has labels
 * `"instance_id"` and `"zone"`:
 *
 *     { "type": "gce_instance",
 *       "labels": { "instance_id": "12345678901234",
 *                   "zone": "us-central1-a" }}
 */
export interface MonitoredResourceSDKType {
    type: string;
    labels: {
        [key: string]: string;
    };
}
export interface MonitoredResourceMetadata_UserLabelsEntry {
    key: string;
    value: string;
}
export interface MonitoredResourceMetadata_UserLabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface MonitoredResourceMetadata_UserLabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface MonitoredResourceMetadata_UserLabelsEntryAminoMsg {
    type: string;
    value: MonitoredResourceMetadata_UserLabelsEntryAmino;
}
export interface MonitoredResourceMetadata_UserLabelsEntrySDKType {
    key: string;
    value: string;
}
/**
 * Auxiliary metadata for a [MonitoredResource][google.api.MonitoredResource] object.
 * [MonitoredResource][google.api.MonitoredResource] objects contain the minimum set of information to
 * uniquely identify a monitored resource instance. There is some other useful
 * auxiliary metadata. Monitoring and Logging use an ingestion
 * pipeline to extract metadata for cloud resources of all types, and store
 * the metadata in this message.
 */
export interface MonitoredResourceMetadata {
    /**
     * Output only. Values for predefined system metadata labels.
     * System labels are a kind of metadata extracted by Google, including
     * "machine_image", "vpc", "subnet_id",
     * "security_group", "name", etc.
     * System label values can be only strings, Boolean values, or a list of
     * strings. For example:
     *
     *     { "name": "my-test-instance",
     *       "security_group": ["a", "b", "c"],
     *       "spot_instance": false }
     */
    systemLabels?: Struct;
    /** Output only. A map of user-defined metadata labels. */
    userLabels: {
        [key: string]: string;
    };
}
export interface MonitoredResourceMetadataProtoMsg {
    typeUrl: "/google.api.MonitoredResourceMetadata";
    value: Uint8Array;
}
/**
 * Auxiliary metadata for a [MonitoredResource][google.api.MonitoredResource] object.
 * [MonitoredResource][google.api.MonitoredResource] objects contain the minimum set of information to
 * uniquely identify a monitored resource instance. There is some other useful
 * auxiliary metadata. Monitoring and Logging use an ingestion
 * pipeline to extract metadata for cloud resources of all types, and store
 * the metadata in this message.
 */
export interface MonitoredResourceMetadataAmino {
    /**
     * Output only. Values for predefined system metadata labels.
     * System labels are a kind of metadata extracted by Google, including
     * "machine_image", "vpc", "subnet_id",
     * "security_group", "name", etc.
     * System label values can be only strings, Boolean values, or a list of
     * strings. For example:
     *
     *     { "name": "my-test-instance",
     *       "security_group": ["a", "b", "c"],
     *       "spot_instance": false }
     */
    system_labels?: StructAmino;
    /** Output only. A map of user-defined metadata labels. */
    user_labels?: {
        [key: string]: string;
    };
}
export interface MonitoredResourceMetadataAminoMsg {
    type: "/google.api.MonitoredResourceMetadata";
    value: MonitoredResourceMetadataAmino;
}
/**
 * Auxiliary metadata for a [MonitoredResource][google.api.MonitoredResource] object.
 * [MonitoredResource][google.api.MonitoredResource] objects contain the minimum set of information to
 * uniquely identify a monitored resource instance. There is some other useful
 * auxiliary metadata. Monitoring and Logging use an ingestion
 * pipeline to extract metadata for cloud resources of all types, and store
 * the metadata in this message.
 */
export interface MonitoredResourceMetadataSDKType {
    system_labels?: StructSDKType;
    user_labels: {
        [key: string]: string;
    };
}
export declare const MonitoredResourceDescriptor: {
    typeUrl: string;
    is(o: any): o is MonitoredResourceDescriptor;
    isSDK(o: any): o is MonitoredResourceDescriptorSDKType;
    isAmino(o: any): o is MonitoredResourceDescriptorAmino;
    encode(message: MonitoredResourceDescriptor, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MonitoredResourceDescriptor;
    fromJSON(object: any): MonitoredResourceDescriptor;
    toJSON(message: MonitoredResourceDescriptor): JsonSafe<MonitoredResourceDescriptor>;
    fromPartial(object: DeepPartial<MonitoredResourceDescriptor>): MonitoredResourceDescriptor;
    fromSDK(object: MonitoredResourceDescriptorSDKType): MonitoredResourceDescriptor;
    fromSDKJSON(object: any): MonitoredResourceDescriptorSDKType;
    toSDK(message: MonitoredResourceDescriptor): MonitoredResourceDescriptorSDKType;
    fromAmino(object: MonitoredResourceDescriptorAmino): MonitoredResourceDescriptor;
    toAmino(message: MonitoredResourceDescriptor): MonitoredResourceDescriptorAmino;
    fromAminoMsg(object: MonitoredResourceDescriptorAminoMsg): MonitoredResourceDescriptor;
    fromProtoMsg(message: MonitoredResourceDescriptorProtoMsg): MonitoredResourceDescriptor;
    toProto(message: MonitoredResourceDescriptor): Uint8Array;
    toProtoMsg(message: MonitoredResourceDescriptor): MonitoredResourceDescriptorProtoMsg;
    registerTypeUrl(): void;
};
export declare const MonitoredResource_LabelsEntry: {
    encode(message: MonitoredResource_LabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MonitoredResource_LabelsEntry;
    fromJSON(object: any): MonitoredResource_LabelsEntry;
    toJSON(message: MonitoredResource_LabelsEntry): JsonSafe<MonitoredResource_LabelsEntry>;
    fromPartial(object: DeepPartial<MonitoredResource_LabelsEntry>): MonitoredResource_LabelsEntry;
    fromSDK(object: MonitoredResource_LabelsEntrySDKType): MonitoredResource_LabelsEntry;
    fromSDKJSON(object: any): MonitoredResource_LabelsEntrySDKType;
    toSDK(message: MonitoredResource_LabelsEntry): MonitoredResource_LabelsEntrySDKType;
    fromAmino(object: MonitoredResource_LabelsEntryAmino): MonitoredResource_LabelsEntry;
    toAmino(message: MonitoredResource_LabelsEntry): MonitoredResource_LabelsEntryAmino;
    fromAminoMsg(object: MonitoredResource_LabelsEntryAminoMsg): MonitoredResource_LabelsEntry;
    fromProtoMsg(message: MonitoredResource_LabelsEntryProtoMsg): MonitoredResource_LabelsEntry;
    toProto(message: MonitoredResource_LabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const MonitoredResource: {
    typeUrl: string;
    is(o: any): o is MonitoredResource;
    isSDK(o: any): o is MonitoredResourceSDKType;
    isAmino(o: any): o is MonitoredResourceAmino;
    encode(message: MonitoredResource, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MonitoredResource;
    fromJSON(object: any): MonitoredResource;
    toJSON(message: MonitoredResource): JsonSafe<MonitoredResource>;
    fromPartial(object: DeepPartial<MonitoredResource>): MonitoredResource;
    fromSDK(object: MonitoredResourceSDKType): MonitoredResource;
    fromSDKJSON(object: any): MonitoredResourceSDKType;
    toSDK(message: MonitoredResource): MonitoredResourceSDKType;
    fromAmino(object: MonitoredResourceAmino): MonitoredResource;
    toAmino(message: MonitoredResource): MonitoredResourceAmino;
    fromAminoMsg(object: MonitoredResourceAminoMsg): MonitoredResource;
    fromProtoMsg(message: MonitoredResourceProtoMsg): MonitoredResource;
    toProto(message: MonitoredResource): Uint8Array;
    toProtoMsg(message: MonitoredResource): MonitoredResourceProtoMsg;
    registerTypeUrl(): void;
};
export declare const MonitoredResourceMetadata_UserLabelsEntry: {
    encode(message: MonitoredResourceMetadata_UserLabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MonitoredResourceMetadata_UserLabelsEntry;
    fromJSON(object: any): MonitoredResourceMetadata_UserLabelsEntry;
    toJSON(message: MonitoredResourceMetadata_UserLabelsEntry): JsonSafe<MonitoredResourceMetadata_UserLabelsEntry>;
    fromPartial(object: DeepPartial<MonitoredResourceMetadata_UserLabelsEntry>): MonitoredResourceMetadata_UserLabelsEntry;
    fromSDK(object: MonitoredResourceMetadata_UserLabelsEntrySDKType): MonitoredResourceMetadata_UserLabelsEntry;
    fromSDKJSON(object: any): MonitoredResourceMetadata_UserLabelsEntrySDKType;
    toSDK(message: MonitoredResourceMetadata_UserLabelsEntry): MonitoredResourceMetadata_UserLabelsEntrySDKType;
    fromAmino(object: MonitoredResourceMetadata_UserLabelsEntryAmino): MonitoredResourceMetadata_UserLabelsEntry;
    toAmino(message: MonitoredResourceMetadata_UserLabelsEntry): MonitoredResourceMetadata_UserLabelsEntryAmino;
    fromAminoMsg(object: MonitoredResourceMetadata_UserLabelsEntryAminoMsg): MonitoredResourceMetadata_UserLabelsEntry;
    fromProtoMsg(message: MonitoredResourceMetadata_UserLabelsEntryProtoMsg): MonitoredResourceMetadata_UserLabelsEntry;
    toProto(message: MonitoredResourceMetadata_UserLabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const MonitoredResourceMetadata: {
    typeUrl: string;
    is(o: any): o is MonitoredResourceMetadata;
    isSDK(o: any): o is MonitoredResourceMetadataSDKType;
    isAmino(o: any): o is MonitoredResourceMetadataAmino;
    encode(message: MonitoredResourceMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MonitoredResourceMetadata;
    fromJSON(object: any): MonitoredResourceMetadata;
    toJSON(message: MonitoredResourceMetadata): JsonSafe<MonitoredResourceMetadata>;
    fromPartial(object: DeepPartial<MonitoredResourceMetadata>): MonitoredResourceMetadata;
    fromSDK(object: MonitoredResourceMetadataSDKType): MonitoredResourceMetadata;
    fromSDKJSON(object: any): MonitoredResourceMetadataSDKType;
    toSDK(message: MonitoredResourceMetadata): MonitoredResourceMetadataSDKType;
    fromAmino(object: MonitoredResourceMetadataAmino): MonitoredResourceMetadata;
    toAmino(message: MonitoredResourceMetadata): MonitoredResourceMetadataAmino;
    fromAminoMsg(object: MonitoredResourceMetadataAminoMsg): MonitoredResourceMetadata;
    fromProtoMsg(message: MonitoredResourceMetadataProtoMsg): MonitoredResourceMetadata;
    toProto(message: MonitoredResourceMetadata): Uint8Array;
    toProtoMsg(message: MonitoredResourceMetadata): MonitoredResourceMetadataProtoMsg;
    registerTypeUrl(): void;
};
