import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * Quota configuration helps to achieve fairness and budgeting in service
 * usage.
 *
 * The metric based quota configuration works this way:
 * - The service configuration defines a set of metrics.
 * - For API calls, the quota.metric_rules maps methods to metrics with
 *   corresponding costs.
 * - The quota.limits defines limits on the metrics, which will be used for
 *   quota checks at runtime.
 *
 * An example quota configuration in yaml format:
 *
 *    quota:
 *      limits:
 *
 *      - name: apiWriteQpsPerProject
 *        metric: library.googleapis.com/write_calls
 *        unit: "1/min/{project}"  # rate limit for consumer projects
 *        values:
 *          STANDARD: 10000
 *
 *
 *      # The metric rules bind all methods to the read_calls metric,
 *      # except for the UpdateBook and DeleteBook methods. These two methods
 *      # are mapped to the write_calls metric, with the UpdateBook method
 *      # consuming at twice rate as the DeleteBook method.
 *      metric_rules:
 *      - selector: "*"
 *        metric_costs:
 *          library.googleapis.com/read_calls: 1
 *      - selector: google.example.library.v1.LibraryService.UpdateBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 2
 *      - selector: google.example.library.v1.LibraryService.DeleteBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 1
 *
 *  Corresponding Metric definition:
 *
 *      metrics:
 *      - name: library.googleapis.com/read_calls
 *        display_name: Read requests
 *        metric_kind: DELTA
 *        value_type: INT64
 *
 *      - name: library.googleapis.com/write_calls
 *        display_name: Write requests
 *        metric_kind: DELTA
 *        value_type: INT64
 */
export interface Quota {
    /** List of `QuotaLimit` definitions for the service. */
    limits: QuotaLimit[];
    /**
     * List of `MetricRule` definitions, each one mapping a selected method to one
     * or more metrics.
     */
    metricRules: MetricRule[];
}
export interface QuotaProtoMsg {
    typeUrl: "/google.api.Quota";
    value: Uint8Array;
}
/**
 * Quota configuration helps to achieve fairness and budgeting in service
 * usage.
 *
 * The metric based quota configuration works this way:
 * - The service configuration defines a set of metrics.
 * - For API calls, the quota.metric_rules maps methods to metrics with
 *   corresponding costs.
 * - The quota.limits defines limits on the metrics, which will be used for
 *   quota checks at runtime.
 *
 * An example quota configuration in yaml format:
 *
 *    quota:
 *      limits:
 *
 *      - name: apiWriteQpsPerProject
 *        metric: library.googleapis.com/write_calls
 *        unit: "1/min/{project}"  # rate limit for consumer projects
 *        values:
 *          STANDARD: 10000
 *
 *
 *      # The metric rules bind all methods to the read_calls metric,
 *      # except for the UpdateBook and DeleteBook methods. These two methods
 *      # are mapped to the write_calls metric, with the UpdateBook method
 *      # consuming at twice rate as the DeleteBook method.
 *      metric_rules:
 *      - selector: "*"
 *        metric_costs:
 *          library.googleapis.com/read_calls: 1
 *      - selector: google.example.library.v1.LibraryService.UpdateBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 2
 *      - selector: google.example.library.v1.LibraryService.DeleteBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 1
 *
 *  Corresponding Metric definition:
 *
 *      metrics:
 *      - name: library.googleapis.com/read_calls
 *        display_name: Read requests
 *        metric_kind: DELTA
 *        value_type: INT64
 *
 *      - name: library.googleapis.com/write_calls
 *        display_name: Write requests
 *        metric_kind: DELTA
 *        value_type: INT64
 */
export interface QuotaAmino {
    /** List of `QuotaLimit` definitions for the service. */
    limits?: QuotaLimitAmino[];
    /**
     * List of `MetricRule` definitions, each one mapping a selected method to one
     * or more metrics.
     */
    metric_rules?: MetricRuleAmino[];
}
export interface QuotaAminoMsg {
    type: "/google.api.Quota";
    value: QuotaAmino;
}
/**
 * Quota configuration helps to achieve fairness and budgeting in service
 * usage.
 *
 * The metric based quota configuration works this way:
 * - The service configuration defines a set of metrics.
 * - For API calls, the quota.metric_rules maps methods to metrics with
 *   corresponding costs.
 * - The quota.limits defines limits on the metrics, which will be used for
 *   quota checks at runtime.
 *
 * An example quota configuration in yaml format:
 *
 *    quota:
 *      limits:
 *
 *      - name: apiWriteQpsPerProject
 *        metric: library.googleapis.com/write_calls
 *        unit: "1/min/{project}"  # rate limit for consumer projects
 *        values:
 *          STANDARD: 10000
 *
 *
 *      # The metric rules bind all methods to the read_calls metric,
 *      # except for the UpdateBook and DeleteBook methods. These two methods
 *      # are mapped to the write_calls metric, with the UpdateBook method
 *      # consuming at twice rate as the DeleteBook method.
 *      metric_rules:
 *      - selector: "*"
 *        metric_costs:
 *          library.googleapis.com/read_calls: 1
 *      - selector: google.example.library.v1.LibraryService.UpdateBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 2
 *      - selector: google.example.library.v1.LibraryService.DeleteBook
 *        metric_costs:
 *          library.googleapis.com/write_calls: 1
 *
 *  Corresponding Metric definition:
 *
 *      metrics:
 *      - name: library.googleapis.com/read_calls
 *        display_name: Read requests
 *        metric_kind: DELTA
 *        value_type: INT64
 *
 *      - name: library.googleapis.com/write_calls
 *        display_name: Write requests
 *        metric_kind: DELTA
 *        value_type: INT64
 */
export interface QuotaSDKType {
    limits: QuotaLimitSDKType[];
    metric_rules: MetricRuleSDKType[];
}
export interface MetricRule_MetricCostsEntry {
    key: string;
    value: bigint;
}
export interface MetricRule_MetricCostsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface MetricRule_MetricCostsEntryAmino {
    key?: string;
    value?: string;
}
export interface MetricRule_MetricCostsEntryAminoMsg {
    type: string;
    value: MetricRule_MetricCostsEntryAmino;
}
export interface MetricRule_MetricCostsEntrySDKType {
    key: string;
    value: bigint;
}
/**
 * Bind API methods to metrics. Binding a method to a metric causes that
 * metric's configured quota behaviors to apply to the method call.
 */
export interface MetricRule {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector: string;
    /**
     * Metrics to update when the selected methods are called, and the associated
     * cost applied to each metric.
     *
     * The key of the map is the metric name, and the values are the amount
     * increased for the metric against which the quota limits are defined.
     * The value must not be negative.
     */
    metricCosts: {
        [key: string]: bigint;
    };
}
export interface MetricRuleProtoMsg {
    typeUrl: "/google.api.MetricRule";
    value: Uint8Array;
}
/**
 * Bind API methods to metrics. Binding a method to a metric causes that
 * metric's configured quota behaviors to apply to the method call.
 */
export interface MetricRuleAmino {
    /**
     * Selects the methods to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector?: string;
    /**
     * Metrics to update when the selected methods are called, and the associated
     * cost applied to each metric.
     *
     * The key of the map is the metric name, and the values are the amount
     * increased for the metric against which the quota limits are defined.
     * The value must not be negative.
     */
    metric_costs?: {
        [key: string]: string;
    };
}
export interface MetricRuleAminoMsg {
    type: "/google.api.MetricRule";
    value: MetricRuleAmino;
}
/**
 * Bind API methods to metrics. Binding a method to a metric causes that
 * metric's configured quota behaviors to apply to the method call.
 */
export interface MetricRuleSDKType {
    selector: string;
    metric_costs: {
        [key: string]: bigint;
    };
}
export interface QuotaLimit_ValuesEntry {
    key: string;
    value: bigint;
}
export interface QuotaLimit_ValuesEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface QuotaLimit_ValuesEntryAmino {
    key?: string;
    value?: string;
}
export interface QuotaLimit_ValuesEntryAminoMsg {
    type: string;
    value: QuotaLimit_ValuesEntryAmino;
}
export interface QuotaLimit_ValuesEntrySDKType {
    key: string;
    value: bigint;
}
/**
 * `QuotaLimit` defines a specific limit that applies over a specified duration
 * for a limit type. There can be at most one limit for a duration and limit
 * type combination defined within a `QuotaGroup`.
 */
export interface QuotaLimit {
    /**
     * Name of the quota limit.
     *
     * The name must be provided, and it must be unique within the service. The
     * name can only include alphanumeric characters as well as '-'.
     *
     * The maximum length of the limit name is 64 characters.
     */
    name: string;
    /**
     * Optional. User-visible, extended description for this quota limit.
     * Should be used only when more context is needed to understand this limit
     * than provided by the limit's display name (see: `display_name`).
     */
    description: string;
    /**
     * Default number of tokens that can be consumed during the specified
     * duration. This is the number of tokens assigned when a client
     * application developer activates the service for his/her project.
     *
     * Specifying a value of 0 will block all requests. This can be used if you
     * are provisioning quota to selected consumers and blocking others.
     * Similarly, a value of -1 will indicate an unlimited quota. No other
     * negative values are allowed.
     *
     * Used by group-based quotas only.
     */
    defaultLimit: bigint;
    /**
     * Maximum number of tokens that can be consumed during the specified
     * duration. Client application developers can override the default limit up
     * to this maximum. If specified, this value cannot be set to a value less
     * than the default limit. If not specified, it is set to the default limit.
     *
     * To allow clients to apply overrides with no upper bound, set this to -1,
     * indicating unlimited maximum quota.
     *
     * Used by group-based quotas only.
     */
    maxLimit: bigint;
    /**
     * Free tier value displayed in the Developers Console for this limit.
     * The free tier is the number of tokens that will be subtracted from the
     * billed amount when billing is enabled.
     * This field can only be set on a limit with duration "1d", in a billable
     * group; it is invalid on any other limit. If this field is not set, it
     * defaults to 0, indicating that there is no free tier for this service.
     *
     * Used by group-based quotas only.
     */
    freeTier: bigint;
    /**
     * Duration of this limit in textual notation. Must be "100s" or "1d".
     *
     * Used by group-based quotas only.
     */
    duration: string;
    /**
     * The name of the metric this quota limit applies to. The quota limits with
     * the same metric will be checked together during runtime. The metric must be
     * defined within the service config.
     */
    metric: string;
    /**
     * Specify the unit of the quota limit. It uses the same syntax as
     * [Metric.unit][]. The supported unit kinds are determined by the quota
     * backend system.
     *
     * Here are some examples:
     * * "1/min/{project}" for quota per minute per project.
     *
     * Note: the order of unit components is insignificant.
     * The "1" at the beginning is required to follow the metric unit syntax.
     */
    unit: string;
    /**
     * Tiered limit values. You must specify this as a key:value pair, with an
     * integer value that is the maximum number of requests allowed for the
     * specified unit. Currently only STANDARD is supported.
     */
    values: {
        [key: string]: bigint;
    };
    /**
     * User-visible display name for this limit.
     * Optional. If not set, the UI will provide a default display name based on
     * the quota configuration. This field can be used to override the default
     * display name generated from the configuration.
     */
    displayName: string;
}
export interface QuotaLimitProtoMsg {
    typeUrl: "/google.api.QuotaLimit";
    value: Uint8Array;
}
/**
 * `QuotaLimit` defines a specific limit that applies over a specified duration
 * for a limit type. There can be at most one limit for a duration and limit
 * type combination defined within a `QuotaGroup`.
 */
export interface QuotaLimitAmino {
    /**
     * Name of the quota limit.
     *
     * The name must be provided, and it must be unique within the service. The
     * name can only include alphanumeric characters as well as '-'.
     *
     * The maximum length of the limit name is 64 characters.
     */
    name?: string;
    /**
     * Optional. User-visible, extended description for this quota limit.
     * Should be used only when more context is needed to understand this limit
     * than provided by the limit's display name (see: `display_name`).
     */
    description?: string;
    /**
     * Default number of tokens that can be consumed during the specified
     * duration. This is the number of tokens assigned when a client
     * application developer activates the service for his/her project.
     *
     * Specifying a value of 0 will block all requests. This can be used if you
     * are provisioning quota to selected consumers and blocking others.
     * Similarly, a value of -1 will indicate an unlimited quota. No other
     * negative values are allowed.
     *
     * Used by group-based quotas only.
     */
    default_limit?: string;
    /**
     * Maximum number of tokens that can be consumed during the specified
     * duration. Client application developers can override the default limit up
     * to this maximum. If specified, this value cannot be set to a value less
     * than the default limit. If not specified, it is set to the default limit.
     *
     * To allow clients to apply overrides with no upper bound, set this to -1,
     * indicating unlimited maximum quota.
     *
     * Used by group-based quotas only.
     */
    max_limit?: string;
    /**
     * Free tier value displayed in the Developers Console for this limit.
     * The free tier is the number of tokens that will be subtracted from the
     * billed amount when billing is enabled.
     * This field can only be set on a limit with duration "1d", in a billable
     * group; it is invalid on any other limit. If this field is not set, it
     * defaults to 0, indicating that there is no free tier for this service.
     *
     * Used by group-based quotas only.
     */
    free_tier?: string;
    /**
     * Duration of this limit in textual notation. Must be "100s" or "1d".
     *
     * Used by group-based quotas only.
     */
    duration?: string;
    /**
     * The name of the metric this quota limit applies to. The quota limits with
     * the same metric will be checked together during runtime. The metric must be
     * defined within the service config.
     */
    metric?: string;
    /**
     * Specify the unit of the quota limit. It uses the same syntax as
     * [Metric.unit][]. The supported unit kinds are determined by the quota
     * backend system.
     *
     * Here are some examples:
     * * "1/min/{project}" for quota per minute per project.
     *
     * Note: the order of unit components is insignificant.
     * The "1" at the beginning is required to follow the metric unit syntax.
     */
    unit?: string;
    /**
     * Tiered limit values. You must specify this as a key:value pair, with an
     * integer value that is the maximum number of requests allowed for the
     * specified unit. Currently only STANDARD is supported.
     */
    values?: {
        [key: string]: string;
    };
    /**
     * User-visible display name for this limit.
     * Optional. If not set, the UI will provide a default display name based on
     * the quota configuration. This field can be used to override the default
     * display name generated from the configuration.
     */
    display_name?: string;
}
export interface QuotaLimitAminoMsg {
    type: "/google.api.QuotaLimit";
    value: QuotaLimitAmino;
}
/**
 * `QuotaLimit` defines a specific limit that applies over a specified duration
 * for a limit type. There can be at most one limit for a duration and limit
 * type combination defined within a `QuotaGroup`.
 */
export interface QuotaLimitSDKType {
    name: string;
    description: string;
    default_limit: bigint;
    max_limit: bigint;
    free_tier: bigint;
    duration: string;
    metric: string;
    unit: string;
    values: {
        [key: string]: bigint;
    };
    display_name: string;
}
export declare const Quota: {
    typeUrl: string;
    is(o: any): o is Quota;
    isSDK(o: any): o is QuotaSDKType;
    isAmino(o: any): o is QuotaAmino;
    encode(message: Quota, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Quota;
    fromJSON(object: any): Quota;
    toJSON(message: Quota): JsonSafe<Quota>;
    fromPartial(object: DeepPartial<Quota>): Quota;
    fromSDK(object: QuotaSDKType): Quota;
    fromSDKJSON(object: any): QuotaSDKType;
    toSDK(message: Quota): QuotaSDKType;
    fromAmino(object: QuotaAmino): Quota;
    toAmino(message: Quota): QuotaAmino;
    fromAminoMsg(object: QuotaAminoMsg): Quota;
    fromProtoMsg(message: QuotaProtoMsg): Quota;
    toProto(message: Quota): Uint8Array;
    toProtoMsg(message: Quota): QuotaProtoMsg;
    registerTypeUrl(): void;
};
export declare const MetricRule_MetricCostsEntry: {
    encode(message: MetricRule_MetricCostsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricRule_MetricCostsEntry;
    fromJSON(object: any): MetricRule_MetricCostsEntry;
    toJSON(message: MetricRule_MetricCostsEntry): JsonSafe<MetricRule_MetricCostsEntry>;
    fromPartial(object: DeepPartial<MetricRule_MetricCostsEntry>): MetricRule_MetricCostsEntry;
    fromSDK(object: MetricRule_MetricCostsEntrySDKType): MetricRule_MetricCostsEntry;
    fromSDKJSON(object: any): MetricRule_MetricCostsEntrySDKType;
    toSDK(message: MetricRule_MetricCostsEntry): MetricRule_MetricCostsEntrySDKType;
    fromAmino(object: MetricRule_MetricCostsEntryAmino): MetricRule_MetricCostsEntry;
    toAmino(message: MetricRule_MetricCostsEntry): MetricRule_MetricCostsEntryAmino;
    fromAminoMsg(object: MetricRule_MetricCostsEntryAminoMsg): MetricRule_MetricCostsEntry;
    fromProtoMsg(message: MetricRule_MetricCostsEntryProtoMsg): MetricRule_MetricCostsEntry;
    toProto(message: MetricRule_MetricCostsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const MetricRule: {
    typeUrl: string;
    is(o: any): o is MetricRule;
    isSDK(o: any): o is MetricRuleSDKType;
    isAmino(o: any): o is MetricRuleAmino;
    encode(message: MetricRule, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricRule;
    fromJSON(object: any): MetricRule;
    toJSON(message: MetricRule): JsonSafe<MetricRule>;
    fromPartial(object: DeepPartial<MetricRule>): MetricRule;
    fromSDK(object: MetricRuleSDKType): MetricRule;
    fromSDKJSON(object: any): MetricRuleSDKType;
    toSDK(message: MetricRule): MetricRuleSDKType;
    fromAmino(object: MetricRuleAmino): MetricRule;
    toAmino(message: MetricRule): MetricRuleAmino;
    fromAminoMsg(object: MetricRuleAminoMsg): MetricRule;
    fromProtoMsg(message: MetricRuleProtoMsg): MetricRule;
    toProto(message: MetricRule): Uint8Array;
    toProtoMsg(message: MetricRule): MetricRuleProtoMsg;
    registerTypeUrl(): void;
};
export declare const QuotaLimit_ValuesEntry: {
    encode(message: QuotaLimit_ValuesEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaLimit_ValuesEntry;
    fromJSON(object: any): QuotaLimit_ValuesEntry;
    toJSON(message: QuotaLimit_ValuesEntry): JsonSafe<QuotaLimit_ValuesEntry>;
    fromPartial(object: DeepPartial<QuotaLimit_ValuesEntry>): QuotaLimit_ValuesEntry;
    fromSDK(object: QuotaLimit_ValuesEntrySDKType): QuotaLimit_ValuesEntry;
    fromSDKJSON(object: any): QuotaLimit_ValuesEntrySDKType;
    toSDK(message: QuotaLimit_ValuesEntry): QuotaLimit_ValuesEntrySDKType;
    fromAmino(object: QuotaLimit_ValuesEntryAmino): QuotaLimit_ValuesEntry;
    toAmino(message: QuotaLimit_ValuesEntry): QuotaLimit_ValuesEntryAmino;
    fromAminoMsg(object: QuotaLimit_ValuesEntryAminoMsg): QuotaLimit_ValuesEntry;
    fromProtoMsg(message: QuotaLimit_ValuesEntryProtoMsg): QuotaLimit_ValuesEntry;
    toProto(message: QuotaLimit_ValuesEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const QuotaLimit: {
    typeUrl: string;
    is(o: any): o is QuotaLimit;
    isSDK(o: any): o is QuotaLimitSDKType;
    isAmino(o: any): o is QuotaLimitAmino;
    encode(message: QuotaLimit, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaLimit;
    fromJSON(object: any): QuotaLimit;
    toJSON(message: QuotaLimit): JsonSafe<QuotaLimit>;
    fromPartial(object: DeepPartial<QuotaLimit>): QuotaLimit;
    fromSDK(object: QuotaLimitSDKType): QuotaLimit;
    fromSDKJSON(object: any): QuotaLimitSDKType;
    toSDK(message: QuotaLimit): QuotaLimitSDKType;
    fromAmino(object: QuotaLimitAmino): QuotaLimit;
    toAmino(message: QuotaLimit): QuotaLimitAmino;
    fromAminoMsg(object: QuotaLimitAminoMsg): QuotaLimit;
    fromProtoMsg(message: QuotaLimitProtoMsg): QuotaLimit;
    toProto(message: QuotaLimit): Uint8Array;
    toProtoMsg(message: QuotaLimit): QuotaLimitProtoMsg;
    registerTypeUrl(): void;
};
