import { Distribution_Exemplar, Distribution_ExemplarAmino, Distribution_ExemplarSDKType } from "../../distribution";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicecontrol.v1";
/**
 * Distribution represents a frequency distribution of double-valued sample
 * points. It contains the size of the population of sample points plus
 * additional optional information:
 *
 * * the arithmetic mean of the samples
 * * the minimum and maximum of the samples
 * * the sum-squared-deviation of the samples, used to compute variance
 * * a histogram of the values of the sample points
 */
export interface Distribution {
    /** The total number of samples in the distribution. Must be >= 0. */
    count: bigint;
    /**
     * The arithmetic mean of the samples in the distribution. If `count` is
     * zero then this field must be zero.
     */
    mean: number;
    /** The minimum of the population of values. Ignored if `count` is zero. */
    minimum: number;
    /** The maximum of the population of values. Ignored if `count` is zero. */
    maximum: number;
    /**
     * The sum of squared deviations from the mean:
     *   Sum[i=1..count]((x_i - mean)^2)
     * where each x_i is a sample values. If `count` is zero then this field
     * must be zero, otherwise validation of the request fails.
     */
    sumOfSquaredDeviation: number;
    /**
     * The number of samples in each histogram bucket. `bucket_counts` are
     * optional. If present, they must sum to the `count` value.
     *
     * The buckets are defined below in `bucket_option`. There are N buckets.
     * `bucket_counts[0]` is the number of samples in the underflow bucket.
     * `bucket_counts[1]` to `bucket_counts[N-1]` are the numbers of samples
     * in each of the finite buckets. And `bucket_counts[N] is the number
     * of samples in the overflow bucket. See the comments of `bucket_option`
     * below for more details.
     *
     * Any suffix of trailing zeros may be omitted.
     */
    bucketCounts: bigint[];
    /** Buckets with constant width. */
    linearBuckets?: Distribution_LinearBuckets;
    /** Buckets with exponentially growing width. */
    exponentialBuckets?: Distribution_ExponentialBuckets;
    /** Buckets with arbitrary user-provided width. */
    explicitBuckets?: Distribution_ExplicitBuckets;
    /** Example points. Must be in increasing order of `value` field. */
    exemplars: Distribution_Exemplar[];
}
export interface DistributionProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.Distribution";
    value: Uint8Array;
}
/**
 * Distribution represents a frequency distribution of double-valued sample
 * points. It contains the size of the population of sample points plus
 * additional optional information:
 *
 * * the arithmetic mean of the samples
 * * the minimum and maximum of the samples
 * * the sum-squared-deviation of the samples, used to compute variance
 * * a histogram of the values of the sample points
 */
export interface DistributionAmino {
    /** The total number of samples in the distribution. Must be >= 0. */
    count?: string;
    /**
     * The arithmetic mean of the samples in the distribution. If `count` is
     * zero then this field must be zero.
     */
    mean?: number;
    /** The minimum of the population of values. Ignored if `count` is zero. */
    minimum?: number;
    /** The maximum of the population of values. Ignored if `count` is zero. */
    maximum?: number;
    /**
     * The sum of squared deviations from the mean:
     *   Sum[i=1..count]((x_i - mean)^2)
     * where each x_i is a sample values. If `count` is zero then this field
     * must be zero, otherwise validation of the request fails.
     */
    sum_of_squared_deviation?: number;
    /**
     * The number of samples in each histogram bucket. `bucket_counts` are
     * optional. If present, they must sum to the `count` value.
     *
     * The buckets are defined below in `bucket_option`. There are N buckets.
     * `bucket_counts[0]` is the number of samples in the underflow bucket.
     * `bucket_counts[1]` to `bucket_counts[N-1]` are the numbers of samples
     * in each of the finite buckets. And `bucket_counts[N] is the number
     * of samples in the overflow bucket. See the comments of `bucket_option`
     * below for more details.
     *
     * Any suffix of trailing zeros may be omitted.
     */
    bucket_counts?: string[];
    /** Buckets with constant width. */
    linear_buckets?: Distribution_LinearBucketsAmino;
    /** Buckets with exponentially growing width. */
    exponential_buckets?: Distribution_ExponentialBucketsAmino;
    /** Buckets with arbitrary user-provided width. */
    explicit_buckets?: Distribution_ExplicitBucketsAmino;
    /** Example points. Must be in increasing order of `value` field. */
    exemplars?: Distribution_ExemplarAmino[];
}
export interface DistributionAminoMsg {
    type: "/google.api.servicecontrol.v1.Distribution";
    value: DistributionAmino;
}
/**
 * Distribution represents a frequency distribution of double-valued sample
 * points. It contains the size of the population of sample points plus
 * additional optional information:
 *
 * * the arithmetic mean of the samples
 * * the minimum and maximum of the samples
 * * the sum-squared-deviation of the samples, used to compute variance
 * * a histogram of the values of the sample points
 */
export interface DistributionSDKType {
    count: bigint;
    mean: number;
    minimum: number;
    maximum: number;
    sum_of_squared_deviation: number;
    bucket_counts: bigint[];
    linear_buckets?: Distribution_LinearBucketsSDKType;
    exponential_buckets?: Distribution_ExponentialBucketsSDKType;
    explicit_buckets?: Distribution_ExplicitBucketsSDKType;
    exemplars: Distribution_ExemplarSDKType[];
}
/** Describing buckets with constant width. */
export interface Distribution_LinearBuckets {
    /**
     * The number of finite buckets. With the underflow and overflow buckets,
     * the total number of buckets is `num_finite_buckets` + 2.
     * See comments on `bucket_options` for details.
     */
    numFiniteBuckets: number;
    /**
     * The i'th linear bucket covers the interval
     *   [offset + (i-1) * width, offset + i * width)
     * where i ranges from 1 to num_finite_buckets, inclusive.
     * Must be strictly positive.
     */
    width: number;
    /**
     * The i'th linear bucket covers the interval
     *   [offset + (i-1) * width, offset + i * width)
     * where i ranges from 1 to num_finite_buckets, inclusive.
     */
    offset: number;
}
export interface Distribution_LinearBucketsProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.LinearBuckets";
    value: Uint8Array;
}
/** Describing buckets with constant width. */
export interface Distribution_LinearBucketsAmino {
    /**
     * The number of finite buckets. With the underflow and overflow buckets,
     * the total number of buckets is `num_finite_buckets` + 2.
     * See comments on `bucket_options` for details.
     */
    num_finite_buckets?: number;
    /**
     * The i'th linear bucket covers the interval
     *   [offset + (i-1) * width, offset + i * width)
     * where i ranges from 1 to num_finite_buckets, inclusive.
     * Must be strictly positive.
     */
    width?: number;
    /**
     * The i'th linear bucket covers the interval
     *   [offset + (i-1) * width, offset + i * width)
     * where i ranges from 1 to num_finite_buckets, inclusive.
     */
    offset?: number;
}
export interface Distribution_LinearBucketsAminoMsg {
    type: "/google.api.servicecontrol.v1.LinearBuckets";
    value: Distribution_LinearBucketsAmino;
}
/** Describing buckets with constant width. */
export interface Distribution_LinearBucketsSDKType {
    num_finite_buckets: number;
    width: number;
    offset: number;
}
/** Describing buckets with exponentially growing width. */
export interface Distribution_ExponentialBuckets {
    /**
     * The number of finite buckets. With the underflow and overflow buckets,
     * the total number of buckets is `num_finite_buckets` + 2.
     * See comments on `bucket_options` for details.
     */
    numFiniteBuckets: number;
    /**
     * The i'th exponential bucket covers the interval
     *   [scale * growth_factor^(i-1), scale * growth_factor^i)
     * where i ranges from 1 to num_finite_buckets inclusive.
     * Must be larger than 1.0.
     */
    growthFactor: number;
    /**
     * The i'th exponential bucket covers the interval
     *   [scale * growth_factor^(i-1), scale * growth_factor^i)
     * where i ranges from 1 to num_finite_buckets inclusive.
     * Must be > 0.
     */
    scale: number;
}
export interface Distribution_ExponentialBucketsProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ExponentialBuckets";
    value: Uint8Array;
}
/** Describing buckets with exponentially growing width. */
export interface Distribution_ExponentialBucketsAmino {
    /**
     * The number of finite buckets. With the underflow and overflow buckets,
     * the total number of buckets is `num_finite_buckets` + 2.
     * See comments on `bucket_options` for details.
     */
    num_finite_buckets?: number;
    /**
     * The i'th exponential bucket covers the interval
     *   [scale * growth_factor^(i-1), scale * growth_factor^i)
     * where i ranges from 1 to num_finite_buckets inclusive.
     * Must be larger than 1.0.
     */
    growth_factor?: number;
    /**
     * The i'th exponential bucket covers the interval
     *   [scale * growth_factor^(i-1), scale * growth_factor^i)
     * where i ranges from 1 to num_finite_buckets inclusive.
     * Must be > 0.
     */
    scale?: number;
}
export interface Distribution_ExponentialBucketsAminoMsg {
    type: "/google.api.servicecontrol.v1.ExponentialBuckets";
    value: Distribution_ExponentialBucketsAmino;
}
/** Describing buckets with exponentially growing width. */
export interface Distribution_ExponentialBucketsSDKType {
    num_finite_buckets: number;
    growth_factor: number;
    scale: number;
}
/** Describing buckets with arbitrary user-provided width. */
export interface Distribution_ExplicitBuckets {
    /**
     * 'bound' is a list of strictly increasing boundaries between
     * buckets. Note that a list of length N-1 defines N buckets because
     * of fenceposting. See comments on `bucket_options` for details.
     *
     * The i'th finite bucket covers the interval
     *   [bound[i-1], bound[i])
     * where i ranges from 1 to bound_size() - 1. Note that there are no
     * finite buckets at all if 'bound' only contains a single element; in
     * that special case the single bound defines the boundary between the
     * underflow and overflow buckets.
     *
     * bucket number                   lower bound    upper bound
     *  i == 0 (underflow)              -inf           bound[i]
     *  0 < i < bound_size()            bound[i-1]     bound[i]
     *  i == bound_size() (overflow)    bound[i-1]     +inf
     */
    bounds: number[];
}
export interface Distribution_ExplicitBucketsProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ExplicitBuckets";
    value: Uint8Array;
}
/** Describing buckets with arbitrary user-provided width. */
export interface Distribution_ExplicitBucketsAmino {
    /**
     * 'bound' is a list of strictly increasing boundaries between
     * buckets. Note that a list of length N-1 defines N buckets because
     * of fenceposting. See comments on `bucket_options` for details.
     *
     * The i'th finite bucket covers the interval
     *   [bound[i-1], bound[i])
     * where i ranges from 1 to bound_size() - 1. Note that there are no
     * finite buckets at all if 'bound' only contains a single element; in
     * that special case the single bound defines the boundary between the
     * underflow and overflow buckets.
     *
     * bucket number                   lower bound    upper bound
     *  i == 0 (underflow)              -inf           bound[i]
     *  0 < i < bound_size()            bound[i-1]     bound[i]
     *  i == bound_size() (overflow)    bound[i-1]     +inf
     */
    bounds?: number[];
}
export interface Distribution_ExplicitBucketsAminoMsg {
    type: "/google.api.servicecontrol.v1.ExplicitBuckets";
    value: Distribution_ExplicitBucketsAmino;
}
/** Describing buckets with arbitrary user-provided width. */
export interface Distribution_ExplicitBucketsSDKType {
    bounds: number[];
}
export declare const Distribution: {
    typeUrl: string;
    is(o: any): o is Distribution;
    isSDK(o: any): o is DistributionSDKType;
    isAmino(o: any): o is DistributionAmino;
    encode(message: Distribution, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution;
    fromJSON(object: any): Distribution;
    toJSON(message: Distribution): JsonSafe<Distribution>;
    fromPartial(object: DeepPartial<Distribution>): Distribution;
    fromSDK(object: DistributionSDKType): Distribution;
    fromSDKJSON(object: any): DistributionSDKType;
    toSDK(message: Distribution): DistributionSDKType;
    fromAmino(object: DistributionAmino): Distribution;
    toAmino(message: Distribution): DistributionAmino;
    fromAminoMsg(object: DistributionAminoMsg): Distribution;
    fromProtoMsg(message: DistributionProtoMsg): Distribution;
    toProto(message: Distribution): Uint8Array;
    toProtoMsg(message: Distribution): DistributionProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_LinearBuckets: {
    typeUrl: string;
    is(o: any): o is Distribution_LinearBuckets;
    isSDK(o: any): o is Distribution_LinearBucketsSDKType;
    isAmino(o: any): o is Distribution_LinearBucketsAmino;
    encode(message: Distribution_LinearBuckets, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_LinearBuckets;
    fromJSON(object: any): Distribution_LinearBuckets;
    toJSON(message: Distribution_LinearBuckets): JsonSafe<Distribution_LinearBuckets>;
    fromPartial(object: DeepPartial<Distribution_LinearBuckets>): Distribution_LinearBuckets;
    fromSDK(object: Distribution_LinearBucketsSDKType): Distribution_LinearBuckets;
    fromSDKJSON(object: any): Distribution_LinearBucketsSDKType;
    toSDK(message: Distribution_LinearBuckets): Distribution_LinearBucketsSDKType;
    fromAmino(object: Distribution_LinearBucketsAmino): Distribution_LinearBuckets;
    toAmino(message: Distribution_LinearBuckets): Distribution_LinearBucketsAmino;
    fromAminoMsg(object: Distribution_LinearBucketsAminoMsg): Distribution_LinearBuckets;
    fromProtoMsg(message: Distribution_LinearBucketsProtoMsg): Distribution_LinearBuckets;
    toProto(message: Distribution_LinearBuckets): Uint8Array;
    toProtoMsg(message: Distribution_LinearBuckets): Distribution_LinearBucketsProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_ExponentialBuckets: {
    typeUrl: string;
    is(o: any): o is Distribution_ExponentialBuckets;
    isSDK(o: any): o is Distribution_ExponentialBucketsSDKType;
    isAmino(o: any): o is Distribution_ExponentialBucketsAmino;
    encode(message: Distribution_ExponentialBuckets, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_ExponentialBuckets;
    fromJSON(object: any): Distribution_ExponentialBuckets;
    toJSON(message: Distribution_ExponentialBuckets): JsonSafe<Distribution_ExponentialBuckets>;
    fromPartial(object: DeepPartial<Distribution_ExponentialBuckets>): Distribution_ExponentialBuckets;
    fromSDK(object: Distribution_ExponentialBucketsSDKType): Distribution_ExponentialBuckets;
    fromSDKJSON(object: any): Distribution_ExponentialBucketsSDKType;
    toSDK(message: Distribution_ExponentialBuckets): Distribution_ExponentialBucketsSDKType;
    fromAmino(object: Distribution_ExponentialBucketsAmino): Distribution_ExponentialBuckets;
    toAmino(message: Distribution_ExponentialBuckets): Distribution_ExponentialBucketsAmino;
    fromAminoMsg(object: Distribution_ExponentialBucketsAminoMsg): Distribution_ExponentialBuckets;
    fromProtoMsg(message: Distribution_ExponentialBucketsProtoMsg): Distribution_ExponentialBuckets;
    toProto(message: Distribution_ExponentialBuckets): Uint8Array;
    toProtoMsg(message: Distribution_ExponentialBuckets): Distribution_ExponentialBucketsProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_ExplicitBuckets: {
    typeUrl: string;
    is(o: any): o is Distribution_ExplicitBuckets;
    isSDK(o: any): o is Distribution_ExplicitBucketsSDKType;
    isAmino(o: any): o is Distribution_ExplicitBucketsAmino;
    encode(message: Distribution_ExplicitBuckets, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_ExplicitBuckets;
    fromJSON(object: any): Distribution_ExplicitBuckets;
    toJSON(message: Distribution_ExplicitBuckets): JsonSafe<Distribution_ExplicitBuckets>;
    fromPartial(object: DeepPartial<Distribution_ExplicitBuckets>): Distribution_ExplicitBuckets;
    fromSDK(object: Distribution_ExplicitBucketsSDKType): Distribution_ExplicitBuckets;
    fromSDKJSON(object: any): Distribution_ExplicitBucketsSDKType;
    toSDK(message: Distribution_ExplicitBuckets): Distribution_ExplicitBucketsSDKType;
    fromAmino(object: Distribution_ExplicitBucketsAmino): Distribution_ExplicitBuckets;
    toAmino(message: Distribution_ExplicitBuckets): Distribution_ExplicitBucketsAmino;
    fromAminoMsg(object: Distribution_ExplicitBucketsAminoMsg): Distribution_ExplicitBuckets;
    fromProtoMsg(message: Distribution_ExplicitBucketsProtoMsg): Distribution_ExplicitBuckets;
    toProto(message: Distribution_ExplicitBuckets): Uint8Array;
    toProtoMsg(message: Distribution_ExplicitBuckets): Distribution_ExplicitBucketsProtoMsg;
    registerTypeUrl(): void;
};
