import { LogSeverity } from "../../../logging/type/log_severity";
import { HttpRequest, HttpRequestAmino, HttpRequestSDKType } from "./http_request";
import { Any, AnyAmino, AnySDKType } from "../../../protobuf/any";
import { Struct, StructAmino, StructSDKType } from "../../../protobuf/struct";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicecontrol.v1";
export interface LogEntry_LabelsEntry {
    key: string;
    value: string;
}
export interface LogEntry_LabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface LogEntry_LabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface LogEntry_LabelsEntryAminoMsg {
    type: string;
    value: LogEntry_LabelsEntryAmino;
}
export interface LogEntry_LabelsEntrySDKType {
    key: string;
    value: string;
}
/** An individual log entry. */
export interface LogEntry {
    /**
     * Required. The log to which this log entry belongs. Examples: `"syslog"`,
     * `"book_log"`.
     */
    name: string;
    /**
     * The time the event described by the log entry occurred. If
     * omitted, defaults to operation start time.
     */
    timestamp?: Date;
    /**
     * The severity of the log entry. The default value is
     * `LogSeverity.DEFAULT`.
     */
    severity: LogSeverity;
    /**
     * Optional. Information about the HTTP request associated with this
     * log entry, if applicable.
     */
    httpRequest?: HttpRequest;
    /**
     * Optional. Resource name of the trace associated with the log entry, if any.
     * If this field contains a relative resource name, you can assume the name is
     * relative to `//tracing.googleapis.com`. Example:
     * `projects/my-projectid/traces/06796866738c859f2f19b7cfb3214824`
     */
    trace: string;
    /**
     * A unique ID for the log entry used for deduplication. If omitted,
     * the implementation will generate one based on operation_id.
     */
    insertId: string;
    /**
     * A set of user-defined (key, value) data that provides additional
     * information about the log entry.
     */
    labels: {
        [key: string]: string;
    };
    /**
     * The log entry payload, represented as a protocol buffer that is
     * expressed as a JSON object. The only accepted type currently is
     * [AuditLog][google.cloud.audit.AuditLog].
     */
    protoPayload?: Any;
    /** The log entry payload, represented as a Unicode string (UTF-8). */
    textPayload?: string;
    /**
     * The log entry payload, represented as a structure that
     * is expressed as a JSON object.
     */
    structPayload?: Struct;
    /**
     * Optional. Information about an operation associated with the log entry, if
     * applicable.
     */
    operation?: LogEntryOperation;
    /**
     * Optional. Source code location information associated with the log entry,
     * if any.
     */
    sourceLocation?: LogEntrySourceLocation;
}
export interface LogEntryProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.LogEntry";
    value: Uint8Array;
}
/** An individual log entry. */
export interface LogEntryAmino {
    /**
     * Required. The log to which this log entry belongs. Examples: `"syslog"`,
     * `"book_log"`.
     */
    name?: string;
    /**
     * The time the event described by the log entry occurred. If
     * omitted, defaults to operation start time.
     */
    timestamp?: string;
    /**
     * The severity of the log entry. The default value is
     * `LogSeverity.DEFAULT`.
     */
    severity?: LogSeverity;
    /**
     * Optional. Information about the HTTP request associated with this
     * log entry, if applicable.
     */
    http_request?: HttpRequestAmino;
    /**
     * Optional. Resource name of the trace associated with the log entry, if any.
     * If this field contains a relative resource name, you can assume the name is
     * relative to `//tracing.googleapis.com`. Example:
     * `projects/my-projectid/traces/06796866738c859f2f19b7cfb3214824`
     */
    trace?: string;
    /**
     * A unique ID for the log entry used for deduplication. If omitted,
     * the implementation will generate one based on operation_id.
     */
    insert_id?: string;
    /**
     * A set of user-defined (key, value) data that provides additional
     * information about the log entry.
     */
    labels?: {
        [key: string]: string;
    };
    /**
     * The log entry payload, represented as a protocol buffer that is
     * expressed as a JSON object. The only accepted type currently is
     * [AuditLog][google.cloud.audit.AuditLog].
     */
    proto_payload?: AnyAmino;
    /** The log entry payload, represented as a Unicode string (UTF-8). */
    text_payload?: string;
    /**
     * The log entry payload, represented as a structure that
     * is expressed as a JSON object.
     */
    struct_payload?: StructAmino;
    /**
     * Optional. Information about an operation associated with the log entry, if
     * applicable.
     */
    operation?: LogEntryOperationAmino;
    /**
     * Optional. Source code location information associated with the log entry,
     * if any.
     */
    source_location?: LogEntrySourceLocationAmino;
}
export interface LogEntryAminoMsg {
    type: "/google.api.servicecontrol.v1.LogEntry";
    value: LogEntryAmino;
}
/** An individual log entry. */
export interface LogEntrySDKType {
    name: string;
    timestamp?: Date;
    severity: LogSeverity;
    http_request?: HttpRequestSDKType;
    trace: string;
    insert_id: string;
    labels: {
        [key: string]: string;
    };
    proto_payload?: AnySDKType;
    text_payload?: string;
    struct_payload?: StructSDKType;
    operation?: LogEntryOperationSDKType;
    source_location?: LogEntrySourceLocationSDKType;
}
/**
 * Additional information about a potentially long-running operation with which
 * a log entry is associated.
 */
export interface LogEntryOperation {
    /**
     * Optional. An arbitrary operation identifier. Log entries with the
     * same identifier are assumed to be part of the same operation.
     */
    id: string;
    /**
     * Optional. An arbitrary producer identifier. The combination of
     * `id` and `producer` must be globally unique.  Examples for `producer`:
     * `"MyDivision.MyBigCompany.com"`, `"github.com/MyProject/MyApplication"`.
     */
    producer: string;
    /** Optional. Set this to True if this is the first log entry in the operation. */
    first: boolean;
    /** Optional. Set this to True if this is the last log entry in the operation. */
    last: boolean;
}
export interface LogEntryOperationProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.LogEntryOperation";
    value: Uint8Array;
}
/**
 * Additional information about a potentially long-running operation with which
 * a log entry is associated.
 */
export interface LogEntryOperationAmino {
    /**
     * Optional. An arbitrary operation identifier. Log entries with the
     * same identifier are assumed to be part of the same operation.
     */
    id?: string;
    /**
     * Optional. An arbitrary producer identifier. The combination of
     * `id` and `producer` must be globally unique.  Examples for `producer`:
     * `"MyDivision.MyBigCompany.com"`, `"github.com/MyProject/MyApplication"`.
     */
    producer?: string;
    /** Optional. Set this to True if this is the first log entry in the operation. */
    first?: boolean;
    /** Optional. Set this to True if this is the last log entry in the operation. */
    last?: boolean;
}
export interface LogEntryOperationAminoMsg {
    type: "/google.api.servicecontrol.v1.LogEntryOperation";
    value: LogEntryOperationAmino;
}
/**
 * Additional information about a potentially long-running operation with which
 * a log entry is associated.
 */
export interface LogEntryOperationSDKType {
    id: string;
    producer: string;
    first: boolean;
    last: boolean;
}
/**
 * Additional information about the source code location that produced the log
 * entry.
 */
export interface LogEntrySourceLocation {
    /**
     * Optional. Source file name. Depending on the runtime environment, this
     * might be a simple name or a fully-qualified name.
     */
    file: string;
    /**
     * Optional. Line within the source file. 1-based; 0 indicates no line number
     * available.
     */
    line: bigint;
    /**
     * Optional. Human-readable name of the function or method being invoked, with
     * optional context such as the class or package name. This information may be
     * used in contexts such as the logs viewer, where a file and line number are
     * less meaningful. The format can vary by language. For example:
     * `qual.if.ied.Class.method` (Java), `dir/package.func` (Go), `function`
     * (Python).
     */
    function: string;
}
export interface LogEntrySourceLocationProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.LogEntrySourceLocation";
    value: Uint8Array;
}
/**
 * Additional information about the source code location that produced the log
 * entry.
 */
export interface LogEntrySourceLocationAmino {
    /**
     * Optional. Source file name. Depending on the runtime environment, this
     * might be a simple name or a fully-qualified name.
     */
    file?: string;
    /**
     * Optional. Line within the source file. 1-based; 0 indicates no line number
     * available.
     */
    line?: string;
    /**
     * Optional. Human-readable name of the function or method being invoked, with
     * optional context such as the class or package name. This information may be
     * used in contexts such as the logs viewer, where a file and line number are
     * less meaningful. The format can vary by language. For example:
     * `qual.if.ied.Class.method` (Java), `dir/package.func` (Go), `function`
     * (Python).
     */
    function?: string;
}
export interface LogEntrySourceLocationAminoMsg {
    type: "/google.api.servicecontrol.v1.LogEntrySourceLocation";
    value: LogEntrySourceLocationAmino;
}
/**
 * Additional information about the source code location that produced the log
 * entry.
 */
export interface LogEntrySourceLocationSDKType {
    file: string;
    line: bigint;
    function: string;
}
export declare const LogEntry_LabelsEntry: {
    encode(message: LogEntry_LabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogEntry_LabelsEntry;
    fromJSON(object: any): LogEntry_LabelsEntry;
    toJSON(message: LogEntry_LabelsEntry): JsonSafe<LogEntry_LabelsEntry>;
    fromPartial(object: DeepPartial<LogEntry_LabelsEntry>): LogEntry_LabelsEntry;
    fromSDK(object: LogEntry_LabelsEntrySDKType): LogEntry_LabelsEntry;
    fromSDKJSON(object: any): LogEntry_LabelsEntrySDKType;
    toSDK(message: LogEntry_LabelsEntry): LogEntry_LabelsEntrySDKType;
    fromAmino(object: LogEntry_LabelsEntryAmino): LogEntry_LabelsEntry;
    toAmino(message: LogEntry_LabelsEntry): LogEntry_LabelsEntryAmino;
    fromAminoMsg(object: LogEntry_LabelsEntryAminoMsg): LogEntry_LabelsEntry;
    fromProtoMsg(message: LogEntry_LabelsEntryProtoMsg): LogEntry_LabelsEntry;
    toProto(message: LogEntry_LabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const LogEntry: {
    typeUrl: string;
    is(o: any): o is LogEntry;
    isSDK(o: any): o is LogEntrySDKType;
    isAmino(o: any): o is LogEntryAmino;
    encode(message: LogEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogEntry;
    fromJSON(object: any): LogEntry;
    toJSON(message: LogEntry): JsonSafe<LogEntry>;
    fromPartial(object: DeepPartial<LogEntry>): LogEntry;
    fromSDK(object: LogEntrySDKType): LogEntry;
    fromSDKJSON(object: any): LogEntrySDKType;
    toSDK(message: LogEntry): LogEntrySDKType;
    fromAmino(object: LogEntryAmino): LogEntry;
    toAmino(message: LogEntry): LogEntryAmino;
    fromAminoMsg(object: LogEntryAminoMsg): LogEntry;
    fromProtoMsg(message: LogEntryProtoMsg): LogEntry;
    toProto(message: LogEntry): Uint8Array;
    toProtoMsg(message: LogEntry): LogEntryProtoMsg;
    registerTypeUrl(): void;
};
export declare const LogEntryOperation: {
    typeUrl: string;
    is(o: any): o is LogEntryOperation;
    isSDK(o: any): o is LogEntryOperationSDKType;
    isAmino(o: any): o is LogEntryOperationAmino;
    encode(message: LogEntryOperation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogEntryOperation;
    fromJSON(object: any): LogEntryOperation;
    toJSON(message: LogEntryOperation): JsonSafe<LogEntryOperation>;
    fromPartial(object: DeepPartial<LogEntryOperation>): LogEntryOperation;
    fromSDK(object: LogEntryOperationSDKType): LogEntryOperation;
    fromSDKJSON(object: any): LogEntryOperationSDKType;
    toSDK(message: LogEntryOperation): LogEntryOperationSDKType;
    fromAmino(object: LogEntryOperationAmino): LogEntryOperation;
    toAmino(message: LogEntryOperation): LogEntryOperationAmino;
    fromAminoMsg(object: LogEntryOperationAminoMsg): LogEntryOperation;
    fromProtoMsg(message: LogEntryOperationProtoMsg): LogEntryOperation;
    toProto(message: LogEntryOperation): Uint8Array;
    toProtoMsg(message: LogEntryOperation): LogEntryOperationProtoMsg;
    registerTypeUrl(): void;
};
export declare const LogEntrySourceLocation: {
    typeUrl: string;
    is(o: any): o is LogEntrySourceLocation;
    isSDK(o: any): o is LogEntrySourceLocationSDKType;
    isAmino(o: any): o is LogEntrySourceLocationAmino;
    encode(message: LogEntrySourceLocation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogEntrySourceLocation;
    fromJSON(object: any): LogEntrySourceLocation;
    toJSON(message: LogEntrySourceLocation): JsonSafe<LogEntrySourceLocation>;
    fromPartial(object: DeepPartial<LogEntrySourceLocation>): LogEntrySourceLocation;
    fromSDK(object: LogEntrySourceLocationSDKType): LogEntrySourceLocation;
    fromSDKJSON(object: any): LogEntrySourceLocationSDKType;
    toSDK(message: LogEntrySourceLocation): LogEntrySourceLocationSDKType;
    fromAmino(object: LogEntrySourceLocationAmino): LogEntrySourceLocation;
    toAmino(message: LogEntrySourceLocation): LogEntrySourceLocationAmino;
    fromAminoMsg(object: LogEntrySourceLocationAminoMsg): LogEntrySourceLocation;
    fromProtoMsg(message: LogEntrySourceLocationProtoMsg): LogEntrySourceLocation;
    toProto(message: LogEntrySourceLocation): Uint8Array;
    toProtoMsg(message: LogEntrySourceLocation): LogEntrySourceLocationProtoMsg;
    registerTypeUrl(): void;
};
