import { Distribution, DistributionAmino, DistributionSDKType } from "./distribution";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicecontrol.v1";
export interface MetricValue_LabelsEntry {
    key: string;
    value: string;
}
export interface MetricValue_LabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface MetricValue_LabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface MetricValue_LabelsEntryAminoMsg {
    type: string;
    value: MetricValue_LabelsEntryAmino;
}
export interface MetricValue_LabelsEntrySDKType {
    key: string;
    value: string;
}
/** Represents a single metric value. */
export interface MetricValue {
    /**
     * The labels describing the metric value.
     * See comments on [google.api.servicecontrol.v1.Operation.labels][google.api.servicecontrol.v1.Operation.labels] for
     * the overriding relationship.
     * Note that this map must not contain monitored resource labels.
     */
    labels: {
        [key: string]: string;
    };
    /**
     * The start of the time period over which this metric value's measurement
     * applies. The time period has different semantics for different metric
     * types (cumulative, delta, and gauge). See the metric definition
     * documentation in the service configuration for details. If not specified,
     * [google.api.servicecontrol.v1.Operation.start_time][google.api.servicecontrol.v1.Operation.start_time] will be used.
     */
    startTime?: Date;
    /**
     * The end of the time period over which this metric value's measurement
     * applies.  If not specified,
     * [google.api.servicecontrol.v1.Operation.end_time][google.api.servicecontrol.v1.Operation.end_time] will be used.
     */
    endTime?: Date;
    /** A boolean value. */
    boolValue?: boolean;
    /** A signed 64-bit integer value. */
    int64Value?: bigint;
    /** A double precision floating point value. */
    doubleValue?: number;
    /** A text string value. */
    stringValue?: string;
    /** A distribution value. */
    distributionValue?: Distribution;
}
export interface MetricValueProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.MetricValue";
    value: Uint8Array;
}
/** Represents a single metric value. */
export interface MetricValueAmino {
    /**
     * The labels describing the metric value.
     * See comments on [google.api.servicecontrol.v1.Operation.labels][google.api.servicecontrol.v1.Operation.labels] for
     * the overriding relationship.
     * Note that this map must not contain monitored resource labels.
     */
    labels?: {
        [key: string]: string;
    };
    /**
     * The start of the time period over which this metric value's measurement
     * applies. The time period has different semantics for different metric
     * types (cumulative, delta, and gauge). See the metric definition
     * documentation in the service configuration for details. If not specified,
     * [google.api.servicecontrol.v1.Operation.start_time][google.api.servicecontrol.v1.Operation.start_time] will be used.
     */
    start_time?: string;
    /**
     * The end of the time period over which this metric value's measurement
     * applies.  If not specified,
     * [google.api.servicecontrol.v1.Operation.end_time][google.api.servicecontrol.v1.Operation.end_time] will be used.
     */
    end_time?: string;
    /** A boolean value. */
    bool_value?: boolean;
    /** A signed 64-bit integer value. */
    int64_value?: string;
    /** A double precision floating point value. */
    double_value?: number;
    /** A text string value. */
    string_value?: string;
    /** A distribution value. */
    distribution_value?: DistributionAmino;
}
export interface MetricValueAminoMsg {
    type: "/google.api.servicecontrol.v1.MetricValue";
    value: MetricValueAmino;
}
/** Represents a single metric value. */
export interface MetricValueSDKType {
    labels: {
        [key: string]: string;
    };
    start_time?: Date;
    end_time?: Date;
    bool_value?: boolean;
    int64_value?: bigint;
    double_value?: number;
    string_value?: string;
    distribution_value?: DistributionSDKType;
}
/**
 * Represents a set of metric values in the same metric.
 * Each metric value in the set should have a unique combination of start time,
 * end time, and label values.
 */
export interface MetricValueSet {
    /** The metric name defined in the service configuration. */
    metricName: string;
    /** The values in this metric. */
    metricValues: MetricValue[];
}
export interface MetricValueSetProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.MetricValueSet";
    value: Uint8Array;
}
/**
 * Represents a set of metric values in the same metric.
 * Each metric value in the set should have a unique combination of start time,
 * end time, and label values.
 */
export interface MetricValueSetAmino {
    /** The metric name defined in the service configuration. */
    metric_name?: string;
    /** The values in this metric. */
    metric_values?: MetricValueAmino[];
}
export interface MetricValueSetAminoMsg {
    type: "/google.api.servicecontrol.v1.MetricValueSet";
    value: MetricValueSetAmino;
}
/**
 * Represents a set of metric values in the same metric.
 * Each metric value in the set should have a unique combination of start time,
 * end time, and label values.
 */
export interface MetricValueSetSDKType {
    metric_name: string;
    metric_values: MetricValueSDKType[];
}
export declare const MetricValue_LabelsEntry: {
    encode(message: MetricValue_LabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricValue_LabelsEntry;
    fromJSON(object: any): MetricValue_LabelsEntry;
    toJSON(message: MetricValue_LabelsEntry): JsonSafe<MetricValue_LabelsEntry>;
    fromPartial(object: DeepPartial<MetricValue_LabelsEntry>): MetricValue_LabelsEntry;
    fromSDK(object: MetricValue_LabelsEntrySDKType): MetricValue_LabelsEntry;
    fromSDKJSON(object: any): MetricValue_LabelsEntrySDKType;
    toSDK(message: MetricValue_LabelsEntry): MetricValue_LabelsEntrySDKType;
    fromAmino(object: MetricValue_LabelsEntryAmino): MetricValue_LabelsEntry;
    toAmino(message: MetricValue_LabelsEntry): MetricValue_LabelsEntryAmino;
    fromAminoMsg(object: MetricValue_LabelsEntryAminoMsg): MetricValue_LabelsEntry;
    fromProtoMsg(message: MetricValue_LabelsEntryProtoMsg): MetricValue_LabelsEntry;
    toProto(message: MetricValue_LabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const MetricValue: {
    typeUrl: string;
    is(o: any): o is MetricValue;
    isSDK(o: any): o is MetricValueSDKType;
    isAmino(o: any): o is MetricValueAmino;
    encode(message: MetricValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricValue;
    fromJSON(object: any): MetricValue;
    toJSON(message: MetricValue): JsonSafe<MetricValue>;
    fromPartial(object: DeepPartial<MetricValue>): MetricValue;
    fromSDK(object: MetricValueSDKType): MetricValue;
    fromSDKJSON(object: any): MetricValueSDKType;
    toSDK(message: MetricValue): MetricValueSDKType;
    fromAmino(object: MetricValueAmino): MetricValue;
    toAmino(message: MetricValue): MetricValueAmino;
    fromAminoMsg(object: MetricValueAminoMsg): MetricValue;
    fromProtoMsg(message: MetricValueProtoMsg): MetricValue;
    toProto(message: MetricValue): Uint8Array;
    toProtoMsg(message: MetricValue): MetricValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const MetricValueSet: {
    typeUrl: string;
    is(o: any): o is MetricValueSet;
    isSDK(o: any): o is MetricValueSetSDKType;
    isAmino(o: any): o is MetricValueSetAmino;
    encode(message: MetricValueSet, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MetricValueSet;
    fromJSON(object: any): MetricValueSet;
    toJSON(message: MetricValueSet): JsonSafe<MetricValueSet>;
    fromPartial(object: DeepPartial<MetricValueSet>): MetricValueSet;
    fromSDK(object: MetricValueSetSDKType): MetricValueSet;
    fromSDKJSON(object: any): MetricValueSetSDKType;
    toSDK(message: MetricValueSet): MetricValueSetSDKType;
    fromAmino(object: MetricValueSetAmino): MetricValueSet;
    toAmino(message: MetricValueSet): MetricValueSetAmino;
    fromAminoMsg(object: MetricValueSetAminoMsg): MetricValueSet;
    fromProtoMsg(message: MetricValueSetProtoMsg): MetricValueSet;
    toProto(message: MetricValueSet): Uint8Array;
    toProtoMsg(message: MetricValueSet): MetricValueSetProtoMsg;
    registerTypeUrl(): void;
};
