import { Operation, OperationAmino, OperationSDKType } from "./operation";
import { CheckError, CheckErrorAmino, CheckErrorSDKType } from "./check_error";
import { Status, StatusAmino, StatusSDKType } from "../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicecontrol.v1";
/**
 * The type of the consumer as defined in
 * [Google Resource Manager](https://cloud.google.com/resource-manager/).
 */
export declare enum CheckResponse_ConsumerInfo_ConsumerType {
    /** CONSUMER_TYPE_UNSPECIFIED - This is never used. */
    CONSUMER_TYPE_UNSPECIFIED = 0,
    /** PROJECT - The consumer is a Google Cloud Project. */
    PROJECT = 1,
    /** FOLDER - The consumer is a Google Cloud Folder. */
    FOLDER = 2,
    /** ORGANIZATION - The consumer is a Google Cloud Organization. */
    ORGANIZATION = 3,
    /**
     * SERVICE_SPECIFIC - Service-specific resource container which is defined by the service
     * producer to offer their users the ability to manage service control
     * functionalities at a finer level of granularity than the PROJECT.
     */
    SERVICE_SPECIFIC = 4,
    UNRECOGNIZED = -1
}
export declare const CheckResponse_ConsumerInfo_ConsumerTypeSDKType: typeof CheckResponse_ConsumerInfo_ConsumerType;
export declare const CheckResponse_ConsumerInfo_ConsumerTypeAmino: typeof CheckResponse_ConsumerInfo_ConsumerType;
export declare function checkResponse_ConsumerInfo_ConsumerTypeFromJSON(object: any): CheckResponse_ConsumerInfo_ConsumerType;
export declare function checkResponse_ConsumerInfo_ConsumerTypeToJSON(object: CheckResponse_ConsumerInfo_ConsumerType): string;
/** Request message for the Check method. */
export interface CheckRequest {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    serviceName: string;
    /** The operation to be checked. */
    operation?: Operation;
    /**
     * Specifies which version of service configuration should be used to process
     * the request.
     *
     * If unspecified or no matching version can be found, the
     * latest one will be used.
     */
    serviceConfigId: string;
}
export interface CheckRequestProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.CheckRequest";
    value: Uint8Array;
}
/** Request message for the Check method. */
export interface CheckRequestAmino {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    service_name?: string;
    /** The operation to be checked. */
    operation?: OperationAmino;
    /**
     * Specifies which version of service configuration should be used to process
     * the request.
     *
     * If unspecified or no matching version can be found, the
     * latest one will be used.
     */
    service_config_id?: string;
}
export interface CheckRequestAminoMsg {
    type: "/google.api.servicecontrol.v1.CheckRequest";
    value: CheckRequestAmino;
}
/** Request message for the Check method. */
export interface CheckRequestSDKType {
    service_name: string;
    operation?: OperationSDKType;
    service_config_id: string;
}
/** Response message for the Check method. */
export interface CheckResponse {
    /**
     * The same operation_id value used in the
     * [CheckRequest][google.api.servicecontrol.v1.CheckRequest]. Used for logging
     * and diagnostics purposes.
     */
    operationId: string;
    /**
     * Indicate the decision of the check.
     *
     * If no check errors are present, the service should process the operation.
     * Otherwise the service should use the list of errors to determine the
     * appropriate action.
     */
    checkErrors: CheckError[];
    /** The actual config id used to process the request. */
    serviceConfigId: string;
    /** The current service rollout id used to process the request. */
    serviceRolloutId: string;
    /** Feedback data returned from the server during processing a Check request. */
    checkInfo?: CheckResponse_CheckInfo;
}
export interface CheckResponseProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.CheckResponse";
    value: Uint8Array;
}
/** Response message for the Check method. */
export interface CheckResponseAmino {
    /**
     * The same operation_id value used in the
     * [CheckRequest][google.api.servicecontrol.v1.CheckRequest]. Used for logging
     * and diagnostics purposes.
     */
    operation_id?: string;
    /**
     * Indicate the decision of the check.
     *
     * If no check errors are present, the service should process the operation.
     * Otherwise the service should use the list of errors to determine the
     * appropriate action.
     */
    check_errors?: CheckErrorAmino[];
    /** The actual config id used to process the request. */
    service_config_id?: string;
    /** The current service rollout id used to process the request. */
    service_rollout_id?: string;
    /** Feedback data returned from the server during processing a Check request. */
    check_info?: CheckResponse_CheckInfoAmino;
}
export interface CheckResponseAminoMsg {
    type: "/google.api.servicecontrol.v1.CheckResponse";
    value: CheckResponseAmino;
}
/** Response message for the Check method. */
export interface CheckResponseSDKType {
    operation_id: string;
    check_errors: CheckErrorSDKType[];
    service_config_id: string;
    service_rollout_id: string;
    check_info?: CheckResponse_CheckInfoSDKType;
}
/** Contains additional information about the check operation. */
export interface CheckResponse_CheckInfo {
    /**
     * A list of fields and label keys that are ignored by the server.
     * The client doesn't need to send them for following requests to improve
     * performance and allow better aggregation.
     */
    unusedArguments: string[];
    /** Consumer info of this check. */
    consumerInfo?: CheckResponse_ConsumerInfo;
}
export interface CheckResponse_CheckInfoProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.CheckInfo";
    value: Uint8Array;
}
/** Contains additional information about the check operation. */
export interface CheckResponse_CheckInfoAmino {
    /**
     * A list of fields and label keys that are ignored by the server.
     * The client doesn't need to send them for following requests to improve
     * performance and allow better aggregation.
     */
    unused_arguments?: string[];
    /** Consumer info of this check. */
    consumer_info?: CheckResponse_ConsumerInfoAmino;
}
export interface CheckResponse_CheckInfoAminoMsg {
    type: "/google.api.servicecontrol.v1.CheckInfo";
    value: CheckResponse_CheckInfoAmino;
}
/** Contains additional information about the check operation. */
export interface CheckResponse_CheckInfoSDKType {
    unused_arguments: string[];
    consumer_info?: CheckResponse_ConsumerInfoSDKType;
}
/** `ConsumerInfo` provides information about the consumer. */
export interface CheckResponse_ConsumerInfo {
    /**
     * The Google cloud project number, e.g. 1234567890. A value of 0 indicates
     * no project number is found.
     *
     * NOTE: This field is deprecated after we support flexible consumer
     * id. New code should not depend on this field anymore.
     */
    projectNumber: bigint;
    /**
     * The type of the consumer which should have been defined in
     * [Google Resource Manager](https://cloud.google.com/resource-manager/).
     */
    type: CheckResponse_ConsumerInfo_ConsumerType;
    /**
     * The consumer identity number, can be Google cloud project number, folder
     * number or organization number e.g. 1234567890. A value of 0 indicates no
     * consumer number is found.
     */
    consumerNumber: bigint;
}
export interface CheckResponse_ConsumerInfoProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ConsumerInfo";
    value: Uint8Array;
}
/** `ConsumerInfo` provides information about the consumer. */
export interface CheckResponse_ConsumerInfoAmino {
    /**
     * The Google cloud project number, e.g. 1234567890. A value of 0 indicates
     * no project number is found.
     *
     * NOTE: This field is deprecated after we support flexible consumer
     * id. New code should not depend on this field anymore.
     */
    project_number?: string;
    /**
     * The type of the consumer which should have been defined in
     * [Google Resource Manager](https://cloud.google.com/resource-manager/).
     */
    type?: CheckResponse_ConsumerInfo_ConsumerType;
    /**
     * The consumer identity number, can be Google cloud project number, folder
     * number or organization number e.g. 1234567890. A value of 0 indicates no
     * consumer number is found.
     */
    consumer_number?: string;
}
export interface CheckResponse_ConsumerInfoAminoMsg {
    type: "/google.api.servicecontrol.v1.ConsumerInfo";
    value: CheckResponse_ConsumerInfoAmino;
}
/** `ConsumerInfo` provides information about the consumer. */
export interface CheckResponse_ConsumerInfoSDKType {
    project_number: bigint;
    type: CheckResponse_ConsumerInfo_ConsumerType;
    consumer_number: bigint;
}
/** Request message for the Report method. */
export interface ReportRequest {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    serviceName: string;
    /**
     * Operations to be reported.
     *
     * Typically the service should report one operation per request.
     * Putting multiple operations into a single request is allowed, but should
     * be used only when multiple operations are natually available at the time
     * of the report.
     *
     * There is no limit on the number of operations in the same ReportRequest,
     * however the ReportRequest size should be no larger than 1MB. See
     * [ReportResponse.report_errors][google.api.servicecontrol.v1.ReportResponse.report_errors]
     * for partial failure behavior.
     */
    operations: Operation[];
    /**
     * Specifies which version of service config should be used to process the
     * request.
     *
     * If unspecified or no matching version can be found, the
     * latest one will be used.
     */
    serviceConfigId: string;
}
export interface ReportRequestProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ReportRequest";
    value: Uint8Array;
}
/** Request message for the Report method. */
export interface ReportRequestAmino {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    service_name?: string;
    /**
     * Operations to be reported.
     *
     * Typically the service should report one operation per request.
     * Putting multiple operations into a single request is allowed, but should
     * be used only when multiple operations are natually available at the time
     * of the report.
     *
     * There is no limit on the number of operations in the same ReportRequest,
     * however the ReportRequest size should be no larger than 1MB. See
     * [ReportResponse.report_errors][google.api.servicecontrol.v1.ReportResponse.report_errors]
     * for partial failure behavior.
     */
    operations?: OperationAmino[];
    /**
     * Specifies which version of service config should be used to process the
     * request.
     *
     * If unspecified or no matching version can be found, the
     * latest one will be used.
     */
    service_config_id?: string;
}
export interface ReportRequestAminoMsg {
    type: "/google.api.servicecontrol.v1.ReportRequest";
    value: ReportRequestAmino;
}
/** Request message for the Report method. */
export interface ReportRequestSDKType {
    service_name: string;
    operations: OperationSDKType[];
    service_config_id: string;
}
/** Response message for the Report method. */
export interface ReportResponse {
    /**
     * Partial failures, one for each `Operation` in the request that failed
     * processing. There are three possible combinations of the RPC status:
     *
     * 1. The combination of a successful RPC status and an empty `report_errors`
     *    list indicates a complete success where all `Operations` in the
     *    request are processed successfully.
     * 2. The combination of a successful RPC status and a non-empty
     *    `report_errors` list indicates a partial success where some
     *    `Operations` in the request succeeded. Each
     *    `Operation` that failed processing has a corresponding item
     *    in this list.
     * 3. A failed RPC status indicates a general non-deterministic failure.
     *    When this happens, it's impossible to know which of the
     *    'Operations' in the request succeeded or failed.
     */
    reportErrors: ReportResponse_ReportError[];
    /** The actual config id used to process the request. */
    serviceConfigId: string;
    /** The current service rollout id used to process the request. */
    serviceRolloutId: string;
}
export interface ReportResponseProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ReportResponse";
    value: Uint8Array;
}
/** Response message for the Report method. */
export interface ReportResponseAmino {
    /**
     * Partial failures, one for each `Operation` in the request that failed
     * processing. There are three possible combinations of the RPC status:
     *
     * 1. The combination of a successful RPC status and an empty `report_errors`
     *    list indicates a complete success where all `Operations` in the
     *    request are processed successfully.
     * 2. The combination of a successful RPC status and a non-empty
     *    `report_errors` list indicates a partial success where some
     *    `Operations` in the request succeeded. Each
     *    `Operation` that failed processing has a corresponding item
     *    in this list.
     * 3. A failed RPC status indicates a general non-deterministic failure.
     *    When this happens, it's impossible to know which of the
     *    'Operations' in the request succeeded or failed.
     */
    report_errors?: ReportResponse_ReportErrorAmino[];
    /** The actual config id used to process the request. */
    service_config_id?: string;
    /** The current service rollout id used to process the request. */
    service_rollout_id?: string;
}
export interface ReportResponseAminoMsg {
    type: "/google.api.servicecontrol.v1.ReportResponse";
    value: ReportResponseAmino;
}
/** Response message for the Report method. */
export interface ReportResponseSDKType {
    report_errors: ReportResponse_ReportErrorSDKType[];
    service_config_id: string;
    service_rollout_id: string;
}
/**
 * Represents the processing error of one
 * [Operation][google.api.servicecontrol.v1.Operation] in the request.
 */
export interface ReportResponse_ReportError {
    /**
     * The
     * [Operation.operation_id][google.api.servicecontrol.v1.Operation.operation_id]
     * value from the request.
     */
    operationId: string;
    /**
     * Details of the error when processing the
     * [Operation][google.api.servicecontrol.v1.Operation].
     */
    status?: Status;
}
export interface ReportResponse_ReportErrorProtoMsg {
    typeUrl: "/google.api.servicecontrol.v1.ReportError";
    value: Uint8Array;
}
/**
 * Represents the processing error of one
 * [Operation][google.api.servicecontrol.v1.Operation] in the request.
 */
export interface ReportResponse_ReportErrorAmino {
    /**
     * The
     * [Operation.operation_id][google.api.servicecontrol.v1.Operation.operation_id]
     * value from the request.
     */
    operation_id?: string;
    /**
     * Details of the error when processing the
     * [Operation][google.api.servicecontrol.v1.Operation].
     */
    status?: StatusAmino;
}
export interface ReportResponse_ReportErrorAminoMsg {
    type: "/google.api.servicecontrol.v1.ReportError";
    value: ReportResponse_ReportErrorAmino;
}
/**
 * Represents the processing error of one
 * [Operation][google.api.servicecontrol.v1.Operation] in the request.
 */
export interface ReportResponse_ReportErrorSDKType {
    operation_id: string;
    status?: StatusSDKType;
}
export declare const CheckRequest: {
    typeUrl: string;
    is(o: any): o is CheckRequest;
    isSDK(o: any): o is CheckRequestSDKType;
    isAmino(o: any): o is CheckRequestAmino;
    encode(message: CheckRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckRequest;
    fromJSON(object: any): CheckRequest;
    toJSON(message: CheckRequest): JsonSafe<CheckRequest>;
    fromPartial(object: DeepPartial<CheckRequest>): CheckRequest;
    fromSDK(object: CheckRequestSDKType): CheckRequest;
    fromSDKJSON(object: any): CheckRequestSDKType;
    toSDK(message: CheckRequest): CheckRequestSDKType;
    fromAmino(object: CheckRequestAmino): CheckRequest;
    toAmino(message: CheckRequest): CheckRequestAmino;
    fromAminoMsg(object: CheckRequestAminoMsg): CheckRequest;
    fromProtoMsg(message: CheckRequestProtoMsg): CheckRequest;
    toProto(message: CheckRequest): Uint8Array;
    toProtoMsg(message: CheckRequest): CheckRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckResponse: {
    typeUrl: string;
    is(o: any): o is CheckResponse;
    isSDK(o: any): o is CheckResponseSDKType;
    isAmino(o: any): o is CheckResponseAmino;
    encode(message: CheckResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse;
    fromJSON(object: any): CheckResponse;
    toJSON(message: CheckResponse): JsonSafe<CheckResponse>;
    fromPartial(object: DeepPartial<CheckResponse>): CheckResponse;
    fromSDK(object: CheckResponseSDKType): CheckResponse;
    fromSDKJSON(object: any): CheckResponseSDKType;
    toSDK(message: CheckResponse): CheckResponseSDKType;
    fromAmino(object: CheckResponseAmino): CheckResponse;
    toAmino(message: CheckResponse): CheckResponseAmino;
    fromAminoMsg(object: CheckResponseAminoMsg): CheckResponse;
    fromProtoMsg(message: CheckResponseProtoMsg): CheckResponse;
    toProto(message: CheckResponse): Uint8Array;
    toProtoMsg(message: CheckResponse): CheckResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckResponse_CheckInfo: {
    typeUrl: string;
    is(o: any): o is CheckResponse_CheckInfo;
    isSDK(o: any): o is CheckResponse_CheckInfoSDKType;
    isAmino(o: any): o is CheckResponse_CheckInfoAmino;
    encode(message: CheckResponse_CheckInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse_CheckInfo;
    fromJSON(object: any): CheckResponse_CheckInfo;
    toJSON(message: CheckResponse_CheckInfo): JsonSafe<CheckResponse_CheckInfo>;
    fromPartial(object: DeepPartial<CheckResponse_CheckInfo>): CheckResponse_CheckInfo;
    fromSDK(object: CheckResponse_CheckInfoSDKType): CheckResponse_CheckInfo;
    fromSDKJSON(object: any): CheckResponse_CheckInfoSDKType;
    toSDK(message: CheckResponse_CheckInfo): CheckResponse_CheckInfoSDKType;
    fromAmino(object: CheckResponse_CheckInfoAmino): CheckResponse_CheckInfo;
    toAmino(message: CheckResponse_CheckInfo): CheckResponse_CheckInfoAmino;
    fromAminoMsg(object: CheckResponse_CheckInfoAminoMsg): CheckResponse_CheckInfo;
    fromProtoMsg(message: CheckResponse_CheckInfoProtoMsg): CheckResponse_CheckInfo;
    toProto(message: CheckResponse_CheckInfo): Uint8Array;
    toProtoMsg(message: CheckResponse_CheckInfo): CheckResponse_CheckInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckResponse_ConsumerInfo: {
    typeUrl: string;
    is(o: any): o is CheckResponse_ConsumerInfo;
    isSDK(o: any): o is CheckResponse_ConsumerInfoSDKType;
    isAmino(o: any): o is CheckResponse_ConsumerInfoAmino;
    encode(message: CheckResponse_ConsumerInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse_ConsumerInfo;
    fromJSON(object: any): CheckResponse_ConsumerInfo;
    toJSON(message: CheckResponse_ConsumerInfo): JsonSafe<CheckResponse_ConsumerInfo>;
    fromPartial(object: DeepPartial<CheckResponse_ConsumerInfo>): CheckResponse_ConsumerInfo;
    fromSDK(object: CheckResponse_ConsumerInfoSDKType): CheckResponse_ConsumerInfo;
    fromSDKJSON(object: any): CheckResponse_ConsumerInfoSDKType;
    toSDK(message: CheckResponse_ConsumerInfo): CheckResponse_ConsumerInfoSDKType;
    fromAmino(object: CheckResponse_ConsumerInfoAmino): CheckResponse_ConsumerInfo;
    toAmino(message: CheckResponse_ConsumerInfo): CheckResponse_ConsumerInfoAmino;
    fromAminoMsg(object: CheckResponse_ConsumerInfoAminoMsg): CheckResponse_ConsumerInfo;
    fromProtoMsg(message: CheckResponse_ConsumerInfoProtoMsg): CheckResponse_ConsumerInfo;
    toProto(message: CheckResponse_ConsumerInfo): Uint8Array;
    toProtoMsg(message: CheckResponse_ConsumerInfo): CheckResponse_ConsumerInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const ReportRequest: {
    typeUrl: string;
    is(o: any): o is ReportRequest;
    isSDK(o: any): o is ReportRequestSDKType;
    isAmino(o: any): o is ReportRequestAmino;
    encode(message: ReportRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ReportRequest;
    fromJSON(object: any): ReportRequest;
    toJSON(message: ReportRequest): JsonSafe<ReportRequest>;
    fromPartial(object: DeepPartial<ReportRequest>): ReportRequest;
    fromSDK(object: ReportRequestSDKType): ReportRequest;
    fromSDKJSON(object: any): ReportRequestSDKType;
    toSDK(message: ReportRequest): ReportRequestSDKType;
    fromAmino(object: ReportRequestAmino): ReportRequest;
    toAmino(message: ReportRequest): ReportRequestAmino;
    fromAminoMsg(object: ReportRequestAminoMsg): ReportRequest;
    fromProtoMsg(message: ReportRequestProtoMsg): ReportRequest;
    toProto(message: ReportRequest): Uint8Array;
    toProtoMsg(message: ReportRequest): ReportRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ReportResponse: {
    typeUrl: string;
    is(o: any): o is ReportResponse;
    isSDK(o: any): o is ReportResponseSDKType;
    isAmino(o: any): o is ReportResponseAmino;
    encode(message: ReportResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ReportResponse;
    fromJSON(object: any): ReportResponse;
    toJSON(message: ReportResponse): JsonSafe<ReportResponse>;
    fromPartial(object: DeepPartial<ReportResponse>): ReportResponse;
    fromSDK(object: ReportResponseSDKType): ReportResponse;
    fromSDKJSON(object: any): ReportResponseSDKType;
    toSDK(message: ReportResponse): ReportResponseSDKType;
    fromAmino(object: ReportResponseAmino): ReportResponse;
    toAmino(message: ReportResponse): ReportResponseAmino;
    fromAminoMsg(object: ReportResponseAminoMsg): ReportResponse;
    fromProtoMsg(message: ReportResponseProtoMsg): ReportResponse;
    toProto(message: ReportResponse): Uint8Array;
    toProtoMsg(message: ReportResponse): ReportResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const ReportResponse_ReportError: {
    typeUrl: string;
    is(o: any): o is ReportResponse_ReportError;
    isSDK(o: any): o is ReportResponse_ReportErrorSDKType;
    isAmino(o: any): o is ReportResponse_ReportErrorAmino;
    encode(message: ReportResponse_ReportError, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ReportResponse_ReportError;
    fromJSON(object: any): ReportResponse_ReportError;
    toJSON(message: ReportResponse_ReportError): JsonSafe<ReportResponse_ReportError>;
    fromPartial(object: DeepPartial<ReportResponse_ReportError>): ReportResponse_ReportError;
    fromSDK(object: ReportResponse_ReportErrorSDKType): ReportResponse_ReportError;
    fromSDKJSON(object: any): ReportResponse_ReportErrorSDKType;
    toSDK(message: ReportResponse_ReportError): ReportResponse_ReportErrorSDKType;
    fromAmino(object: ReportResponse_ReportErrorAmino): ReportResponse_ReportError;
    toAmino(message: ReportResponse_ReportError): ReportResponse_ReportErrorAmino;
    fromAminoMsg(object: ReportResponse_ReportErrorAminoMsg): ReportResponse_ReportError;
    fromProtoMsg(message: ReportResponse_ReportErrorProtoMsg): ReportResponse_ReportError;
    toProto(message: ReportResponse_ReportError): Uint8Array;
    toProtoMsg(message: ReportResponse_ReportError): ReportResponse_ReportErrorProtoMsg;
    registerTypeUrl(): void;
};
