import { AttributeContext, AttributeContextAmino, AttributeContextSDKType } from "../../../rpc/context/attribute_context";
import { Status, StatusAmino, StatusSDKType } from "../../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicecontrol.v2";
/** Request message for the Check method. */
export interface CheckRequest {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    serviceName: string;
    /**
     * Specifies the version of the service configuration that should be used to
     * process the request. Must not be empty. Set this field to 'latest' to
     * specify using the latest configuration.
     */
    serviceConfigId: string;
    /** Describes attributes about the operation being executed by the service. */
    attributes?: AttributeContext;
    /** Describes the resources and the policies applied to each resource. */
    resources: ResourceInfo[];
    /** Optional. Contains a comma-separated list of flags. */
    flags: string;
}
export interface CheckRequestProtoMsg {
    typeUrl: "/google.api.servicecontrol.v2.CheckRequest";
    value: Uint8Array;
}
/** Request message for the Check method. */
export interface CheckRequestAmino {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    service_name?: string;
    /**
     * Specifies the version of the service configuration that should be used to
     * process the request. Must not be empty. Set this field to 'latest' to
     * specify using the latest configuration.
     */
    service_config_id?: string;
    /** Describes attributes about the operation being executed by the service. */
    attributes?: AttributeContextAmino;
    /** Describes the resources and the policies applied to each resource. */
    resources?: ResourceInfoAmino[];
    /** Optional. Contains a comma-separated list of flags. */
    flags?: string;
}
export interface CheckRequestAminoMsg {
    type: "/google.api.servicecontrol.v2.CheckRequest";
    value: CheckRequestAmino;
}
/** Request message for the Check method. */
export interface CheckRequestSDKType {
    service_name: string;
    service_config_id: string;
    attributes?: AttributeContextSDKType;
    resources: ResourceInfoSDKType[];
    flags: string;
}
/** Describes a resource referenced in the request. */
export interface ResourceInfo {
    /** The name of the resource referenced in the request. */
    name: string;
    /** The resource type in the format of "{service}/{kind}". */
    type: string;
    /**
     * The resource permission needed for this request.
     * The format must be "{service}/{plural}.{verb}".
     */
    permission: string;
    /**
     * Optional. The identifier of the container of this resource. For Google
     * Cloud APIs, the resource container must be one of the following formats:
     *     - `projects/<project-id or project-number>`
     *     - `folders/<folder-id>`
     *     - `organizations/<organization-id>`
     * For the policy enforcement on the container level (VPCSC and Location
     * Policy check), this field takes precedence on the container extracted from
     * name when presents.
     */
    container: string;
    /**
     * Optional. The location of the resource. The value must be a valid zone,
     * region or multiregion. For example: "europe-west4" or
     * "northamerica-northeast1-a"
     */
    location: string;
}
export interface ResourceInfoProtoMsg {
    typeUrl: "/google.api.servicecontrol.v2.ResourceInfo";
    value: Uint8Array;
}
/** Describes a resource referenced in the request. */
export interface ResourceInfoAmino {
    /** The name of the resource referenced in the request. */
    name?: string;
    /** The resource type in the format of "{service}/{kind}". */
    type?: string;
    /**
     * The resource permission needed for this request.
     * The format must be "{service}/{plural}.{verb}".
     */
    permission?: string;
    /**
     * Optional. The identifier of the container of this resource. For Google
     * Cloud APIs, the resource container must be one of the following formats:
     *     - `projects/<project-id or project-number>`
     *     - `folders/<folder-id>`
     *     - `organizations/<organization-id>`
     * For the policy enforcement on the container level (VPCSC and Location
     * Policy check), this field takes precedence on the container extracted from
     * name when presents.
     */
    container?: string;
    /**
     * Optional. The location of the resource. The value must be a valid zone,
     * region or multiregion. For example: "europe-west4" or
     * "northamerica-northeast1-a"
     */
    location?: string;
}
export interface ResourceInfoAminoMsg {
    type: "/google.api.servicecontrol.v2.ResourceInfo";
    value: ResourceInfoAmino;
}
/** Describes a resource referenced in the request. */
export interface ResourceInfoSDKType {
    name: string;
    type: string;
    permission: string;
    container: string;
    location: string;
}
export interface CheckResponse_HeadersEntry {
    key: string;
    value: string;
}
export interface CheckResponse_HeadersEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface CheckResponse_HeadersEntryAmino {
    key?: string;
    value?: string;
}
export interface CheckResponse_HeadersEntryAminoMsg {
    type: string;
    value: CheckResponse_HeadersEntryAmino;
}
export interface CheckResponse_HeadersEntrySDKType {
    key: string;
    value: string;
}
/** Response message for the Check method. */
export interface CheckResponse {
    /**
     * Operation is allowed when this field is not set. Any non-'OK' status
     * indicates a denial; [google.rpc.Status.details][google.rpc.Status.details]
     * would contain additional details about the denial.
     */
    status?: Status;
    /** Returns a set of request contexts generated from the `CheckRequest`. */
    headers: {
        [key: string]: string;
    };
}
export interface CheckResponseProtoMsg {
    typeUrl: "/google.api.servicecontrol.v2.CheckResponse";
    value: Uint8Array;
}
/** Response message for the Check method. */
export interface CheckResponseAmino {
    /**
     * Operation is allowed when this field is not set. Any non-'OK' status
     * indicates a denial; [google.rpc.Status.details][google.rpc.Status.details]
     * would contain additional details about the denial.
     */
    status?: StatusAmino;
    /** Returns a set of request contexts generated from the `CheckRequest`. */
    headers?: {
        [key: string]: string;
    };
}
export interface CheckResponseAminoMsg {
    type: "/google.api.servicecontrol.v2.CheckResponse";
    value: CheckResponseAmino;
}
/** Response message for the Check method. */
export interface CheckResponseSDKType {
    status?: StatusSDKType;
    headers: {
        [key: string]: string;
    };
}
/** Request message for the Report method. */
export interface ReportRequest {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    serviceName: string;
    /**
     * Specifies the version of the service configuration that should be used to
     * process the request. Must not be empty. Set this field to 'latest' to
     * specify using the latest configuration.
     */
    serviceConfigId: string;
    /**
     * Describes the list of operations to be reported. Each operation is
     * represented as an AttributeContext, and contains all attributes around an
     * API access.
     */
    operations: AttributeContext[];
}
export interface ReportRequestProtoMsg {
    typeUrl: "/google.api.servicecontrol.v2.ReportRequest";
    value: Uint8Array;
}
/** Request message for the Report method. */
export interface ReportRequestAmino {
    /**
     * The service name as specified in its service configuration. For example,
     * `"pubsub.googleapis.com"`.
     *
     * See
     * [google.api.Service](https://cloud.google.com/service-management/reference/rpc/google.api#google.api.Service)
     * for the definition of a service name.
     */
    service_name?: string;
    /**
     * Specifies the version of the service configuration that should be used to
     * process the request. Must not be empty. Set this field to 'latest' to
     * specify using the latest configuration.
     */
    service_config_id?: string;
    /**
     * Describes the list of operations to be reported. Each operation is
     * represented as an AttributeContext, and contains all attributes around an
     * API access.
     */
    operations?: AttributeContextAmino[];
}
export interface ReportRequestAminoMsg {
    type: "/google.api.servicecontrol.v2.ReportRequest";
    value: ReportRequestAmino;
}
/** Request message for the Report method. */
export interface ReportRequestSDKType {
    service_name: string;
    service_config_id: string;
    operations: AttributeContextSDKType[];
}
/**
 * Response message for the Report method.
 * If the request contains any invalid data, the server returns an RPC error.
 */
export interface ReportResponse {
}
export interface ReportResponseProtoMsg {
    typeUrl: "/google.api.servicecontrol.v2.ReportResponse";
    value: Uint8Array;
}
/**
 * Response message for the Report method.
 * If the request contains any invalid data, the server returns an RPC error.
 */
export interface ReportResponseAmino {
}
export interface ReportResponseAminoMsg {
    type: "/google.api.servicecontrol.v2.ReportResponse";
    value: ReportResponseAmino;
}
/**
 * Response message for the Report method.
 * If the request contains any invalid data, the server returns an RPC error.
 */
export interface ReportResponseSDKType {
}
export declare const CheckRequest: {
    typeUrl: string;
    is(o: any): o is CheckRequest;
    isSDK(o: any): o is CheckRequestSDKType;
    isAmino(o: any): o is CheckRequestAmino;
    encode(message: CheckRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckRequest;
    fromJSON(object: any): CheckRequest;
    toJSON(message: CheckRequest): JsonSafe<CheckRequest>;
    fromPartial(object: DeepPartial<CheckRequest>): CheckRequest;
    fromSDK(object: CheckRequestSDKType): CheckRequest;
    fromSDKJSON(object: any): CheckRequestSDKType;
    toSDK(message: CheckRequest): CheckRequestSDKType;
    fromAmino(object: CheckRequestAmino): CheckRequest;
    toAmino(message: CheckRequest): CheckRequestAmino;
    fromAminoMsg(object: CheckRequestAminoMsg): CheckRequest;
    fromProtoMsg(message: CheckRequestProtoMsg): CheckRequest;
    toProto(message: CheckRequest): Uint8Array;
    toProtoMsg(message: CheckRequest): CheckRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ResourceInfo: {
    typeUrl: string;
    is(o: any): o is ResourceInfo;
    isSDK(o: any): o is ResourceInfoSDKType;
    isAmino(o: any): o is ResourceInfoAmino;
    encode(message: ResourceInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ResourceInfo;
    fromJSON(object: any): ResourceInfo;
    toJSON(message: ResourceInfo): JsonSafe<ResourceInfo>;
    fromPartial(object: DeepPartial<ResourceInfo>): ResourceInfo;
    fromSDK(object: ResourceInfoSDKType): ResourceInfo;
    fromSDKJSON(object: any): ResourceInfoSDKType;
    toSDK(message: ResourceInfo): ResourceInfoSDKType;
    fromAmino(object: ResourceInfoAmino): ResourceInfo;
    toAmino(message: ResourceInfo): ResourceInfoAmino;
    fromAminoMsg(object: ResourceInfoAminoMsg): ResourceInfo;
    fromProtoMsg(message: ResourceInfoProtoMsg): ResourceInfo;
    toProto(message: ResourceInfo): Uint8Array;
    toProtoMsg(message: ResourceInfo): ResourceInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const CheckResponse_HeadersEntry: {
    encode(message: CheckResponse_HeadersEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse_HeadersEntry;
    fromJSON(object: any): CheckResponse_HeadersEntry;
    toJSON(message: CheckResponse_HeadersEntry): JsonSafe<CheckResponse_HeadersEntry>;
    fromPartial(object: DeepPartial<CheckResponse_HeadersEntry>): CheckResponse_HeadersEntry;
    fromSDK(object: CheckResponse_HeadersEntrySDKType): CheckResponse_HeadersEntry;
    fromSDKJSON(object: any): CheckResponse_HeadersEntrySDKType;
    toSDK(message: CheckResponse_HeadersEntry): CheckResponse_HeadersEntrySDKType;
    fromAmino(object: CheckResponse_HeadersEntryAmino): CheckResponse_HeadersEntry;
    toAmino(message: CheckResponse_HeadersEntry): CheckResponse_HeadersEntryAmino;
    fromAminoMsg(object: CheckResponse_HeadersEntryAminoMsg): CheckResponse_HeadersEntry;
    fromProtoMsg(message: CheckResponse_HeadersEntryProtoMsg): CheckResponse_HeadersEntry;
    toProto(message: CheckResponse_HeadersEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const CheckResponse: {
    typeUrl: string;
    is(o: any): o is CheckResponse;
    isSDK(o: any): o is CheckResponseSDKType;
    isAmino(o: any): o is CheckResponseAmino;
    encode(message: CheckResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CheckResponse;
    fromJSON(object: any): CheckResponse;
    toJSON(message: CheckResponse): JsonSafe<CheckResponse>;
    fromPartial(object: DeepPartial<CheckResponse>): CheckResponse;
    fromSDK(object: CheckResponseSDKType): CheckResponse;
    fromSDKJSON(object: any): CheckResponseSDKType;
    toSDK(message: CheckResponse): CheckResponseSDKType;
    fromAmino(object: CheckResponseAmino): CheckResponse;
    toAmino(message: CheckResponse): CheckResponseAmino;
    fromAminoMsg(object: CheckResponseAminoMsg): CheckResponse;
    fromProtoMsg(message: CheckResponseProtoMsg): CheckResponse;
    toProto(message: CheckResponse): Uint8Array;
    toProtoMsg(message: CheckResponse): CheckResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const ReportRequest: {
    typeUrl: string;
    is(o: any): o is ReportRequest;
    isSDK(o: any): o is ReportRequestSDKType;
    isAmino(o: any): o is ReportRequestAmino;
    encode(message: ReportRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ReportRequest;
    fromJSON(object: any): ReportRequest;
    toJSON(message: ReportRequest): JsonSafe<ReportRequest>;
    fromPartial(object: DeepPartial<ReportRequest>): ReportRequest;
    fromSDK(object: ReportRequestSDKType): ReportRequest;
    fromSDKJSON(object: any): ReportRequestSDKType;
    toSDK(message: ReportRequest): ReportRequestSDKType;
    fromAmino(object: ReportRequestAmino): ReportRequest;
    toAmino(message: ReportRequest): ReportRequestAmino;
    fromAminoMsg(object: ReportRequestAminoMsg): ReportRequest;
    fromProtoMsg(message: ReportRequestProtoMsg): ReportRequest;
    toProto(message: ReportRequest): Uint8Array;
    toProtoMsg(message: ReportRequest): ReportRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ReportResponse: {
    typeUrl: string;
    is(o: any): o is ReportResponse;
    isSDK(o: any): o is ReportResponseSDKType;
    isAmino(o: any): o is ReportResponseAmino;
    encode(_: ReportResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ReportResponse;
    fromJSON(_: any): ReportResponse;
    toJSON(_: ReportResponse): JsonSafe<ReportResponse>;
    fromPartial(_: DeepPartial<ReportResponse>): ReportResponse;
    fromSDK(_: ReportResponseSDKType): ReportResponse;
    fromSDKJSON(_: any): ReportResponseSDKType;
    toSDK(_: ReportResponse): ReportResponseSDKType;
    fromAmino(_: ReportResponseAmino): ReportResponse;
    toAmino(_: ReportResponse): ReportResponseAmino;
    fromAminoMsg(object: ReportResponseAminoMsg): ReportResponse;
    fromProtoMsg(message: ReportResponseProtoMsg): ReportResponse;
    toProto(message: ReportResponse): Uint8Array;
    toProtoMsg(message: ReportResponse): ReportResponseProtoMsg;
    registerTypeUrl(): void;
};
