import { ConfigChange, ConfigChangeAmino, ConfigChangeSDKType } from "../../config_change";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.servicemanagement.v1";
/** Code describes the status of the operation (or one of its steps). */
export declare enum OperationMetadata_Status {
    /** STATUS_UNSPECIFIED - Unspecifed code. */
    STATUS_UNSPECIFIED = 0,
    /** DONE - The operation or step has completed without errors. */
    DONE = 1,
    /** NOT_STARTED - The operation or step has not started yet. */
    NOT_STARTED = 2,
    /** IN_PROGRESS - The operation or step is in progress. */
    IN_PROGRESS = 3,
    /**
     * FAILED - The operation or step has completed with errors. If the operation is
     * rollbackable, the rollback completed with errors too.
     */
    FAILED = 4,
    /** CANCELLED - The operation or step has completed with cancellation. */
    CANCELLED = 5,
    UNRECOGNIZED = -1
}
export declare const OperationMetadata_StatusSDKType: typeof OperationMetadata_Status;
export declare const OperationMetadata_StatusAmino: typeof OperationMetadata_Status;
export declare function operationMetadata_StatusFromJSON(object: any): OperationMetadata_Status;
export declare function operationMetadata_StatusToJSON(object: OperationMetadata_Status): string;
/** The kind of diagnostic information possible. */
export declare enum Diagnostic_Kind {
    /** WARNING - Warnings and errors */
    WARNING = 0,
    /** ERROR - Only errors */
    ERROR = 1,
    UNRECOGNIZED = -1
}
export declare const Diagnostic_KindSDKType: typeof Diagnostic_Kind;
export declare const Diagnostic_KindAmino: typeof Diagnostic_Kind;
export declare function diagnostic_KindFromJSON(object: any): Diagnostic_Kind;
export declare function diagnostic_KindToJSON(object: Diagnostic_Kind): string;
export declare enum ConfigFile_FileType {
    /** FILE_TYPE_UNSPECIFIED - Unknown file type. */
    FILE_TYPE_UNSPECIFIED = 0,
    /** SERVICE_CONFIG_YAML - YAML-specification of service. */
    SERVICE_CONFIG_YAML = 1,
    /** OPEN_API_JSON - OpenAPI specification, serialized in JSON. */
    OPEN_API_JSON = 2,
    /** OPEN_API_YAML - OpenAPI specification, serialized in YAML. */
    OPEN_API_YAML = 3,
    /**
     * FILE_DESCRIPTOR_SET_PROTO - FileDescriptorSet, generated by protoc.
     *
     * To generate, use protoc with imports and source info included.
     * For an example test.proto file, the following command would put the value
     * in a new file named out.pb.
     *
     * $protoc --include_imports --include_source_info test.proto -o out.pb
     */
    FILE_DESCRIPTOR_SET_PROTO = 4,
    /**
     * PROTO_FILE - Uncompiled Proto file. Used for storage and display purposes only,
     * currently server-side compilation is not supported. Should match the
     * inputs to 'protoc' command used to generated FILE_DESCRIPTOR_SET_PROTO. A
     * file of this type can only be included if at least one file of type
     * FILE_DESCRIPTOR_SET_PROTO is included.
     */
    PROTO_FILE = 6,
    UNRECOGNIZED = -1
}
export declare const ConfigFile_FileTypeSDKType: typeof ConfigFile_FileType;
export declare const ConfigFile_FileTypeAmino: typeof ConfigFile_FileType;
export declare function configFile_FileTypeFromJSON(object: any): ConfigFile_FileType;
export declare function configFile_FileTypeToJSON(object: ConfigFile_FileType): string;
/** Status of a Rollout. */
export declare enum Rollout_RolloutStatus {
    /** ROLLOUT_STATUS_UNSPECIFIED - No status specified. */
    ROLLOUT_STATUS_UNSPECIFIED = 0,
    /** IN_PROGRESS - The Rollout is in progress. */
    IN_PROGRESS = 1,
    /** SUCCESS - The Rollout has completed successfully. */
    SUCCESS = 2,
    /**
     * CANCELLED - The Rollout has been cancelled. This can happen if you have overlapping
     * Rollout pushes, and the previous ones will be cancelled.
     */
    CANCELLED = 3,
    /** FAILED - The Rollout has failed and the rollback attempt has failed too. */
    FAILED = 4,
    /** PENDING - The Rollout has not started yet and is pending for execution. */
    PENDING = 5,
    /**
     * FAILED_ROLLED_BACK - The Rollout has failed and rolled back to the previous successful
     * Rollout.
     */
    FAILED_ROLLED_BACK = 6,
    UNRECOGNIZED = -1
}
export declare const Rollout_RolloutStatusSDKType: typeof Rollout_RolloutStatus;
export declare const Rollout_RolloutStatusAmino: typeof Rollout_RolloutStatus;
export declare function rollout_RolloutStatusFromJSON(object: any): Rollout_RolloutStatus;
export declare function rollout_RolloutStatusToJSON(object: Rollout_RolloutStatus): string;
/**
 * The full representation of a Service that is managed by
 * Google Service Management.
 */
export interface ManagedService {
    /**
     * The name of the service. See the [overview](/service-management/overview)
     * for naming requirements.
     */
    serviceName: string;
    /** ID of the project that produces and owns this service. */
    producerProjectId: string;
}
export interface ManagedServiceProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.ManagedService";
    value: Uint8Array;
}
/**
 * The full representation of a Service that is managed by
 * Google Service Management.
 */
export interface ManagedServiceAmino {
    /**
     * The name of the service. See the [overview](/service-management/overview)
     * for naming requirements.
     */
    service_name?: string;
    /** ID of the project that produces and owns this service. */
    producer_project_id?: string;
}
export interface ManagedServiceAminoMsg {
    type: "/google.api.servicemanagement.v1.ManagedService";
    value: ManagedServiceAmino;
}
/**
 * The full representation of a Service that is managed by
 * Google Service Management.
 */
export interface ManagedServiceSDKType {
    service_name: string;
    producer_project_id: string;
}
/** The metadata associated with a long running operation resource. */
export interface OperationMetadata {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resourceNames: string[];
    /** Detailed status information for each step. The order is undetermined. */
    steps: OperationMetadata_Step[];
    /** Percentage of completion of this operation, ranging from 0 to 100. */
    progressPercentage: number;
    /** The start time of the operation. */
    startTime?: Date;
}
export interface OperationMetadataProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.OperationMetadata";
    value: Uint8Array;
}
/** The metadata associated with a long running operation resource. */
export interface OperationMetadataAmino {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resource_names?: string[];
    /** Detailed status information for each step. The order is undetermined. */
    steps?: OperationMetadata_StepAmino[];
    /** Percentage of completion of this operation, ranging from 0 to 100. */
    progress_percentage?: number;
    /** The start time of the operation. */
    start_time?: string;
}
export interface OperationMetadataAminoMsg {
    type: "/google.api.servicemanagement.v1.OperationMetadata";
    value: OperationMetadataAmino;
}
/** The metadata associated with a long running operation resource. */
export interface OperationMetadataSDKType {
    resource_names: string[];
    steps: OperationMetadata_StepSDKType[];
    progress_percentage: number;
    start_time?: Date;
}
/** Represents the status of one operation step. */
export interface OperationMetadata_Step {
    /** The short description of the step. */
    description: string;
    /** The status code. */
    status: OperationMetadata_Status;
}
export interface OperationMetadata_StepProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.Step";
    value: Uint8Array;
}
/** Represents the status of one operation step. */
export interface OperationMetadata_StepAmino {
    /** The short description of the step. */
    description?: string;
    /** The status code. */
    status?: OperationMetadata_Status;
}
export interface OperationMetadata_StepAminoMsg {
    type: "/google.api.servicemanagement.v1.Step";
    value: OperationMetadata_StepAmino;
}
/** Represents the status of one operation step. */
export interface OperationMetadata_StepSDKType {
    description: string;
    status: OperationMetadata_Status;
}
/** Represents a diagnostic message (error or warning) */
export interface Diagnostic {
    /** File name and line number of the error or warning. */
    location: string;
    /** The kind of diagnostic information provided. */
    kind: Diagnostic_Kind;
    /** Message describing the error or warning. */
    message: string;
}
export interface DiagnosticProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.Diagnostic";
    value: Uint8Array;
}
/** Represents a diagnostic message (error or warning) */
export interface DiagnosticAmino {
    /** File name and line number of the error or warning. */
    location?: string;
    /** The kind of diagnostic information provided. */
    kind?: Diagnostic_Kind;
    /** Message describing the error or warning. */
    message?: string;
}
export interface DiagnosticAminoMsg {
    type: "/google.api.servicemanagement.v1.Diagnostic";
    value: DiagnosticAmino;
}
/** Represents a diagnostic message (error or warning) */
export interface DiagnosticSDKType {
    location: string;
    kind: Diagnostic_Kind;
    message: string;
}
/**
 * Represents a source file which is used to generate the service configuration
 * defined by `google.api.Service`.
 */
export interface ConfigSource {
    /**
     * A unique ID for a specific instance of this message, typically assigned
     * by the client for tracking purpose. If empty, the server may choose to
     * generate one instead.
     */
    id: string;
    /**
     * Set of source configuration files that are used to generate a service
     * configuration (`google.api.Service`).
     */
    files: ConfigFile[];
}
export interface ConfigSourceProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.ConfigSource";
    value: Uint8Array;
}
/**
 * Represents a source file which is used to generate the service configuration
 * defined by `google.api.Service`.
 */
export interface ConfigSourceAmino {
    /**
     * A unique ID for a specific instance of this message, typically assigned
     * by the client for tracking purpose. If empty, the server may choose to
     * generate one instead.
     */
    id?: string;
    /**
     * Set of source configuration files that are used to generate a service
     * configuration (`google.api.Service`).
     */
    files?: ConfigFileAmino[];
}
export interface ConfigSourceAminoMsg {
    type: "/google.api.servicemanagement.v1.ConfigSource";
    value: ConfigSourceAmino;
}
/**
 * Represents a source file which is used to generate the service configuration
 * defined by `google.api.Service`.
 */
export interface ConfigSourceSDKType {
    id: string;
    files: ConfigFileSDKType[];
}
/** Generic specification of a source configuration file */
export interface ConfigFile {
    /** The file name of the configuration file (full or relative path). */
    filePath: string;
    /** The bytes that constitute the file. */
    fileContents: Uint8Array;
    /** The type of configuration file this represents. */
    fileType: ConfigFile_FileType;
}
export interface ConfigFileProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.ConfigFile";
    value: Uint8Array;
}
/** Generic specification of a source configuration file */
export interface ConfigFileAmino {
    /** The file name of the configuration file (full or relative path). */
    file_path?: string;
    /** The bytes that constitute the file. */
    file_contents?: string;
    /** The type of configuration file this represents. */
    file_type?: ConfigFile_FileType;
}
export interface ConfigFileAminoMsg {
    type: "/google.api.servicemanagement.v1.ConfigFile";
    value: ConfigFileAmino;
}
/** Generic specification of a source configuration file */
export interface ConfigFileSDKType {
    file_path: string;
    file_contents: Uint8Array;
    file_type: ConfigFile_FileType;
}
/** Represents a service configuration with its name and id. */
export interface ConfigRef {
    /**
     * Resource name of a service config. It must have the following
     * format: "services/{service name}/configs/{config id}".
     */
    name: string;
}
export interface ConfigRefProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.ConfigRef";
    value: Uint8Array;
}
/** Represents a service configuration with its name and id. */
export interface ConfigRefAmino {
    /**
     * Resource name of a service config. It must have the following
     * format: "services/{service name}/configs/{config id}".
     */
    name?: string;
}
export interface ConfigRefAminoMsg {
    type: "/google.api.servicemanagement.v1.ConfigRef";
    value: ConfigRefAmino;
}
/** Represents a service configuration with its name and id. */
export interface ConfigRefSDKType {
    name: string;
}
/**
 * Change report associated with a particular service configuration.
 *
 * It contains a list of ConfigChanges based on the comparison between
 * two service configurations.
 */
export interface ChangeReport {
    /**
     * List of changes between two service configurations.
     * The changes will be alphabetically sorted based on the identifier
     * of each change.
     * A ConfigChange identifier is a dot separated path to the configuration.
     * Example: visibility.rules[selector='LibraryService.CreateBook'].restriction
     */
    configChanges: ConfigChange[];
}
export interface ChangeReportProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.ChangeReport";
    value: Uint8Array;
}
/**
 * Change report associated with a particular service configuration.
 *
 * It contains a list of ConfigChanges based on the comparison between
 * two service configurations.
 */
export interface ChangeReportAmino {
    /**
     * List of changes between two service configurations.
     * The changes will be alphabetically sorted based on the identifier
     * of each change.
     * A ConfigChange identifier is a dot separated path to the configuration.
     * Example: visibility.rules[selector='LibraryService.CreateBook'].restriction
     */
    config_changes?: ConfigChangeAmino[];
}
export interface ChangeReportAminoMsg {
    type: "/google.api.servicemanagement.v1.ChangeReport";
    value: ChangeReportAmino;
}
/**
 * Change report associated with a particular service configuration.
 *
 * It contains a list of ConfigChanges based on the comparison between
 * two service configurations.
 */
export interface ChangeReportSDKType {
    config_changes: ConfigChangeSDKType[];
}
/**
 * A rollout resource that defines how service configuration versions are pushed
 * to control plane systems. Typically, you create a new version of the
 * service config, and then create a Rollout to push the service config.
 */
export interface Rollout {
    /**
     * Optional. Unique identifier of this Rollout. Must be no longer than 63 characters
     * and only lower case letters, digits, '.', '_' and '-' are allowed.
     *
     * If not specified by client, the server will generate one. The generated id
     * will have the form of <date><revision number>, where "date" is the create
     * date in ISO 8601 format.  "revision number" is a monotonically increasing
     * positive number that is reset every day for each service.
     * An example of the generated rollout_id is '2016-02-16r1'
     */
    rolloutId: string;
    /** Creation time of the rollout. Readonly. */
    createTime?: Date;
    /** The user who created the Rollout. Readonly. */
    createdBy: string;
    /**
     * The status of this rollout. Readonly. In case of a failed rollout,
     * the system will automatically rollback to the current Rollout
     * version. Readonly.
     */
    status: Rollout_RolloutStatus;
    /**
     * Google Service Control selects service configurations based on
     * traffic percentage.
     */
    trafficPercentStrategy?: Rollout_TrafficPercentStrategy;
    /**
     * The strategy associated with a rollout to delete a `ManagedService`.
     * Readonly.
     */
    deleteServiceStrategy?: Rollout_DeleteServiceStrategy;
    /** The name of the service associated with this Rollout. */
    serviceName: string;
}
export interface RolloutProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.Rollout";
    value: Uint8Array;
}
/**
 * A rollout resource that defines how service configuration versions are pushed
 * to control plane systems. Typically, you create a new version of the
 * service config, and then create a Rollout to push the service config.
 */
export interface RolloutAmino {
    /**
     * Optional. Unique identifier of this Rollout. Must be no longer than 63 characters
     * and only lower case letters, digits, '.', '_' and '-' are allowed.
     *
     * If not specified by client, the server will generate one. The generated id
     * will have the form of <date><revision number>, where "date" is the create
     * date in ISO 8601 format.  "revision number" is a monotonically increasing
     * positive number that is reset every day for each service.
     * An example of the generated rollout_id is '2016-02-16r1'
     */
    rollout_id?: string;
    /** Creation time of the rollout. Readonly. */
    create_time?: string;
    /** The user who created the Rollout. Readonly. */
    created_by?: string;
    /**
     * The status of this rollout. Readonly. In case of a failed rollout,
     * the system will automatically rollback to the current Rollout
     * version. Readonly.
     */
    status?: Rollout_RolloutStatus;
    /**
     * Google Service Control selects service configurations based on
     * traffic percentage.
     */
    traffic_percent_strategy?: Rollout_TrafficPercentStrategyAmino;
    /**
     * The strategy associated with a rollout to delete a `ManagedService`.
     * Readonly.
     */
    delete_service_strategy?: Rollout_DeleteServiceStrategyAmino;
    /** The name of the service associated with this Rollout. */
    service_name?: string;
}
export interface RolloutAminoMsg {
    type: "/google.api.servicemanagement.v1.Rollout";
    value: RolloutAmino;
}
/**
 * A rollout resource that defines how service configuration versions are pushed
 * to control plane systems. Typically, you create a new version of the
 * service config, and then create a Rollout to push the service config.
 */
export interface RolloutSDKType {
    rollout_id: string;
    create_time?: Date;
    created_by: string;
    status: Rollout_RolloutStatus;
    traffic_percent_strategy?: Rollout_TrafficPercentStrategySDKType;
    delete_service_strategy?: Rollout_DeleteServiceStrategySDKType;
    service_name: string;
}
export interface Rollout_TrafficPercentStrategy_PercentagesEntry {
    key: string;
    value: number;
}
export interface Rollout_TrafficPercentStrategy_PercentagesEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface Rollout_TrafficPercentStrategy_PercentagesEntryAmino {
    key?: string;
    value?: number;
}
export interface Rollout_TrafficPercentStrategy_PercentagesEntryAminoMsg {
    type: string;
    value: Rollout_TrafficPercentStrategy_PercentagesEntryAmino;
}
export interface Rollout_TrafficPercentStrategy_PercentagesEntrySDKType {
    key: string;
    value: number;
}
/**
 * Strategy that specifies how clients of Google Service Controller want to
 * send traffic to use different config versions. This is generally
 * used by API proxy to split traffic based on your configured percentage for
 * each config version.
 *
 * One example of how to gradually rollout a new service configuration using
 * this
 * strategy:
 * Day 1
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160206"
 *       traffic_percent_strategy {
 *         percentages: {
 *           "example.googleapis.com/20160201": 70.00
 *           "example.googleapis.com/20160206": 30.00
 *         }
 *       }
 *     }
 *
 * Day 2
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160207"
 *       traffic_percent_strategy: {
 *         percentages: {
 *           "example.googleapis.com/20160206": 100.00
 *         }
 *       }
 *     }
 */
export interface Rollout_TrafficPercentStrategy {
    /**
     * Maps service configuration IDs to their corresponding traffic percentage.
     * Key is the service configuration ID, Value is the traffic percentage
     * which must be greater than 0.0 and the sum must equal to 100.0.
     */
    percentages: {
        [key: string]: number;
    };
}
export interface Rollout_TrafficPercentStrategyProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.TrafficPercentStrategy";
    value: Uint8Array;
}
/**
 * Strategy that specifies how clients of Google Service Controller want to
 * send traffic to use different config versions. This is generally
 * used by API proxy to split traffic based on your configured percentage for
 * each config version.
 *
 * One example of how to gradually rollout a new service configuration using
 * this
 * strategy:
 * Day 1
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160206"
 *       traffic_percent_strategy {
 *         percentages: {
 *           "example.googleapis.com/20160201": 70.00
 *           "example.googleapis.com/20160206": 30.00
 *         }
 *       }
 *     }
 *
 * Day 2
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160207"
 *       traffic_percent_strategy: {
 *         percentages: {
 *           "example.googleapis.com/20160206": 100.00
 *         }
 *       }
 *     }
 */
export interface Rollout_TrafficPercentStrategyAmino {
    /**
     * Maps service configuration IDs to their corresponding traffic percentage.
     * Key is the service configuration ID, Value is the traffic percentage
     * which must be greater than 0.0 and the sum must equal to 100.0.
     */
    percentages?: {
        [key: string]: number;
    };
}
export interface Rollout_TrafficPercentStrategyAminoMsg {
    type: "/google.api.servicemanagement.v1.TrafficPercentStrategy";
    value: Rollout_TrafficPercentStrategyAmino;
}
/**
 * Strategy that specifies how clients of Google Service Controller want to
 * send traffic to use different config versions. This is generally
 * used by API proxy to split traffic based on your configured percentage for
 * each config version.
 *
 * One example of how to gradually rollout a new service configuration using
 * this
 * strategy:
 * Day 1
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160206"
 *       traffic_percent_strategy {
 *         percentages: {
 *           "example.googleapis.com/20160201": 70.00
 *           "example.googleapis.com/20160206": 30.00
 *         }
 *       }
 *     }
 *
 * Day 2
 *
 *     Rollout {
 *       id: "example.googleapis.com/rollout_20160207"
 *       traffic_percent_strategy: {
 *         percentages: {
 *           "example.googleapis.com/20160206": 100.00
 *         }
 *       }
 *     }
 */
export interface Rollout_TrafficPercentStrategySDKType {
    percentages: {
        [key: string]: number;
    };
}
/**
 * Strategy used to delete a service. This strategy is a placeholder only
 * used by the system generated rollout to delete a service.
 */
export interface Rollout_DeleteServiceStrategy {
}
export interface Rollout_DeleteServiceStrategyProtoMsg {
    typeUrl: "/google.api.servicemanagement.v1.DeleteServiceStrategy";
    value: Uint8Array;
}
/**
 * Strategy used to delete a service. This strategy is a placeholder only
 * used by the system generated rollout to delete a service.
 */
export interface Rollout_DeleteServiceStrategyAmino {
}
export interface Rollout_DeleteServiceStrategyAminoMsg {
    type: "/google.api.servicemanagement.v1.DeleteServiceStrategy";
    value: Rollout_DeleteServiceStrategyAmino;
}
/**
 * Strategy used to delete a service. This strategy is a placeholder only
 * used by the system generated rollout to delete a service.
 */
export interface Rollout_DeleteServiceStrategySDKType {
}
export declare const ManagedService: {
    typeUrl: string;
    is(o: any): o is ManagedService;
    isSDK(o: any): o is ManagedServiceSDKType;
    isAmino(o: any): o is ManagedServiceAmino;
    encode(message: ManagedService, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ManagedService;
    fromJSON(object: any): ManagedService;
    toJSON(message: ManagedService): JsonSafe<ManagedService>;
    fromPartial(object: DeepPartial<ManagedService>): ManagedService;
    fromSDK(object: ManagedServiceSDKType): ManagedService;
    fromSDKJSON(object: any): ManagedServiceSDKType;
    toSDK(message: ManagedService): ManagedServiceSDKType;
    fromAmino(object: ManagedServiceAmino): ManagedService;
    toAmino(message: ManagedService): ManagedServiceAmino;
    fromAminoMsg(object: ManagedServiceAminoMsg): ManagedService;
    fromProtoMsg(message: ManagedServiceProtoMsg): ManagedService;
    toProto(message: ManagedService): Uint8Array;
    toProtoMsg(message: ManagedService): ManagedServiceProtoMsg;
    registerTypeUrl(): void;
};
export declare const OperationMetadata: {
    typeUrl: string;
    is(o: any): o is OperationMetadata;
    isSDK(o: any): o is OperationMetadataSDKType;
    isAmino(o: any): o is OperationMetadataAmino;
    encode(message: OperationMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OperationMetadata;
    fromJSON(object: any): OperationMetadata;
    toJSON(message: OperationMetadata): JsonSafe<OperationMetadata>;
    fromPartial(object: DeepPartial<OperationMetadata>): OperationMetadata;
    fromSDK(object: OperationMetadataSDKType): OperationMetadata;
    fromSDKJSON(object: any): OperationMetadataSDKType;
    toSDK(message: OperationMetadata): OperationMetadataSDKType;
    fromAmino(object: OperationMetadataAmino): OperationMetadata;
    toAmino(message: OperationMetadata): OperationMetadataAmino;
    fromAminoMsg(object: OperationMetadataAminoMsg): OperationMetadata;
    fromProtoMsg(message: OperationMetadataProtoMsg): OperationMetadata;
    toProto(message: OperationMetadata): Uint8Array;
    toProtoMsg(message: OperationMetadata): OperationMetadataProtoMsg;
    registerTypeUrl(): void;
};
export declare const OperationMetadata_Step: {
    typeUrl: string;
    is(o: any): o is OperationMetadata_Step;
    isSDK(o: any): o is OperationMetadata_StepSDKType;
    isAmino(o: any): o is OperationMetadata_StepAmino;
    encode(message: OperationMetadata_Step, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OperationMetadata_Step;
    fromJSON(object: any): OperationMetadata_Step;
    toJSON(message: OperationMetadata_Step): JsonSafe<OperationMetadata_Step>;
    fromPartial(object: DeepPartial<OperationMetadata_Step>): OperationMetadata_Step;
    fromSDK(object: OperationMetadata_StepSDKType): OperationMetadata_Step;
    fromSDKJSON(object: any): OperationMetadata_StepSDKType;
    toSDK(message: OperationMetadata_Step): OperationMetadata_StepSDKType;
    fromAmino(object: OperationMetadata_StepAmino): OperationMetadata_Step;
    toAmino(message: OperationMetadata_Step): OperationMetadata_StepAmino;
    fromAminoMsg(object: OperationMetadata_StepAminoMsg): OperationMetadata_Step;
    fromProtoMsg(message: OperationMetadata_StepProtoMsg): OperationMetadata_Step;
    toProto(message: OperationMetadata_Step): Uint8Array;
    toProtoMsg(message: OperationMetadata_Step): OperationMetadata_StepProtoMsg;
    registerTypeUrl(): void;
};
export declare const Diagnostic: {
    typeUrl: string;
    is(o: any): o is Diagnostic;
    isSDK(o: any): o is DiagnosticSDKType;
    isAmino(o: any): o is DiagnosticAmino;
    encode(message: Diagnostic, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Diagnostic;
    fromJSON(object: any): Diagnostic;
    toJSON(message: Diagnostic): JsonSafe<Diagnostic>;
    fromPartial(object: DeepPartial<Diagnostic>): Diagnostic;
    fromSDK(object: DiagnosticSDKType): Diagnostic;
    fromSDKJSON(object: any): DiagnosticSDKType;
    toSDK(message: Diagnostic): DiagnosticSDKType;
    fromAmino(object: DiagnosticAmino): Diagnostic;
    toAmino(message: Diagnostic): DiagnosticAmino;
    fromAminoMsg(object: DiagnosticAminoMsg): Diagnostic;
    fromProtoMsg(message: DiagnosticProtoMsg): Diagnostic;
    toProto(message: Diagnostic): Uint8Array;
    toProtoMsg(message: Diagnostic): DiagnosticProtoMsg;
    registerTypeUrl(): void;
};
export declare const ConfigSource: {
    typeUrl: string;
    is(o: any): o is ConfigSource;
    isSDK(o: any): o is ConfigSourceSDKType;
    isAmino(o: any): o is ConfigSourceAmino;
    encode(message: ConfigSource, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConfigSource;
    fromJSON(object: any): ConfigSource;
    toJSON(message: ConfigSource): JsonSafe<ConfigSource>;
    fromPartial(object: DeepPartial<ConfigSource>): ConfigSource;
    fromSDK(object: ConfigSourceSDKType): ConfigSource;
    fromSDKJSON(object: any): ConfigSourceSDKType;
    toSDK(message: ConfigSource): ConfigSourceSDKType;
    fromAmino(object: ConfigSourceAmino): ConfigSource;
    toAmino(message: ConfigSource): ConfigSourceAmino;
    fromAminoMsg(object: ConfigSourceAminoMsg): ConfigSource;
    fromProtoMsg(message: ConfigSourceProtoMsg): ConfigSource;
    toProto(message: ConfigSource): Uint8Array;
    toProtoMsg(message: ConfigSource): ConfigSourceProtoMsg;
    registerTypeUrl(): void;
};
export declare const ConfigFile: {
    typeUrl: string;
    is(o: any): o is ConfigFile;
    isSDK(o: any): o is ConfigFileSDKType;
    isAmino(o: any): o is ConfigFileAmino;
    encode(message: ConfigFile, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConfigFile;
    fromJSON(object: any): ConfigFile;
    toJSON(message: ConfigFile): JsonSafe<ConfigFile>;
    fromPartial(object: DeepPartial<ConfigFile>): ConfigFile;
    fromSDK(object: ConfigFileSDKType): ConfigFile;
    fromSDKJSON(object: any): ConfigFileSDKType;
    toSDK(message: ConfigFile): ConfigFileSDKType;
    fromAmino(object: ConfigFileAmino): ConfigFile;
    toAmino(message: ConfigFile): ConfigFileAmino;
    fromAminoMsg(object: ConfigFileAminoMsg): ConfigFile;
    fromProtoMsg(message: ConfigFileProtoMsg): ConfigFile;
    toProto(message: ConfigFile): Uint8Array;
    toProtoMsg(message: ConfigFile): ConfigFileProtoMsg;
    registerTypeUrl(): void;
};
export declare const ConfigRef: {
    typeUrl: string;
    is(o: any): o is ConfigRef;
    isSDK(o: any): o is ConfigRefSDKType;
    isAmino(o: any): o is ConfigRefAmino;
    encode(message: ConfigRef, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConfigRef;
    fromJSON(object: any): ConfigRef;
    toJSON(message: ConfigRef): JsonSafe<ConfigRef>;
    fromPartial(object: DeepPartial<ConfigRef>): ConfigRef;
    fromSDK(object: ConfigRefSDKType): ConfigRef;
    fromSDKJSON(object: any): ConfigRefSDKType;
    toSDK(message: ConfigRef): ConfigRefSDKType;
    fromAmino(object: ConfigRefAmino): ConfigRef;
    toAmino(message: ConfigRef): ConfigRefAmino;
    fromAminoMsg(object: ConfigRefAminoMsg): ConfigRef;
    fromProtoMsg(message: ConfigRefProtoMsg): ConfigRef;
    toProto(message: ConfigRef): Uint8Array;
    toProtoMsg(message: ConfigRef): ConfigRefProtoMsg;
    registerTypeUrl(): void;
};
export declare const ChangeReport: {
    typeUrl: string;
    is(o: any): o is ChangeReport;
    isSDK(o: any): o is ChangeReportSDKType;
    isAmino(o: any): o is ChangeReportAmino;
    encode(message: ChangeReport, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ChangeReport;
    fromJSON(object: any): ChangeReport;
    toJSON(message: ChangeReport): JsonSafe<ChangeReport>;
    fromPartial(object: DeepPartial<ChangeReport>): ChangeReport;
    fromSDK(object: ChangeReportSDKType): ChangeReport;
    fromSDKJSON(object: any): ChangeReportSDKType;
    toSDK(message: ChangeReport): ChangeReportSDKType;
    fromAmino(object: ChangeReportAmino): ChangeReport;
    toAmino(message: ChangeReport): ChangeReportAmino;
    fromAminoMsg(object: ChangeReportAminoMsg): ChangeReport;
    fromProtoMsg(message: ChangeReportProtoMsg): ChangeReport;
    toProto(message: ChangeReport): Uint8Array;
    toProtoMsg(message: ChangeReport): ChangeReportProtoMsg;
    registerTypeUrl(): void;
};
export declare const Rollout: {
    typeUrl: string;
    is(o: any): o is Rollout;
    isSDK(o: any): o is RolloutSDKType;
    isAmino(o: any): o is RolloutAmino;
    encode(message: Rollout, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Rollout;
    fromJSON(object: any): Rollout;
    toJSON(message: Rollout): JsonSafe<Rollout>;
    fromPartial(object: DeepPartial<Rollout>): Rollout;
    fromSDK(object: RolloutSDKType): Rollout;
    fromSDKJSON(object: any): RolloutSDKType;
    toSDK(message: Rollout): RolloutSDKType;
    fromAmino(object: RolloutAmino): Rollout;
    toAmino(message: Rollout): RolloutAmino;
    fromAminoMsg(object: RolloutAminoMsg): Rollout;
    fromProtoMsg(message: RolloutProtoMsg): Rollout;
    toProto(message: Rollout): Uint8Array;
    toProtoMsg(message: Rollout): RolloutProtoMsg;
    registerTypeUrl(): void;
};
export declare const Rollout_TrafficPercentStrategy_PercentagesEntry: {
    encode(message: Rollout_TrafficPercentStrategy_PercentagesEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Rollout_TrafficPercentStrategy_PercentagesEntry;
    fromJSON(object: any): Rollout_TrafficPercentStrategy_PercentagesEntry;
    toJSON(message: Rollout_TrafficPercentStrategy_PercentagesEntry): JsonSafe<Rollout_TrafficPercentStrategy_PercentagesEntry>;
    fromPartial(object: DeepPartial<Rollout_TrafficPercentStrategy_PercentagesEntry>): Rollout_TrafficPercentStrategy_PercentagesEntry;
    fromSDK(object: Rollout_TrafficPercentStrategy_PercentagesEntrySDKType): Rollout_TrafficPercentStrategy_PercentagesEntry;
    fromSDKJSON(object: any): Rollout_TrafficPercentStrategy_PercentagesEntrySDKType;
    toSDK(message: Rollout_TrafficPercentStrategy_PercentagesEntry): Rollout_TrafficPercentStrategy_PercentagesEntrySDKType;
    fromAmino(object: Rollout_TrafficPercentStrategy_PercentagesEntryAmino): Rollout_TrafficPercentStrategy_PercentagesEntry;
    toAmino(message: Rollout_TrafficPercentStrategy_PercentagesEntry): Rollout_TrafficPercentStrategy_PercentagesEntryAmino;
    fromAminoMsg(object: Rollout_TrafficPercentStrategy_PercentagesEntryAminoMsg): Rollout_TrafficPercentStrategy_PercentagesEntry;
    fromProtoMsg(message: Rollout_TrafficPercentStrategy_PercentagesEntryProtoMsg): Rollout_TrafficPercentStrategy_PercentagesEntry;
    toProto(message: Rollout_TrafficPercentStrategy_PercentagesEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const Rollout_TrafficPercentStrategy: {
    typeUrl: string;
    is(o: any): o is Rollout_TrafficPercentStrategy;
    isSDK(o: any): o is Rollout_TrafficPercentStrategySDKType;
    isAmino(o: any): o is Rollout_TrafficPercentStrategyAmino;
    encode(message: Rollout_TrafficPercentStrategy, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Rollout_TrafficPercentStrategy;
    fromJSON(object: any): Rollout_TrafficPercentStrategy;
    toJSON(message: Rollout_TrafficPercentStrategy): JsonSafe<Rollout_TrafficPercentStrategy>;
    fromPartial(object: DeepPartial<Rollout_TrafficPercentStrategy>): Rollout_TrafficPercentStrategy;
    fromSDK(object: Rollout_TrafficPercentStrategySDKType): Rollout_TrafficPercentStrategy;
    fromSDKJSON(object: any): Rollout_TrafficPercentStrategySDKType;
    toSDK(message: Rollout_TrafficPercentStrategy): Rollout_TrafficPercentStrategySDKType;
    fromAmino(object: Rollout_TrafficPercentStrategyAmino): Rollout_TrafficPercentStrategy;
    toAmino(message: Rollout_TrafficPercentStrategy): Rollout_TrafficPercentStrategyAmino;
    fromAminoMsg(object: Rollout_TrafficPercentStrategyAminoMsg): Rollout_TrafficPercentStrategy;
    fromProtoMsg(message: Rollout_TrafficPercentStrategyProtoMsg): Rollout_TrafficPercentStrategy;
    toProto(message: Rollout_TrafficPercentStrategy): Uint8Array;
    toProtoMsg(message: Rollout_TrafficPercentStrategy): Rollout_TrafficPercentStrategyProtoMsg;
    registerTypeUrl(): void;
};
export declare const Rollout_DeleteServiceStrategy: {
    typeUrl: string;
    is(o: any): o is Rollout_DeleteServiceStrategy;
    isSDK(o: any): o is Rollout_DeleteServiceStrategySDKType;
    isAmino(o: any): o is Rollout_DeleteServiceStrategyAmino;
    encode(_: Rollout_DeleteServiceStrategy, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Rollout_DeleteServiceStrategy;
    fromJSON(_: any): Rollout_DeleteServiceStrategy;
    toJSON(_: Rollout_DeleteServiceStrategy): JsonSafe<Rollout_DeleteServiceStrategy>;
    fromPartial(_: DeepPartial<Rollout_DeleteServiceStrategy>): Rollout_DeleteServiceStrategy;
    fromSDK(_: Rollout_DeleteServiceStrategySDKType): Rollout_DeleteServiceStrategy;
    fromSDKJSON(_: any): Rollout_DeleteServiceStrategySDKType;
    toSDK(_: Rollout_DeleteServiceStrategy): Rollout_DeleteServiceStrategySDKType;
    fromAmino(_: Rollout_DeleteServiceStrategyAmino): Rollout_DeleteServiceStrategy;
    toAmino(_: Rollout_DeleteServiceStrategy): Rollout_DeleteServiceStrategyAmino;
    fromAminoMsg(object: Rollout_DeleteServiceStrategyAminoMsg): Rollout_DeleteServiceStrategy;
    fromProtoMsg(message: Rollout_DeleteServiceStrategyProtoMsg): Rollout_DeleteServiceStrategy;
    toProto(message: Rollout_DeleteServiceStrategy): Uint8Array;
    toProtoMsg(message: Rollout_DeleteServiceStrategy): Rollout_DeleteServiceStrategyProtoMsg;
    registerTypeUrl(): void;
};
