import { Api, ApiAmino, ApiSDKType } from "../../../protobuf/api";
import { Documentation, DocumentationAmino, DocumentationSDKType } from "../../documentation";
import { Quota, QuotaAmino, QuotaSDKType } from "../../quota";
import { Authentication, AuthenticationAmino, AuthenticationSDKType } from "../../auth";
import { Usage, UsageAmino, UsageSDKType } from "../../usage";
import { Endpoint, EndpointAmino, EndpointSDKType } from "../../endpoint";
import { MonitoredResourceDescriptor, MonitoredResourceDescriptorAmino, MonitoredResourceDescriptorSDKType } from "../../monitored_resource";
import { Monitoring, MonitoringAmino, MonitoringSDKType } from "../../monitoring";
import { DeepPartial } from "../../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.serviceusage.v1";
/** Whether or not a service has been enabled for use by a consumer. */
export declare enum State {
    /**
     * STATE_UNSPECIFIED - The default value, which indicates that the enabled state of the service
     * is unspecified or not meaningful. Currently, all consumers other than
     * projects (such as folders and organizations) are always in this state.
     */
    STATE_UNSPECIFIED = 0,
    /**
     * DISABLED - The service cannot be used by this consumer. It has either been explicitly
     * disabled, or has never been enabled.
     */
    DISABLED = 1,
    /** ENABLED - The service has been explicitly enabled for use by this consumer. */
    ENABLED = 2,
    UNRECOGNIZED = -1
}
export declare const StateSDKType: typeof State;
export declare const StateAmino: typeof State;
export declare function stateFromJSON(object: any): State;
export declare function stateToJSON(object: State): string;
/** A service that is available for use by the consumer. */
export interface Service {
    /**
     * The resource name of the consumer and service.
     *
     * A valid name would be:
     * - projects/123/services/serviceusage.googleapis.com
     */
    name: string;
    /**
     * The resource name of the consumer.
     *
     * A valid name would be:
     * - projects/123
     */
    parent: string;
    /**
     * The service configuration of the available service.
     * Some fields may be filtered out of the configuration in responses to
     * the `ListServices` method. These fields are present only in responses to
     * the `GetService` method.
     */
    config?: ServiceConfig;
    /** Whether or not the service has been enabled for use by the consumer. */
    state: State;
}
export interface ServiceProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.Service";
    value: Uint8Array;
}
/** A service that is available for use by the consumer. */
export interface ServiceAmino {
    /**
     * The resource name of the consumer and service.
     *
     * A valid name would be:
     * - projects/123/services/serviceusage.googleapis.com
     */
    name?: string;
    /**
     * The resource name of the consumer.
     *
     * A valid name would be:
     * - projects/123
     */
    parent?: string;
    /**
     * The service configuration of the available service.
     * Some fields may be filtered out of the configuration in responses to
     * the `ListServices` method. These fields are present only in responses to
     * the `GetService` method.
     */
    config?: ServiceConfigAmino;
    /** Whether or not the service has been enabled for use by the consumer. */
    state?: State;
}
export interface ServiceAminoMsg {
    type: "/google.api.serviceusage.v1.Service";
    value: ServiceAmino;
}
/** A service that is available for use by the consumer. */
export interface ServiceSDKType {
    name: string;
    parent: string;
    config?: ServiceConfigSDKType;
    state: State;
}
/** The configuration of the service. */
export interface ServiceConfig {
    /**
     * The DNS address at which this service is available.
     *
     * An example DNS address would be:
     * `calendar.googleapis.com`.
     */
    name: string;
    /** The product title for this service. */
    title: string;
    /**
     * A list of API interfaces exported by this service. Contains only the names,
     * versions, and method names of the interfaces.
     */
    apis: Api[];
    /**
     * Additional API documentation. Contains only the summary and the
     * documentation URL.
     */
    documentation?: Documentation;
    /** Quota configuration. */
    quota?: Quota;
    /** Auth configuration. Contains only the OAuth rules. */
    authentication?: Authentication;
    /** Configuration controlling usage of this service. */
    usage?: Usage;
    /**
     * Configuration for network endpoints. Contains only the names and aliases
     * of the endpoints.
     */
    endpoints: Endpoint[];
    /**
     * Defines the monitored resources used by this service. This is required
     * by the [Service.monitoring][google.api.Service.monitoring] and [Service.logging][google.api.Service.logging] configurations.
     */
    monitoredResources: MonitoredResourceDescriptor[];
    /**
     * Monitoring configuration.
     * This should not include the 'producer_destinations' field.
     */
    monitoring?: Monitoring;
}
export interface ServiceConfigProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.ServiceConfig";
    value: Uint8Array;
}
/** The configuration of the service. */
export interface ServiceConfigAmino {
    /**
     * The DNS address at which this service is available.
     *
     * An example DNS address would be:
     * `calendar.googleapis.com`.
     */
    name?: string;
    /** The product title for this service. */
    title?: string;
    /**
     * A list of API interfaces exported by this service. Contains only the names,
     * versions, and method names of the interfaces.
     */
    apis?: ApiAmino[];
    /**
     * Additional API documentation. Contains only the summary and the
     * documentation URL.
     */
    documentation?: DocumentationAmino;
    /** Quota configuration. */
    quota?: QuotaAmino;
    /** Auth configuration. Contains only the OAuth rules. */
    authentication?: AuthenticationAmino;
    /** Configuration controlling usage of this service. */
    usage?: UsageAmino;
    /**
     * Configuration for network endpoints. Contains only the names and aliases
     * of the endpoints.
     */
    endpoints?: EndpointAmino[];
    /**
     * Defines the monitored resources used by this service. This is required
     * by the [Service.monitoring][google.api.Service.monitoring] and [Service.logging][google.api.Service.logging] configurations.
     */
    monitored_resources?: MonitoredResourceDescriptorAmino[];
    /**
     * Monitoring configuration.
     * This should not include the 'producer_destinations' field.
     */
    monitoring?: MonitoringAmino;
}
export interface ServiceConfigAminoMsg {
    type: "/google.api.serviceusage.v1.ServiceConfig";
    value: ServiceConfigAmino;
}
/** The configuration of the service. */
export interface ServiceConfigSDKType {
    name: string;
    title: string;
    apis: ApiSDKType[];
    documentation?: DocumentationSDKType;
    quota?: QuotaSDKType;
    authentication?: AuthenticationSDKType;
    usage?: UsageSDKType;
    endpoints: EndpointSDKType[];
    monitored_resources: MonitoredResourceDescriptorSDKType[];
    monitoring?: MonitoringSDKType;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadata {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resourceNames: string[];
}
export interface OperationMetadataProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.OperationMetadata";
    value: Uint8Array;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadataAmino {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resource_names?: string[];
}
export interface OperationMetadataAminoMsg {
    type: "/google.api.serviceusage.v1.OperationMetadata";
    value: OperationMetadataAmino;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadataSDKType {
    resource_names: string[];
}
export declare const Service: {
    typeUrl: string;
    is(o: any): o is Service;
    isSDK(o: any): o is ServiceSDKType;
    isAmino(o: any): o is ServiceAmino;
    encode(message: Service, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Service;
    fromJSON(object: any): Service;
    toJSON(message: Service): JsonSafe<Service>;
    fromPartial(object: DeepPartial<Service>): Service;
    fromSDK(object: ServiceSDKType): Service;
    fromSDKJSON(object: any): ServiceSDKType;
    toSDK(message: Service): ServiceSDKType;
    fromAmino(object: ServiceAmino): Service;
    toAmino(message: Service): ServiceAmino;
    fromAminoMsg(object: ServiceAminoMsg): Service;
    fromProtoMsg(message: ServiceProtoMsg): Service;
    toProto(message: Service): Uint8Array;
    toProtoMsg(message: Service): ServiceProtoMsg;
    registerTypeUrl(): void;
};
export declare const ServiceConfig: {
    typeUrl: string;
    is(o: any): o is ServiceConfig;
    isSDK(o: any): o is ServiceConfigSDKType;
    isAmino(o: any): o is ServiceConfigAmino;
    encode(message: ServiceConfig, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ServiceConfig;
    fromJSON(object: any): ServiceConfig;
    toJSON(message: ServiceConfig): JsonSafe<ServiceConfig>;
    fromPartial(object: DeepPartial<ServiceConfig>): ServiceConfig;
    fromSDK(object: ServiceConfigSDKType): ServiceConfig;
    fromSDKJSON(object: any): ServiceConfigSDKType;
    toSDK(message: ServiceConfig): ServiceConfigSDKType;
    fromAmino(object: ServiceConfigAmino): ServiceConfig;
    toAmino(message: ServiceConfig): ServiceConfigAmino;
    fromAminoMsg(object: ServiceConfigAminoMsg): ServiceConfig;
    fromProtoMsg(message: ServiceConfigProtoMsg): ServiceConfig;
    toProto(message: ServiceConfig): Uint8Array;
    toProtoMsg(message: ServiceConfig): ServiceConfigProtoMsg;
    registerTypeUrl(): void;
};
export declare const OperationMetadata: {
    typeUrl: string;
    is(o: any): o is OperationMetadata;
    isSDK(o: any): o is OperationMetadataSDKType;
    isAmino(o: any): o is OperationMetadataAmino;
    encode(message: OperationMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OperationMetadata;
    fromJSON(object: any): OperationMetadata;
    toJSON(message: OperationMetadata): JsonSafe<OperationMetadata>;
    fromPartial(object: DeepPartial<OperationMetadata>): OperationMetadata;
    fromSDK(object: OperationMetadataSDKType): OperationMetadata;
    fromSDKJSON(object: any): OperationMetadataSDKType;
    toSDK(message: OperationMetadata): OperationMetadataSDKType;
    fromAmino(object: OperationMetadataAmino): OperationMetadata;
    toAmino(message: OperationMetadata): OperationMetadataAmino;
    fromAminoMsg(object: OperationMetadataAminoMsg): OperationMetadata;
    fromProtoMsg(message: OperationMetadataProtoMsg): OperationMetadata;
    toProto(message: OperationMetadata): Uint8Array;
    toProtoMsg(message: OperationMetadata): OperationMetadataProtoMsg;
    registerTypeUrl(): void;
};
