import { Service, ServiceAmino, ServiceSDKType } from "./resources";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.serviceusage.v1";
/**
 * Enum to determine if service usage should be checked when disabling a
 * service.
 */
export declare enum DisableServiceRequest_CheckIfServiceHasUsage {
    /** CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED - When unset, the default behavior is used, which is SKIP. */
    CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED = 0,
    /** SKIP - If set, skip checking service usage when disabling a service. */
    SKIP = 1,
    /**
     * CHECK - If set, service usage is checked when disabling the service. If a
     * service, or its dependents, has usage in the last 30 days, the request
     * returns a FAILED_PRECONDITION error.
     */
    CHECK = 2,
    UNRECOGNIZED = -1
}
export declare const DisableServiceRequest_CheckIfServiceHasUsageSDKType: typeof DisableServiceRequest_CheckIfServiceHasUsage;
export declare const DisableServiceRequest_CheckIfServiceHasUsageAmino: typeof DisableServiceRequest_CheckIfServiceHasUsage;
export declare function disableServiceRequest_CheckIfServiceHasUsageFromJSON(object: any): DisableServiceRequest_CheckIfServiceHasUsage;
export declare function disableServiceRequest_CheckIfServiceHasUsageToJSON(object: DisableServiceRequest_CheckIfServiceHasUsage): string;
/** Request message for the `EnableService` method. */
export interface EnableServiceRequest {
    /**
     * Name of the consumer and service to enable the service on.
     *
     * The `EnableService` and `DisableService` methods currently only support
     * projects.
     *
     * Enabling a service requires that the service is public or is shared with
     * the user enabling the service.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name: string;
}
export interface EnableServiceRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.EnableServiceRequest";
    value: Uint8Array;
}
/** Request message for the `EnableService` method. */
export interface EnableServiceRequestAmino {
    /**
     * Name of the consumer and service to enable the service on.
     *
     * The `EnableService` and `DisableService` methods currently only support
     * projects.
     *
     * Enabling a service requires that the service is public or is shared with
     * the user enabling the service.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name?: string;
}
export interface EnableServiceRequestAminoMsg {
    type: "/google.api.serviceusage.v1.EnableServiceRequest";
    value: EnableServiceRequestAmino;
}
/** Request message for the `EnableService` method. */
export interface EnableServiceRequestSDKType {
    name: string;
}
/**
 * Response message for the `EnableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface EnableServiceResponse {
    /** The new state of the service after enabling. */
    service?: Service;
}
export interface EnableServiceResponseProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.EnableServiceResponse";
    value: Uint8Array;
}
/**
 * Response message for the `EnableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface EnableServiceResponseAmino {
    /** The new state of the service after enabling. */
    service?: ServiceAmino;
}
export interface EnableServiceResponseAminoMsg {
    type: "/google.api.serviceusage.v1.EnableServiceResponse";
    value: EnableServiceResponseAmino;
}
/**
 * Response message for the `EnableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface EnableServiceResponseSDKType {
    service?: ServiceSDKType;
}
/** Request message for the `DisableService` method. */
export interface DisableServiceRequest {
    /**
     * Name of the consumer and service to disable the service on.
     *
     * The enable and disable methods currently only support projects.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name: string;
    /**
     * Indicates if services that are enabled and which depend on this service
     * should also be disabled. If not set, an error will be generated if any
     * enabled services depend on the service to be disabled. When set, the
     * service, and any enabled services that depend on it, will be disabled
     * together.
     */
    disableDependentServices: boolean;
    /** Defines the behavior for checking service usage when disabling a service. */
    checkIfServiceHasUsage: DisableServiceRequest_CheckIfServiceHasUsage;
}
export interface DisableServiceRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.DisableServiceRequest";
    value: Uint8Array;
}
/** Request message for the `DisableService` method. */
export interface DisableServiceRequestAmino {
    /**
     * Name of the consumer and service to disable the service on.
     *
     * The enable and disable methods currently only support projects.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name?: string;
    /**
     * Indicates if services that are enabled and which depend on this service
     * should also be disabled. If not set, an error will be generated if any
     * enabled services depend on the service to be disabled. When set, the
     * service, and any enabled services that depend on it, will be disabled
     * together.
     */
    disable_dependent_services?: boolean;
    /** Defines the behavior for checking service usage when disabling a service. */
    check_if_service_has_usage?: DisableServiceRequest_CheckIfServiceHasUsage;
}
export interface DisableServiceRequestAminoMsg {
    type: "/google.api.serviceusage.v1.DisableServiceRequest";
    value: DisableServiceRequestAmino;
}
/** Request message for the `DisableService` method. */
export interface DisableServiceRequestSDKType {
    name: string;
    disable_dependent_services: boolean;
    check_if_service_has_usage: DisableServiceRequest_CheckIfServiceHasUsage;
}
/**
 * Response message for the `DisableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface DisableServiceResponse {
    /** The new state of the service after disabling. */
    service?: Service;
}
export interface DisableServiceResponseProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.DisableServiceResponse";
    value: Uint8Array;
}
/**
 * Response message for the `DisableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface DisableServiceResponseAmino {
    /** The new state of the service after disabling. */
    service?: ServiceAmino;
}
export interface DisableServiceResponseAminoMsg {
    type: "/google.api.serviceusage.v1.DisableServiceResponse";
    value: DisableServiceResponseAmino;
}
/**
 * Response message for the `DisableService` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface DisableServiceResponseSDKType {
    service?: ServiceSDKType;
}
/** Request message for the `GetService` method. */
export interface GetServiceRequest {
    /**
     * Name of the consumer and service to get the `ConsumerState` for.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name: string;
}
export interface GetServiceRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.GetServiceRequest";
    value: Uint8Array;
}
/** Request message for the `GetService` method. */
export interface GetServiceRequestAmino {
    /**
     * Name of the consumer and service to get the `ConsumerState` for.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     */
    name?: string;
}
export interface GetServiceRequestAminoMsg {
    type: "/google.api.serviceusage.v1.GetServiceRequest";
    value: GetServiceRequestAmino;
}
/** Request message for the `GetService` method. */
export interface GetServiceRequestSDKType {
    name: string;
}
/** Request message for the `ListServices` method. */
export interface ListServicesRequest {
    /**
     * Parent to search for services on.
     *
     * An example name would be:
     * `projects/123` where `123` is the project number.
     */
    parent: string;
    /**
     * Requested size of the next page of data.
     * Requested page size cannot exceed 200.
     * If not set, the default page size is 50.
     */
    pageSize: number;
    /**
     * Token identifying which result to start with, which is returned by a
     * previous list call.
     */
    pageToken: string;
    /**
     * Only list services that conform to the given filter.
     * The allowed filter strings are `state:ENABLED` and `state:DISABLED`.
     */
    filter: string;
}
export interface ListServicesRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.ListServicesRequest";
    value: Uint8Array;
}
/** Request message for the `ListServices` method. */
export interface ListServicesRequestAmino {
    /**
     * Parent to search for services on.
     *
     * An example name would be:
     * `projects/123` where `123` is the project number.
     */
    parent?: string;
    /**
     * Requested size of the next page of data.
     * Requested page size cannot exceed 200.
     * If not set, the default page size is 50.
     */
    page_size?: number;
    /**
     * Token identifying which result to start with, which is returned by a
     * previous list call.
     */
    page_token?: string;
    /**
     * Only list services that conform to the given filter.
     * The allowed filter strings are `state:ENABLED` and `state:DISABLED`.
     */
    filter?: string;
}
export interface ListServicesRequestAminoMsg {
    type: "/google.api.serviceusage.v1.ListServicesRequest";
    value: ListServicesRequestAmino;
}
/** Request message for the `ListServices` method. */
export interface ListServicesRequestSDKType {
    parent: string;
    page_size: number;
    page_token: string;
    filter: string;
}
/** Response message for the `ListServices` method. */
export interface ListServicesResponse {
    /** The available services for the requested project. */
    services: Service[];
    /**
     * Token that can be passed to `ListServices` to resume a paginated
     * query.
     */
    nextPageToken: string;
}
export interface ListServicesResponseProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.ListServicesResponse";
    value: Uint8Array;
}
/** Response message for the `ListServices` method. */
export interface ListServicesResponseAmino {
    /** The available services for the requested project. */
    services?: ServiceAmino[];
    /**
     * Token that can be passed to `ListServices` to resume a paginated
     * query.
     */
    next_page_token?: string;
}
export interface ListServicesResponseAminoMsg {
    type: "/google.api.serviceusage.v1.ListServicesResponse";
    value: ListServicesResponseAmino;
}
/** Response message for the `ListServices` method. */
export interface ListServicesResponseSDKType {
    services: ServiceSDKType[];
    next_page_token: string;
}
/** Request message for the `BatchEnableServices` method. */
export interface BatchEnableServicesRequest {
    /**
     * Parent to enable services on.
     *
     * An example name would be:
     * `projects/123` where `123` is the project number.
     *
     * The `BatchEnableServices` method currently only supports projects.
     */
    parent: string;
    /**
     * The identifiers of the services to enable on the project.
     *
     * A valid identifier would be:
     * serviceusage.googleapis.com
     *
     * Enabling services requires that each service is public or is shared with
     * the user enabling the service.
     *
     * A single request can enable a maximum of 20 services at a time. If more
     * than 20 services are specified, the request will fail, and no state changes
     * will occur.
     */
    serviceIds: string[];
}
export interface BatchEnableServicesRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesRequest";
    value: Uint8Array;
}
/** Request message for the `BatchEnableServices` method. */
export interface BatchEnableServicesRequestAmino {
    /**
     * Parent to enable services on.
     *
     * An example name would be:
     * `projects/123` where `123` is the project number.
     *
     * The `BatchEnableServices` method currently only supports projects.
     */
    parent?: string;
    /**
     * The identifiers of the services to enable on the project.
     *
     * A valid identifier would be:
     * serviceusage.googleapis.com
     *
     * Enabling services requires that each service is public or is shared with
     * the user enabling the service.
     *
     * A single request can enable a maximum of 20 services at a time. If more
     * than 20 services are specified, the request will fail, and no state changes
     * will occur.
     */
    service_ids?: string[];
}
export interface BatchEnableServicesRequestAminoMsg {
    type: "/google.api.serviceusage.v1.BatchEnableServicesRequest";
    value: BatchEnableServicesRequestAmino;
}
/** Request message for the `BatchEnableServices` method. */
export interface BatchEnableServicesRequestSDKType {
    parent: string;
    service_ids: string[];
}
/**
 * Response message for the `BatchEnableServices` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface BatchEnableServicesResponse {
    /** The new state of the services after enabling. */
    services: Service[];
    /**
     * If allow_partial_success is true, and one or more services could not be
     * enabled, this field contains the details about each failure.
     */
    failures: BatchEnableServicesResponse_EnableFailure[];
}
export interface BatchEnableServicesResponseProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.BatchEnableServicesResponse";
    value: Uint8Array;
}
/**
 * Response message for the `BatchEnableServices` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface BatchEnableServicesResponseAmino {
    /** The new state of the services after enabling. */
    services?: ServiceAmino[];
    /**
     * If allow_partial_success is true, and one or more services could not be
     * enabled, this field contains the details about each failure.
     */
    failures?: BatchEnableServicesResponse_EnableFailureAmino[];
}
export interface BatchEnableServicesResponseAminoMsg {
    type: "/google.api.serviceusage.v1.BatchEnableServicesResponse";
    value: BatchEnableServicesResponseAmino;
}
/**
 * Response message for the `BatchEnableServices` method.
 * This response message is assigned to the `response` field of the returned
 * Operation when that operation is done.
 */
export interface BatchEnableServicesResponseSDKType {
    services: ServiceSDKType[];
    failures: BatchEnableServicesResponse_EnableFailureSDKType[];
}
/** Provides error messages for the failing services. */
export interface BatchEnableServicesResponse_EnableFailure {
    /** The service id of a service that could not be enabled. */
    serviceId: string;
    /** An error message describing why the service could not be enabled. */
    errorMessage: string;
}
export interface BatchEnableServicesResponse_EnableFailureProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.EnableFailure";
    value: Uint8Array;
}
/** Provides error messages for the failing services. */
export interface BatchEnableServicesResponse_EnableFailureAmino {
    /** The service id of a service that could not be enabled. */
    service_id?: string;
    /** An error message describing why the service could not be enabled. */
    error_message?: string;
}
export interface BatchEnableServicesResponse_EnableFailureAminoMsg {
    type: "/google.api.serviceusage.v1.EnableFailure";
    value: BatchEnableServicesResponse_EnableFailureAmino;
}
/** Provides error messages for the failing services. */
export interface BatchEnableServicesResponse_EnableFailureSDKType {
    service_id: string;
    error_message: string;
}
/** Request message for the `BatchGetServices` method. */
export interface BatchGetServicesRequest {
    /**
     * Parent to retrieve services from.
     * If this is set, the parent of all of the services specified in `names` must
     * match this field. An example name would be: `projects/123` where `123` is
     * the project number. The `BatchGetServices` method currently only supports
     * projects.
     */
    parent: string;
    /**
     * Names of the services to retrieve.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     * A single request can get a maximum of 30 services at a time.
     */
    names: string[];
}
export interface BatchGetServicesRequestProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.BatchGetServicesRequest";
    value: Uint8Array;
}
/** Request message for the `BatchGetServices` method. */
export interface BatchGetServicesRequestAmino {
    /**
     * Parent to retrieve services from.
     * If this is set, the parent of all of the services specified in `names` must
     * match this field. An example name would be: `projects/123` where `123` is
     * the project number. The `BatchGetServices` method currently only supports
     * projects.
     */
    parent?: string;
    /**
     * Names of the services to retrieve.
     *
     * An example name would be:
     * `projects/123/services/serviceusage.googleapis.com` where `123` is the
     * project number.
     * A single request can get a maximum of 30 services at a time.
     */
    names?: string[];
}
export interface BatchGetServicesRequestAminoMsg {
    type: "/google.api.serviceusage.v1.BatchGetServicesRequest";
    value: BatchGetServicesRequestAmino;
}
/** Request message for the `BatchGetServices` method. */
export interface BatchGetServicesRequestSDKType {
    parent: string;
    names: string[];
}
/** Response message for the `BatchGetServices` method. */
export interface BatchGetServicesResponse {
    /** The requested Service states. */
    services: Service[];
}
export interface BatchGetServicesResponseProtoMsg {
    typeUrl: "/google.api.serviceusage.v1.BatchGetServicesResponse";
    value: Uint8Array;
}
/** Response message for the `BatchGetServices` method. */
export interface BatchGetServicesResponseAmino {
    /** The requested Service states. */
    services?: ServiceAmino[];
}
export interface BatchGetServicesResponseAminoMsg {
    type: "/google.api.serviceusage.v1.BatchGetServicesResponse";
    value: BatchGetServicesResponseAmino;
}
/** Response message for the `BatchGetServices` method. */
export interface BatchGetServicesResponseSDKType {
    services: ServiceSDKType[];
}
export declare const EnableServiceRequest: {
    typeUrl: string;
    is(o: any): o is EnableServiceRequest;
    isSDK(o: any): o is EnableServiceRequestSDKType;
    isAmino(o: any): o is EnableServiceRequestAmino;
    encode(message: EnableServiceRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EnableServiceRequest;
    fromJSON(object: any): EnableServiceRequest;
    toJSON(message: EnableServiceRequest): JsonSafe<EnableServiceRequest>;
    fromPartial(object: DeepPartial<EnableServiceRequest>): EnableServiceRequest;
    fromSDK(object: EnableServiceRequestSDKType): EnableServiceRequest;
    fromSDKJSON(object: any): EnableServiceRequestSDKType;
    toSDK(message: EnableServiceRequest): EnableServiceRequestSDKType;
    fromAmino(object: EnableServiceRequestAmino): EnableServiceRequest;
    toAmino(message: EnableServiceRequest): EnableServiceRequestAmino;
    fromAminoMsg(object: EnableServiceRequestAminoMsg): EnableServiceRequest;
    fromProtoMsg(message: EnableServiceRequestProtoMsg): EnableServiceRequest;
    toProto(message: EnableServiceRequest): Uint8Array;
    toProtoMsg(message: EnableServiceRequest): EnableServiceRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const EnableServiceResponse: {
    typeUrl: string;
    is(o: any): o is EnableServiceResponse;
    isSDK(o: any): o is EnableServiceResponseSDKType;
    isAmino(o: any): o is EnableServiceResponseAmino;
    encode(message: EnableServiceResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EnableServiceResponse;
    fromJSON(object: any): EnableServiceResponse;
    toJSON(message: EnableServiceResponse): JsonSafe<EnableServiceResponse>;
    fromPartial(object: DeepPartial<EnableServiceResponse>): EnableServiceResponse;
    fromSDK(object: EnableServiceResponseSDKType): EnableServiceResponse;
    fromSDKJSON(object: any): EnableServiceResponseSDKType;
    toSDK(message: EnableServiceResponse): EnableServiceResponseSDKType;
    fromAmino(object: EnableServiceResponseAmino): EnableServiceResponse;
    toAmino(message: EnableServiceResponse): EnableServiceResponseAmino;
    fromAminoMsg(object: EnableServiceResponseAminoMsg): EnableServiceResponse;
    fromProtoMsg(message: EnableServiceResponseProtoMsg): EnableServiceResponse;
    toProto(message: EnableServiceResponse): Uint8Array;
    toProtoMsg(message: EnableServiceResponse): EnableServiceResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const DisableServiceRequest: {
    typeUrl: string;
    is(o: any): o is DisableServiceRequest;
    isSDK(o: any): o is DisableServiceRequestSDKType;
    isAmino(o: any): o is DisableServiceRequestAmino;
    encode(message: DisableServiceRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DisableServiceRequest;
    fromJSON(object: any): DisableServiceRequest;
    toJSON(message: DisableServiceRequest): JsonSafe<DisableServiceRequest>;
    fromPartial(object: DeepPartial<DisableServiceRequest>): DisableServiceRequest;
    fromSDK(object: DisableServiceRequestSDKType): DisableServiceRequest;
    fromSDKJSON(object: any): DisableServiceRequestSDKType;
    toSDK(message: DisableServiceRequest): DisableServiceRequestSDKType;
    fromAmino(object: DisableServiceRequestAmino): DisableServiceRequest;
    toAmino(message: DisableServiceRequest): DisableServiceRequestAmino;
    fromAminoMsg(object: DisableServiceRequestAminoMsg): DisableServiceRequest;
    fromProtoMsg(message: DisableServiceRequestProtoMsg): DisableServiceRequest;
    toProto(message: DisableServiceRequest): Uint8Array;
    toProtoMsg(message: DisableServiceRequest): DisableServiceRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DisableServiceResponse: {
    typeUrl: string;
    is(o: any): o is DisableServiceResponse;
    isSDK(o: any): o is DisableServiceResponseSDKType;
    isAmino(o: any): o is DisableServiceResponseAmino;
    encode(message: DisableServiceResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DisableServiceResponse;
    fromJSON(object: any): DisableServiceResponse;
    toJSON(message: DisableServiceResponse): JsonSafe<DisableServiceResponse>;
    fromPartial(object: DeepPartial<DisableServiceResponse>): DisableServiceResponse;
    fromSDK(object: DisableServiceResponseSDKType): DisableServiceResponse;
    fromSDKJSON(object: any): DisableServiceResponseSDKType;
    toSDK(message: DisableServiceResponse): DisableServiceResponseSDKType;
    fromAmino(object: DisableServiceResponseAmino): DisableServiceResponse;
    toAmino(message: DisableServiceResponse): DisableServiceResponseAmino;
    fromAminoMsg(object: DisableServiceResponseAminoMsg): DisableServiceResponse;
    fromProtoMsg(message: DisableServiceResponseProtoMsg): DisableServiceResponse;
    toProto(message: DisableServiceResponse): Uint8Array;
    toProtoMsg(message: DisableServiceResponse): DisableServiceResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetServiceRequest: {
    typeUrl: string;
    is(o: any): o is GetServiceRequest;
    isSDK(o: any): o is GetServiceRequestSDKType;
    isAmino(o: any): o is GetServiceRequestAmino;
    encode(message: GetServiceRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetServiceRequest;
    fromJSON(object: any): GetServiceRequest;
    toJSON(message: GetServiceRequest): JsonSafe<GetServiceRequest>;
    fromPartial(object: DeepPartial<GetServiceRequest>): GetServiceRequest;
    fromSDK(object: GetServiceRequestSDKType): GetServiceRequest;
    fromSDKJSON(object: any): GetServiceRequestSDKType;
    toSDK(message: GetServiceRequest): GetServiceRequestSDKType;
    fromAmino(object: GetServiceRequestAmino): GetServiceRequest;
    toAmino(message: GetServiceRequest): GetServiceRequestAmino;
    fromAminoMsg(object: GetServiceRequestAminoMsg): GetServiceRequest;
    fromProtoMsg(message: GetServiceRequestProtoMsg): GetServiceRequest;
    toProto(message: GetServiceRequest): Uint8Array;
    toProtoMsg(message: GetServiceRequest): GetServiceRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListServicesRequest: {
    typeUrl: string;
    is(o: any): o is ListServicesRequest;
    isSDK(o: any): o is ListServicesRequestSDKType;
    isAmino(o: any): o is ListServicesRequestAmino;
    encode(message: ListServicesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListServicesRequest;
    fromJSON(object: any): ListServicesRequest;
    toJSON(message: ListServicesRequest): JsonSafe<ListServicesRequest>;
    fromPartial(object: DeepPartial<ListServicesRequest>): ListServicesRequest;
    fromSDK(object: ListServicesRequestSDKType): ListServicesRequest;
    fromSDKJSON(object: any): ListServicesRequestSDKType;
    toSDK(message: ListServicesRequest): ListServicesRequestSDKType;
    fromAmino(object: ListServicesRequestAmino): ListServicesRequest;
    toAmino(message: ListServicesRequest): ListServicesRequestAmino;
    fromAminoMsg(object: ListServicesRequestAminoMsg): ListServicesRequest;
    fromProtoMsg(message: ListServicesRequestProtoMsg): ListServicesRequest;
    toProto(message: ListServicesRequest): Uint8Array;
    toProtoMsg(message: ListServicesRequest): ListServicesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListServicesResponse: {
    typeUrl: string;
    is(o: any): o is ListServicesResponse;
    isSDK(o: any): o is ListServicesResponseSDKType;
    isAmino(o: any): o is ListServicesResponseAmino;
    encode(message: ListServicesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListServicesResponse;
    fromJSON(object: any): ListServicesResponse;
    toJSON(message: ListServicesResponse): JsonSafe<ListServicesResponse>;
    fromPartial(object: DeepPartial<ListServicesResponse>): ListServicesResponse;
    fromSDK(object: ListServicesResponseSDKType): ListServicesResponse;
    fromSDKJSON(object: any): ListServicesResponseSDKType;
    toSDK(message: ListServicesResponse): ListServicesResponseSDKType;
    fromAmino(object: ListServicesResponseAmino): ListServicesResponse;
    toAmino(message: ListServicesResponse): ListServicesResponseAmino;
    fromAminoMsg(object: ListServicesResponseAminoMsg): ListServicesResponse;
    fromProtoMsg(message: ListServicesResponseProtoMsg): ListServicesResponse;
    toProto(message: ListServicesResponse): Uint8Array;
    toProtoMsg(message: ListServicesResponse): ListServicesResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const BatchEnableServicesRequest: {
    typeUrl: string;
    is(o: any): o is BatchEnableServicesRequest;
    isSDK(o: any): o is BatchEnableServicesRequestSDKType;
    isAmino(o: any): o is BatchEnableServicesRequestAmino;
    encode(message: BatchEnableServicesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BatchEnableServicesRequest;
    fromJSON(object: any): BatchEnableServicesRequest;
    toJSON(message: BatchEnableServicesRequest): JsonSafe<BatchEnableServicesRequest>;
    fromPartial(object: DeepPartial<BatchEnableServicesRequest>): BatchEnableServicesRequest;
    fromSDK(object: BatchEnableServicesRequestSDKType): BatchEnableServicesRequest;
    fromSDKJSON(object: any): BatchEnableServicesRequestSDKType;
    toSDK(message: BatchEnableServicesRequest): BatchEnableServicesRequestSDKType;
    fromAmino(object: BatchEnableServicesRequestAmino): BatchEnableServicesRequest;
    toAmino(message: BatchEnableServicesRequest): BatchEnableServicesRequestAmino;
    fromAminoMsg(object: BatchEnableServicesRequestAminoMsg): BatchEnableServicesRequest;
    fromProtoMsg(message: BatchEnableServicesRequestProtoMsg): BatchEnableServicesRequest;
    toProto(message: BatchEnableServicesRequest): Uint8Array;
    toProtoMsg(message: BatchEnableServicesRequest): BatchEnableServicesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const BatchEnableServicesResponse: {
    typeUrl: string;
    is(o: any): o is BatchEnableServicesResponse;
    isSDK(o: any): o is BatchEnableServicesResponseSDKType;
    isAmino(o: any): o is BatchEnableServicesResponseAmino;
    encode(message: BatchEnableServicesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BatchEnableServicesResponse;
    fromJSON(object: any): BatchEnableServicesResponse;
    toJSON(message: BatchEnableServicesResponse): JsonSafe<BatchEnableServicesResponse>;
    fromPartial(object: DeepPartial<BatchEnableServicesResponse>): BatchEnableServicesResponse;
    fromSDK(object: BatchEnableServicesResponseSDKType): BatchEnableServicesResponse;
    fromSDKJSON(object: any): BatchEnableServicesResponseSDKType;
    toSDK(message: BatchEnableServicesResponse): BatchEnableServicesResponseSDKType;
    fromAmino(object: BatchEnableServicesResponseAmino): BatchEnableServicesResponse;
    toAmino(message: BatchEnableServicesResponse): BatchEnableServicesResponseAmino;
    fromAminoMsg(object: BatchEnableServicesResponseAminoMsg): BatchEnableServicesResponse;
    fromProtoMsg(message: BatchEnableServicesResponseProtoMsg): BatchEnableServicesResponse;
    toProto(message: BatchEnableServicesResponse): Uint8Array;
    toProtoMsg(message: BatchEnableServicesResponse): BatchEnableServicesResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const BatchEnableServicesResponse_EnableFailure: {
    typeUrl: string;
    is(o: any): o is BatchEnableServicesResponse_EnableFailure;
    isSDK(o: any): o is BatchEnableServicesResponse_EnableFailureSDKType;
    isAmino(o: any): o is BatchEnableServicesResponse_EnableFailureAmino;
    encode(message: BatchEnableServicesResponse_EnableFailure, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BatchEnableServicesResponse_EnableFailure;
    fromJSON(object: any): BatchEnableServicesResponse_EnableFailure;
    toJSON(message: BatchEnableServicesResponse_EnableFailure): JsonSafe<BatchEnableServicesResponse_EnableFailure>;
    fromPartial(object: DeepPartial<BatchEnableServicesResponse_EnableFailure>): BatchEnableServicesResponse_EnableFailure;
    fromSDK(object: BatchEnableServicesResponse_EnableFailureSDKType): BatchEnableServicesResponse_EnableFailure;
    fromSDKJSON(object: any): BatchEnableServicesResponse_EnableFailureSDKType;
    toSDK(message: BatchEnableServicesResponse_EnableFailure): BatchEnableServicesResponse_EnableFailureSDKType;
    fromAmino(object: BatchEnableServicesResponse_EnableFailureAmino): BatchEnableServicesResponse_EnableFailure;
    toAmino(message: BatchEnableServicesResponse_EnableFailure): BatchEnableServicesResponse_EnableFailureAmino;
    fromAminoMsg(object: BatchEnableServicesResponse_EnableFailureAminoMsg): BatchEnableServicesResponse_EnableFailure;
    fromProtoMsg(message: BatchEnableServicesResponse_EnableFailureProtoMsg): BatchEnableServicesResponse_EnableFailure;
    toProto(message: BatchEnableServicesResponse_EnableFailure): Uint8Array;
    toProtoMsg(message: BatchEnableServicesResponse_EnableFailure): BatchEnableServicesResponse_EnableFailureProtoMsg;
    registerTypeUrl(): void;
};
export declare const BatchGetServicesRequest: {
    typeUrl: string;
    is(o: any): o is BatchGetServicesRequest;
    isSDK(o: any): o is BatchGetServicesRequestSDKType;
    isAmino(o: any): o is BatchGetServicesRequestAmino;
    encode(message: BatchGetServicesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BatchGetServicesRequest;
    fromJSON(object: any): BatchGetServicesRequest;
    toJSON(message: BatchGetServicesRequest): JsonSafe<BatchGetServicesRequest>;
    fromPartial(object: DeepPartial<BatchGetServicesRequest>): BatchGetServicesRequest;
    fromSDK(object: BatchGetServicesRequestSDKType): BatchGetServicesRequest;
    fromSDKJSON(object: any): BatchGetServicesRequestSDKType;
    toSDK(message: BatchGetServicesRequest): BatchGetServicesRequestSDKType;
    fromAmino(object: BatchGetServicesRequestAmino): BatchGetServicesRequest;
    toAmino(message: BatchGetServicesRequest): BatchGetServicesRequestAmino;
    fromAminoMsg(object: BatchGetServicesRequestAminoMsg): BatchGetServicesRequest;
    fromProtoMsg(message: BatchGetServicesRequestProtoMsg): BatchGetServicesRequest;
    toProto(message: BatchGetServicesRequest): Uint8Array;
    toProtoMsg(message: BatchGetServicesRequest): BatchGetServicesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const BatchGetServicesResponse: {
    typeUrl: string;
    is(o: any): o is BatchGetServicesResponse;
    isSDK(o: any): o is BatchGetServicesResponseSDKType;
    isAmino(o: any): o is BatchGetServicesResponseAmino;
    encode(message: BatchGetServicesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BatchGetServicesResponse;
    fromJSON(object: any): BatchGetServicesResponse;
    toJSON(message: BatchGetServicesResponse): JsonSafe<BatchGetServicesResponse>;
    fromPartial(object: DeepPartial<BatchGetServicesResponse>): BatchGetServicesResponse;
    fromSDK(object: BatchGetServicesResponseSDKType): BatchGetServicesResponse;
    fromSDKJSON(object: any): BatchGetServicesResponseSDKType;
    toSDK(message: BatchGetServicesResponse): BatchGetServicesResponseSDKType;
    fromAmino(object: BatchGetServicesResponseAmino): BatchGetServicesResponse;
    toAmino(message: BatchGetServicesResponse): BatchGetServicesResponseAmino;
    fromAminoMsg(object: BatchGetServicesResponseAminoMsg): BatchGetServicesResponse;
    fromProtoMsg(message: BatchGetServicesResponseProtoMsg): BatchGetServicesResponse;
    toProto(message: BatchGetServicesResponse): Uint8Array;
    toProtoMsg(message: BatchGetServicesResponse): BatchGetServicesResponseProtoMsg;
    registerTypeUrl(): void;
};
