import { Api, ApiAmino, ApiSDKType } from "../../../protobuf/api";
import { Documentation, DocumentationAmino, DocumentationSDKType } from "../../documentation";
import { Quota, QuotaAmino, QuotaSDKType } from "../../quota";
import { Authentication, AuthenticationAmino, AuthenticationSDKType } from "../../auth";
import { Usage, UsageAmino, UsageSDKType } from "../../usage";
import { Endpoint, EndpointAmino, EndpointSDKType } from "../../endpoint";
import { MonitoredResourceDescriptor, MonitoredResourceDescriptorAmino, MonitoredResourceDescriptorSDKType } from "../../monitored_resource";
import { Monitoring, MonitoringAmino, MonitoringSDKType } from "../../monitoring";
import { DeepPartial } from "../../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { JsonSafe } from "../../../../json-safe";
export declare const protobufPackage = "google.api.serviceusage.v1beta1";
/** Whether or not a service has been enabled for use by a consumer. */
export declare enum State {
    /**
     * STATE_UNSPECIFIED - The default value, which indicates that the enabled state of the service
     * is unspecified or not meaningful. Currently, all consumers other than
     * projects (such as folders and organizations) are always in this state.
     */
    STATE_UNSPECIFIED = 0,
    /**
     * DISABLED - The service cannot be used by this consumer. It has either been explicitly
     * disabled, or has never been enabled.
     */
    DISABLED = 1,
    /** ENABLED - The service has been explicitly enabled for use by this consumer. */
    ENABLED = 2,
    UNRECOGNIZED = -1
}
export declare const StateSDKType: typeof State;
export declare const StateAmino: typeof State;
export declare function stateFromJSON(object: any): State;
export declare function stateToJSON(object: State): string;
/**
 * Selected view of quota. Can be used to request more detailed quota
 * information when retrieving quota metrics and limits.
 */
export declare enum QuotaView {
    /**
     * QUOTA_VIEW_UNSPECIFIED - No quota view specified. Requests that do not specify a quota view will
     * typically default to the BASIC view.
     */
    QUOTA_VIEW_UNSPECIFIED = 0,
    /** BASIC - Only buckets with overrides are shown in the response. */
    BASIC = 1,
    /**
     * FULL - Include per-location buckets even if they do not have overrides.
     * When the view is FULL, and a limit has regional or zonal quota, the limit
     * will include buckets for all regions or zones that could support
     * overrides, even if none are currently present. In some cases this will
     * cause the response to become very large; callers that do not need this
     * extra information should use the BASIC view instead.
     */
    FULL = 2,
    UNRECOGNIZED = -1
}
export declare const QuotaViewSDKType: typeof QuotaView;
export declare const QuotaViewAmino: typeof QuotaView;
export declare function quotaViewFromJSON(object: any): QuotaView;
export declare function quotaViewToJSON(object: QuotaView): string;
/** Enumerations of quota safety checks. */
export declare enum QuotaSafetyCheck {
    /** QUOTA_SAFETY_CHECK_UNSPECIFIED - Unspecified quota safety check. */
    QUOTA_SAFETY_CHECK_UNSPECIFIED = 0,
    /**
     * LIMIT_DECREASE_BELOW_USAGE - Validates that a quota mutation would not cause the consumer's effective
     * limit to be lower than the consumer's quota usage.
     */
    LIMIT_DECREASE_BELOW_USAGE = 1,
    /**
     * LIMIT_DECREASE_PERCENTAGE_TOO_HIGH - Validates that a quota mutation would not cause the consumer's effective
     * limit to decrease by more than 10 percent.
     */
    LIMIT_DECREASE_PERCENTAGE_TOO_HIGH = 2,
    UNRECOGNIZED = -1
}
export declare const QuotaSafetyCheckSDKType: typeof QuotaSafetyCheck;
export declare const QuotaSafetyCheckAmino: typeof QuotaSafetyCheck;
export declare function quotaSafetyCheckFromJSON(object: any): QuotaSafetyCheck;
export declare function quotaSafetyCheckToJSON(object: QuotaSafetyCheck): string;
/** A service that is available for use by the consumer. */
export interface Service {
    /**
     * The resource name of the consumer and service.
     *
     * A valid name would be:
     * - `projects/123/services/serviceusage.googleapis.com`
     */
    name: string;
    /**
     * The resource name of the consumer.
     *
     * A valid name would be:
     * - `projects/123`
     */
    parent: string;
    /**
     * The service configuration of the available service.
     * Some fields may be filtered out of the configuration in responses to
     * the `ListServices` method. These fields are present only in responses to
     * the `GetService` method.
     */
    config?: ServiceConfig;
    /** Whether or not the service has been enabled for use by the consumer. */
    state: State;
}
export interface ServiceProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.Service";
    value: Uint8Array;
}
/** A service that is available for use by the consumer. */
export interface ServiceAmino {
    /**
     * The resource name of the consumer and service.
     *
     * A valid name would be:
     * - `projects/123/services/serviceusage.googleapis.com`
     */
    name?: string;
    /**
     * The resource name of the consumer.
     *
     * A valid name would be:
     * - `projects/123`
     */
    parent?: string;
    /**
     * The service configuration of the available service.
     * Some fields may be filtered out of the configuration in responses to
     * the `ListServices` method. These fields are present only in responses to
     * the `GetService` method.
     */
    config?: ServiceConfigAmino;
    /** Whether or not the service has been enabled for use by the consumer. */
    state?: State;
}
export interface ServiceAminoMsg {
    type: "/google.api.serviceusage.v1beta1.Service";
    value: ServiceAmino;
}
/** A service that is available for use by the consumer. */
export interface ServiceSDKType {
    name: string;
    parent: string;
    config?: ServiceConfigSDKType;
    state: State;
}
/** The configuration of the service. */
export interface ServiceConfig {
    /**
     * The DNS address at which this service is available.
     *
     * An example DNS address would be:
     * `calendar.googleapis.com`.
     */
    name: string;
    /** The product title for this service. */
    title: string;
    /**
     * A list of API interfaces exported by this service. Contains only the names,
     * versions, and method names of the interfaces.
     */
    apis: Api[];
    /**
     * Additional API documentation. Contains only the summary and the
     * documentation URL.
     */
    documentation?: Documentation;
    /** Quota configuration. */
    quota?: Quota;
    /** Auth configuration. Contains only the OAuth rules. */
    authentication?: Authentication;
    /** Configuration controlling usage of this service. */
    usage?: Usage;
    /**
     * Configuration for network endpoints. Contains only the names and aliases
     * of the endpoints.
     */
    endpoints: Endpoint[];
    /**
     * Defines the monitored resources used by this service. This is required
     * by the [Service.monitoring][google.api.Service.monitoring] and [Service.logging][google.api.Service.logging] configurations.
     */
    monitoredResources: MonitoredResourceDescriptor[];
    /**
     * Monitoring configuration.
     * This should not include the 'producer_destinations' field.
     */
    monitoring?: Monitoring;
}
export interface ServiceConfigProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.ServiceConfig";
    value: Uint8Array;
}
/** The configuration of the service. */
export interface ServiceConfigAmino {
    /**
     * The DNS address at which this service is available.
     *
     * An example DNS address would be:
     * `calendar.googleapis.com`.
     */
    name?: string;
    /** The product title for this service. */
    title?: string;
    /**
     * A list of API interfaces exported by this service. Contains only the names,
     * versions, and method names of the interfaces.
     */
    apis?: ApiAmino[];
    /**
     * Additional API documentation. Contains only the summary and the
     * documentation URL.
     */
    documentation?: DocumentationAmino;
    /** Quota configuration. */
    quota?: QuotaAmino;
    /** Auth configuration. Contains only the OAuth rules. */
    authentication?: AuthenticationAmino;
    /** Configuration controlling usage of this service. */
    usage?: UsageAmino;
    /**
     * Configuration for network endpoints. Contains only the names and aliases
     * of the endpoints.
     */
    endpoints?: EndpointAmino[];
    /**
     * Defines the monitored resources used by this service. This is required
     * by the [Service.monitoring][google.api.Service.monitoring] and [Service.logging][google.api.Service.logging] configurations.
     */
    monitored_resources?: MonitoredResourceDescriptorAmino[];
    /**
     * Monitoring configuration.
     * This should not include the 'producer_destinations' field.
     */
    monitoring?: MonitoringAmino;
}
export interface ServiceConfigAminoMsg {
    type: "/google.api.serviceusage.v1beta1.ServiceConfig";
    value: ServiceConfigAmino;
}
/** The configuration of the service. */
export interface ServiceConfigSDKType {
    name: string;
    title: string;
    apis: ApiSDKType[];
    documentation?: DocumentationSDKType;
    quota?: QuotaSDKType;
    authentication?: AuthenticationSDKType;
    usage?: UsageSDKType;
    endpoints: EndpointSDKType[];
    monitored_resources: MonitoredResourceDescriptorSDKType[];
    monitoring?: MonitoringSDKType;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadata {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resourceNames: string[];
}
export interface OperationMetadataProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.OperationMetadata";
    value: Uint8Array;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadataAmino {
    /**
     * The full name of the resources that this operation is directly
     * associated with.
     */
    resource_names?: string[];
}
export interface OperationMetadataAminoMsg {
    type: "/google.api.serviceusage.v1beta1.OperationMetadata";
    value: OperationMetadataAmino;
}
/** The operation metadata returned for the batchend services operation. */
export interface OperationMetadataSDKType {
    resource_names: string[];
}
/** Consumer quota settings for a quota metric. */
export interface ConsumerQuotaMetric {
    /**
     * The resource name of the quota settings on this metric for this consumer.
     *
     * An example name would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name: string;
    /**
     * The name of the metric.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric: string;
    /**
     * The display name of the metric.
     *
     * An example name would be:
     * `CPUs`
     */
    displayName: string;
    /** The consumer quota for each quota limit defined on the metric. */
    consumerQuotaLimits: ConsumerQuotaLimit[];
    /**
     * The quota limits targeting the descendant containers of the
     * consumer in request.
     *
     * If the consumer in request is of type `organizations`
     * or `folders`, the field will list per-project limits in the metric; if the
     * consumer in request is of type `project`, the field will be empty.
     *
     * The `quota_buckets` field of each descendant consumer quota limit will not
     * be populated.
     */
    descendantConsumerQuotaLimits: ConsumerQuotaLimit[];
    /** The units in which the metric value is reported. */
    unit: string;
}
export interface ConsumerQuotaMetricProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaMetric";
    value: Uint8Array;
}
/** Consumer quota settings for a quota metric. */
export interface ConsumerQuotaMetricAmino {
    /**
     * The resource name of the quota settings on this metric for this consumer.
     *
     * An example name would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name?: string;
    /**
     * The name of the metric.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric?: string;
    /**
     * The display name of the metric.
     *
     * An example name would be:
     * `CPUs`
     */
    display_name?: string;
    /** The consumer quota for each quota limit defined on the metric. */
    consumer_quota_limits?: ConsumerQuotaLimitAmino[];
    /**
     * The quota limits targeting the descendant containers of the
     * consumer in request.
     *
     * If the consumer in request is of type `organizations`
     * or `folders`, the field will list per-project limits in the metric; if the
     * consumer in request is of type `project`, the field will be empty.
     *
     * The `quota_buckets` field of each descendant consumer quota limit will not
     * be populated.
     */
    descendant_consumer_quota_limits?: ConsumerQuotaLimitAmino[];
    /** The units in which the metric value is reported. */
    unit?: string;
}
export interface ConsumerQuotaMetricAminoMsg {
    type: "/google.api.serviceusage.v1beta1.ConsumerQuotaMetric";
    value: ConsumerQuotaMetricAmino;
}
/** Consumer quota settings for a quota metric. */
export interface ConsumerQuotaMetricSDKType {
    name: string;
    metric: string;
    display_name: string;
    consumer_quota_limits: ConsumerQuotaLimitSDKType[];
    descendant_consumer_quota_limits: ConsumerQuotaLimitSDKType[];
    unit: string;
}
/** Consumer quota settings for a quota limit. */
export interface ConsumerQuotaLimit {
    /**
     * The resource name of the quota limit.
     *
     * An example name would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name: string;
    /**
     * The name of the parent metric of this limit.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric: string;
    /**
     * The limit unit.
     *
     * An example unit would be
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit: string;
    /** Whether this limit is precise or imprecise. */
    isPrecise: boolean;
    /** Whether admin overrides are allowed on this limit */
    allowsAdminOverrides: boolean;
    /**
     * Summary of the enforced quota buckets, organized by quota dimension,
     * ordered from least specific to most specific (for example, the global
     * default bucket, with no quota dimensions, will always appear first).
     */
    quotaBuckets: QuotaBucket[];
}
export interface ConsumerQuotaLimitProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.ConsumerQuotaLimit";
    value: Uint8Array;
}
/** Consumer quota settings for a quota limit. */
export interface ConsumerQuotaLimitAmino {
    /**
     * The resource name of the quota limit.
     *
     * An example name would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name?: string;
    /**
     * The name of the parent metric of this limit.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric?: string;
    /**
     * The limit unit.
     *
     * An example unit would be
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit?: string;
    /** Whether this limit is precise or imprecise. */
    is_precise?: boolean;
    /** Whether admin overrides are allowed on this limit */
    allows_admin_overrides?: boolean;
    /**
     * Summary of the enforced quota buckets, organized by quota dimension,
     * ordered from least specific to most specific (for example, the global
     * default bucket, with no quota dimensions, will always appear first).
     */
    quota_buckets?: QuotaBucketAmino[];
}
export interface ConsumerQuotaLimitAminoMsg {
    type: "/google.api.serviceusage.v1beta1.ConsumerQuotaLimit";
    value: ConsumerQuotaLimitAmino;
}
/** Consumer quota settings for a quota limit. */
export interface ConsumerQuotaLimitSDKType {
    name: string;
    metric: string;
    unit: string;
    is_precise: boolean;
    allows_admin_overrides: boolean;
    quota_buckets: QuotaBucketSDKType[];
}
export interface QuotaBucket_DimensionsEntry {
    key: string;
    value: string;
}
export interface QuotaBucket_DimensionsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface QuotaBucket_DimensionsEntryAmino {
    key?: string;
    value?: string;
}
export interface QuotaBucket_DimensionsEntryAminoMsg {
    type: string;
    value: QuotaBucket_DimensionsEntryAmino;
}
export interface QuotaBucket_DimensionsEntrySDKType {
    key: string;
    value: string;
}
/** A quota bucket is a quota provisioning unit for a specific set of dimensions. */
export interface QuotaBucket {
    /**
     * The effective limit of this quota bucket. Equal to default_limit if there
     * are no overrides.
     */
    effectiveLimit: bigint;
    /**
     * The default limit of this quota bucket, as specified by the service
     * configuration.
     */
    defaultLimit: bigint;
    /** Producer override on this quota bucket. */
    producerOverride?: QuotaOverride;
    /** Consumer override on this quota bucket. */
    consumerOverride?: QuotaOverride;
    /** Admin override on this quota bucket. */
    adminOverride?: QuotaOverride;
    /**
     * The dimensions of this quota bucket.
     *
     * If this map is empty, this is the global bucket, which is the default quota
     * value applied to all requests that do not have a more specific override.
     *
     * If this map is nonempty, the default limit, effective limit, and quota
     * overrides apply only to requests that have the dimensions given in the map.
     *
     * For example, if the map has key `region` and value `us-east-1`, then the
     * specified effective limit is only effective in that region, and the
     * specified overrides apply only in that region.
     */
    dimensions: {
        [key: string]: string;
    };
}
export interface QuotaBucketProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.QuotaBucket";
    value: Uint8Array;
}
/** A quota bucket is a quota provisioning unit for a specific set of dimensions. */
export interface QuotaBucketAmino {
    /**
     * The effective limit of this quota bucket. Equal to default_limit if there
     * are no overrides.
     */
    effective_limit?: string;
    /**
     * The default limit of this quota bucket, as specified by the service
     * configuration.
     */
    default_limit?: string;
    /** Producer override on this quota bucket. */
    producer_override?: QuotaOverrideAmino;
    /** Consumer override on this quota bucket. */
    consumer_override?: QuotaOverrideAmino;
    /** Admin override on this quota bucket. */
    admin_override?: QuotaOverrideAmino;
    /**
     * The dimensions of this quota bucket.
     *
     * If this map is empty, this is the global bucket, which is the default quota
     * value applied to all requests that do not have a more specific override.
     *
     * If this map is nonempty, the default limit, effective limit, and quota
     * overrides apply only to requests that have the dimensions given in the map.
     *
     * For example, if the map has key `region` and value `us-east-1`, then the
     * specified effective limit is only effective in that region, and the
     * specified overrides apply only in that region.
     */
    dimensions?: {
        [key: string]: string;
    };
}
export interface QuotaBucketAminoMsg {
    type: "/google.api.serviceusage.v1beta1.QuotaBucket";
    value: QuotaBucketAmino;
}
/** A quota bucket is a quota provisioning unit for a specific set of dimensions. */
export interface QuotaBucketSDKType {
    effective_limit: bigint;
    default_limit: bigint;
    producer_override?: QuotaOverrideSDKType;
    consumer_override?: QuotaOverrideSDKType;
    admin_override?: QuotaOverrideSDKType;
    dimensions: {
        [key: string]: string;
    };
}
export interface QuotaOverride_DimensionsEntry {
    key: string;
    value: string;
}
export interface QuotaOverride_DimensionsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface QuotaOverride_DimensionsEntryAmino {
    key?: string;
    value?: string;
}
export interface QuotaOverride_DimensionsEntryAminoMsg {
    type: string;
    value: QuotaOverride_DimensionsEntryAmino;
}
export interface QuotaOverride_DimensionsEntrySDKType {
    key: string;
    value: string;
}
/** A quota override */
export interface QuotaOverride {
    /**
     * The resource name of the override.
     * This name is generated by the server when the override is created.
     *
     * Example names would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d`
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name: string;
    /**
     * The overriding quota limit value.
     * Can be any nonnegative integer, or -1 (unlimited quota).
     */
    overrideValue: bigint;
    /**
     * If this map is nonempty, then this override applies only to specific values
     * for dimensions defined in the limit unit.
     *
     * For example, an override on a limit with the unit `1/{project}/{region}`
     * could contain an entry with the key `region` and the value `us-east-1`;
     * the override is only applied to quota consumed in that region.
     *
     * This map has the following restrictions:
     *
     * *   Keys that are not defined in the limit's unit are not valid keys.
     *     Any string appearing in `{brackets}` in the unit (besides `{project}`
     *     or
     *     `{user}`) is a defined key.
     * *   `project` is not a valid key; the project is already specified in
     *     the parent resource name.
     * *   `user` is not a valid key; the API does not support quota overrides
     *     that apply only to a specific user.
     * *   If `region` appears as a key, its value must be a valid Cloud region.
     * *   If `zone` appears as a key, its value must be a valid Cloud zone.
     * *   If any valid key other than `region` or `zone` appears in the map, then
     *     all valid keys other than `region` or `zone` must also appear in the
     *     map.
     */
    dimensions: {
        [key: string]: string;
    };
    /**
     * The name of the metric to which this override applies.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric: string;
    /**
     * The limit unit of the limit to which this override applies.
     *
     * An example unit would be:
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit: string;
    /**
     * The resource name of the ancestor that requested the override. For example:
     * `organizations/12345` or `folders/67890`.
     * Used by admin overrides only.
     */
    adminOverrideAncestor: string;
}
export interface QuotaOverrideProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.QuotaOverride";
    value: Uint8Array;
}
/** A quota override */
export interface QuotaOverrideAmino {
    /**
     * The resource name of the override.
     * This name is generated by the server when the override is created.
     *
     * Example names would be:
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminOverrides/4a3f2c1d`
     * `projects/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/consumerOverrides/4a3f2c1d`
     *
     * The resource name is intended to be opaque and should not be parsed for
     * its component strings, since its representation could change in the future.
     */
    name?: string;
    /**
     * The overriding quota limit value.
     * Can be any nonnegative integer, or -1 (unlimited quota).
     */
    override_value?: string;
    /**
     * If this map is nonempty, then this override applies only to specific values
     * for dimensions defined in the limit unit.
     *
     * For example, an override on a limit with the unit `1/{project}/{region}`
     * could contain an entry with the key `region` and the value `us-east-1`;
     * the override is only applied to quota consumed in that region.
     *
     * This map has the following restrictions:
     *
     * *   Keys that are not defined in the limit's unit are not valid keys.
     *     Any string appearing in `{brackets}` in the unit (besides `{project}`
     *     or
     *     `{user}`) is a defined key.
     * *   `project` is not a valid key; the project is already specified in
     *     the parent resource name.
     * *   `user` is not a valid key; the API does not support quota overrides
     *     that apply only to a specific user.
     * *   If `region` appears as a key, its value must be a valid Cloud region.
     * *   If `zone` appears as a key, its value must be a valid Cloud zone.
     * *   If any valid key other than `region` or `zone` appears in the map, then
     *     all valid keys other than `region` or `zone` must also appear in the
     *     map.
     */
    dimensions?: {
        [key: string]: string;
    };
    /**
     * The name of the metric to which this override applies.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric?: string;
    /**
     * The limit unit of the limit to which this override applies.
     *
     * An example unit would be:
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit?: string;
    /**
     * The resource name of the ancestor that requested the override. For example:
     * `organizations/12345` or `folders/67890`.
     * Used by admin overrides only.
     */
    admin_override_ancestor?: string;
}
export interface QuotaOverrideAminoMsg {
    type: "/google.api.serviceusage.v1beta1.QuotaOverride";
    value: QuotaOverrideAmino;
}
/** A quota override */
export interface QuotaOverrideSDKType {
    name: string;
    override_value: bigint;
    dimensions: {
        [key: string]: string;
    };
    metric: string;
    unit: string;
    admin_override_ancestor: string;
}
/** Import data embedded in the request message */
export interface OverrideInlineSource {
    /**
     * The overrides to create.
     * Each override must have a value for 'metric' and 'unit', to specify
     * which metric and which limit the override should be applied to.
     * The 'name' field of the override does not need to be set; it is ignored.
     */
    overrides: QuotaOverride[];
}
export interface OverrideInlineSourceProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.OverrideInlineSource";
    value: Uint8Array;
}
/** Import data embedded in the request message */
export interface OverrideInlineSourceAmino {
    /**
     * The overrides to create.
     * Each override must have a value for 'metric' and 'unit', to specify
     * which metric and which limit the override should be applied to.
     * The 'name' field of the override does not need to be set; it is ignored.
     */
    overrides?: QuotaOverrideAmino[];
}
export interface OverrideInlineSourceAminoMsg {
    type: "/google.api.serviceusage.v1beta1.OverrideInlineSource";
    value: OverrideInlineSourceAmino;
}
/** Import data embedded in the request message */
export interface OverrideInlineSourceSDKType {
    overrides: QuotaOverrideSDKType[];
}
export interface AdminQuotaPolicy_DimensionsEntry {
    key: string;
    value: string;
}
export interface AdminQuotaPolicy_DimensionsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface AdminQuotaPolicy_DimensionsEntryAmino {
    key?: string;
    value?: string;
}
export interface AdminQuotaPolicy_DimensionsEntryAminoMsg {
    type: string;
    value: AdminQuotaPolicy_DimensionsEntryAmino;
}
export interface AdminQuotaPolicy_DimensionsEntrySDKType {
    key: string;
    value: string;
}
/** Quota policy created by quota administrator. */
export interface AdminQuotaPolicy {
    /**
     * The resource name of the policy.
     * This name is generated by the server when the policy is created.
     *
     * Example names would be:
     * `organizations/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminQuotaPolicies/4a3f2c1d`
     */
    name: string;
    /**
     * The quota policy value.
     * Can be any nonnegative integer, or -1 (unlimited quota).
     */
    policyValue: bigint;
    /**
     * If this map is nonempty, then this policy applies only to specific values
     * for dimensions defined in the limit unit.
     *
     * For example, an policy on a limit with the unit `1/{project}/{region}`
     * could contain an entry with the key `region` and the value `us-east-1`;
     * the policy is only applied to quota consumed in that region.
     *
     * This map has the following restrictions:
     *
     * *   If `region` appears as a key, its value must be a valid Cloud region.
     * *   If `zone` appears as a key, its value must be a valid Cloud zone.
     * *   Keys other than `region` or `zone` are not valid.
     */
    dimensions: {
        [key: string]: string;
    };
    /**
     * The name of the metric to which this policy applies.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric: string;
    /**
     * The limit unit of the limit to which this policy applies.
     *
     * An example unit would be:
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit: string;
    /**
     * The cloud resource container at which the quota policy is created. The
     * format is `{container_type}/{container_number}`
     */
    container: string;
}
export interface AdminQuotaPolicyProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.AdminQuotaPolicy";
    value: Uint8Array;
}
/** Quota policy created by quota administrator. */
export interface AdminQuotaPolicyAmino {
    /**
     * The resource name of the policy.
     * This name is generated by the server when the policy is created.
     *
     * Example names would be:
     * `organizations/123/services/compute.googleapis.com/consumerQuotaMetrics/compute.googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/adminQuotaPolicies/4a3f2c1d`
     */
    name?: string;
    /**
     * The quota policy value.
     * Can be any nonnegative integer, or -1 (unlimited quota).
     */
    policy_value?: string;
    /**
     * If this map is nonempty, then this policy applies only to specific values
     * for dimensions defined in the limit unit.
     *
     * For example, an policy on a limit with the unit `1/{project}/{region}`
     * could contain an entry with the key `region` and the value `us-east-1`;
     * the policy is only applied to quota consumed in that region.
     *
     * This map has the following restrictions:
     *
     * *   If `region` appears as a key, its value must be a valid Cloud region.
     * *   If `zone` appears as a key, its value must be a valid Cloud zone.
     * *   Keys other than `region` or `zone` are not valid.
     */
    dimensions?: {
        [key: string]: string;
    };
    /**
     * The name of the metric to which this policy applies.
     *
     * An example name would be:
     * `compute.googleapis.com/cpus`
     */
    metric?: string;
    /**
     * The limit unit of the limit to which this policy applies.
     *
     * An example unit would be:
     * `1/{project}/{region}`
     * Note that `{project}` and `{region}` are not placeholders in this example;
     * the literal characters `{` and `}` occur in the string.
     */
    unit?: string;
    /**
     * The cloud resource container at which the quota policy is created. The
     * format is `{container_type}/{container_number}`
     */
    container?: string;
}
export interface AdminQuotaPolicyAminoMsg {
    type: "/google.api.serviceusage.v1beta1.AdminQuotaPolicy";
    value: AdminQuotaPolicyAmino;
}
/** Quota policy created by quota administrator. */
export interface AdminQuotaPolicySDKType {
    name: string;
    policy_value: bigint;
    dimensions: {
        [key: string]: string;
    };
    metric: string;
    unit: string;
    container: string;
}
/**
 * Service identity for a service. This is the identity that service producer
 * should use to access consumer resources.
 */
export interface ServiceIdentity {
    /**
     * The email address of the service account that a service producer would use
     * to access consumer resources.
     */
    email: string;
    /**
     * The unique and stable id of the service account.
     * https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts#ServiceAccount
     */
    uniqueId: string;
}
export interface ServiceIdentityProtoMsg {
    typeUrl: "/google.api.serviceusage.v1beta1.ServiceIdentity";
    value: Uint8Array;
}
/**
 * Service identity for a service. This is the identity that service producer
 * should use to access consumer resources.
 */
export interface ServiceIdentityAmino {
    /**
     * The email address of the service account that a service producer would use
     * to access consumer resources.
     */
    email?: string;
    /**
     * The unique and stable id of the service account.
     * https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts#ServiceAccount
     */
    unique_id?: string;
}
export interface ServiceIdentityAminoMsg {
    type: "/google.api.serviceusage.v1beta1.ServiceIdentity";
    value: ServiceIdentityAmino;
}
/**
 * Service identity for a service. This is the identity that service producer
 * should use to access consumer resources.
 */
export interface ServiceIdentitySDKType {
    email: string;
    unique_id: string;
}
export declare const Service: {
    typeUrl: string;
    is(o: any): o is Service;
    isSDK(o: any): o is ServiceSDKType;
    isAmino(o: any): o is ServiceAmino;
    encode(message: Service, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Service;
    fromJSON(object: any): Service;
    toJSON(message: Service): JsonSafe<Service>;
    fromPartial(object: DeepPartial<Service>): Service;
    fromSDK(object: ServiceSDKType): Service;
    fromSDKJSON(object: any): ServiceSDKType;
    toSDK(message: Service): ServiceSDKType;
    fromAmino(object: ServiceAmino): Service;
    toAmino(message: Service): ServiceAmino;
    fromAminoMsg(object: ServiceAminoMsg): Service;
    fromProtoMsg(message: ServiceProtoMsg): Service;
    toProto(message: Service): Uint8Array;
    toProtoMsg(message: Service): ServiceProtoMsg;
    registerTypeUrl(): void;
};
export declare const ServiceConfig: {
    typeUrl: string;
    is(o: any): o is ServiceConfig;
    isSDK(o: any): o is ServiceConfigSDKType;
    isAmino(o: any): o is ServiceConfigAmino;
    encode(message: ServiceConfig, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ServiceConfig;
    fromJSON(object: any): ServiceConfig;
    toJSON(message: ServiceConfig): JsonSafe<ServiceConfig>;
    fromPartial(object: DeepPartial<ServiceConfig>): ServiceConfig;
    fromSDK(object: ServiceConfigSDKType): ServiceConfig;
    fromSDKJSON(object: any): ServiceConfigSDKType;
    toSDK(message: ServiceConfig): ServiceConfigSDKType;
    fromAmino(object: ServiceConfigAmino): ServiceConfig;
    toAmino(message: ServiceConfig): ServiceConfigAmino;
    fromAminoMsg(object: ServiceConfigAminoMsg): ServiceConfig;
    fromProtoMsg(message: ServiceConfigProtoMsg): ServiceConfig;
    toProto(message: ServiceConfig): Uint8Array;
    toProtoMsg(message: ServiceConfig): ServiceConfigProtoMsg;
    registerTypeUrl(): void;
};
export declare const OperationMetadata: {
    typeUrl: string;
    is(o: any): o is OperationMetadata;
    isSDK(o: any): o is OperationMetadataSDKType;
    isAmino(o: any): o is OperationMetadataAmino;
    encode(message: OperationMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OperationMetadata;
    fromJSON(object: any): OperationMetadata;
    toJSON(message: OperationMetadata): JsonSafe<OperationMetadata>;
    fromPartial(object: DeepPartial<OperationMetadata>): OperationMetadata;
    fromSDK(object: OperationMetadataSDKType): OperationMetadata;
    fromSDKJSON(object: any): OperationMetadataSDKType;
    toSDK(message: OperationMetadata): OperationMetadataSDKType;
    fromAmino(object: OperationMetadataAmino): OperationMetadata;
    toAmino(message: OperationMetadata): OperationMetadataAmino;
    fromAminoMsg(object: OperationMetadataAminoMsg): OperationMetadata;
    fromProtoMsg(message: OperationMetadataProtoMsg): OperationMetadata;
    toProto(message: OperationMetadata): Uint8Array;
    toProtoMsg(message: OperationMetadata): OperationMetadataProtoMsg;
    registerTypeUrl(): void;
};
export declare const ConsumerQuotaMetric: {
    typeUrl: string;
    is(o: any): o is ConsumerQuotaMetric;
    isSDK(o: any): o is ConsumerQuotaMetricSDKType;
    isAmino(o: any): o is ConsumerQuotaMetricAmino;
    encode(message: ConsumerQuotaMetric, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConsumerQuotaMetric;
    fromJSON(object: any): ConsumerQuotaMetric;
    toJSON(message: ConsumerQuotaMetric): JsonSafe<ConsumerQuotaMetric>;
    fromPartial(object: DeepPartial<ConsumerQuotaMetric>): ConsumerQuotaMetric;
    fromSDK(object: ConsumerQuotaMetricSDKType): ConsumerQuotaMetric;
    fromSDKJSON(object: any): ConsumerQuotaMetricSDKType;
    toSDK(message: ConsumerQuotaMetric): ConsumerQuotaMetricSDKType;
    fromAmino(object: ConsumerQuotaMetricAmino): ConsumerQuotaMetric;
    toAmino(message: ConsumerQuotaMetric): ConsumerQuotaMetricAmino;
    fromAminoMsg(object: ConsumerQuotaMetricAminoMsg): ConsumerQuotaMetric;
    fromProtoMsg(message: ConsumerQuotaMetricProtoMsg): ConsumerQuotaMetric;
    toProto(message: ConsumerQuotaMetric): Uint8Array;
    toProtoMsg(message: ConsumerQuotaMetric): ConsumerQuotaMetricProtoMsg;
    registerTypeUrl(): void;
};
export declare const ConsumerQuotaLimit: {
    typeUrl: string;
    is(o: any): o is ConsumerQuotaLimit;
    isSDK(o: any): o is ConsumerQuotaLimitSDKType;
    isAmino(o: any): o is ConsumerQuotaLimitAmino;
    encode(message: ConsumerQuotaLimit, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConsumerQuotaLimit;
    fromJSON(object: any): ConsumerQuotaLimit;
    toJSON(message: ConsumerQuotaLimit): JsonSafe<ConsumerQuotaLimit>;
    fromPartial(object: DeepPartial<ConsumerQuotaLimit>): ConsumerQuotaLimit;
    fromSDK(object: ConsumerQuotaLimitSDKType): ConsumerQuotaLimit;
    fromSDKJSON(object: any): ConsumerQuotaLimitSDKType;
    toSDK(message: ConsumerQuotaLimit): ConsumerQuotaLimitSDKType;
    fromAmino(object: ConsumerQuotaLimitAmino): ConsumerQuotaLimit;
    toAmino(message: ConsumerQuotaLimit): ConsumerQuotaLimitAmino;
    fromAminoMsg(object: ConsumerQuotaLimitAminoMsg): ConsumerQuotaLimit;
    fromProtoMsg(message: ConsumerQuotaLimitProtoMsg): ConsumerQuotaLimit;
    toProto(message: ConsumerQuotaLimit): Uint8Array;
    toProtoMsg(message: ConsumerQuotaLimit): ConsumerQuotaLimitProtoMsg;
    registerTypeUrl(): void;
};
export declare const QuotaBucket_DimensionsEntry: {
    encode(message: QuotaBucket_DimensionsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaBucket_DimensionsEntry;
    fromJSON(object: any): QuotaBucket_DimensionsEntry;
    toJSON(message: QuotaBucket_DimensionsEntry): JsonSafe<QuotaBucket_DimensionsEntry>;
    fromPartial(object: DeepPartial<QuotaBucket_DimensionsEntry>): QuotaBucket_DimensionsEntry;
    fromSDK(object: QuotaBucket_DimensionsEntrySDKType): QuotaBucket_DimensionsEntry;
    fromSDKJSON(object: any): QuotaBucket_DimensionsEntrySDKType;
    toSDK(message: QuotaBucket_DimensionsEntry): QuotaBucket_DimensionsEntrySDKType;
    fromAmino(object: QuotaBucket_DimensionsEntryAmino): QuotaBucket_DimensionsEntry;
    toAmino(message: QuotaBucket_DimensionsEntry): QuotaBucket_DimensionsEntryAmino;
    fromAminoMsg(object: QuotaBucket_DimensionsEntryAminoMsg): QuotaBucket_DimensionsEntry;
    fromProtoMsg(message: QuotaBucket_DimensionsEntryProtoMsg): QuotaBucket_DimensionsEntry;
    toProto(message: QuotaBucket_DimensionsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const QuotaBucket: {
    typeUrl: string;
    is(o: any): o is QuotaBucket;
    isSDK(o: any): o is QuotaBucketSDKType;
    isAmino(o: any): o is QuotaBucketAmino;
    encode(message: QuotaBucket, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaBucket;
    fromJSON(object: any): QuotaBucket;
    toJSON(message: QuotaBucket): JsonSafe<QuotaBucket>;
    fromPartial(object: DeepPartial<QuotaBucket>): QuotaBucket;
    fromSDK(object: QuotaBucketSDKType): QuotaBucket;
    fromSDKJSON(object: any): QuotaBucketSDKType;
    toSDK(message: QuotaBucket): QuotaBucketSDKType;
    fromAmino(object: QuotaBucketAmino): QuotaBucket;
    toAmino(message: QuotaBucket): QuotaBucketAmino;
    fromAminoMsg(object: QuotaBucketAminoMsg): QuotaBucket;
    fromProtoMsg(message: QuotaBucketProtoMsg): QuotaBucket;
    toProto(message: QuotaBucket): Uint8Array;
    toProtoMsg(message: QuotaBucket): QuotaBucketProtoMsg;
    registerTypeUrl(): void;
};
export declare const QuotaOverride_DimensionsEntry: {
    encode(message: QuotaOverride_DimensionsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaOverride_DimensionsEntry;
    fromJSON(object: any): QuotaOverride_DimensionsEntry;
    toJSON(message: QuotaOverride_DimensionsEntry): JsonSafe<QuotaOverride_DimensionsEntry>;
    fromPartial(object: DeepPartial<QuotaOverride_DimensionsEntry>): QuotaOverride_DimensionsEntry;
    fromSDK(object: QuotaOverride_DimensionsEntrySDKType): QuotaOverride_DimensionsEntry;
    fromSDKJSON(object: any): QuotaOverride_DimensionsEntrySDKType;
    toSDK(message: QuotaOverride_DimensionsEntry): QuotaOverride_DimensionsEntrySDKType;
    fromAmino(object: QuotaOverride_DimensionsEntryAmino): QuotaOverride_DimensionsEntry;
    toAmino(message: QuotaOverride_DimensionsEntry): QuotaOverride_DimensionsEntryAmino;
    fromAminoMsg(object: QuotaOverride_DimensionsEntryAminoMsg): QuotaOverride_DimensionsEntry;
    fromProtoMsg(message: QuotaOverride_DimensionsEntryProtoMsg): QuotaOverride_DimensionsEntry;
    toProto(message: QuotaOverride_DimensionsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const QuotaOverride: {
    typeUrl: string;
    is(o: any): o is QuotaOverride;
    isSDK(o: any): o is QuotaOverrideSDKType;
    isAmino(o: any): o is QuotaOverrideAmino;
    encode(message: QuotaOverride, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaOverride;
    fromJSON(object: any): QuotaOverride;
    toJSON(message: QuotaOverride): JsonSafe<QuotaOverride>;
    fromPartial(object: DeepPartial<QuotaOverride>): QuotaOverride;
    fromSDK(object: QuotaOverrideSDKType): QuotaOverride;
    fromSDKJSON(object: any): QuotaOverrideSDKType;
    toSDK(message: QuotaOverride): QuotaOverrideSDKType;
    fromAmino(object: QuotaOverrideAmino): QuotaOverride;
    toAmino(message: QuotaOverride): QuotaOverrideAmino;
    fromAminoMsg(object: QuotaOverrideAminoMsg): QuotaOverride;
    fromProtoMsg(message: QuotaOverrideProtoMsg): QuotaOverride;
    toProto(message: QuotaOverride): Uint8Array;
    toProtoMsg(message: QuotaOverride): QuotaOverrideProtoMsg;
    registerTypeUrl(): void;
};
export declare const OverrideInlineSource: {
    typeUrl: string;
    is(o: any): o is OverrideInlineSource;
    isSDK(o: any): o is OverrideInlineSourceSDKType;
    isAmino(o: any): o is OverrideInlineSourceAmino;
    encode(message: OverrideInlineSource, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OverrideInlineSource;
    fromJSON(object: any): OverrideInlineSource;
    toJSON(message: OverrideInlineSource): JsonSafe<OverrideInlineSource>;
    fromPartial(object: DeepPartial<OverrideInlineSource>): OverrideInlineSource;
    fromSDK(object: OverrideInlineSourceSDKType): OverrideInlineSource;
    fromSDKJSON(object: any): OverrideInlineSourceSDKType;
    toSDK(message: OverrideInlineSource): OverrideInlineSourceSDKType;
    fromAmino(object: OverrideInlineSourceAmino): OverrideInlineSource;
    toAmino(message: OverrideInlineSource): OverrideInlineSourceAmino;
    fromAminoMsg(object: OverrideInlineSourceAminoMsg): OverrideInlineSource;
    fromProtoMsg(message: OverrideInlineSourceProtoMsg): OverrideInlineSource;
    toProto(message: OverrideInlineSource): Uint8Array;
    toProtoMsg(message: OverrideInlineSource): OverrideInlineSourceProtoMsg;
    registerTypeUrl(): void;
};
export declare const AdminQuotaPolicy_DimensionsEntry: {
    encode(message: AdminQuotaPolicy_DimensionsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AdminQuotaPolicy_DimensionsEntry;
    fromJSON(object: any): AdminQuotaPolicy_DimensionsEntry;
    toJSON(message: AdminQuotaPolicy_DimensionsEntry): JsonSafe<AdminQuotaPolicy_DimensionsEntry>;
    fromPartial(object: DeepPartial<AdminQuotaPolicy_DimensionsEntry>): AdminQuotaPolicy_DimensionsEntry;
    fromSDK(object: AdminQuotaPolicy_DimensionsEntrySDKType): AdminQuotaPolicy_DimensionsEntry;
    fromSDKJSON(object: any): AdminQuotaPolicy_DimensionsEntrySDKType;
    toSDK(message: AdminQuotaPolicy_DimensionsEntry): AdminQuotaPolicy_DimensionsEntrySDKType;
    fromAmino(object: AdminQuotaPolicy_DimensionsEntryAmino): AdminQuotaPolicy_DimensionsEntry;
    toAmino(message: AdminQuotaPolicy_DimensionsEntry): AdminQuotaPolicy_DimensionsEntryAmino;
    fromAminoMsg(object: AdminQuotaPolicy_DimensionsEntryAminoMsg): AdminQuotaPolicy_DimensionsEntry;
    fromProtoMsg(message: AdminQuotaPolicy_DimensionsEntryProtoMsg): AdminQuotaPolicy_DimensionsEntry;
    toProto(message: AdminQuotaPolicy_DimensionsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const AdminQuotaPolicy: {
    typeUrl: string;
    is(o: any): o is AdminQuotaPolicy;
    isSDK(o: any): o is AdminQuotaPolicySDKType;
    isAmino(o: any): o is AdminQuotaPolicyAmino;
    encode(message: AdminQuotaPolicy, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): AdminQuotaPolicy;
    fromJSON(object: any): AdminQuotaPolicy;
    toJSON(message: AdminQuotaPolicy): JsonSafe<AdminQuotaPolicy>;
    fromPartial(object: DeepPartial<AdminQuotaPolicy>): AdminQuotaPolicy;
    fromSDK(object: AdminQuotaPolicySDKType): AdminQuotaPolicy;
    fromSDKJSON(object: any): AdminQuotaPolicySDKType;
    toSDK(message: AdminQuotaPolicy): AdminQuotaPolicySDKType;
    fromAmino(object: AdminQuotaPolicyAmino): AdminQuotaPolicy;
    toAmino(message: AdminQuotaPolicy): AdminQuotaPolicyAmino;
    fromAminoMsg(object: AdminQuotaPolicyAminoMsg): AdminQuotaPolicy;
    fromProtoMsg(message: AdminQuotaPolicyProtoMsg): AdminQuotaPolicy;
    toProto(message: AdminQuotaPolicy): Uint8Array;
    toProtoMsg(message: AdminQuotaPolicy): AdminQuotaPolicyProtoMsg;
    registerTypeUrl(): void;
};
export declare const ServiceIdentity: {
    typeUrl: string;
    is(o: any): o is ServiceIdentity;
    isSDK(o: any): o is ServiceIdentitySDKType;
    isAmino(o: any): o is ServiceIdentityAmino;
    encode(message: ServiceIdentity, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ServiceIdentity;
    fromJSON(object: any): ServiceIdentity;
    toJSON(message: ServiceIdentity): JsonSafe<ServiceIdentity>;
    fromPartial(object: DeepPartial<ServiceIdentity>): ServiceIdentity;
    fromSDK(object: ServiceIdentitySDKType): ServiceIdentity;
    fromSDKJSON(object: any): ServiceIdentitySDKType;
    toSDK(message: ServiceIdentity): ServiceIdentitySDKType;
    fromAmino(object: ServiceIdentityAmino): ServiceIdentity;
    toAmino(message: ServiceIdentity): ServiceIdentityAmino;
    fromAminoMsg(object: ServiceIdentityAminoMsg): ServiceIdentity;
    fromProtoMsg(message: ServiceIdentityProtoMsg): ServiceIdentity;
    toProto(message: ServiceIdentity): Uint8Array;
    toProtoMsg(message: ServiceIdentity): ServiceIdentityProtoMsg;
    registerTypeUrl(): void;
};
