import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * ### System parameter configuration
 *
 * A system parameter is a special kind of parameter defined by the API
 * system, not by an individual API. It is typically mapped to an HTTP header
 * and/or a URL query parameter. This configuration specifies which methods
 * change the names of the system parameters.
 */
export interface SystemParameters {
    /**
     * Define system parameters.
     *
     * The parameters defined here will override the default parameters
     * implemented by the system. If this field is missing from the service
     * config, default system parameters will be used. Default system parameters
     * and names is implementation-dependent.
     *
     * Example: define api key for all methods
     *
     *     system_parameters
     *       rules:
     *         - selector: "*"
     *           parameters:
     *             - name: api_key
     *               url_query_parameter: api_key
     *
     *
     * Example: define 2 api key names for a specific method.
     *
     *     system_parameters
     *       rules:
     *         - selector: "/ListShelves"
     *           parameters:
     *             - name: api_key
     *               http_header: Api-Key1
     *             - name: api_key
     *               http_header: Api-Key2
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules: SystemParameterRule[];
}
export interface SystemParametersProtoMsg {
    typeUrl: "/google.api.SystemParameters";
    value: Uint8Array;
}
/**
 * ### System parameter configuration
 *
 * A system parameter is a special kind of parameter defined by the API
 * system, not by an individual API. It is typically mapped to an HTTP header
 * and/or a URL query parameter. This configuration specifies which methods
 * change the names of the system parameters.
 */
export interface SystemParametersAmino {
    /**
     * Define system parameters.
     *
     * The parameters defined here will override the default parameters
     * implemented by the system. If this field is missing from the service
     * config, default system parameters will be used. Default system parameters
     * and names is implementation-dependent.
     *
     * Example: define api key for all methods
     *
     *     system_parameters
     *       rules:
     *         - selector: "*"
     *           parameters:
     *             - name: api_key
     *               url_query_parameter: api_key
     *
     *
     * Example: define 2 api key names for a specific method.
     *
     *     system_parameters
     *       rules:
     *         - selector: "/ListShelves"
     *           parameters:
     *             - name: api_key
     *               http_header: Api-Key1
     *             - name: api_key
     *               http_header: Api-Key2
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules?: SystemParameterRuleAmino[];
}
export interface SystemParametersAminoMsg {
    type: "/google.api.SystemParameters";
    value: SystemParametersAmino;
}
/**
 * ### System parameter configuration
 *
 * A system parameter is a special kind of parameter defined by the API
 * system, not by an individual API. It is typically mapped to an HTTP header
 * and/or a URL query parameter. This configuration specifies which methods
 * change the names of the system parameters.
 */
export interface SystemParametersSDKType {
    rules: SystemParameterRuleSDKType[];
}
/**
 * Define a system parameter rule mapping system parameter definitions to
 * methods.
 */
export interface SystemParameterRule {
    /**
     * Selects the methods to which this rule applies. Use '*' to indicate all
     * methods in all APIs.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector: string;
    /**
     * Define parameters. Multiple names may be defined for a parameter.
     * For a given method call, only one of them should be used. If multiple
     * names are used the behavior is implementation-dependent.
     * If none of the specified names are present the behavior is
     * parameter-dependent.
     */
    parameters: SystemParameter[];
}
export interface SystemParameterRuleProtoMsg {
    typeUrl: "/google.api.SystemParameterRule";
    value: Uint8Array;
}
/**
 * Define a system parameter rule mapping system parameter definitions to
 * methods.
 */
export interface SystemParameterRuleAmino {
    /**
     * Selects the methods to which this rule applies. Use '*' to indicate all
     * methods in all APIs.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector?: string;
    /**
     * Define parameters. Multiple names may be defined for a parameter.
     * For a given method call, only one of them should be used. If multiple
     * names are used the behavior is implementation-dependent.
     * If none of the specified names are present the behavior is
     * parameter-dependent.
     */
    parameters?: SystemParameterAmino[];
}
export interface SystemParameterRuleAminoMsg {
    type: "/google.api.SystemParameterRule";
    value: SystemParameterRuleAmino;
}
/**
 * Define a system parameter rule mapping system parameter definitions to
 * methods.
 */
export interface SystemParameterRuleSDKType {
    selector: string;
    parameters: SystemParameterSDKType[];
}
/**
 * Define a parameter's name and location. The parameter may be passed as either
 * an HTTP header or a URL query parameter, and if both are passed the behavior
 * is implementation-dependent.
 */
export interface SystemParameter {
    /** Define the name of the parameter, such as "api_key" . It is case sensitive. */
    name: string;
    /**
     * Define the HTTP header name to use for the parameter. It is case
     * insensitive.
     */
    httpHeader: string;
    /**
     * Define the URL query parameter name to use for the parameter. It is case
     * sensitive.
     */
    urlQueryParameter: string;
}
export interface SystemParameterProtoMsg {
    typeUrl: "/google.api.SystemParameter";
    value: Uint8Array;
}
/**
 * Define a parameter's name and location. The parameter may be passed as either
 * an HTTP header or a URL query parameter, and if both are passed the behavior
 * is implementation-dependent.
 */
export interface SystemParameterAmino {
    /** Define the name of the parameter, such as "api_key" . It is case sensitive. */
    name?: string;
    /**
     * Define the HTTP header name to use for the parameter. It is case
     * insensitive.
     */
    http_header?: string;
    /**
     * Define the URL query parameter name to use for the parameter. It is case
     * sensitive.
     */
    url_query_parameter?: string;
}
export interface SystemParameterAminoMsg {
    type: "/google.api.SystemParameter";
    value: SystemParameterAmino;
}
/**
 * Define a parameter's name and location. The parameter may be passed as either
 * an HTTP header or a URL query parameter, and if both are passed the behavior
 * is implementation-dependent.
 */
export interface SystemParameterSDKType {
    name: string;
    http_header: string;
    url_query_parameter: string;
}
export declare const SystemParameters: {
    typeUrl: string;
    is(o: any): o is SystemParameters;
    isSDK(o: any): o is SystemParametersSDKType;
    isAmino(o: any): o is SystemParametersAmino;
    encode(message: SystemParameters, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SystemParameters;
    fromJSON(object: any): SystemParameters;
    toJSON(message: SystemParameters): JsonSafe<SystemParameters>;
    fromPartial(object: DeepPartial<SystemParameters>): SystemParameters;
    fromSDK(object: SystemParametersSDKType): SystemParameters;
    fromSDKJSON(object: any): SystemParametersSDKType;
    toSDK(message: SystemParameters): SystemParametersSDKType;
    fromAmino(object: SystemParametersAmino): SystemParameters;
    toAmino(message: SystemParameters): SystemParametersAmino;
    fromAminoMsg(object: SystemParametersAminoMsg): SystemParameters;
    fromProtoMsg(message: SystemParametersProtoMsg): SystemParameters;
    toProto(message: SystemParameters): Uint8Array;
    toProtoMsg(message: SystemParameters): SystemParametersProtoMsg;
    registerTypeUrl(): void;
};
export declare const SystemParameterRule: {
    typeUrl: string;
    is(o: any): o is SystemParameterRule;
    isSDK(o: any): o is SystemParameterRuleSDKType;
    isAmino(o: any): o is SystemParameterRuleAmino;
    encode(message: SystemParameterRule, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SystemParameterRule;
    fromJSON(object: any): SystemParameterRule;
    toJSON(message: SystemParameterRule): JsonSafe<SystemParameterRule>;
    fromPartial(object: DeepPartial<SystemParameterRule>): SystemParameterRule;
    fromSDK(object: SystemParameterRuleSDKType): SystemParameterRule;
    fromSDKJSON(object: any): SystemParameterRuleSDKType;
    toSDK(message: SystemParameterRule): SystemParameterRuleSDKType;
    fromAmino(object: SystemParameterRuleAmino): SystemParameterRule;
    toAmino(message: SystemParameterRule): SystemParameterRuleAmino;
    fromAminoMsg(object: SystemParameterRuleAminoMsg): SystemParameterRule;
    fromProtoMsg(message: SystemParameterRuleProtoMsg): SystemParameterRule;
    toProto(message: SystemParameterRule): Uint8Array;
    toProtoMsg(message: SystemParameterRule): SystemParameterRuleProtoMsg;
    registerTypeUrl(): void;
};
export declare const SystemParameter: {
    typeUrl: string;
    is(o: any): o is SystemParameter;
    isSDK(o: any): o is SystemParameterSDKType;
    isAmino(o: any): o is SystemParameterAmino;
    encode(message: SystemParameter, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SystemParameter;
    fromJSON(object: any): SystemParameter;
    toJSON(message: SystemParameter): JsonSafe<SystemParameter>;
    fromPartial(object: DeepPartial<SystemParameter>): SystemParameter;
    fromSDK(object: SystemParameterSDKType): SystemParameter;
    fromSDKJSON(object: any): SystemParameterSDKType;
    toSDK(message: SystemParameter): SystemParameterSDKType;
    fromAmino(object: SystemParameterAmino): SystemParameter;
    toAmino(message: SystemParameter): SystemParameterAmino;
    fromAminoMsg(object: SystemParameterAminoMsg): SystemParameter;
    fromProtoMsg(message: SystemParameterProtoMsg): SystemParameter;
    toProto(message: SystemParameter): Uint8Array;
    toProtoMsg(message: SystemParameter): SystemParameterProtoMsg;
    registerTypeUrl(): void;
};
