import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
import { DeepPartial } from "../../helpers";
export declare const protobufPackage = "google.api";
/**
 * `Visibility` defines restrictions for the visibility of service
 * elements.  Restrictions are specified using visibility labels
 * (e.g., PREVIEW) that are elsewhere linked to users and projects.
 *
 * Users and projects can have access to more than one visibility label. The
 * effective visibility for multiple labels is the union of each label's
 * elements, plus any unrestricted elements.
 *
 * If an element and its parents have no restrictions, visibility is
 * unconditionally granted.
 *
 * Example:
 *
 *     visibility:
 *       rules:
 *       - selector: google.calendar.Calendar.EnhancedSearch
 *         restriction: PREVIEW
 *       - selector: google.calendar.Calendar.Delegate
 *         restriction: INTERNAL
 *
 * Here, all methods are publicly visible except for the restricted methods
 * EnhancedSearch and Delegate.
 */
export interface Visibility {
    /**
     * A list of visibility rules that apply to individual API elements.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules: VisibilityRule[];
}
export interface VisibilityProtoMsg {
    typeUrl: "/google.api.Visibility";
    value: Uint8Array;
}
/**
 * `Visibility` defines restrictions for the visibility of service
 * elements.  Restrictions are specified using visibility labels
 * (e.g., PREVIEW) that are elsewhere linked to users and projects.
 *
 * Users and projects can have access to more than one visibility label. The
 * effective visibility for multiple labels is the union of each label's
 * elements, plus any unrestricted elements.
 *
 * If an element and its parents have no restrictions, visibility is
 * unconditionally granted.
 *
 * Example:
 *
 *     visibility:
 *       rules:
 *       - selector: google.calendar.Calendar.EnhancedSearch
 *         restriction: PREVIEW
 *       - selector: google.calendar.Calendar.Delegate
 *         restriction: INTERNAL
 *
 * Here, all methods are publicly visible except for the restricted methods
 * EnhancedSearch and Delegate.
 */
export interface VisibilityAmino {
    /**
     * A list of visibility rules that apply to individual API elements.
     *
     * **NOTE:** All service configuration rules follow "last one wins" order.
     */
    rules?: VisibilityRuleAmino[];
}
export interface VisibilityAminoMsg {
    type: "/google.api.Visibility";
    value: VisibilityAmino;
}
/**
 * `Visibility` defines restrictions for the visibility of service
 * elements.  Restrictions are specified using visibility labels
 * (e.g., PREVIEW) that are elsewhere linked to users and projects.
 *
 * Users and projects can have access to more than one visibility label. The
 * effective visibility for multiple labels is the union of each label's
 * elements, plus any unrestricted elements.
 *
 * If an element and its parents have no restrictions, visibility is
 * unconditionally granted.
 *
 * Example:
 *
 *     visibility:
 *       rules:
 *       - selector: google.calendar.Calendar.EnhancedSearch
 *         restriction: PREVIEW
 *       - selector: google.calendar.Calendar.Delegate
 *         restriction: INTERNAL
 *
 * Here, all methods are publicly visible except for the restricted methods
 * EnhancedSearch and Delegate.
 */
export interface VisibilitySDKType {
    rules: VisibilityRuleSDKType[];
}
/**
 * A visibility rule provides visibility configuration for an individual API
 * element.
 */
export interface VisibilityRule {
    /**
     * Selects methods, messages, fields, enums, etc. to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector: string;
    /**
     * A comma-separated list of visibility labels that apply to the `selector`.
     * Any of the listed labels can be used to grant the visibility.
     *
     * If a rule has multiple labels, removing one of the labels but not all of
     * them can break clients.
     *
     * Example:
     *
     *     visibility:
     *       rules:
     *       - selector: google.calendar.Calendar.EnhancedSearch
     *         restriction: INTERNAL, PREVIEW
     *
     * Removing INTERNAL from this restriction will break clients that rely on
     * this method and only had access to it through INTERNAL.
     */
    restriction: string;
}
export interface VisibilityRuleProtoMsg {
    typeUrl: "/google.api.VisibilityRule";
    value: Uint8Array;
}
/**
 * A visibility rule provides visibility configuration for an individual API
 * element.
 */
export interface VisibilityRuleAmino {
    /**
     * Selects methods, messages, fields, enums, etc. to which this rule applies.
     *
     * Refer to [selector][google.api.DocumentationRule.selector] for syntax details.
     */
    selector?: string;
    /**
     * A comma-separated list of visibility labels that apply to the `selector`.
     * Any of the listed labels can be used to grant the visibility.
     *
     * If a rule has multiple labels, removing one of the labels but not all of
     * them can break clients.
     *
     * Example:
     *
     *     visibility:
     *       rules:
     *       - selector: google.calendar.Calendar.EnhancedSearch
     *         restriction: INTERNAL, PREVIEW
     *
     * Removing INTERNAL from this restriction will break clients that rely on
     * this method and only had access to it through INTERNAL.
     */
    restriction?: string;
}
export interface VisibilityRuleAminoMsg {
    type: "/google.api.VisibilityRule";
    value: VisibilityRuleAmino;
}
/**
 * A visibility rule provides visibility configuration for an individual API
 * element.
 */
export interface VisibilityRuleSDKType {
    selector: string;
    restriction: string;
}
export declare const Visibility: {
    typeUrl: string;
    is(o: any): o is Visibility;
    isSDK(o: any): o is VisibilitySDKType;
    isAmino(o: any): o is VisibilityAmino;
    encode(message: Visibility, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Visibility;
    fromJSON(object: any): Visibility;
    toJSON(message: Visibility): JsonSafe<Visibility>;
    fromPartial(object: DeepPartial<Visibility>): Visibility;
    fromSDK(object: VisibilitySDKType): Visibility;
    fromSDKJSON(object: any): VisibilitySDKType;
    toSDK(message: Visibility): VisibilitySDKType;
    fromAmino(object: VisibilityAmino): Visibility;
    toAmino(message: Visibility): VisibilityAmino;
    fromAminoMsg(object: VisibilityAminoMsg): Visibility;
    fromProtoMsg(message: VisibilityProtoMsg): Visibility;
    toProto(message: Visibility): Uint8Array;
    toProtoMsg(message: Visibility): VisibilityProtoMsg;
    registerTypeUrl(): void;
};
export declare const VisibilityRule: {
    typeUrl: string;
    is(o: any): o is VisibilityRule;
    isSDK(o: any): o is VisibilityRuleSDKType;
    isAmino(o: any): o is VisibilityRuleAmino;
    encode(message: VisibilityRule, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): VisibilityRule;
    fromJSON(object: any): VisibilityRule;
    toJSON(message: VisibilityRule): JsonSafe<VisibilityRule>;
    fromPartial(object: DeepPartial<VisibilityRule>): VisibilityRule;
    fromSDK(object: VisibilityRuleSDKType): VisibilityRule;
    fromSDKJSON(object: any): VisibilityRuleSDKType;
    toSDK(message: VisibilityRule): VisibilityRuleSDKType;
    fromAmino(object: VisibilityRuleAmino): VisibilityRule;
    toAmino(message: VisibilityRule): VisibilityRuleAmino;
    fromAminoMsg(object: VisibilityRuleAminoMsg): VisibilityRule;
    fromProtoMsg(message: VisibilityRuleProtoMsg): VisibilityRule;
    toProto(message: VisibilityRule): Uint8Array;
    toProtoMsg(message: VisibilityRule): VisibilityRuleProtoMsg;
    registerTypeUrl(): void;
};
