import { MonitoredResource, MonitoredResourceAmino, MonitoredResourceSDKType, MonitoredResourceDescriptor, MonitoredResourceDescriptorAmino, MonitoredResourceDescriptorSDKType } from "../../api/monitored_resource";
import { LogEntry, LogEntryAmino, LogEntrySDKType } from "./log_entry";
import { Duration, DurationAmino, DurationSDKType } from "../../protobuf/duration";
import { Status, StatusAmino, StatusSDKType } from "../../rpc/status";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "google.logging.v2";
/** An indicator of why entries were omitted. */
export declare enum TailLogEntriesResponse_SuppressionInfo_Reason {
    /** REASON_UNSPECIFIED - Unexpected default. */
    REASON_UNSPECIFIED = 0,
    /**
     * RATE_LIMIT - Indicates suppression occurred due to relevant entries being
     * received in excess of rate limits. For quotas and limits, see
     * [Logging API quotas and
     * limits](https://cloud.google.com/logging/quotas#api-limits).
     */
    RATE_LIMIT = 1,
    /**
     * NOT_CONSUMED - Indicates suppression occurred due to the client not consuming
     * responses quickly enough.
     */
    NOT_CONSUMED = 2,
    UNRECOGNIZED = -1
}
export declare const TailLogEntriesResponse_SuppressionInfo_ReasonSDKType: typeof TailLogEntriesResponse_SuppressionInfo_Reason;
export declare const TailLogEntriesResponse_SuppressionInfo_ReasonAmino: typeof TailLogEntriesResponse_SuppressionInfo_Reason;
export declare function tailLogEntriesResponse_SuppressionInfo_ReasonFromJSON(object: any): TailLogEntriesResponse_SuppressionInfo_Reason;
export declare function tailLogEntriesResponse_SuppressionInfo_ReasonToJSON(object: TailLogEntriesResponse_SuppressionInfo_Reason): string;
/** The parameters to DeleteLog. */
export interface DeleteLogRequest {
    /**
     * Required. The resource name of the log to delete:
     *
     * * `projects/[PROJECT_ID]/logs/[LOG_ID]`
     * * `organizations/[ORGANIZATION_ID]/logs/[LOG_ID]`
     * * `billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]`
     * * `folders/[FOLDER_ID]/logs/[LOG_ID]`
     *
     * `[LOG_ID]` must be URL-encoded. For example,
     * `"projects/my-project-id/logs/syslog"`,
     * `"organizations/123/logs/cloudaudit.googleapis.com%2Factivity"`.
     *
     * For more information about log names, see
     * [LogEntry][google.logging.v2.LogEntry].
     */
    logName: string;
}
export interface DeleteLogRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteLogRequest";
    value: Uint8Array;
}
/** The parameters to DeleteLog. */
export interface DeleteLogRequestAmino {
    /**
     * Required. The resource name of the log to delete:
     *
     * * `projects/[PROJECT_ID]/logs/[LOG_ID]`
     * * `organizations/[ORGANIZATION_ID]/logs/[LOG_ID]`
     * * `billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]`
     * * `folders/[FOLDER_ID]/logs/[LOG_ID]`
     *
     * `[LOG_ID]` must be URL-encoded. For example,
     * `"projects/my-project-id/logs/syslog"`,
     * `"organizations/123/logs/cloudaudit.googleapis.com%2Factivity"`.
     *
     * For more information about log names, see
     * [LogEntry][google.logging.v2.LogEntry].
     */
    log_name?: string;
}
export interface DeleteLogRequestAminoMsg {
    type: "/google.logging.v2.DeleteLogRequest";
    value: DeleteLogRequestAmino;
}
/** The parameters to DeleteLog. */
export interface DeleteLogRequestSDKType {
    log_name: string;
}
export interface WriteLogEntriesRequest_LabelsEntry {
    key: string;
    value: string;
}
export interface WriteLogEntriesRequest_LabelsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface WriteLogEntriesRequest_LabelsEntryAmino {
    key?: string;
    value?: string;
}
export interface WriteLogEntriesRequest_LabelsEntryAminoMsg {
    type: string;
    value: WriteLogEntriesRequest_LabelsEntryAmino;
}
export interface WriteLogEntriesRequest_LabelsEntrySDKType {
    key: string;
    value: string;
}
/** The parameters to WriteLogEntries. */
export interface WriteLogEntriesRequest {
    /**
     * Optional. A default log resource name that is assigned to all log entries
     * in `entries` that do not specify a value for `log_name`:
     *
     * * `projects/[PROJECT_ID]/logs/[LOG_ID]`
     * * `organizations/[ORGANIZATION_ID]/logs/[LOG_ID]`
     * * `billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]`
     * * `folders/[FOLDER_ID]/logs/[LOG_ID]`
     *
     * `[LOG_ID]` must be URL-encoded. For example:
     *
     *     "projects/my-project-id/logs/syslog"
     *     "organizations/123/logs/cloudaudit.googleapis.com%2Factivity"
     *
     * The permission `logging.logEntries.create` is needed on each project,
     * organization, billing account, or folder that is receiving new log
     * entries, whether the resource is specified in `logName` or in an
     * individual log entry.
     */
    logName: string;
    /**
     * Optional. A default monitored resource object that is assigned to all log
     * entries in `entries` that do not specify a value for `resource`. Example:
     *
     *     { "type": "gce_instance",
     *       "labels": {
     *         "zone": "us-central1-a", "instance_id": "00000000000000000000" }}
     *
     * See [LogEntry][google.logging.v2.LogEntry].
     */
    resource?: MonitoredResource;
    /**
     * Optional. Default labels that are added to the `labels` field of all log
     * entries in `entries`. If a log entry already has a label with the same key
     * as a label in this parameter, then the log entry's label is not changed.
     * See [LogEntry][google.logging.v2.LogEntry].
     */
    labels: {
        [key: string]: string;
    };
    /**
     * Required. The log entries to send to Logging. The order of log
     * entries in this list does not matter. Values supplied in this method's
     * `log_name`, `resource`, and `labels` fields are copied into those log
     * entries in this list that do not include values for their corresponding
     * fields. For more information, see the
     * [LogEntry][google.logging.v2.LogEntry] type.
     *
     * If the `timestamp` or `insert_id` fields are missing in log entries, then
     * this method supplies the current time or a unique identifier, respectively.
     * The supplied values are chosen so that, among the log entries that did not
     * supply their own values, the entries earlier in the list will sort before
     * the entries later in the list. See the `entries.list` method.
     *
     * Log entries with timestamps that are more than the
     * [logs retention period](https://cloud.google.com/logging/quotas) in
     * the past or more than 24 hours in the future will not be available when
     * calling `entries.list`. However, those log entries can still be [exported
     * with
     * LogSinks](https://cloud.google.com/logging/docs/api/tasks/exporting-logs).
     *
     * To improve throughput and to avoid exceeding the
     * [quota limit](https://cloud.google.com/logging/quotas) for calls to
     * `entries.write`, you should try to include several log entries in this
     * list, rather than calling this method for each individual log entry.
     */
    entries: LogEntry[];
    /**
     * Optional. Whether valid entries should be written even if some other
     * entries fail due to INVALID_ARGUMENT or PERMISSION_DENIED errors. If any
     * entry is not written, then the response status is the error associated
     * with one of the failed entries and the response includes error details
     * keyed by the entries' zero-based index in the `entries.write` method.
     */
    partialSuccess: boolean;
    /**
     * Optional. If true, the request should expect normal response, but the
     * entries won't be persisted nor exported. Useful for checking whether the
     * logging API endpoints are working properly before sending valuable data.
     */
    dryRun: boolean;
}
export interface WriteLogEntriesRequestProtoMsg {
    typeUrl: "/google.logging.v2.WriteLogEntriesRequest";
    value: Uint8Array;
}
/** The parameters to WriteLogEntries. */
export interface WriteLogEntriesRequestAmino {
    /**
     * Optional. A default log resource name that is assigned to all log entries
     * in `entries` that do not specify a value for `log_name`:
     *
     * * `projects/[PROJECT_ID]/logs/[LOG_ID]`
     * * `organizations/[ORGANIZATION_ID]/logs/[LOG_ID]`
     * * `billingAccounts/[BILLING_ACCOUNT_ID]/logs/[LOG_ID]`
     * * `folders/[FOLDER_ID]/logs/[LOG_ID]`
     *
     * `[LOG_ID]` must be URL-encoded. For example:
     *
     *     "projects/my-project-id/logs/syslog"
     *     "organizations/123/logs/cloudaudit.googleapis.com%2Factivity"
     *
     * The permission `logging.logEntries.create` is needed on each project,
     * organization, billing account, or folder that is receiving new log
     * entries, whether the resource is specified in `logName` or in an
     * individual log entry.
     */
    log_name?: string;
    /**
     * Optional. A default monitored resource object that is assigned to all log
     * entries in `entries` that do not specify a value for `resource`. Example:
     *
     *     { "type": "gce_instance",
     *       "labels": {
     *         "zone": "us-central1-a", "instance_id": "00000000000000000000" }}
     *
     * See [LogEntry][google.logging.v2.LogEntry].
     */
    resource?: MonitoredResourceAmino;
    /**
     * Optional. Default labels that are added to the `labels` field of all log
     * entries in `entries`. If a log entry already has a label with the same key
     * as a label in this parameter, then the log entry's label is not changed.
     * See [LogEntry][google.logging.v2.LogEntry].
     */
    labels?: {
        [key: string]: string;
    };
    /**
     * Required. The log entries to send to Logging. The order of log
     * entries in this list does not matter. Values supplied in this method's
     * `log_name`, `resource`, and `labels` fields are copied into those log
     * entries in this list that do not include values for their corresponding
     * fields. For more information, see the
     * [LogEntry][google.logging.v2.LogEntry] type.
     *
     * If the `timestamp` or `insert_id` fields are missing in log entries, then
     * this method supplies the current time or a unique identifier, respectively.
     * The supplied values are chosen so that, among the log entries that did not
     * supply their own values, the entries earlier in the list will sort before
     * the entries later in the list. See the `entries.list` method.
     *
     * Log entries with timestamps that are more than the
     * [logs retention period](https://cloud.google.com/logging/quotas) in
     * the past or more than 24 hours in the future will not be available when
     * calling `entries.list`. However, those log entries can still be [exported
     * with
     * LogSinks](https://cloud.google.com/logging/docs/api/tasks/exporting-logs).
     *
     * To improve throughput and to avoid exceeding the
     * [quota limit](https://cloud.google.com/logging/quotas) for calls to
     * `entries.write`, you should try to include several log entries in this
     * list, rather than calling this method for each individual log entry.
     */
    entries?: LogEntryAmino[];
    /**
     * Optional. Whether valid entries should be written even if some other
     * entries fail due to INVALID_ARGUMENT or PERMISSION_DENIED errors. If any
     * entry is not written, then the response status is the error associated
     * with one of the failed entries and the response includes error details
     * keyed by the entries' zero-based index in the `entries.write` method.
     */
    partial_success?: boolean;
    /**
     * Optional. If true, the request should expect normal response, but the
     * entries won't be persisted nor exported. Useful for checking whether the
     * logging API endpoints are working properly before sending valuable data.
     */
    dry_run?: boolean;
}
export interface WriteLogEntriesRequestAminoMsg {
    type: "/google.logging.v2.WriteLogEntriesRequest";
    value: WriteLogEntriesRequestAmino;
}
/** The parameters to WriteLogEntries. */
export interface WriteLogEntriesRequestSDKType {
    log_name: string;
    resource?: MonitoredResourceSDKType;
    labels: {
        [key: string]: string;
    };
    entries: LogEntrySDKType[];
    partial_success: boolean;
    dry_run: boolean;
}
/** Result returned from WriteLogEntries. */
export interface WriteLogEntriesResponse {
}
export interface WriteLogEntriesResponseProtoMsg {
    typeUrl: "/google.logging.v2.WriteLogEntriesResponse";
    value: Uint8Array;
}
/** Result returned from WriteLogEntries. */
export interface WriteLogEntriesResponseAmino {
}
export interface WriteLogEntriesResponseAminoMsg {
    type: "/google.logging.v2.WriteLogEntriesResponse";
    value: WriteLogEntriesResponseAmino;
}
/** Result returned from WriteLogEntries. */
export interface WriteLogEntriesResponseSDKType {
}
export interface WriteLogEntriesPartialErrors_LogEntryErrorsEntry {
    key: number;
    value?: Status;
}
export interface WriteLogEntriesPartialErrors_LogEntryErrorsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface WriteLogEntriesPartialErrors_LogEntryErrorsEntryAmino {
    key?: number;
    value?: StatusAmino;
}
export interface WriteLogEntriesPartialErrors_LogEntryErrorsEntryAminoMsg {
    type: string;
    value: WriteLogEntriesPartialErrors_LogEntryErrorsEntryAmino;
}
export interface WriteLogEntriesPartialErrors_LogEntryErrorsEntrySDKType {
    key: number;
    value?: StatusSDKType;
}
/** Error details for WriteLogEntries with partial success. */
export interface WriteLogEntriesPartialErrors {
    /**
     * When `WriteLogEntriesRequest.partial_success` is true, records the error
     * status for entries that were not written due to a permanent error, keyed
     * by the entry's zero-based index in `WriteLogEntriesRequest.entries`.
     *
     * Failed requests for which no entries are written will not include
     * per-entry errors.
     */
    logEntryErrors: {
        [key: number]: Status;
    };
}
export interface WriteLogEntriesPartialErrorsProtoMsg {
    typeUrl: "/google.logging.v2.WriteLogEntriesPartialErrors";
    value: Uint8Array;
}
/** Error details for WriteLogEntries with partial success. */
export interface WriteLogEntriesPartialErrorsAmino {
    /**
     * When `WriteLogEntriesRequest.partial_success` is true, records the error
     * status for entries that were not written due to a permanent error, keyed
     * by the entry's zero-based index in `WriteLogEntriesRequest.entries`.
     *
     * Failed requests for which no entries are written will not include
     * per-entry errors.
     */
    log_entry_errors?: {
        [key: number]: StatusAmino;
    };
}
export interface WriteLogEntriesPartialErrorsAminoMsg {
    type: "/google.logging.v2.WriteLogEntriesPartialErrors";
    value: WriteLogEntriesPartialErrorsAmino;
}
/** Error details for WriteLogEntries with partial success. */
export interface WriteLogEntriesPartialErrorsSDKType {
    log_entry_errors: {
        [key: number]: StatusSDKType;
    };
}
/** The parameters to `ListLogEntries`. */
export interface ListLogEntriesRequest {
    /**
     * Required. Names of one or more parent resources from which to
     * retrieve log entries:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     *
     * May alternatively be one or more views:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *
     * Projects listed in the `project_ids` field are added to this list.
     */
    resourceNames: string[];
    /**
     * Optional. A filter that chooses which log entries to return.  See [Advanced
     * Logs Queries](https://cloud.google.com/logging/docs/view/advanced-queries).
     * Only log entries that match the filter are returned.  An empty filter
     * matches all log entries in the resources listed in `resource_names`.
     * Referencing a parent resource that is not listed in `resource_names` will
     * cause the filter to return no results. The maximum length of the filter is
     * 20000 characters.
     */
    filter: string;
    /**
     * Optional. How the results should be sorted.  Presently, the only permitted
     * values are `"timestamp asc"` (default) and `"timestamp desc"`. The first
     * option returns entries in order of increasing values of
     * `LogEntry.timestamp` (oldest first), and the second option returns entries
     * in order of decreasing timestamps (newest first).  Entries with equal
     * timestamps are returned in order of their `insert_id` values.
     */
    orderBy: string;
    /**
     * Optional. The maximum number of results to return from this request. Default is 50.
     * If the value is negative or exceeds 1000, the request is rejected. The
     * presence of `next_page_token` in the response indicates that more results
     * might be available.
     */
    pageSize: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `page_token` must be the value of
     * `next_page_token` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
}
export interface ListLogEntriesRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListLogEntriesRequest";
    value: Uint8Array;
}
/** The parameters to `ListLogEntries`. */
export interface ListLogEntriesRequestAmino {
    /**
     * Required. Names of one or more parent resources from which to
     * retrieve log entries:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     *
     * May alternatively be one or more views:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *
     * Projects listed in the `project_ids` field are added to this list.
     */
    resource_names?: string[];
    /**
     * Optional. A filter that chooses which log entries to return.  See [Advanced
     * Logs Queries](https://cloud.google.com/logging/docs/view/advanced-queries).
     * Only log entries that match the filter are returned.  An empty filter
     * matches all log entries in the resources listed in `resource_names`.
     * Referencing a parent resource that is not listed in `resource_names` will
     * cause the filter to return no results. The maximum length of the filter is
     * 20000 characters.
     */
    filter?: string;
    /**
     * Optional. How the results should be sorted.  Presently, the only permitted
     * values are `"timestamp asc"` (default) and `"timestamp desc"`. The first
     * option returns entries in order of increasing values of
     * `LogEntry.timestamp` (oldest first), and the second option returns entries
     * in order of decreasing timestamps (newest first).  Entries with equal
     * timestamps are returned in order of their `insert_id` values.
     */
    order_by?: string;
    /**
     * Optional. The maximum number of results to return from this request. Default is 50.
     * If the value is negative or exceeds 1000, the request is rejected. The
     * presence of `next_page_token` in the response indicates that more results
     * might be available.
     */
    page_size?: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `page_token` must be the value of
     * `next_page_token` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
}
export interface ListLogEntriesRequestAminoMsg {
    type: "/google.logging.v2.ListLogEntriesRequest";
    value: ListLogEntriesRequestAmino;
}
/** The parameters to `ListLogEntries`. */
export interface ListLogEntriesRequestSDKType {
    resource_names: string[];
    filter: string;
    order_by: string;
    page_size: number;
    page_token: string;
}
/** Result returned from `ListLogEntries`. */
export interface ListLogEntriesResponse {
    /**
     * A list of log entries.  If `entries` is empty, `nextPageToken` may still be
     * returned, indicating that more entries may exist.  See `nextPageToken` for
     * more information.
     */
    entries: LogEntry[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     *
     * If a value for `next_page_token` appears and the `entries` field is empty,
     * it means that the search found no log entries so far but it did not have
     * time to search all the possible log entries.  Retry the method with this
     * value for `page_token` to continue the search.  Alternatively, consider
     * speeding up the search by changing your filter to specify a single log name
     * or resource type, or to narrow the time range of the search.
     */
    nextPageToken: string;
}
export interface ListLogEntriesResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListLogEntriesResponse";
    value: Uint8Array;
}
/** Result returned from `ListLogEntries`. */
export interface ListLogEntriesResponseAmino {
    /**
     * A list of log entries.  If `entries` is empty, `nextPageToken` may still be
     * returned, indicating that more entries may exist.  See `nextPageToken` for
     * more information.
     */
    entries?: LogEntryAmino[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     *
     * If a value for `next_page_token` appears and the `entries` field is empty,
     * it means that the search found no log entries so far but it did not have
     * time to search all the possible log entries.  Retry the method with this
     * value for `page_token` to continue the search.  Alternatively, consider
     * speeding up the search by changing your filter to specify a single log name
     * or resource type, or to narrow the time range of the search.
     */
    next_page_token?: string;
}
export interface ListLogEntriesResponseAminoMsg {
    type: "/google.logging.v2.ListLogEntriesResponse";
    value: ListLogEntriesResponseAmino;
}
/** Result returned from `ListLogEntries`. */
export interface ListLogEntriesResponseSDKType {
    entries: LogEntrySDKType[];
    next_page_token: string;
}
/** The parameters to ListMonitoredResourceDescriptors */
export interface ListMonitoredResourceDescriptorsRequest {
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored.  The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `pageToken` must be the value of
     * `nextPageToken` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
}
export interface ListMonitoredResourceDescriptorsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsRequest";
    value: Uint8Array;
}
/** The parameters to ListMonitoredResourceDescriptors */
export interface ListMonitoredResourceDescriptorsRequestAmino {
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored.  The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `pageToken` must be the value of
     * `nextPageToken` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
}
export interface ListMonitoredResourceDescriptorsRequestAminoMsg {
    type: "/google.logging.v2.ListMonitoredResourceDescriptorsRequest";
    value: ListMonitoredResourceDescriptorsRequestAmino;
}
/** The parameters to ListMonitoredResourceDescriptors */
export interface ListMonitoredResourceDescriptorsRequestSDKType {
    page_size: number;
    page_token: string;
}
/** Result returned from ListMonitoredResourceDescriptors. */
export interface ListMonitoredResourceDescriptorsResponse {
    /** A list of resource descriptors. */
    resourceDescriptors: MonitoredResourceDescriptor[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListMonitoredResourceDescriptorsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListMonitoredResourceDescriptorsResponse";
    value: Uint8Array;
}
/** Result returned from ListMonitoredResourceDescriptors. */
export interface ListMonitoredResourceDescriptorsResponseAmino {
    /** A list of resource descriptors. */
    resource_descriptors?: MonitoredResourceDescriptorAmino[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListMonitoredResourceDescriptorsResponseAminoMsg {
    type: "/google.logging.v2.ListMonitoredResourceDescriptorsResponse";
    value: ListMonitoredResourceDescriptorsResponseAmino;
}
/** Result returned from ListMonitoredResourceDescriptors. */
export interface ListMonitoredResourceDescriptorsResponseSDKType {
    resource_descriptors: MonitoredResourceDescriptorSDKType[];
    next_page_token: string;
}
/** The parameters to ListLogs. */
export interface ListLogsRequest {
    /**
     * Required. The resource name that owns the logs:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     */
    parent: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored.  The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `pageToken` must be the value of
     * `nextPageToken` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The resource name that owns the logs:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *
     * To support legacy queries, it could also be:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     */
    resourceNames: string[];
}
export interface ListLogsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListLogsRequest";
    value: Uint8Array;
}
/** The parameters to ListLogs. */
export interface ListLogsRequestAmino {
    /**
     * Required. The resource name that owns the logs:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     */
    parent?: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored.  The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method.  `pageToken` must be the value of
     * `nextPageToken` from the previous response.  The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The resource name that owns the logs:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *
     * To support legacy queries, it could also be:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     */
    resource_names?: string[];
}
export interface ListLogsRequestAminoMsg {
    type: "/google.logging.v2.ListLogsRequest";
    value: ListLogsRequestAmino;
}
/** The parameters to ListLogs. */
export interface ListLogsRequestSDKType {
    parent: string;
    page_size: number;
    page_token: string;
    resource_names: string[];
}
/** Result returned from ListLogs. */
export interface ListLogsResponse {
    /**
     * A list of log names. For example,
     * `"projects/my-project/logs/syslog"` or
     * `"organizations/123/logs/cloudresourcemanager.googleapis.com%2Factivity"`.
     */
    logNames: string[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListLogsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListLogsResponse";
    value: Uint8Array;
}
/** Result returned from ListLogs. */
export interface ListLogsResponseAmino {
    /**
     * A list of log names. For example,
     * `"projects/my-project/logs/syslog"` or
     * `"organizations/123/logs/cloudresourcemanager.googleapis.com%2Factivity"`.
     */
    log_names?: string[];
    /**
     * If there might be more results than those appearing in this response, then
     * `nextPageToken` is included.  To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListLogsResponseAminoMsg {
    type: "/google.logging.v2.ListLogsResponse";
    value: ListLogsResponseAmino;
}
/** Result returned from ListLogs. */
export interface ListLogsResponseSDKType {
    log_names: string[];
    next_page_token: string;
}
/** The parameters to `TailLogEntries`. */
export interface TailLogEntriesRequest {
    /**
     * Required. Name of a parent resource from which to retrieve log entries:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     *
     * May alternatively be one or more views:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     */
    resourceNames: string[];
    /**
     * Optional. A filter that chooses which log entries to return.  See [Advanced
     * Logs Filters](https://cloud.google.com/logging/docs/view/advanced_filters).
     * Only log entries that match the filter are returned.  An empty filter
     * matches all log entries in the resources listed in `resource_names`.
     * Referencing a parent resource that is not in `resource_names` will cause
     * the filter to return no results. The maximum length of the filter is 20000
     * characters.
     */
    filter: string;
    /**
     * Optional. The amount of time to buffer log entries at the server before
     * being returned to prevent out of order results due to late arriving log
     * entries. Valid values are between 0-60000 milliseconds. Defaults to 2000
     * milliseconds.
     */
    bufferWindow?: Duration;
}
export interface TailLogEntriesRequestProtoMsg {
    typeUrl: "/google.logging.v2.TailLogEntriesRequest";
    value: Uint8Array;
}
/** The parameters to `TailLogEntries`. */
export interface TailLogEntriesRequestAmino {
    /**
     * Required. Name of a parent resource from which to retrieve log entries:
     *
     * *  `projects/[PROJECT_ID]`
     * *  `organizations/[ORGANIZATION_ID]`
     * *  `billingAccounts/[BILLING_ACCOUNT_ID]`
     * *  `folders/[FOLDER_ID]`
     *
     * May alternatively be one or more views:
     *
     *  * `projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     *  * `folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]`
     */
    resource_names?: string[];
    /**
     * Optional. A filter that chooses which log entries to return.  See [Advanced
     * Logs Filters](https://cloud.google.com/logging/docs/view/advanced_filters).
     * Only log entries that match the filter are returned.  An empty filter
     * matches all log entries in the resources listed in `resource_names`.
     * Referencing a parent resource that is not in `resource_names` will cause
     * the filter to return no results. The maximum length of the filter is 20000
     * characters.
     */
    filter?: string;
    /**
     * Optional. The amount of time to buffer log entries at the server before
     * being returned to prevent out of order results due to late arriving log
     * entries. Valid values are between 0-60000 milliseconds. Defaults to 2000
     * milliseconds.
     */
    buffer_window?: DurationAmino;
}
export interface TailLogEntriesRequestAminoMsg {
    type: "/google.logging.v2.TailLogEntriesRequest";
    value: TailLogEntriesRequestAmino;
}
/** The parameters to `TailLogEntries`. */
export interface TailLogEntriesRequestSDKType {
    resource_names: string[];
    filter: string;
    buffer_window?: DurationSDKType;
}
/** Result returned from `TailLogEntries`. */
export interface TailLogEntriesResponse {
    /**
     * A list of log entries. Each response in the stream will order entries with
     * increasing values of `LogEntry.timestamp`. Ordering is not guaranteed
     * between separate responses.
     */
    entries: LogEntry[];
    /**
     * If entries that otherwise would have been included in the session were not
     * sent back to the client, counts of relevant entries omitted from the
     * session with the reason that they were not included. There will be at most
     * one of each reason per response. The counts represent the number of
     * suppressed entries since the last streamed response.
     */
    suppressionInfo: TailLogEntriesResponse_SuppressionInfo[];
}
export interface TailLogEntriesResponseProtoMsg {
    typeUrl: "/google.logging.v2.TailLogEntriesResponse";
    value: Uint8Array;
}
/** Result returned from `TailLogEntries`. */
export interface TailLogEntriesResponseAmino {
    /**
     * A list of log entries. Each response in the stream will order entries with
     * increasing values of `LogEntry.timestamp`. Ordering is not guaranteed
     * between separate responses.
     */
    entries?: LogEntryAmino[];
    /**
     * If entries that otherwise would have been included in the session were not
     * sent back to the client, counts of relevant entries omitted from the
     * session with the reason that they were not included. There will be at most
     * one of each reason per response. The counts represent the number of
     * suppressed entries since the last streamed response.
     */
    suppression_info?: TailLogEntriesResponse_SuppressionInfoAmino[];
}
export interface TailLogEntriesResponseAminoMsg {
    type: "/google.logging.v2.TailLogEntriesResponse";
    value: TailLogEntriesResponseAmino;
}
/** Result returned from `TailLogEntries`. */
export interface TailLogEntriesResponseSDKType {
    entries: LogEntrySDKType[];
    suppression_info: TailLogEntriesResponse_SuppressionInfoSDKType[];
}
/** Information about entries that were omitted from the session. */
export interface TailLogEntriesResponse_SuppressionInfo {
    /** The reason that entries were omitted from the session. */
    reason: TailLogEntriesResponse_SuppressionInfo_Reason;
    /** A lower bound on the count of entries omitted due to `reason`. */
    suppressedCount: number;
}
export interface TailLogEntriesResponse_SuppressionInfoProtoMsg {
    typeUrl: "/google.logging.v2.SuppressionInfo";
    value: Uint8Array;
}
/** Information about entries that were omitted from the session. */
export interface TailLogEntriesResponse_SuppressionInfoAmino {
    /** The reason that entries were omitted from the session. */
    reason?: TailLogEntriesResponse_SuppressionInfo_Reason;
    /** A lower bound on the count of entries omitted due to `reason`. */
    suppressed_count?: number;
}
export interface TailLogEntriesResponse_SuppressionInfoAminoMsg {
    type: "/google.logging.v2.SuppressionInfo";
    value: TailLogEntriesResponse_SuppressionInfoAmino;
}
/** Information about entries that were omitted from the session. */
export interface TailLogEntriesResponse_SuppressionInfoSDKType {
    reason: TailLogEntriesResponse_SuppressionInfo_Reason;
    suppressed_count: number;
}
export declare const DeleteLogRequest: {
    typeUrl: string;
    is(o: any): o is DeleteLogRequest;
    isSDK(o: any): o is DeleteLogRequestSDKType;
    isAmino(o: any): o is DeleteLogRequestAmino;
    encode(message: DeleteLogRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteLogRequest;
    fromJSON(object: any): DeleteLogRequest;
    toJSON(message: DeleteLogRequest): JsonSafe<DeleteLogRequest>;
    fromPartial(object: DeepPartial<DeleteLogRequest>): DeleteLogRequest;
    fromSDK(object: DeleteLogRequestSDKType): DeleteLogRequest;
    fromSDKJSON(object: any): DeleteLogRequestSDKType;
    toSDK(message: DeleteLogRequest): DeleteLogRequestSDKType;
    fromAmino(object: DeleteLogRequestAmino): DeleteLogRequest;
    toAmino(message: DeleteLogRequest): DeleteLogRequestAmino;
    fromAminoMsg(object: DeleteLogRequestAminoMsg): DeleteLogRequest;
    fromProtoMsg(message: DeleteLogRequestProtoMsg): DeleteLogRequest;
    toProto(message: DeleteLogRequest): Uint8Array;
    toProtoMsg(message: DeleteLogRequest): DeleteLogRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const WriteLogEntriesRequest_LabelsEntry: {
    encode(message: WriteLogEntriesRequest_LabelsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WriteLogEntriesRequest_LabelsEntry;
    fromJSON(object: any): WriteLogEntriesRequest_LabelsEntry;
    toJSON(message: WriteLogEntriesRequest_LabelsEntry): JsonSafe<WriteLogEntriesRequest_LabelsEntry>;
    fromPartial(object: DeepPartial<WriteLogEntriesRequest_LabelsEntry>): WriteLogEntriesRequest_LabelsEntry;
    fromSDK(object: WriteLogEntriesRequest_LabelsEntrySDKType): WriteLogEntriesRequest_LabelsEntry;
    fromSDKJSON(object: any): WriteLogEntriesRequest_LabelsEntrySDKType;
    toSDK(message: WriteLogEntriesRequest_LabelsEntry): WriteLogEntriesRequest_LabelsEntrySDKType;
    fromAmino(object: WriteLogEntriesRequest_LabelsEntryAmino): WriteLogEntriesRequest_LabelsEntry;
    toAmino(message: WriteLogEntriesRequest_LabelsEntry): WriteLogEntriesRequest_LabelsEntryAmino;
    fromAminoMsg(object: WriteLogEntriesRequest_LabelsEntryAminoMsg): WriteLogEntriesRequest_LabelsEntry;
    fromProtoMsg(message: WriteLogEntriesRequest_LabelsEntryProtoMsg): WriteLogEntriesRequest_LabelsEntry;
    toProto(message: WriteLogEntriesRequest_LabelsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const WriteLogEntriesRequest: {
    typeUrl: string;
    is(o: any): o is WriteLogEntriesRequest;
    isSDK(o: any): o is WriteLogEntriesRequestSDKType;
    isAmino(o: any): o is WriteLogEntriesRequestAmino;
    encode(message: WriteLogEntriesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WriteLogEntriesRequest;
    fromJSON(object: any): WriteLogEntriesRequest;
    toJSON(message: WriteLogEntriesRequest): JsonSafe<WriteLogEntriesRequest>;
    fromPartial(object: DeepPartial<WriteLogEntriesRequest>): WriteLogEntriesRequest;
    fromSDK(object: WriteLogEntriesRequestSDKType): WriteLogEntriesRequest;
    fromSDKJSON(object: any): WriteLogEntriesRequestSDKType;
    toSDK(message: WriteLogEntriesRequest): WriteLogEntriesRequestSDKType;
    fromAmino(object: WriteLogEntriesRequestAmino): WriteLogEntriesRequest;
    toAmino(message: WriteLogEntriesRequest): WriteLogEntriesRequestAmino;
    fromAminoMsg(object: WriteLogEntriesRequestAminoMsg): WriteLogEntriesRequest;
    fromProtoMsg(message: WriteLogEntriesRequestProtoMsg): WriteLogEntriesRequest;
    toProto(message: WriteLogEntriesRequest): Uint8Array;
    toProtoMsg(message: WriteLogEntriesRequest): WriteLogEntriesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const WriteLogEntriesResponse: {
    typeUrl: string;
    is(o: any): o is WriteLogEntriesResponse;
    isSDK(o: any): o is WriteLogEntriesResponseSDKType;
    isAmino(o: any): o is WriteLogEntriesResponseAmino;
    encode(_: WriteLogEntriesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WriteLogEntriesResponse;
    fromJSON(_: any): WriteLogEntriesResponse;
    toJSON(_: WriteLogEntriesResponse): JsonSafe<WriteLogEntriesResponse>;
    fromPartial(_: DeepPartial<WriteLogEntriesResponse>): WriteLogEntriesResponse;
    fromSDK(_: WriteLogEntriesResponseSDKType): WriteLogEntriesResponse;
    fromSDKJSON(_: any): WriteLogEntriesResponseSDKType;
    toSDK(_: WriteLogEntriesResponse): WriteLogEntriesResponseSDKType;
    fromAmino(_: WriteLogEntriesResponseAmino): WriteLogEntriesResponse;
    toAmino(_: WriteLogEntriesResponse): WriteLogEntriesResponseAmino;
    fromAminoMsg(object: WriteLogEntriesResponseAminoMsg): WriteLogEntriesResponse;
    fromProtoMsg(message: WriteLogEntriesResponseProtoMsg): WriteLogEntriesResponse;
    toProto(message: WriteLogEntriesResponse): Uint8Array;
    toProtoMsg(message: WriteLogEntriesResponse): WriteLogEntriesResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const WriteLogEntriesPartialErrors_LogEntryErrorsEntry: {
    encode(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    fromJSON(object: any): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    toJSON(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntry): JsonSafe<WriteLogEntriesPartialErrors_LogEntryErrorsEntry>;
    fromPartial(object: DeepPartial<WriteLogEntriesPartialErrors_LogEntryErrorsEntry>): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    fromSDK(object: WriteLogEntriesPartialErrors_LogEntryErrorsEntrySDKType): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    fromSDKJSON(object: any): WriteLogEntriesPartialErrors_LogEntryErrorsEntrySDKType;
    toSDK(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntry): WriteLogEntriesPartialErrors_LogEntryErrorsEntrySDKType;
    fromAmino(object: WriteLogEntriesPartialErrors_LogEntryErrorsEntryAmino): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    toAmino(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntry): WriteLogEntriesPartialErrors_LogEntryErrorsEntryAmino;
    fromAminoMsg(object: WriteLogEntriesPartialErrors_LogEntryErrorsEntryAminoMsg): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    fromProtoMsg(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntryProtoMsg): WriteLogEntriesPartialErrors_LogEntryErrorsEntry;
    toProto(message: WriteLogEntriesPartialErrors_LogEntryErrorsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const WriteLogEntriesPartialErrors: {
    typeUrl: string;
    is(o: any): o is WriteLogEntriesPartialErrors;
    isSDK(o: any): o is WriteLogEntriesPartialErrorsSDKType;
    isAmino(o: any): o is WriteLogEntriesPartialErrorsAmino;
    encode(message: WriteLogEntriesPartialErrors, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WriteLogEntriesPartialErrors;
    fromJSON(object: any): WriteLogEntriesPartialErrors;
    toJSON(message: WriteLogEntriesPartialErrors): JsonSafe<WriteLogEntriesPartialErrors>;
    fromPartial(object: DeepPartial<WriteLogEntriesPartialErrors>): WriteLogEntriesPartialErrors;
    fromSDK(object: WriteLogEntriesPartialErrorsSDKType): WriteLogEntriesPartialErrors;
    fromSDKJSON(object: any): WriteLogEntriesPartialErrorsSDKType;
    toSDK(message: WriteLogEntriesPartialErrors): WriteLogEntriesPartialErrorsSDKType;
    fromAmino(object: WriteLogEntriesPartialErrorsAmino): WriteLogEntriesPartialErrors;
    toAmino(message: WriteLogEntriesPartialErrors): WriteLogEntriesPartialErrorsAmino;
    fromAminoMsg(object: WriteLogEntriesPartialErrorsAminoMsg): WriteLogEntriesPartialErrors;
    fromProtoMsg(message: WriteLogEntriesPartialErrorsProtoMsg): WriteLogEntriesPartialErrors;
    toProto(message: WriteLogEntriesPartialErrors): Uint8Array;
    toProtoMsg(message: WriteLogEntriesPartialErrors): WriteLogEntriesPartialErrorsProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogEntriesRequest: {
    typeUrl: string;
    is(o: any): o is ListLogEntriesRequest;
    isSDK(o: any): o is ListLogEntriesRequestSDKType;
    isAmino(o: any): o is ListLogEntriesRequestAmino;
    encode(message: ListLogEntriesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogEntriesRequest;
    fromJSON(object: any): ListLogEntriesRequest;
    toJSON(message: ListLogEntriesRequest): JsonSafe<ListLogEntriesRequest>;
    fromPartial(object: DeepPartial<ListLogEntriesRequest>): ListLogEntriesRequest;
    fromSDK(object: ListLogEntriesRequestSDKType): ListLogEntriesRequest;
    fromSDKJSON(object: any): ListLogEntriesRequestSDKType;
    toSDK(message: ListLogEntriesRequest): ListLogEntriesRequestSDKType;
    fromAmino(object: ListLogEntriesRequestAmino): ListLogEntriesRequest;
    toAmino(message: ListLogEntriesRequest): ListLogEntriesRequestAmino;
    fromAminoMsg(object: ListLogEntriesRequestAminoMsg): ListLogEntriesRequest;
    fromProtoMsg(message: ListLogEntriesRequestProtoMsg): ListLogEntriesRequest;
    toProto(message: ListLogEntriesRequest): Uint8Array;
    toProtoMsg(message: ListLogEntriesRequest): ListLogEntriesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogEntriesResponse: {
    typeUrl: string;
    is(o: any): o is ListLogEntriesResponse;
    isSDK(o: any): o is ListLogEntriesResponseSDKType;
    isAmino(o: any): o is ListLogEntriesResponseAmino;
    encode(message: ListLogEntriesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogEntriesResponse;
    fromJSON(object: any): ListLogEntriesResponse;
    toJSON(message: ListLogEntriesResponse): JsonSafe<ListLogEntriesResponse>;
    fromPartial(object: DeepPartial<ListLogEntriesResponse>): ListLogEntriesResponse;
    fromSDK(object: ListLogEntriesResponseSDKType): ListLogEntriesResponse;
    fromSDKJSON(object: any): ListLogEntriesResponseSDKType;
    toSDK(message: ListLogEntriesResponse): ListLogEntriesResponseSDKType;
    fromAmino(object: ListLogEntriesResponseAmino): ListLogEntriesResponse;
    toAmino(message: ListLogEntriesResponse): ListLogEntriesResponseAmino;
    fromAminoMsg(object: ListLogEntriesResponseAminoMsg): ListLogEntriesResponse;
    fromProtoMsg(message: ListLogEntriesResponseProtoMsg): ListLogEntriesResponse;
    toProto(message: ListLogEntriesResponse): Uint8Array;
    toProtoMsg(message: ListLogEntriesResponse): ListLogEntriesResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListMonitoredResourceDescriptorsRequest: {
    typeUrl: string;
    is(o: any): o is ListMonitoredResourceDescriptorsRequest;
    isSDK(o: any): o is ListMonitoredResourceDescriptorsRequestSDKType;
    isAmino(o: any): o is ListMonitoredResourceDescriptorsRequestAmino;
    encode(message: ListMonitoredResourceDescriptorsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListMonitoredResourceDescriptorsRequest;
    fromJSON(object: any): ListMonitoredResourceDescriptorsRequest;
    toJSON(message: ListMonitoredResourceDescriptorsRequest): JsonSafe<ListMonitoredResourceDescriptorsRequest>;
    fromPartial(object: DeepPartial<ListMonitoredResourceDescriptorsRequest>): ListMonitoredResourceDescriptorsRequest;
    fromSDK(object: ListMonitoredResourceDescriptorsRequestSDKType): ListMonitoredResourceDescriptorsRequest;
    fromSDKJSON(object: any): ListMonitoredResourceDescriptorsRequestSDKType;
    toSDK(message: ListMonitoredResourceDescriptorsRequest): ListMonitoredResourceDescriptorsRequestSDKType;
    fromAmino(object: ListMonitoredResourceDescriptorsRequestAmino): ListMonitoredResourceDescriptorsRequest;
    toAmino(message: ListMonitoredResourceDescriptorsRequest): ListMonitoredResourceDescriptorsRequestAmino;
    fromAminoMsg(object: ListMonitoredResourceDescriptorsRequestAminoMsg): ListMonitoredResourceDescriptorsRequest;
    fromProtoMsg(message: ListMonitoredResourceDescriptorsRequestProtoMsg): ListMonitoredResourceDescriptorsRequest;
    toProto(message: ListMonitoredResourceDescriptorsRequest): Uint8Array;
    toProtoMsg(message: ListMonitoredResourceDescriptorsRequest): ListMonitoredResourceDescriptorsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListMonitoredResourceDescriptorsResponse: {
    typeUrl: string;
    is(o: any): o is ListMonitoredResourceDescriptorsResponse;
    isSDK(o: any): o is ListMonitoredResourceDescriptorsResponseSDKType;
    isAmino(o: any): o is ListMonitoredResourceDescriptorsResponseAmino;
    encode(message: ListMonitoredResourceDescriptorsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListMonitoredResourceDescriptorsResponse;
    fromJSON(object: any): ListMonitoredResourceDescriptorsResponse;
    toJSON(message: ListMonitoredResourceDescriptorsResponse): JsonSafe<ListMonitoredResourceDescriptorsResponse>;
    fromPartial(object: DeepPartial<ListMonitoredResourceDescriptorsResponse>): ListMonitoredResourceDescriptorsResponse;
    fromSDK(object: ListMonitoredResourceDescriptorsResponseSDKType): ListMonitoredResourceDescriptorsResponse;
    fromSDKJSON(object: any): ListMonitoredResourceDescriptorsResponseSDKType;
    toSDK(message: ListMonitoredResourceDescriptorsResponse): ListMonitoredResourceDescriptorsResponseSDKType;
    fromAmino(object: ListMonitoredResourceDescriptorsResponseAmino): ListMonitoredResourceDescriptorsResponse;
    toAmino(message: ListMonitoredResourceDescriptorsResponse): ListMonitoredResourceDescriptorsResponseAmino;
    fromAminoMsg(object: ListMonitoredResourceDescriptorsResponseAminoMsg): ListMonitoredResourceDescriptorsResponse;
    fromProtoMsg(message: ListMonitoredResourceDescriptorsResponseProtoMsg): ListMonitoredResourceDescriptorsResponse;
    toProto(message: ListMonitoredResourceDescriptorsResponse): Uint8Array;
    toProtoMsg(message: ListMonitoredResourceDescriptorsResponse): ListMonitoredResourceDescriptorsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogsRequest: {
    typeUrl: string;
    is(o: any): o is ListLogsRequest;
    isSDK(o: any): o is ListLogsRequestSDKType;
    isAmino(o: any): o is ListLogsRequestAmino;
    encode(message: ListLogsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogsRequest;
    fromJSON(object: any): ListLogsRequest;
    toJSON(message: ListLogsRequest): JsonSafe<ListLogsRequest>;
    fromPartial(object: DeepPartial<ListLogsRequest>): ListLogsRequest;
    fromSDK(object: ListLogsRequestSDKType): ListLogsRequest;
    fromSDKJSON(object: any): ListLogsRequestSDKType;
    toSDK(message: ListLogsRequest): ListLogsRequestSDKType;
    fromAmino(object: ListLogsRequestAmino): ListLogsRequest;
    toAmino(message: ListLogsRequest): ListLogsRequestAmino;
    fromAminoMsg(object: ListLogsRequestAminoMsg): ListLogsRequest;
    fromProtoMsg(message: ListLogsRequestProtoMsg): ListLogsRequest;
    toProto(message: ListLogsRequest): Uint8Array;
    toProtoMsg(message: ListLogsRequest): ListLogsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogsResponse: {
    typeUrl: string;
    is(o: any): o is ListLogsResponse;
    isSDK(o: any): o is ListLogsResponseSDKType;
    isAmino(o: any): o is ListLogsResponseAmino;
    encode(message: ListLogsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogsResponse;
    fromJSON(object: any): ListLogsResponse;
    toJSON(message: ListLogsResponse): JsonSafe<ListLogsResponse>;
    fromPartial(object: DeepPartial<ListLogsResponse>): ListLogsResponse;
    fromSDK(object: ListLogsResponseSDKType): ListLogsResponse;
    fromSDKJSON(object: any): ListLogsResponseSDKType;
    toSDK(message: ListLogsResponse): ListLogsResponseSDKType;
    fromAmino(object: ListLogsResponseAmino): ListLogsResponse;
    toAmino(message: ListLogsResponse): ListLogsResponseAmino;
    fromAminoMsg(object: ListLogsResponseAminoMsg): ListLogsResponse;
    fromProtoMsg(message: ListLogsResponseProtoMsg): ListLogsResponse;
    toProto(message: ListLogsResponse): Uint8Array;
    toProtoMsg(message: ListLogsResponse): ListLogsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const TailLogEntriesRequest: {
    typeUrl: string;
    is(o: any): o is TailLogEntriesRequest;
    isSDK(o: any): o is TailLogEntriesRequestSDKType;
    isAmino(o: any): o is TailLogEntriesRequestAmino;
    encode(message: TailLogEntriesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TailLogEntriesRequest;
    fromJSON(object: any): TailLogEntriesRequest;
    toJSON(message: TailLogEntriesRequest): JsonSafe<TailLogEntriesRequest>;
    fromPartial(object: DeepPartial<TailLogEntriesRequest>): TailLogEntriesRequest;
    fromSDK(object: TailLogEntriesRequestSDKType): TailLogEntriesRequest;
    fromSDKJSON(object: any): TailLogEntriesRequestSDKType;
    toSDK(message: TailLogEntriesRequest): TailLogEntriesRequestSDKType;
    fromAmino(object: TailLogEntriesRequestAmino): TailLogEntriesRequest;
    toAmino(message: TailLogEntriesRequest): TailLogEntriesRequestAmino;
    fromAminoMsg(object: TailLogEntriesRequestAminoMsg): TailLogEntriesRequest;
    fromProtoMsg(message: TailLogEntriesRequestProtoMsg): TailLogEntriesRequest;
    toProto(message: TailLogEntriesRequest): Uint8Array;
    toProtoMsg(message: TailLogEntriesRequest): TailLogEntriesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const TailLogEntriesResponse: {
    typeUrl: string;
    is(o: any): o is TailLogEntriesResponse;
    isSDK(o: any): o is TailLogEntriesResponseSDKType;
    isAmino(o: any): o is TailLogEntriesResponseAmino;
    encode(message: TailLogEntriesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TailLogEntriesResponse;
    fromJSON(object: any): TailLogEntriesResponse;
    toJSON(message: TailLogEntriesResponse): JsonSafe<TailLogEntriesResponse>;
    fromPartial(object: DeepPartial<TailLogEntriesResponse>): TailLogEntriesResponse;
    fromSDK(object: TailLogEntriesResponseSDKType): TailLogEntriesResponse;
    fromSDKJSON(object: any): TailLogEntriesResponseSDKType;
    toSDK(message: TailLogEntriesResponse): TailLogEntriesResponseSDKType;
    fromAmino(object: TailLogEntriesResponseAmino): TailLogEntriesResponse;
    toAmino(message: TailLogEntriesResponse): TailLogEntriesResponseAmino;
    fromAminoMsg(object: TailLogEntriesResponseAminoMsg): TailLogEntriesResponse;
    fromProtoMsg(message: TailLogEntriesResponseProtoMsg): TailLogEntriesResponse;
    toProto(message: TailLogEntriesResponse): Uint8Array;
    toProtoMsg(message: TailLogEntriesResponse): TailLogEntriesResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const TailLogEntriesResponse_SuppressionInfo: {
    typeUrl: string;
    is(o: any): o is TailLogEntriesResponse_SuppressionInfo;
    isSDK(o: any): o is TailLogEntriesResponse_SuppressionInfoSDKType;
    isAmino(o: any): o is TailLogEntriesResponse_SuppressionInfoAmino;
    encode(message: TailLogEntriesResponse_SuppressionInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TailLogEntriesResponse_SuppressionInfo;
    fromJSON(object: any): TailLogEntriesResponse_SuppressionInfo;
    toJSON(message: TailLogEntriesResponse_SuppressionInfo): JsonSafe<TailLogEntriesResponse_SuppressionInfo>;
    fromPartial(object: DeepPartial<TailLogEntriesResponse_SuppressionInfo>): TailLogEntriesResponse_SuppressionInfo;
    fromSDK(object: TailLogEntriesResponse_SuppressionInfoSDKType): TailLogEntriesResponse_SuppressionInfo;
    fromSDKJSON(object: any): TailLogEntriesResponse_SuppressionInfoSDKType;
    toSDK(message: TailLogEntriesResponse_SuppressionInfo): TailLogEntriesResponse_SuppressionInfoSDKType;
    fromAmino(object: TailLogEntriesResponse_SuppressionInfoAmino): TailLogEntriesResponse_SuppressionInfo;
    toAmino(message: TailLogEntriesResponse_SuppressionInfo): TailLogEntriesResponse_SuppressionInfoAmino;
    fromAminoMsg(object: TailLogEntriesResponse_SuppressionInfoAminoMsg): TailLogEntriesResponse_SuppressionInfo;
    fromProtoMsg(message: TailLogEntriesResponse_SuppressionInfoProtoMsg): TailLogEntriesResponse_SuppressionInfo;
    toProto(message: TailLogEntriesResponse_SuppressionInfo): Uint8Array;
    toProtoMsg(message: TailLogEntriesResponse_SuppressionInfo): TailLogEntriesResponse_SuppressionInfoProtoMsg;
    registerTypeUrl(): void;
};
