import { FieldMask, FieldMaskAmino, FieldMaskSDKType } from "../../protobuf/field_mask";
import { DeepPartial } from "../../../helpers";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "google.logging.v2";
/** Deprecated. This is unused. */
export declare enum LogSink_VersionFormat {
    /** VERSION_FORMAT_UNSPECIFIED - An unspecified format version that will default to V2. */
    VERSION_FORMAT_UNSPECIFIED = 0,
    /** V2 - `LogEntry` version 2 format. */
    V2 = 1,
    /** V1 - `LogEntry` version 1 format. */
    V1 = 2,
    UNRECOGNIZED = -1
}
export declare const LogSink_VersionFormatSDKType: typeof LogSink_VersionFormat;
export declare const LogSink_VersionFormatAmino: typeof LogSink_VersionFormat;
export declare function logSink_VersionFormatFromJSON(object: any): LogSink_VersionFormat;
export declare function logSink_VersionFormatToJSON(object: LogSink_VersionFormat): string;
/** LogBucket lifecycle states. */
export declare enum LifecycleState {
    /**
     * LIFECYCLE_STATE_UNSPECIFIED - Unspecified state. This is only used/useful for distinguishing unset
     * values.
     */
    LIFECYCLE_STATE_UNSPECIFIED = 0,
    /** ACTIVE - The normal and active state. */
    ACTIVE = 1,
    /**
     * DELETE_REQUESTED - The resource has been marked for deletion by the user. For some resources
     * (e.g. buckets), this can be reversed by an un-delete operation.
     */
    DELETE_REQUESTED = 2,
    UNRECOGNIZED = -1
}
export declare const LifecycleStateSDKType: typeof LifecycleState;
export declare const LifecycleStateAmino: typeof LifecycleState;
export declare function lifecycleStateFromJSON(object: any): LifecycleState;
export declare function lifecycleStateToJSON(object: LifecycleState): string;
/**
 * List of different operation states.
 * High level state of the operation. This is used to report the job's
 * current state to the user. Once a long running operation is created,
 * the current state of the operation can be queried even before the
 * operation is finished and the final result is available.
 */
export declare enum OperationState {
    /** OPERATION_STATE_UNSPECIFIED - Should not be used. */
    OPERATION_STATE_UNSPECIFIED = 0,
    /** OPERATION_STATE_SCHEDULED - The operation is scheduled. */
    OPERATION_STATE_SCHEDULED = 1,
    /** OPERATION_STATE_WAITING_FOR_PERMISSIONS - Waiting for necessary permissions. */
    OPERATION_STATE_WAITING_FOR_PERMISSIONS = 2,
    /** OPERATION_STATE_RUNNING - The operation is running. */
    OPERATION_STATE_RUNNING = 3,
    /** OPERATION_STATE_SUCCEEDED - The operation was completed successfully. */
    OPERATION_STATE_SUCCEEDED = 4,
    /** OPERATION_STATE_FAILED - The operation failed. */
    OPERATION_STATE_FAILED = 5,
    /** OPERATION_STATE_CANCELLED - The operation was cancelled by the user. */
    OPERATION_STATE_CANCELLED = 6,
    UNRECOGNIZED = -1
}
export declare const OperationStateSDKType: typeof OperationState;
export declare const OperationStateAmino: typeof OperationState;
export declare function operationStateFromJSON(object: any): OperationState;
export declare function operationStateToJSON(object: OperationState): string;
/** Describes a repository in which log entries are stored. */
export interface LogBucket {
    /**
     * Output only. The resource name of the bucket.
     *
     * For example:
     *
     *   `projects/my-project/locations/global/buckets/my-bucket`
     *
     * For a list of supported locations, see [Supported
     * Regions](https://cloud.google.com/logging/docs/region-support)
     *
     * For the location of `global` it is unspecified where log entries are
     * actually stored.
     *
     * After a bucket has been created, the location cannot be changed.
     */
    name: string;
    /** Describes this bucket. */
    description: string;
    /**
     * Output only. The creation timestamp of the bucket. This is not set for any of the
     * default buckets.
     */
    createTime?: Date;
    /** Output only. The last update timestamp of the bucket. */
    updateTime?: Date;
    /**
     * Logs will be retained by default for this amount of time, after which they
     * will automatically be deleted. The minimum retention period is 1 day. If
     * this value is set to zero at bucket creation time, the default time of 30
     * days will be used.
     */
    retentionDays: number;
    /**
     * Whether the bucket is locked.
     *
     * The retention period on a locked bucket cannot be changed. Locked buckets
     * may only be deleted if they are empty.
     */
    locked: boolean;
    /** Output only. The bucket lifecycle state. */
    lifecycleState: LifecycleState;
    /**
     * Log entry field paths that are denied access in this bucket.
     *
     * The following fields and their children are eligible: `textPayload`,
     * `jsonPayload`, `protoPayload`, `httpRequest`, `labels`, `sourceLocation`.
     *
     * Restricting a repeated field will restrict all values. Adding a parent will
     * block all child fields. (e.g. `foo.bar` will block `foo.bar.baz`)
     */
    restrictedFields: string[];
    /**
     * The CMEK settings of the log bucket. If present, new log entries written to
     * this log bucket are encrypted using the CMEK key provided in this
     * configuration. If a log bucket has CMEK settings, the CMEK settings cannot
     * be disabled later by updating the log bucket. Changing the KMS key is
     * allowed.
     */
    cmekSettings?: CmekSettings;
}
export interface LogBucketProtoMsg {
    typeUrl: "/google.logging.v2.LogBucket";
    value: Uint8Array;
}
/** Describes a repository in which log entries are stored. */
export interface LogBucketAmino {
    /**
     * Output only. The resource name of the bucket.
     *
     * For example:
     *
     *   `projects/my-project/locations/global/buckets/my-bucket`
     *
     * For a list of supported locations, see [Supported
     * Regions](https://cloud.google.com/logging/docs/region-support)
     *
     * For the location of `global` it is unspecified where log entries are
     * actually stored.
     *
     * After a bucket has been created, the location cannot be changed.
     */
    name?: string;
    /** Describes this bucket. */
    description?: string;
    /**
     * Output only. The creation timestamp of the bucket. This is not set for any of the
     * default buckets.
     */
    create_time?: string;
    /** Output only. The last update timestamp of the bucket. */
    update_time?: string;
    /**
     * Logs will be retained by default for this amount of time, after which they
     * will automatically be deleted. The minimum retention period is 1 day. If
     * this value is set to zero at bucket creation time, the default time of 30
     * days will be used.
     */
    retention_days?: number;
    /**
     * Whether the bucket is locked.
     *
     * The retention period on a locked bucket cannot be changed. Locked buckets
     * may only be deleted if they are empty.
     */
    locked?: boolean;
    /** Output only. The bucket lifecycle state. */
    lifecycle_state?: LifecycleState;
    /**
     * Log entry field paths that are denied access in this bucket.
     *
     * The following fields and their children are eligible: `textPayload`,
     * `jsonPayload`, `protoPayload`, `httpRequest`, `labels`, `sourceLocation`.
     *
     * Restricting a repeated field will restrict all values. Adding a parent will
     * block all child fields. (e.g. `foo.bar` will block `foo.bar.baz`)
     */
    restricted_fields?: string[];
    /**
     * The CMEK settings of the log bucket. If present, new log entries written to
     * this log bucket are encrypted using the CMEK key provided in this
     * configuration. If a log bucket has CMEK settings, the CMEK settings cannot
     * be disabled later by updating the log bucket. Changing the KMS key is
     * allowed.
     */
    cmek_settings?: CmekSettingsAmino;
}
export interface LogBucketAminoMsg {
    type: "/google.logging.v2.LogBucket";
    value: LogBucketAmino;
}
/** Describes a repository in which log entries are stored. */
export interface LogBucketSDKType {
    name: string;
    description: string;
    create_time?: Date;
    update_time?: Date;
    retention_days: number;
    locked: boolean;
    lifecycle_state: LifecycleState;
    restricted_fields: string[];
    cmek_settings?: CmekSettingsSDKType;
}
/** Describes a view over log entries in a bucket. */
export interface LogView {
    /**
     * The resource name of the view.
     *
     * For example:
     *
     *   `projects/my-project/locations/global/buckets/my-bucket/views/my-view`
     */
    name: string;
    /** Describes this view. */
    description: string;
    /** Output only. The creation timestamp of the view. */
    createTime?: Date;
    /** Output only. The last update timestamp of the view. */
    updateTime?: Date;
    /**
     * Filter that restricts which log entries in a bucket are visible in this
     * view.
     *
     * Filters are restricted to be a logical AND of ==/!= of any of the
     * following:
     *
     *   - originating project/folder/organization/billing account.
     *   - resource type
     *   - log id
     *
     * For example:
     *
     *   SOURCE("projects/myproject") AND resource.type = "gce_instance"
     *                                AND LOG_ID("stdout")
     */
    filter: string;
}
export interface LogViewProtoMsg {
    typeUrl: "/google.logging.v2.LogView";
    value: Uint8Array;
}
/** Describes a view over log entries in a bucket. */
export interface LogViewAmino {
    /**
     * The resource name of the view.
     *
     * For example:
     *
     *   `projects/my-project/locations/global/buckets/my-bucket/views/my-view`
     */
    name?: string;
    /** Describes this view. */
    description?: string;
    /** Output only. The creation timestamp of the view. */
    create_time?: string;
    /** Output only. The last update timestamp of the view. */
    update_time?: string;
    /**
     * Filter that restricts which log entries in a bucket are visible in this
     * view.
     *
     * Filters are restricted to be a logical AND of ==/!= of any of the
     * following:
     *
     *   - originating project/folder/organization/billing account.
     *   - resource type
     *   - log id
     *
     * For example:
     *
     *   SOURCE("projects/myproject") AND resource.type = "gce_instance"
     *                                AND LOG_ID("stdout")
     */
    filter?: string;
}
export interface LogViewAminoMsg {
    type: "/google.logging.v2.LogView";
    value: LogViewAmino;
}
/** Describes a view over log entries in a bucket. */
export interface LogViewSDKType {
    name: string;
    description: string;
    create_time?: Date;
    update_time?: Date;
    filter: string;
}
/**
 * Describes a sink used to export log entries to one of the following
 * destinations in any project: a Cloud Storage bucket, a BigQuery dataset, a
 * Pub/Sub topic or a Cloud Logging log bucket. A logs filter controls which log
 * entries are exported. The sink must be created within a project,
 * organization, billing account, or folder.
 */
export interface LogSink {
    /**
     * Required. The client-assigned sink identifier, unique within the project.
     *
     * For example: `"my-syslog-errors-to-pubsub"`. Sink identifiers are limited
     * to 100 characters and can include only the following characters: upper and
     * lower-case alphanumeric characters, underscores, hyphens, and periods.
     * First character has to be alphanumeric.
     */
    name: string;
    /**
     * Required. The export destination:
     *
     *     "storage.googleapis.com/[GCS_BUCKET]"
     *     "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]"
     *     "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]"
     *
     * The sink's `writer_identity`, set when the sink is created, must have
     * permission to write to the destination or else the log entries are not
     * exported. For more information, see
     * [Exporting Logs with
     * Sinks](https://cloud.google.com/logging/docs/api/tasks/exporting-logs).
     */
    destination: string;
    /**
     * Optional. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced-queries). The
     * only exported log entries are those that are in the resource owning the
     * sink and that match the filter.
     *
     * For example:
     *
     *   `logName="projects/[PROJECT_ID]/logs/[LOG_ID]" AND severity>=ERROR`
     */
    filter: string;
    /**
     * Optional. A description of this sink.
     *
     * The maximum length of the description is 8000 characters.
     */
    description: string;
    /**
     * Optional. If set to true, then this sink is disabled and it does not export any log
     * entries.
     */
    disabled: boolean;
    /**
     * Optional. Log entries that match any of these exclusion filters will not be exported.
     *
     * If a log entry is matched by both `filter` and one of `exclusion_filters`
     * it will not be exported.
     */
    exclusions: LogExclusion[];
    /** Deprecated. This field is unused. */
    /** @deprecated */
    outputVersionFormat: LogSink_VersionFormat;
    /**
     * Output only. An IAM identity&mdash;a service account or group&mdash;under which Cloud
     * Logging writes the exported log entries to the sink's destination. This
     * field is set by
     * [sinks.create][google.logging.v2.ConfigServiceV2.CreateSink] and
     * [sinks.update][google.logging.v2.ConfigServiceV2.UpdateSink] based on the
     * value of `unique_writer_identity` in those methods.
     *
     * Until you grant this identity write-access to the destination, log entry
     * exports from this sink will fail. For more information, see [Granting
     * Access for a
     * Resource](https://cloud.google.com/iam/docs/granting-roles-to-service-accounts#granting_access_to_a_service_account_for_a_resource).
     * Consult the destination service's documentation to determine the
     * appropriate IAM roles to assign to the identity.
     *
     * Sinks that have a destination that is a log bucket in the same project as
     * the sink do not have a writer_identity and no additional permissions are
     * required.
     */
    writerIdentity: string;
    /**
     * Optional. This field applies only to sinks owned by organizations and folders. If the
     * field is false, the default, only the logs owned by the sink's parent
     * resource are available for export. If the field is true, then log entries
     * from all the projects, folders, and billing accounts contained in the
     * sink's parent resource are also available for export. Whether a particular
     * log entry from the children is exported depends on the sink's filter
     * expression.
     *
     * For example, if this field is true, then the filter
     * `resource.type=gce_instance` would export all Compute Engine VM instance
     * log entries from all projects in the sink's parent.
     *
     * To only export entries from certain child projects, filter on the project
     * part of the log name:
     *
     *   logName:("projects/test-project1/" OR "projects/test-project2/") AND
     *   resource.type=gce_instance
     */
    includeChildren: boolean;
    /** Optional. Options that affect sinks exporting data to BigQuery. */
    bigqueryOptions?: BigQueryOptions;
    /**
     * Output only. The creation timestamp of the sink.
     *
     * This field may not be present for older sinks.
     */
    createTime?: Date;
    /**
     * Output only. The last update timestamp of the sink.
     *
     * This field may not be present for older sinks.
     */
    updateTime?: Date;
}
export interface LogSinkProtoMsg {
    typeUrl: "/google.logging.v2.LogSink";
    value: Uint8Array;
}
/**
 * Describes a sink used to export log entries to one of the following
 * destinations in any project: a Cloud Storage bucket, a BigQuery dataset, a
 * Pub/Sub topic or a Cloud Logging log bucket. A logs filter controls which log
 * entries are exported. The sink must be created within a project,
 * organization, billing account, or folder.
 */
export interface LogSinkAmino {
    /**
     * Required. The client-assigned sink identifier, unique within the project.
     *
     * For example: `"my-syslog-errors-to-pubsub"`. Sink identifiers are limited
     * to 100 characters and can include only the following characters: upper and
     * lower-case alphanumeric characters, underscores, hyphens, and periods.
     * First character has to be alphanumeric.
     */
    name?: string;
    /**
     * Required. The export destination:
     *
     *     "storage.googleapis.com/[GCS_BUCKET]"
     *     "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]"
     *     "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]"
     *
     * The sink's `writer_identity`, set when the sink is created, must have
     * permission to write to the destination or else the log entries are not
     * exported. For more information, see
     * [Exporting Logs with
     * Sinks](https://cloud.google.com/logging/docs/api/tasks/exporting-logs).
     */
    destination?: string;
    /**
     * Optional. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced-queries). The
     * only exported log entries are those that are in the resource owning the
     * sink and that match the filter.
     *
     * For example:
     *
     *   `logName="projects/[PROJECT_ID]/logs/[LOG_ID]" AND severity>=ERROR`
     */
    filter?: string;
    /**
     * Optional. A description of this sink.
     *
     * The maximum length of the description is 8000 characters.
     */
    description?: string;
    /**
     * Optional. If set to true, then this sink is disabled and it does not export any log
     * entries.
     */
    disabled?: boolean;
    /**
     * Optional. Log entries that match any of these exclusion filters will not be exported.
     *
     * If a log entry is matched by both `filter` and one of `exclusion_filters`
     * it will not be exported.
     */
    exclusions?: LogExclusionAmino[];
    /** Deprecated. This field is unused. */
    /** @deprecated */
    output_version_format?: LogSink_VersionFormat;
    /**
     * Output only. An IAM identity&mdash;a service account or group&mdash;under which Cloud
     * Logging writes the exported log entries to the sink's destination. This
     * field is set by
     * [sinks.create][google.logging.v2.ConfigServiceV2.CreateSink] and
     * [sinks.update][google.logging.v2.ConfigServiceV2.UpdateSink] based on the
     * value of `unique_writer_identity` in those methods.
     *
     * Until you grant this identity write-access to the destination, log entry
     * exports from this sink will fail. For more information, see [Granting
     * Access for a
     * Resource](https://cloud.google.com/iam/docs/granting-roles-to-service-accounts#granting_access_to_a_service_account_for_a_resource).
     * Consult the destination service's documentation to determine the
     * appropriate IAM roles to assign to the identity.
     *
     * Sinks that have a destination that is a log bucket in the same project as
     * the sink do not have a writer_identity and no additional permissions are
     * required.
     */
    writer_identity?: string;
    /**
     * Optional. This field applies only to sinks owned by organizations and folders. If the
     * field is false, the default, only the logs owned by the sink's parent
     * resource are available for export. If the field is true, then log entries
     * from all the projects, folders, and billing accounts contained in the
     * sink's parent resource are also available for export. Whether a particular
     * log entry from the children is exported depends on the sink's filter
     * expression.
     *
     * For example, if this field is true, then the filter
     * `resource.type=gce_instance` would export all Compute Engine VM instance
     * log entries from all projects in the sink's parent.
     *
     * To only export entries from certain child projects, filter on the project
     * part of the log name:
     *
     *   logName:("projects/test-project1/" OR "projects/test-project2/") AND
     *   resource.type=gce_instance
     */
    include_children?: boolean;
    /** Optional. Options that affect sinks exporting data to BigQuery. */
    bigquery_options?: BigQueryOptionsAmino;
    /**
     * Output only. The creation timestamp of the sink.
     *
     * This field may not be present for older sinks.
     */
    create_time?: string;
    /**
     * Output only. The last update timestamp of the sink.
     *
     * This field may not be present for older sinks.
     */
    update_time?: string;
}
export interface LogSinkAminoMsg {
    type: "/google.logging.v2.LogSink";
    value: LogSinkAmino;
}
/**
 * Describes a sink used to export log entries to one of the following
 * destinations in any project: a Cloud Storage bucket, a BigQuery dataset, a
 * Pub/Sub topic or a Cloud Logging log bucket. A logs filter controls which log
 * entries are exported. The sink must be created within a project,
 * organization, billing account, or folder.
 */
export interface LogSinkSDKType {
    name: string;
    destination: string;
    filter: string;
    description: string;
    disabled: boolean;
    exclusions: LogExclusionSDKType[];
    /** @deprecated */
    output_version_format: LogSink_VersionFormat;
    writer_identity: string;
    include_children: boolean;
    bigquery_options?: BigQueryOptionsSDKType;
    create_time?: Date;
    update_time?: Date;
}
/** Options that change functionality of a sink exporting data to BigQuery. */
export interface BigQueryOptions {
    /**
     * Optional. Whether to use [BigQuery's partition
     * tables](https://cloud.google.com/bigquery/docs/partitioned-tables). By
     * default, Cloud Logging creates dated tables based on the log entries'
     * timestamps, e.g. syslog_20170523. With partitioned tables the date suffix
     * is no longer present and [special query
     * syntax](https://cloud.google.com/bigquery/docs/querying-partitioned-tables)
     * has to be used instead. In both cases, tables are sharded based on UTC
     * timezone.
     */
    usePartitionedTables: boolean;
    /**
     * Output only. True if new timestamp column based partitioning is in use, false if legacy
     * ingestion-time partitioning is in use.
     *
     * All new sinks will have this field set true and will use timestamp column
     * based partitioning. If use_partitioned_tables is false, this value has no
     * meaning and will be false. Legacy sinks using partitioned tables will have
     * this field set to false.
     */
    usesTimestampColumnPartitioning: boolean;
}
export interface BigQueryOptionsProtoMsg {
    typeUrl: "/google.logging.v2.BigQueryOptions";
    value: Uint8Array;
}
/** Options that change functionality of a sink exporting data to BigQuery. */
export interface BigQueryOptionsAmino {
    /**
     * Optional. Whether to use [BigQuery's partition
     * tables](https://cloud.google.com/bigquery/docs/partitioned-tables). By
     * default, Cloud Logging creates dated tables based on the log entries'
     * timestamps, e.g. syslog_20170523. With partitioned tables the date suffix
     * is no longer present and [special query
     * syntax](https://cloud.google.com/bigquery/docs/querying-partitioned-tables)
     * has to be used instead. In both cases, tables are sharded based on UTC
     * timezone.
     */
    use_partitioned_tables?: boolean;
    /**
     * Output only. True if new timestamp column based partitioning is in use, false if legacy
     * ingestion-time partitioning is in use.
     *
     * All new sinks will have this field set true and will use timestamp column
     * based partitioning. If use_partitioned_tables is false, this value has no
     * meaning and will be false. Legacy sinks using partitioned tables will have
     * this field set to false.
     */
    uses_timestamp_column_partitioning?: boolean;
}
export interface BigQueryOptionsAminoMsg {
    type: "/google.logging.v2.BigQueryOptions";
    value: BigQueryOptionsAmino;
}
/** Options that change functionality of a sink exporting data to BigQuery. */
export interface BigQueryOptionsSDKType {
    use_partitioned_tables: boolean;
    uses_timestamp_column_partitioning: boolean;
}
/** The parameters to `ListBuckets`. */
export interface ListBucketsRequest {
    /**
     * Required. The parent resource whose buckets are to be listed:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]"
     *
     * Note: The locations portion of the resource must be specified, but
     * supplying the character `-` in place of [LOCATION_ID] will return all
     * buckets.
     */
    parent: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the preceding call
     * to this method. `pageToken` must be the value of `nextPageToken` from the
     * previous response. The values of other method parameters should be
     * identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The maximum number of results to return from this request. Non-positive
     * values are ignored. The presence of `nextPageToken` in the response
     * indicates that more results might be available.
     */
    pageSize: number;
}
export interface ListBucketsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListBucketsRequest";
    value: Uint8Array;
}
/** The parameters to `ListBuckets`. */
export interface ListBucketsRequestAmino {
    /**
     * Required. The parent resource whose buckets are to be listed:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]"
     *
     * Note: The locations portion of the resource must be specified, but
     * supplying the character `-` in place of [LOCATION_ID] will return all
     * buckets.
     */
    parent?: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the preceding call
     * to this method. `pageToken` must be the value of `nextPageToken` from the
     * previous response. The values of other method parameters should be
     * identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The maximum number of results to return from this request. Non-positive
     * values are ignored. The presence of `nextPageToken` in the response
     * indicates that more results might be available.
     */
    page_size?: number;
}
export interface ListBucketsRequestAminoMsg {
    type: "/google.logging.v2.ListBucketsRequest";
    value: ListBucketsRequestAmino;
}
/** The parameters to `ListBuckets`. */
export interface ListBucketsRequestSDKType {
    parent: string;
    page_token: string;
    page_size: number;
}
/** The response from ListBuckets. */
export interface ListBucketsResponse {
    /** A list of buckets. */
    buckets: LogBucket[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListBucketsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListBucketsResponse";
    value: Uint8Array;
}
/** The response from ListBuckets. */
export interface ListBucketsResponseAmino {
    /** A list of buckets. */
    buckets?: LogBucketAmino[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListBucketsResponseAminoMsg {
    type: "/google.logging.v2.ListBucketsResponse";
    value: ListBucketsResponseAmino;
}
/** The response from ListBuckets. */
export interface ListBucketsResponseSDKType {
    buckets: LogBucketSDKType[];
    next_page_token: string;
}
/** The parameters to `CreateBucket`. */
export interface CreateBucketRequest {
    /**
     * Required. The resource in which to create the log bucket:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global"`
     */
    parent: string;
    /**
     * Required. A client-assigned identifier such as `"my-bucket"`. Identifiers are limited
     * to 100 characters and can include only letters, digits, underscores,
     * hyphens, and periods.
     */
    bucketId: string;
    /**
     * Required. The new bucket. The region specified in the new bucket must be compliant
     * with any Location Restriction Org Policy. The name field in the bucket is
     * ignored.
     */
    bucket?: LogBucket;
}
export interface CreateBucketRequestProtoMsg {
    typeUrl: "/google.logging.v2.CreateBucketRequest";
    value: Uint8Array;
}
/** The parameters to `CreateBucket`. */
export interface CreateBucketRequestAmino {
    /**
     * Required. The resource in which to create the log bucket:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global"`
     */
    parent?: string;
    /**
     * Required. A client-assigned identifier such as `"my-bucket"`. Identifiers are limited
     * to 100 characters and can include only letters, digits, underscores,
     * hyphens, and periods.
     */
    bucket_id?: string;
    /**
     * Required. The new bucket. The region specified in the new bucket must be compliant
     * with any Location Restriction Org Policy. The name field in the bucket is
     * ignored.
     */
    bucket?: LogBucketAmino;
}
export interface CreateBucketRequestAminoMsg {
    type: "/google.logging.v2.CreateBucketRequest";
    value: CreateBucketRequestAmino;
}
/** The parameters to `CreateBucket`. */
export interface CreateBucketRequestSDKType {
    parent: string;
    bucket_id: string;
    bucket?: LogBucketSDKType;
}
/** The parameters to `UpdateBucket`. */
export interface UpdateBucketRequest {
    /**
     * Required. The full resource name of the bucket to update.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name: string;
    /** Required. The updated bucket. */
    bucket?: LogBucket;
    /**
     * Required. Field mask that specifies the fields in `bucket` that need an update. A
     * bucket field will be overwritten if, and only if, it is in the update mask.
     * `name` and output only fields cannot be updated.
     *
     * For a detailed `FieldMask` definition, see:
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=retention_days`
     */
    updateMask?: FieldMask;
}
export interface UpdateBucketRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateBucketRequest";
    value: Uint8Array;
}
/** The parameters to `UpdateBucket`. */
export interface UpdateBucketRequestAmino {
    /**
     * Required. The full resource name of the bucket to update.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name?: string;
    /** Required. The updated bucket. */
    bucket?: LogBucketAmino;
    /**
     * Required. Field mask that specifies the fields in `bucket` that need an update. A
     * bucket field will be overwritten if, and only if, it is in the update mask.
     * `name` and output only fields cannot be updated.
     *
     * For a detailed `FieldMask` definition, see:
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=retention_days`
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateBucketRequestAminoMsg {
    type: "/google.logging.v2.UpdateBucketRequest";
    value: UpdateBucketRequestAmino;
}
/** The parameters to `UpdateBucket`. */
export interface UpdateBucketRequestSDKType {
    name: string;
    bucket?: LogBucketSDKType;
    update_mask?: FieldMaskSDKType;
}
/** The parameters to `GetBucket`. */
export interface GetBucketRequest {
    /**
     * Required. The resource name of the bucket:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name: string;
}
export interface GetBucketRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetBucketRequest";
    value: Uint8Array;
}
/** The parameters to `GetBucket`. */
export interface GetBucketRequestAmino {
    /**
     * Required. The resource name of the bucket:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name?: string;
}
export interface GetBucketRequestAminoMsg {
    type: "/google.logging.v2.GetBucketRequest";
    value: GetBucketRequestAmino;
}
/** The parameters to `GetBucket`. */
export interface GetBucketRequestSDKType {
    name: string;
}
/** The parameters to `DeleteBucket`. */
export interface DeleteBucketRequest {
    /**
     * Required. The full resource name of the bucket to delete.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name: string;
}
export interface DeleteBucketRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteBucketRequest";
    value: Uint8Array;
}
/** The parameters to `DeleteBucket`. */
export interface DeleteBucketRequestAmino {
    /**
     * Required. The full resource name of the bucket to delete.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name?: string;
}
export interface DeleteBucketRequestAminoMsg {
    type: "/google.logging.v2.DeleteBucketRequest";
    value: DeleteBucketRequestAmino;
}
/** The parameters to `DeleteBucket`. */
export interface DeleteBucketRequestSDKType {
    name: string;
}
/** The parameters to `UndeleteBucket`. */
export interface UndeleteBucketRequest {
    /**
     * Required. The full resource name of the bucket to undelete.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name: string;
}
export interface UndeleteBucketRequestProtoMsg {
    typeUrl: "/google.logging.v2.UndeleteBucketRequest";
    value: Uint8Array;
}
/** The parameters to `UndeleteBucket`. */
export interface UndeleteBucketRequestAmino {
    /**
     * Required. The full resource name of the bucket to undelete.
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "organizations/[ORGANIZATION_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *     "folders/[FOLDER_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    name?: string;
}
export interface UndeleteBucketRequestAminoMsg {
    type: "/google.logging.v2.UndeleteBucketRequest";
    value: UndeleteBucketRequestAmino;
}
/** The parameters to `UndeleteBucket`. */
export interface UndeleteBucketRequestSDKType {
    name: string;
}
/** The parameters to `ListViews`. */
export interface ListViewsRequest {
    /**
     * Required. The bucket whose views are to be listed:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     */
    parent: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the preceding call
     * to this method. `pageToken` must be the value of `nextPageToken` from the
     * previous response. The values of other method parameters should be
     * identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The maximum number of results to return from this request.
     *
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
}
export interface ListViewsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListViewsRequest";
    value: Uint8Array;
}
/** The parameters to `ListViews`. */
export interface ListViewsRequestAmino {
    /**
     * Required. The bucket whose views are to be listed:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"
     */
    parent?: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the preceding call
     * to this method. `pageToken` must be the value of `nextPageToken` from the
     * previous response. The values of other method parameters should be
     * identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The maximum number of results to return from this request.
     *
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
}
export interface ListViewsRequestAminoMsg {
    type: "/google.logging.v2.ListViewsRequest";
    value: ListViewsRequestAmino;
}
/** The parameters to `ListViews`. */
export interface ListViewsRequestSDKType {
    parent: string;
    page_token: string;
    page_size: number;
}
/** The response from ListViews. */
export interface ListViewsResponse {
    /** A list of views. */
    views: LogView[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListViewsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListViewsResponse";
    value: Uint8Array;
}
/** The response from ListViews. */
export interface ListViewsResponseAmino {
    /** A list of views. */
    views?: LogViewAmino[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListViewsResponseAminoMsg {
    type: "/google.logging.v2.ListViewsResponse";
    value: ListViewsResponseAmino;
}
/** The response from ListViews. */
export interface ListViewsResponseSDKType {
    views: LogViewSDKType[];
    next_page_token: string;
}
/** The parameters to `CreateView`. */
export interface CreateViewRequest {
    /**
     * Required. The bucket in which to create the view
     *
     *     `"projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"`
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    parent: string;
    /** Required. The id to use for this view. */
    viewId: string;
    /** Required. The new view. */
    view?: LogView;
}
export interface CreateViewRequestProtoMsg {
    typeUrl: "/google.logging.v2.CreateViewRequest";
    value: Uint8Array;
}
/** The parameters to `CreateView`. */
export interface CreateViewRequestAmino {
    /**
     * Required. The bucket in which to create the view
     *
     *     `"projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]"`
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket"`
     */
    parent?: string;
    /** Required. The id to use for this view. */
    view_id?: string;
    /** Required. The new view. */
    view?: LogViewAmino;
}
export interface CreateViewRequestAminoMsg {
    type: "/google.logging.v2.CreateViewRequest";
    value: CreateViewRequestAmino;
}
/** The parameters to `CreateView`. */
export interface CreateViewRequestSDKType {
    parent: string;
    view_id: string;
    view?: LogViewSDKType;
}
/** The parameters to `UpdateView`. */
export interface UpdateViewRequest {
    /**
     * Required. The full resource name of the view to update
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name: string;
    /** Required. The updated view. */
    view?: LogView;
    /**
     * Optional. Field mask that specifies the fields in `view` that need
     * an update. A field will be overwritten if, and only if, it is
     * in the update mask. `name` and output only fields cannot be updated.
     *
     * For a detailed `FieldMask` definition, see
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=filter`
     */
    updateMask?: FieldMask;
}
export interface UpdateViewRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateViewRequest";
    value: Uint8Array;
}
/** The parameters to `UpdateView`. */
export interface UpdateViewRequestAmino {
    /**
     * Required. The full resource name of the view to update
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name?: string;
    /** Required. The updated view. */
    view?: LogViewAmino;
    /**
     * Optional. Field mask that specifies the fields in `view` that need
     * an update. A field will be overwritten if, and only if, it is
     * in the update mask. `name` and output only fields cannot be updated.
     *
     * For a detailed `FieldMask` definition, see
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=filter`
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateViewRequestAminoMsg {
    type: "/google.logging.v2.UpdateViewRequest";
    value: UpdateViewRequestAmino;
}
/** The parameters to `UpdateView`. */
export interface UpdateViewRequestSDKType {
    name: string;
    view?: LogViewSDKType;
    update_mask?: FieldMaskSDKType;
}
/** The parameters to `GetView`. */
export interface GetViewRequest {
    /**
     * Required. The resource name of the policy:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name: string;
}
export interface GetViewRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetViewRequest";
    value: Uint8Array;
}
/** The parameters to `GetView`. */
export interface GetViewRequestAmino {
    /**
     * Required. The resource name of the policy:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name?: string;
}
export interface GetViewRequestAminoMsg {
    type: "/google.logging.v2.GetViewRequest";
    value: GetViewRequestAmino;
}
/** The parameters to `GetView`. */
export interface GetViewRequestSDKType {
    name: string;
}
/** The parameters to `DeleteView`. */
export interface DeleteViewRequest {
    /**
     * Required. The full resource name of the view to delete:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *    `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name: string;
}
export interface DeleteViewRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteViewRequest";
    value: Uint8Array;
}
/** The parameters to `DeleteView`. */
export interface DeleteViewRequestAmino {
    /**
     * Required. The full resource name of the view to delete:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION_ID]/buckets/[BUCKET_ID]/views/[VIEW_ID]"
     *
     * For example:
     *
     *    `"projects/my-project/locations/global/buckets/my-bucket/views/my-view"`
     */
    name?: string;
}
export interface DeleteViewRequestAminoMsg {
    type: "/google.logging.v2.DeleteViewRequest";
    value: DeleteViewRequestAmino;
}
/** The parameters to `DeleteView`. */
export interface DeleteViewRequestSDKType {
    name: string;
}
/** The parameters to `ListSinks`. */
export interface ListSinksRequest {
    /**
     * Required. The parent resource whose sinks are to be listed:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     */
    parent: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
}
export interface ListSinksRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListSinksRequest";
    value: Uint8Array;
}
/** The parameters to `ListSinks`. */
export interface ListSinksRequestAmino {
    /**
     * Required. The parent resource whose sinks are to be listed:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     */
    parent?: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
}
export interface ListSinksRequestAminoMsg {
    type: "/google.logging.v2.ListSinksRequest";
    value: ListSinksRequestAmino;
}
/** The parameters to `ListSinks`. */
export interface ListSinksRequestSDKType {
    parent: string;
    page_token: string;
    page_size: number;
}
/** Result returned from `ListSinks`. */
export interface ListSinksResponse {
    /** A list of sinks. */
    sinks: LogSink[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListSinksResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListSinksResponse";
    value: Uint8Array;
}
/** Result returned from `ListSinks`. */
export interface ListSinksResponseAmino {
    /** A list of sinks. */
    sinks?: LogSinkAmino[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListSinksResponseAminoMsg {
    type: "/google.logging.v2.ListSinksResponse";
    value: ListSinksResponseAmino;
}
/** Result returned from `ListSinks`. */
export interface ListSinksResponseSDKType {
    sinks: LogSinkSDKType[];
    next_page_token: string;
}
/** The parameters to `GetSink`. */
export interface GetSinkRequest {
    /**
     * Required. The resource name of the sink:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sinkName: string;
}
export interface GetSinkRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetSinkRequest";
    value: Uint8Array;
}
/** The parameters to `GetSink`. */
export interface GetSinkRequestAmino {
    /**
     * Required. The resource name of the sink:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sink_name?: string;
}
export interface GetSinkRequestAminoMsg {
    type: "/google.logging.v2.GetSinkRequest";
    value: GetSinkRequestAmino;
}
/** The parameters to `GetSink`. */
export interface GetSinkRequestSDKType {
    sink_name: string;
}
/** The parameters to `CreateSink`. */
export interface CreateSinkRequest {
    /**
     * Required. The resource in which to create the sink:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     *
     * For examples:
     *
     *   `"projects/my-project"`
     *   `"organizations/123456789"`
     */
    parent: string;
    /**
     * Required. The new sink, whose `name` parameter is a sink identifier that
     * is not already in use.
     */
    sink?: LogSink;
    /**
     * Optional. Determines the kind of IAM identity returned as `writer_identity`
     * in the new sink. If this value is omitted or set to false, and if the
     * sink's parent is a project, then the value returned as `writer_identity` is
     * the same group or service account used by Cloud Logging before the addition
     * of writer identities to this API. The sink's destination must be in the
     * same project as the sink itself.
     *
     * If this field is set to true, or if the sink is owned by a non-project
     * resource such as an organization, then the value of `writer_identity` will
     * be a unique service account used only for exports from the new sink. For
     * more information, see `writer_identity` in [LogSink][google.logging.v2.LogSink].
     */
    uniqueWriterIdentity: boolean;
}
export interface CreateSinkRequestProtoMsg {
    typeUrl: "/google.logging.v2.CreateSinkRequest";
    value: Uint8Array;
}
/** The parameters to `CreateSink`. */
export interface CreateSinkRequestAmino {
    /**
     * Required. The resource in which to create the sink:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     *
     * For examples:
     *
     *   `"projects/my-project"`
     *   `"organizations/123456789"`
     */
    parent?: string;
    /**
     * Required. The new sink, whose `name` parameter is a sink identifier that
     * is not already in use.
     */
    sink?: LogSinkAmino;
    /**
     * Optional. Determines the kind of IAM identity returned as `writer_identity`
     * in the new sink. If this value is omitted or set to false, and if the
     * sink's parent is a project, then the value returned as `writer_identity` is
     * the same group or service account used by Cloud Logging before the addition
     * of writer identities to this API. The sink's destination must be in the
     * same project as the sink itself.
     *
     * If this field is set to true, or if the sink is owned by a non-project
     * resource such as an organization, then the value of `writer_identity` will
     * be a unique service account used only for exports from the new sink. For
     * more information, see `writer_identity` in [LogSink][google.logging.v2.LogSink].
     */
    unique_writer_identity?: boolean;
}
export interface CreateSinkRequestAminoMsg {
    type: "/google.logging.v2.CreateSinkRequest";
    value: CreateSinkRequestAmino;
}
/** The parameters to `CreateSink`. */
export interface CreateSinkRequestSDKType {
    parent: string;
    sink?: LogSinkSDKType;
    unique_writer_identity: boolean;
}
/** The parameters to `UpdateSink`. */
export interface UpdateSinkRequest {
    /**
     * Required. The full resource name of the sink to update, including the parent
     * resource and the sink identifier:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sinkName: string;
    /**
     * Required. The updated sink, whose name is the same identifier that appears as part
     * of `sink_name`.
     */
    sink?: LogSink;
    /**
     * Optional. See [sinks.create][google.logging.v2.ConfigServiceV2.CreateSink]
     * for a description of this field. When updating a sink, the effect of this
     * field on the value of `writer_identity` in the updated sink depends on both
     * the old and new values of this field:
     *
     * +   If the old and new values of this field are both false or both true,
     *     then there is no change to the sink's `writer_identity`.
     * +   If the old value is false and the new value is true, then
     *     `writer_identity` is changed to a unique service account.
     * +   It is an error if the old value is true and the new value is
     *     set to false or defaulted to false.
     */
    uniqueWriterIdentity: boolean;
    /**
     * Optional. Field mask that specifies the fields in `sink` that need
     * an update. A sink field will be overwritten if, and only if, it is
     * in the update mask. `name` and output only fields cannot be updated.
     *
     * An empty `updateMask` is temporarily treated as using the following mask
     * for backwards compatibility purposes:
     *
     *   `destination,filter,includeChildren`
     *
     * At some point in the future, behavior will be removed and specifying an
     * empty `updateMask` will be an error.
     *
     * For a detailed `FieldMask` definition, see
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=filter`
     */
    updateMask?: FieldMask;
}
export interface UpdateSinkRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateSinkRequest";
    value: Uint8Array;
}
/** The parameters to `UpdateSink`. */
export interface UpdateSinkRequestAmino {
    /**
     * Required. The full resource name of the sink to update, including the parent
     * resource and the sink identifier:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sink_name?: string;
    /**
     * Required. The updated sink, whose name is the same identifier that appears as part
     * of `sink_name`.
     */
    sink?: LogSinkAmino;
    /**
     * Optional. See [sinks.create][google.logging.v2.ConfigServiceV2.CreateSink]
     * for a description of this field. When updating a sink, the effect of this
     * field on the value of `writer_identity` in the updated sink depends on both
     * the old and new values of this field:
     *
     * +   If the old and new values of this field are both false or both true,
     *     then there is no change to the sink's `writer_identity`.
     * +   If the old value is false and the new value is true, then
     *     `writer_identity` is changed to a unique service account.
     * +   It is an error if the old value is true and the new value is
     *     set to false or defaulted to false.
     */
    unique_writer_identity?: boolean;
    /**
     * Optional. Field mask that specifies the fields in `sink` that need
     * an update. A sink field will be overwritten if, and only if, it is
     * in the update mask. `name` and output only fields cannot be updated.
     *
     * An empty `updateMask` is temporarily treated as using the following mask
     * for backwards compatibility purposes:
     *
     *   `destination,filter,includeChildren`
     *
     * At some point in the future, behavior will be removed and specifying an
     * empty `updateMask` will be an error.
     *
     * For a detailed `FieldMask` definition, see
     * https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.FieldMask
     *
     * For example: `updateMask=filter`
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateSinkRequestAminoMsg {
    type: "/google.logging.v2.UpdateSinkRequest";
    value: UpdateSinkRequestAmino;
}
/** The parameters to `UpdateSink`. */
export interface UpdateSinkRequestSDKType {
    sink_name: string;
    sink?: LogSinkSDKType;
    unique_writer_identity: boolean;
    update_mask?: FieldMaskSDKType;
}
/** The parameters to `DeleteSink`. */
export interface DeleteSinkRequest {
    /**
     * Required. The full resource name of the sink to delete, including the parent
     * resource and the sink identifier:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sinkName: string;
}
export interface DeleteSinkRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteSinkRequest";
    value: Uint8Array;
}
/** The parameters to `DeleteSink`. */
export interface DeleteSinkRequestAmino {
    /**
     * Required. The full resource name of the sink to delete, including the parent
     * resource and the sink identifier:
     *
     *     "projects/[PROJECT_ID]/sinks/[SINK_ID]"
     *     "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/sinks/[SINK_ID]"
     *     "folders/[FOLDER_ID]/sinks/[SINK_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/sinks/my-sink"`
     */
    sink_name?: string;
}
export interface DeleteSinkRequestAminoMsg {
    type: "/google.logging.v2.DeleteSinkRequest";
    value: DeleteSinkRequestAmino;
}
/** The parameters to `DeleteSink`. */
export interface DeleteSinkRequestSDKType {
    sink_name: string;
}
/**
 * Specifies a set of log entries that are filtered out by a sink. If
 * your Google Cloud resource receives a large volume of log entries, you can
 * use exclusions to reduce your chargeable logs. Note that exclusions on
 * organization-level and folder-level sinks don't apply to child resources.
 * Note also that you cannot modify the _Required sink or exclude logs from it.
 */
export interface LogExclusion {
    /**
     * Required. A client-assigned identifier, such as `"load-balancer-exclusion"`.
     * Identifiers are limited to 100 characters and can include only letters,
     * digits, underscores, hyphens, and periods. First character has to be
     * alphanumeric.
     */
    name: string;
    /** Optional. A description of this exclusion. */
    description: string;
    /**
     * Required. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced-queries) that
     * matches the log entries to be excluded. By using the [sample
     * function](https://cloud.google.com/logging/docs/view/advanced-queries#sample),
     * you can exclude less than 100% of the matching log entries.
     *
     * For example, the following query matches 99% of low-severity log entries
     * from Google Cloud Storage buckets:
     *
     *   `resource.type=gcs_bucket severity<ERROR sample(insertId, 0.99)`
     */
    filter: string;
    /**
     * Optional. If set to True, then this exclusion is disabled and it does not
     * exclude any log entries. You can [update an
     * exclusion][google.logging.v2.ConfigServiceV2.UpdateExclusion] to change the
     * value of this field.
     */
    disabled: boolean;
    /**
     * Output only. The creation timestamp of the exclusion.
     *
     * This field may not be present for older exclusions.
     */
    createTime?: Date;
    /**
     * Output only. The last update timestamp of the exclusion.
     *
     * This field may not be present for older exclusions.
     */
    updateTime?: Date;
}
export interface LogExclusionProtoMsg {
    typeUrl: "/google.logging.v2.LogExclusion";
    value: Uint8Array;
}
/**
 * Specifies a set of log entries that are filtered out by a sink. If
 * your Google Cloud resource receives a large volume of log entries, you can
 * use exclusions to reduce your chargeable logs. Note that exclusions on
 * organization-level and folder-level sinks don't apply to child resources.
 * Note also that you cannot modify the _Required sink or exclude logs from it.
 */
export interface LogExclusionAmino {
    /**
     * Required. A client-assigned identifier, such as `"load-balancer-exclusion"`.
     * Identifiers are limited to 100 characters and can include only letters,
     * digits, underscores, hyphens, and periods. First character has to be
     * alphanumeric.
     */
    name?: string;
    /** Optional. A description of this exclusion. */
    description?: string;
    /**
     * Required. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced-queries) that
     * matches the log entries to be excluded. By using the [sample
     * function](https://cloud.google.com/logging/docs/view/advanced-queries#sample),
     * you can exclude less than 100% of the matching log entries.
     *
     * For example, the following query matches 99% of low-severity log entries
     * from Google Cloud Storage buckets:
     *
     *   `resource.type=gcs_bucket severity<ERROR sample(insertId, 0.99)`
     */
    filter?: string;
    /**
     * Optional. If set to True, then this exclusion is disabled and it does not
     * exclude any log entries. You can [update an
     * exclusion][google.logging.v2.ConfigServiceV2.UpdateExclusion] to change the
     * value of this field.
     */
    disabled?: boolean;
    /**
     * Output only. The creation timestamp of the exclusion.
     *
     * This field may not be present for older exclusions.
     */
    create_time?: string;
    /**
     * Output only. The last update timestamp of the exclusion.
     *
     * This field may not be present for older exclusions.
     */
    update_time?: string;
}
export interface LogExclusionAminoMsg {
    type: "/google.logging.v2.LogExclusion";
    value: LogExclusionAmino;
}
/**
 * Specifies a set of log entries that are filtered out by a sink. If
 * your Google Cloud resource receives a large volume of log entries, you can
 * use exclusions to reduce your chargeable logs. Note that exclusions on
 * organization-level and folder-level sinks don't apply to child resources.
 * Note also that you cannot modify the _Required sink or exclude logs from it.
 */
export interface LogExclusionSDKType {
    name: string;
    description: string;
    filter: string;
    disabled: boolean;
    create_time?: Date;
    update_time?: Date;
}
/** The parameters to `ListExclusions`. */
export interface ListExclusionsRequest {
    /**
     * Required. The parent resource whose exclusions are to be listed.
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     */
    parent: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
}
export interface ListExclusionsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListExclusionsRequest";
    value: Uint8Array;
}
/** The parameters to `ListExclusions`. */
export interface ListExclusionsRequestAmino {
    /**
     * Required. The parent resource whose exclusions are to be listed.
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     */
    parent?: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
}
export interface ListExclusionsRequestAminoMsg {
    type: "/google.logging.v2.ListExclusionsRequest";
    value: ListExclusionsRequestAmino;
}
/** The parameters to `ListExclusions`. */
export interface ListExclusionsRequestSDKType {
    parent: string;
    page_token: string;
    page_size: number;
}
/** Result returned from `ListExclusions`. */
export interface ListExclusionsResponse {
    /** A list of exclusions. */
    exclusions: LogExclusion[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListExclusionsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListExclusionsResponse";
    value: Uint8Array;
}
/** Result returned from `ListExclusions`. */
export interface ListExclusionsResponseAmino {
    /** A list of exclusions. */
    exclusions?: LogExclusionAmino[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call the same
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListExclusionsResponseAminoMsg {
    type: "/google.logging.v2.ListExclusionsResponse";
    value: ListExclusionsResponseAmino;
}
/** Result returned from `ListExclusions`. */
export interface ListExclusionsResponseSDKType {
    exclusions: LogExclusionSDKType[];
    next_page_token: string;
}
/** The parameters to `GetExclusion`. */
export interface GetExclusionRequest {
    /**
     * Required. The resource name of an existing exclusion:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name: string;
}
export interface GetExclusionRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetExclusionRequest";
    value: Uint8Array;
}
/** The parameters to `GetExclusion`. */
export interface GetExclusionRequestAmino {
    /**
     * Required. The resource name of an existing exclusion:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name?: string;
}
export interface GetExclusionRequestAminoMsg {
    type: "/google.logging.v2.GetExclusionRequest";
    value: GetExclusionRequestAmino;
}
/** The parameters to `GetExclusion`. */
export interface GetExclusionRequestSDKType {
    name: string;
}
/** The parameters to `CreateExclusion`. */
export interface CreateExclusionRequest {
    /**
     * Required. The parent resource in which to create the exclusion:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     *
     * For examples:
     *
     *   `"projects/my-logging-project"`
     *   `"organizations/123456789"`
     */
    parent: string;
    /**
     * Required. The new exclusion, whose `name` parameter is an exclusion name
     * that is not already used in the parent resource.
     */
    exclusion?: LogExclusion;
}
export interface CreateExclusionRequestProtoMsg {
    typeUrl: "/google.logging.v2.CreateExclusionRequest";
    value: Uint8Array;
}
/** The parameters to `CreateExclusion`. */
export interface CreateExclusionRequestAmino {
    /**
     * Required. The parent resource in which to create the exclusion:
     *
     *     "projects/[PROJECT_ID]"
     *     "organizations/[ORGANIZATION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]"
     *     "folders/[FOLDER_ID]"
     *
     * For examples:
     *
     *   `"projects/my-logging-project"`
     *   `"organizations/123456789"`
     */
    parent?: string;
    /**
     * Required. The new exclusion, whose `name` parameter is an exclusion name
     * that is not already used in the parent resource.
     */
    exclusion?: LogExclusionAmino;
}
export interface CreateExclusionRequestAminoMsg {
    type: "/google.logging.v2.CreateExclusionRequest";
    value: CreateExclusionRequestAmino;
}
/** The parameters to `CreateExclusion`. */
export interface CreateExclusionRequestSDKType {
    parent: string;
    exclusion?: LogExclusionSDKType;
}
/** The parameters to `UpdateExclusion`. */
export interface UpdateExclusionRequest {
    /**
     * Required. The resource name of the exclusion to update:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name: string;
    /**
     * Required. New values for the existing exclusion. Only the fields specified in
     * `update_mask` are relevant.
     */
    exclusion?: LogExclusion;
    /**
     * Required. A non-empty list of fields to change in the existing exclusion. New values
     * for the fields are taken from the corresponding fields in the
     * [LogExclusion][google.logging.v2.LogExclusion] included in this request. Fields not mentioned in
     * `update_mask` are not changed and are ignored in the request.
     *
     * For example, to change the filter and description of an exclusion,
     * specify an `update_mask` of `"filter,description"`.
     */
    updateMask?: FieldMask;
}
export interface UpdateExclusionRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateExclusionRequest";
    value: Uint8Array;
}
/** The parameters to `UpdateExclusion`. */
export interface UpdateExclusionRequestAmino {
    /**
     * Required. The resource name of the exclusion to update:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name?: string;
    /**
     * Required. New values for the existing exclusion. Only the fields specified in
     * `update_mask` are relevant.
     */
    exclusion?: LogExclusionAmino;
    /**
     * Required. A non-empty list of fields to change in the existing exclusion. New values
     * for the fields are taken from the corresponding fields in the
     * [LogExclusion][google.logging.v2.LogExclusion] included in this request. Fields not mentioned in
     * `update_mask` are not changed and are ignored in the request.
     *
     * For example, to change the filter and description of an exclusion,
     * specify an `update_mask` of `"filter,description"`.
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateExclusionRequestAminoMsg {
    type: "/google.logging.v2.UpdateExclusionRequest";
    value: UpdateExclusionRequestAmino;
}
/** The parameters to `UpdateExclusion`. */
export interface UpdateExclusionRequestSDKType {
    name: string;
    exclusion?: LogExclusionSDKType;
    update_mask?: FieldMaskSDKType;
}
/** The parameters to `DeleteExclusion`. */
export interface DeleteExclusionRequest {
    /**
     * Required. The resource name of an existing exclusion to delete:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name: string;
}
export interface DeleteExclusionRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteExclusionRequest";
    value: Uint8Array;
}
/** The parameters to `DeleteExclusion`. */
export interface DeleteExclusionRequestAmino {
    /**
     * Required. The resource name of an existing exclusion to delete:
     *
     *     "projects/[PROJECT_ID]/exclusions/[EXCLUSION_ID]"
     *     "organizations/[ORGANIZATION_ID]/exclusions/[EXCLUSION_ID]"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/exclusions/[EXCLUSION_ID]"
     *     "folders/[FOLDER_ID]/exclusions/[EXCLUSION_ID]"
     *
     * For example:
     *
     *   `"projects/my-project/exclusions/my-exclusion"`
     */
    name?: string;
}
export interface DeleteExclusionRequestAminoMsg {
    type: "/google.logging.v2.DeleteExclusionRequest";
    value: DeleteExclusionRequestAmino;
}
/** The parameters to `DeleteExclusion`. */
export interface DeleteExclusionRequestSDKType {
    name: string;
}
/**
 * The parameters to
 * [GetCmekSettings][google.logging.v2.ConfigServiceV2.GetCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetCmekSettingsRequest {
    /**
     * Required. The resource for which to retrieve CMEK settings.
     *
     *     "projects/[PROJECT_ID]/cmekSettings"
     *     "organizations/[ORGANIZATION_ID]/cmekSettings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/cmekSettings"
     *     "folders/[FOLDER_ID]/cmekSettings"
     *
     * For example:
     *
     *   `"organizations/12345/cmekSettings"`
     *
     * Note: CMEK for the Log Router can be configured for Google Cloud projects,
     * folders, organizations and billing accounts. Once configured for an
     * organization, it applies to all projects and folders in the Google Cloud
     * organization.
     */
    name: string;
}
export interface GetCmekSettingsRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetCmekSettingsRequest";
    value: Uint8Array;
}
/**
 * The parameters to
 * [GetCmekSettings][google.logging.v2.ConfigServiceV2.GetCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetCmekSettingsRequestAmino {
    /**
     * Required. The resource for which to retrieve CMEK settings.
     *
     *     "projects/[PROJECT_ID]/cmekSettings"
     *     "organizations/[ORGANIZATION_ID]/cmekSettings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/cmekSettings"
     *     "folders/[FOLDER_ID]/cmekSettings"
     *
     * For example:
     *
     *   `"organizations/12345/cmekSettings"`
     *
     * Note: CMEK for the Log Router can be configured for Google Cloud projects,
     * folders, organizations and billing accounts. Once configured for an
     * organization, it applies to all projects and folders in the Google Cloud
     * organization.
     */
    name?: string;
}
export interface GetCmekSettingsRequestAminoMsg {
    type: "/google.logging.v2.GetCmekSettingsRequest";
    value: GetCmekSettingsRequestAmino;
}
/**
 * The parameters to
 * [GetCmekSettings][google.logging.v2.ConfigServiceV2.GetCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetCmekSettingsRequestSDKType {
    name: string;
}
/**
 * The parameters to
 * [UpdateCmekSettings][google.logging.v2.ConfigServiceV2.UpdateCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateCmekSettingsRequest {
    /**
     * Required. The resource name for the CMEK settings to update.
     *
     *     "projects/[PROJECT_ID]/cmekSettings"
     *     "organizations/[ORGANIZATION_ID]/cmekSettings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/cmekSettings"
     *     "folders/[FOLDER_ID]/cmekSettings"
     *
     * For example:
     *
     *   `"organizations/12345/cmekSettings"`
     *
     * Note: CMEK for the Log Router can currently only be configured for Google
     * Cloud organizations. Once configured, it applies to all projects and
     * folders in the Google Cloud organization.
     */
    name: string;
    /**
     * Required. The CMEK settings to update.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    cmekSettings?: CmekSettings;
    /**
     * Optional. Field mask identifying which fields from `cmek_settings` should
     * be updated. A field will be overwritten if and only if it is in the update
     * mask. Output only fields cannot be updated.
     *
     * See [FieldMask][google.protobuf.FieldMask] for more information.
     *
     * For example: `"updateMask=kmsKeyName"`
     */
    updateMask?: FieldMask;
}
export interface UpdateCmekSettingsRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateCmekSettingsRequest";
    value: Uint8Array;
}
/**
 * The parameters to
 * [UpdateCmekSettings][google.logging.v2.ConfigServiceV2.UpdateCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateCmekSettingsRequestAmino {
    /**
     * Required. The resource name for the CMEK settings to update.
     *
     *     "projects/[PROJECT_ID]/cmekSettings"
     *     "organizations/[ORGANIZATION_ID]/cmekSettings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/cmekSettings"
     *     "folders/[FOLDER_ID]/cmekSettings"
     *
     * For example:
     *
     *   `"organizations/12345/cmekSettings"`
     *
     * Note: CMEK for the Log Router can currently only be configured for Google
     * Cloud organizations. Once configured, it applies to all projects and
     * folders in the Google Cloud organization.
     */
    name?: string;
    /**
     * Required. The CMEK settings to update.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    cmek_settings?: CmekSettingsAmino;
    /**
     * Optional. Field mask identifying which fields from `cmek_settings` should
     * be updated. A field will be overwritten if and only if it is in the update
     * mask. Output only fields cannot be updated.
     *
     * See [FieldMask][google.protobuf.FieldMask] for more information.
     *
     * For example: `"updateMask=kmsKeyName"`
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateCmekSettingsRequestAminoMsg {
    type: "/google.logging.v2.UpdateCmekSettingsRequest";
    value: UpdateCmekSettingsRequestAmino;
}
/**
 * The parameters to
 * [UpdateCmekSettings][google.logging.v2.ConfigServiceV2.UpdateCmekSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateCmekSettingsRequestSDKType {
    name: string;
    cmek_settings?: CmekSettingsSDKType;
    update_mask?: FieldMaskSDKType;
}
/**
 * Describes the customer-managed encryption key (CMEK) settings associated with
 * a project, folder, organization, billing account, or flexible resource.
 *
 * Note: CMEK for the Log Router can currently only be configured for Google
 * Cloud organizations. Once configured, it applies to all projects and folders
 * in the Google Cloud organization.
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface CmekSettings {
    /** Output only. The resource name of the CMEK settings. */
    name: string;
    /**
     * The resource name for the configured Cloud KMS key.
     *
     * KMS key name format:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/cryptoKeys/[KEY]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/us-central1/keyRings/my-ring/cryptoKeys/my-key"`
     *
     *
     *
     * To enable CMEK for the Log Router, set this field to a valid
     * `kms_key_name` for which the associated service account has the required
     * cloudkms.cryptoKeyEncrypterDecrypter roles assigned for the key.
     *
     * The Cloud KMS key used by the Log Router can be updated by changing the
     * `kms_key_name` to a new valid key name or disabled by setting the key name
     * to an empty string. Encryption operations that are in progress will be
     * completed with the key that was in use when they started. Decryption
     * operations will be completed using the key that was used at the time of
     * encryption unless access to that key has been revoked.
     *
     * To disable CMEK for the Log Router, set this field to an empty string.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kmsKeyName: string;
    /**
     * Output only. The service account that will be used by the Log Router to access your
     * Cloud KMS key.
     *
     * Before enabling CMEK for Log Router, you must first assign the
     * cloudkms.cryptoKeyEncrypterDecrypter role to the service account that
     * the Log Router will use to access your Cloud KMS key. Use
     * [GetCmekSettings][google.logging.v2.ConfigServiceV2.GetCmekSettings] to
     * obtain the service account ID.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    serviceAccountId: string;
}
export interface CmekSettingsProtoMsg {
    typeUrl: "/google.logging.v2.CmekSettings";
    value: Uint8Array;
}
/**
 * Describes the customer-managed encryption key (CMEK) settings associated with
 * a project, folder, organization, billing account, or flexible resource.
 *
 * Note: CMEK for the Log Router can currently only be configured for Google
 * Cloud organizations. Once configured, it applies to all projects and folders
 * in the Google Cloud organization.
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface CmekSettingsAmino {
    /** Output only. The resource name of the CMEK settings. */
    name?: string;
    /**
     * The resource name for the configured Cloud KMS key.
     *
     * KMS key name format:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/cryptoKeys/[KEY]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/us-central1/keyRings/my-ring/cryptoKeys/my-key"`
     *
     *
     *
     * To enable CMEK for the Log Router, set this field to a valid
     * `kms_key_name` for which the associated service account has the required
     * cloudkms.cryptoKeyEncrypterDecrypter roles assigned for the key.
     *
     * The Cloud KMS key used by the Log Router can be updated by changing the
     * `kms_key_name` to a new valid key name or disabled by setting the key name
     * to an empty string. Encryption operations that are in progress will be
     * completed with the key that was in use when they started. Decryption
     * operations will be completed using the key that was used at the time of
     * encryption unless access to that key has been revoked.
     *
     * To disable CMEK for the Log Router, set this field to an empty string.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kms_key_name?: string;
    /**
     * Output only. The service account that will be used by the Log Router to access your
     * Cloud KMS key.
     *
     * Before enabling CMEK for Log Router, you must first assign the
     * cloudkms.cryptoKeyEncrypterDecrypter role to the service account that
     * the Log Router will use to access your Cloud KMS key. Use
     * [GetCmekSettings][google.logging.v2.ConfigServiceV2.GetCmekSettings] to
     * obtain the service account ID.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    service_account_id?: string;
}
export interface CmekSettingsAminoMsg {
    type: "/google.logging.v2.CmekSettings";
    value: CmekSettingsAmino;
}
/**
 * Describes the customer-managed encryption key (CMEK) settings associated with
 * a project, folder, organization, billing account, or flexible resource.
 *
 * Note: CMEK for the Log Router can currently only be configured for Google
 * Cloud organizations. Once configured, it applies to all projects and folders
 * in the Google Cloud organization.
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface CmekSettingsSDKType {
    name: string;
    kms_key_name: string;
    service_account_id: string;
}
/**
 * The parameters to
 * [GetSettings][google.logging.v2.ConfigServiceV2.GetSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetSettingsRequest {
    /**
     * Required. The resource for which to retrieve settings.
     *
     *     "projects/[PROJECT_ID]/settings"
     *     "organizations/[ORGANIZATION_ID]/settings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/settings"
     *     "folders/[FOLDER_ID]/settings"
     *
     * For example:
     *
     *   `"organizations/12345/settings"`
     *
     * Note: Settings for the Log Router can be get for Google Cloud projects,
     * folders, organizations and billing accounts. Currently it can only be
     * configured for organizations. Once configured for an organization, it
     * applies to all projects and folders in the Google Cloud organization.
     */
    name: string;
}
export interface GetSettingsRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetSettingsRequest";
    value: Uint8Array;
}
/**
 * The parameters to
 * [GetSettings][google.logging.v2.ConfigServiceV2.GetSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetSettingsRequestAmino {
    /**
     * Required. The resource for which to retrieve settings.
     *
     *     "projects/[PROJECT_ID]/settings"
     *     "organizations/[ORGANIZATION_ID]/settings"
     *     "billingAccounts/[BILLING_ACCOUNT_ID]/settings"
     *     "folders/[FOLDER_ID]/settings"
     *
     * For example:
     *
     *   `"organizations/12345/settings"`
     *
     * Note: Settings for the Log Router can be get for Google Cloud projects,
     * folders, organizations and billing accounts. Currently it can only be
     * configured for organizations. Once configured for an organization, it
     * applies to all projects and folders in the Google Cloud organization.
     */
    name?: string;
}
export interface GetSettingsRequestAminoMsg {
    type: "/google.logging.v2.GetSettingsRequest";
    value: GetSettingsRequestAmino;
}
/**
 * The parameters to
 * [GetSettings][google.logging.v2.ConfigServiceV2.GetSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface GetSettingsRequestSDKType {
    name: string;
}
/**
 * The parameters to
 * [UpdateSettings][google.logging.v2.ConfigServiceV2.UpdateSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateSettingsRequest {
    /**
     * Required. The resource name for the settings to update.
     *
     *     "organizations/[ORGANIZATION_ID]/settings"
     *
     * For example:
     *
     *   `"organizations/12345/settings"`
     *
     * Note: Settings for the Log Router can currently only be configured for
     * Google Cloud organizations. Once configured, it applies to all projects and
     * folders in the Google Cloud organization.
     */
    name: string;
    /**
     * Required. The settings to update.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    settings?: Settings;
    /**
     * Optional. Field mask identifying which fields from `settings` should
     * be updated. A field will be overwritten if and only if it is in the update
     * mask. Output only fields cannot be updated.
     *
     * See [FieldMask][google.protobuf.FieldMask] for more information.
     *
     * For example: `"updateMask=kmsKeyName"`
     */
    updateMask?: FieldMask;
}
export interface UpdateSettingsRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateSettingsRequest";
    value: Uint8Array;
}
/**
 * The parameters to
 * [UpdateSettings][google.logging.v2.ConfigServiceV2.UpdateSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateSettingsRequestAmino {
    /**
     * Required. The resource name for the settings to update.
     *
     *     "organizations/[ORGANIZATION_ID]/settings"
     *
     * For example:
     *
     *   `"organizations/12345/settings"`
     *
     * Note: Settings for the Log Router can currently only be configured for
     * Google Cloud organizations. Once configured, it applies to all projects and
     * folders in the Google Cloud organization.
     */
    name?: string;
    /**
     * Required. The settings to update.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    settings?: SettingsAmino;
    /**
     * Optional. Field mask identifying which fields from `settings` should
     * be updated. A field will be overwritten if and only if it is in the update
     * mask. Output only fields cannot be updated.
     *
     * See [FieldMask][google.protobuf.FieldMask] for more information.
     *
     * For example: `"updateMask=kmsKeyName"`
     */
    update_mask?: FieldMaskAmino;
}
export interface UpdateSettingsRequestAminoMsg {
    type: "/google.logging.v2.UpdateSettingsRequest";
    value: UpdateSettingsRequestAmino;
}
/**
 * The parameters to
 * [UpdateSettings][google.logging.v2.ConfigServiceV2.UpdateSettings].
 *
 * See [Enabling CMEK for Log
 * Router](https://cloud.google.com/logging/docs/routing/managed-encryption) for
 * more information.
 */
export interface UpdateSettingsRequestSDKType {
    name: string;
    settings?: SettingsSDKType;
    update_mask?: FieldMaskSDKType;
}
/**
 * Describes the settings associated with a project, folder, organization,
 * billing account, or flexible resource.
 */
export interface Settings {
    /** Output only. The resource name of the settings. */
    name: string;
    /**
     * Optional. The resource name for the configured Cloud KMS key.
     *
     * KMS key name format:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/cryptoKeys/[KEY]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/us-central1/keyRings/my-ring/cryptoKeys/my-key"`
     *
     *
     *
     * To enable CMEK for the Log Router, set this field to a valid
     * `kms_key_name` for which the associated service account has the required
     * `roles/cloudkms.cryptoKeyEncrypterDecrypter` role assigned for the key.
     *
     * The Cloud KMS key used by the Log Router can be updated by changing the
     * `kms_key_name` to a new valid key name. Encryption operations that are in
     * progress will be completed with the key that was in use when they started.
     * Decryption operations will be completed using the key that was used at the
     * time of encryption unless access to that key has been revoked.
     *
     * To disable CMEK for the Log Router, set this field to an empty string.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kmsKeyName: string;
    /**
     * Output only. The service account that will be used by the Log Router to access your
     * Cloud KMS key.
     *
     * Before enabling CMEK for Log Router, you must first assign the role
     * `roles/cloudkms.cryptoKeyEncrypterDecrypter` to the service account that
     * the Log Router will use to access your Cloud KMS key. Use
     * [GetSettings][google.logging.v2.ConfigServiceV2.GetSettings] to
     * obtain the service account ID.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kmsServiceAccountId: string;
    /**
     * Optional. The Cloud region that will be used for _Default and _Required log buckets
     * for newly created projects and folders. For example `europe-west1`.
     * This setting does not affect the location of custom log buckets.
     */
    storageLocation: string;
    /**
     * Optional. If set to true, the _Default sink in newly created projects and folders
     * will created in a disabled state. This can be used to automatically disable
     * log ingestion if there is already an aggregated sink configured in the
     * hierarchy. The _Default sink can be re-enabled manually if needed.
     */
    disableDefaultSink: boolean;
}
export interface SettingsProtoMsg {
    typeUrl: "/google.logging.v2.Settings";
    value: Uint8Array;
}
/**
 * Describes the settings associated with a project, folder, organization,
 * billing account, or flexible resource.
 */
export interface SettingsAmino {
    /** Output only. The resource name of the settings. */
    name?: string;
    /**
     * Optional. The resource name for the configured Cloud KMS key.
     *
     * KMS key name format:
     *
     *     "projects/[PROJECT_ID]/locations/[LOCATION]/keyRings/[KEYRING]/cryptoKeys/[KEY]"
     *
     * For example:
     *
     *   `"projects/my-project/locations/us-central1/keyRings/my-ring/cryptoKeys/my-key"`
     *
     *
     *
     * To enable CMEK for the Log Router, set this field to a valid
     * `kms_key_name` for which the associated service account has the required
     * `roles/cloudkms.cryptoKeyEncrypterDecrypter` role assigned for the key.
     *
     * The Cloud KMS key used by the Log Router can be updated by changing the
     * `kms_key_name` to a new valid key name. Encryption operations that are in
     * progress will be completed with the key that was in use when they started.
     * Decryption operations will be completed using the key that was used at the
     * time of encryption unless access to that key has been revoked.
     *
     * To disable CMEK for the Log Router, set this field to an empty string.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kms_key_name?: string;
    /**
     * Output only. The service account that will be used by the Log Router to access your
     * Cloud KMS key.
     *
     * Before enabling CMEK for Log Router, you must first assign the role
     * `roles/cloudkms.cryptoKeyEncrypterDecrypter` to the service account that
     * the Log Router will use to access your Cloud KMS key. Use
     * [GetSettings][google.logging.v2.ConfigServiceV2.GetSettings] to
     * obtain the service account ID.
     *
     * See [Enabling CMEK for Log
     * Router](https://cloud.google.com/logging/docs/routing/managed-encryption)
     * for more information.
     */
    kms_service_account_id?: string;
    /**
     * Optional. The Cloud region that will be used for _Default and _Required log buckets
     * for newly created projects and folders. For example `europe-west1`.
     * This setting does not affect the location of custom log buckets.
     */
    storage_location?: string;
    /**
     * Optional. If set to true, the _Default sink in newly created projects and folders
     * will created in a disabled state. This can be used to automatically disable
     * log ingestion if there is already an aggregated sink configured in the
     * hierarchy. The _Default sink can be re-enabled manually if needed.
     */
    disable_default_sink?: boolean;
}
export interface SettingsAminoMsg {
    type: "/google.logging.v2.Settings";
    value: SettingsAmino;
}
/**
 * Describes the settings associated with a project, folder, organization,
 * billing account, or flexible resource.
 */
export interface SettingsSDKType {
    name: string;
    kms_key_name: string;
    kms_service_account_id: string;
    storage_location: string;
    disable_default_sink: boolean;
}
/** The parameters to CopyLogEntries. */
export interface CopyLogEntriesRequest {
    /**
     * Required. Log bucket from which to copy log entries.
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-source-bucket"`
     */
    name: string;
    /**
     * Optional. A filter specifying which log entries to copy. The filter must be no more
     * than 20k characters. An empty filter matches all log entries.
     */
    filter: string;
    /** Required. Destination to which to copy log entries. */
    destination: string;
}
export interface CopyLogEntriesRequestProtoMsg {
    typeUrl: "/google.logging.v2.CopyLogEntriesRequest";
    value: Uint8Array;
}
/** The parameters to CopyLogEntries. */
export interface CopyLogEntriesRequestAmino {
    /**
     * Required. Log bucket from which to copy log entries.
     *
     * For example:
     *
     *   `"projects/my-project/locations/global/buckets/my-source-bucket"`
     */
    name?: string;
    /**
     * Optional. A filter specifying which log entries to copy. The filter must be no more
     * than 20k characters. An empty filter matches all log entries.
     */
    filter?: string;
    /** Required. Destination to which to copy log entries. */
    destination?: string;
}
export interface CopyLogEntriesRequestAminoMsg {
    type: "/google.logging.v2.CopyLogEntriesRequest";
    value: CopyLogEntriesRequestAmino;
}
/** The parameters to CopyLogEntries. */
export interface CopyLogEntriesRequestSDKType {
    name: string;
    filter: string;
    destination: string;
}
/** Metadata for CopyLogEntries long running operations. */
export interface CopyLogEntriesMetadata {
    /** The create time of an operation. */
    startTime?: Date;
    /** The end time of an operation. */
    endTime?: Date;
    /** State of an operation. */
    state: OperationState;
    /** Identifies whether the user has requested cancellation of the operation. */
    cancellationRequested: boolean;
    /** CopyLogEntries RPC request. */
    request?: CopyLogEntriesRequest;
    /** Estimated progress of the operation (0 - 100%). */
    progress: number;
    /**
     * The IAM identity of a service account that must be granted access to the
     * destination.
     *
     * If the service account is not granted permission to the destination within
     * an hour, the operation will be cancelled.
     *
     * For example: `"serviceAccount:foo@bar.com"`
     */
    writerIdentity: string;
}
export interface CopyLogEntriesMetadataProtoMsg {
    typeUrl: "/google.logging.v2.CopyLogEntriesMetadata";
    value: Uint8Array;
}
/** Metadata for CopyLogEntries long running operations. */
export interface CopyLogEntriesMetadataAmino {
    /** The create time of an operation. */
    start_time?: string;
    /** The end time of an operation. */
    end_time?: string;
    /** State of an operation. */
    state?: OperationState;
    /** Identifies whether the user has requested cancellation of the operation. */
    cancellation_requested?: boolean;
    /** CopyLogEntries RPC request. */
    request?: CopyLogEntriesRequestAmino;
    /** Estimated progress of the operation (0 - 100%). */
    progress?: number;
    /**
     * The IAM identity of a service account that must be granted access to the
     * destination.
     *
     * If the service account is not granted permission to the destination within
     * an hour, the operation will be cancelled.
     *
     * For example: `"serviceAccount:foo@bar.com"`
     */
    writer_identity?: string;
}
export interface CopyLogEntriesMetadataAminoMsg {
    type: "/google.logging.v2.CopyLogEntriesMetadata";
    value: CopyLogEntriesMetadataAmino;
}
/** Metadata for CopyLogEntries long running operations. */
export interface CopyLogEntriesMetadataSDKType {
    start_time?: Date;
    end_time?: Date;
    state: OperationState;
    cancellation_requested: boolean;
    request?: CopyLogEntriesRequestSDKType;
    progress: number;
    writer_identity: string;
}
/** Response type for CopyLogEntries long running operations. */
export interface CopyLogEntriesResponse {
    /** Number of log entries copied. */
    logEntriesCopiedCount: bigint;
}
export interface CopyLogEntriesResponseProtoMsg {
    typeUrl: "/google.logging.v2.CopyLogEntriesResponse";
    value: Uint8Array;
}
/** Response type for CopyLogEntries long running operations. */
export interface CopyLogEntriesResponseAmino {
    /** Number of log entries copied. */
    log_entries_copied_count?: string;
}
export interface CopyLogEntriesResponseAminoMsg {
    type: "/google.logging.v2.CopyLogEntriesResponse";
    value: CopyLogEntriesResponseAmino;
}
/** Response type for CopyLogEntries long running operations. */
export interface CopyLogEntriesResponseSDKType {
    log_entries_copied_count: bigint;
}
export declare const LogBucket: {
    typeUrl: string;
    is(o: any): o is LogBucket;
    isSDK(o: any): o is LogBucketSDKType;
    isAmino(o: any): o is LogBucketAmino;
    encode(message: LogBucket, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogBucket;
    fromJSON(object: any): LogBucket;
    toJSON(message: LogBucket): JsonSafe<LogBucket>;
    fromPartial(object: DeepPartial<LogBucket>): LogBucket;
    fromSDK(object: LogBucketSDKType): LogBucket;
    fromSDKJSON(object: any): LogBucketSDKType;
    toSDK(message: LogBucket): LogBucketSDKType;
    fromAmino(object: LogBucketAmino): LogBucket;
    toAmino(message: LogBucket): LogBucketAmino;
    fromAminoMsg(object: LogBucketAminoMsg): LogBucket;
    fromProtoMsg(message: LogBucketProtoMsg): LogBucket;
    toProto(message: LogBucket): Uint8Array;
    toProtoMsg(message: LogBucket): LogBucketProtoMsg;
    registerTypeUrl(): void;
};
export declare const LogView: {
    typeUrl: string;
    is(o: any): o is LogView;
    isSDK(o: any): o is LogViewSDKType;
    isAmino(o: any): o is LogViewAmino;
    encode(message: LogView, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogView;
    fromJSON(object: any): LogView;
    toJSON(message: LogView): JsonSafe<LogView>;
    fromPartial(object: DeepPartial<LogView>): LogView;
    fromSDK(object: LogViewSDKType): LogView;
    fromSDKJSON(object: any): LogViewSDKType;
    toSDK(message: LogView): LogViewSDKType;
    fromAmino(object: LogViewAmino): LogView;
    toAmino(message: LogView): LogViewAmino;
    fromAminoMsg(object: LogViewAminoMsg): LogView;
    fromProtoMsg(message: LogViewProtoMsg): LogView;
    toProto(message: LogView): Uint8Array;
    toProtoMsg(message: LogView): LogViewProtoMsg;
    registerTypeUrl(): void;
};
export declare const LogSink: {
    typeUrl: string;
    is(o: any): o is LogSink;
    isSDK(o: any): o is LogSinkSDKType;
    isAmino(o: any): o is LogSinkAmino;
    encode(message: LogSink, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogSink;
    fromJSON(object: any): LogSink;
    toJSON(message: LogSink): JsonSafe<LogSink>;
    fromPartial(object: DeepPartial<LogSink>): LogSink;
    fromSDK(object: LogSinkSDKType): LogSink;
    fromSDKJSON(object: any): LogSinkSDKType;
    toSDK(message: LogSink): LogSinkSDKType;
    fromAmino(object: LogSinkAmino): LogSink;
    toAmino(message: LogSink): LogSinkAmino;
    fromAminoMsg(object: LogSinkAminoMsg): LogSink;
    fromProtoMsg(message: LogSinkProtoMsg): LogSink;
    toProto(message: LogSink): Uint8Array;
    toProtoMsg(message: LogSink): LogSinkProtoMsg;
    registerTypeUrl(): void;
};
export declare const BigQueryOptions: {
    typeUrl: string;
    is(o: any): o is BigQueryOptions;
    isSDK(o: any): o is BigQueryOptionsSDKType;
    isAmino(o: any): o is BigQueryOptionsAmino;
    encode(message: BigQueryOptions, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BigQueryOptions;
    fromJSON(object: any): BigQueryOptions;
    toJSON(message: BigQueryOptions): JsonSafe<BigQueryOptions>;
    fromPartial(object: DeepPartial<BigQueryOptions>): BigQueryOptions;
    fromSDK(object: BigQueryOptionsSDKType): BigQueryOptions;
    fromSDKJSON(object: any): BigQueryOptionsSDKType;
    toSDK(message: BigQueryOptions): BigQueryOptionsSDKType;
    fromAmino(object: BigQueryOptionsAmino): BigQueryOptions;
    toAmino(message: BigQueryOptions): BigQueryOptionsAmino;
    fromAminoMsg(object: BigQueryOptionsAminoMsg): BigQueryOptions;
    fromProtoMsg(message: BigQueryOptionsProtoMsg): BigQueryOptions;
    toProto(message: BigQueryOptions): Uint8Array;
    toProtoMsg(message: BigQueryOptions): BigQueryOptionsProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListBucketsRequest: {
    typeUrl: string;
    is(o: any): o is ListBucketsRequest;
    isSDK(o: any): o is ListBucketsRequestSDKType;
    isAmino(o: any): o is ListBucketsRequestAmino;
    encode(message: ListBucketsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListBucketsRequest;
    fromJSON(object: any): ListBucketsRequest;
    toJSON(message: ListBucketsRequest): JsonSafe<ListBucketsRequest>;
    fromPartial(object: DeepPartial<ListBucketsRequest>): ListBucketsRequest;
    fromSDK(object: ListBucketsRequestSDKType): ListBucketsRequest;
    fromSDKJSON(object: any): ListBucketsRequestSDKType;
    toSDK(message: ListBucketsRequest): ListBucketsRequestSDKType;
    fromAmino(object: ListBucketsRequestAmino): ListBucketsRequest;
    toAmino(message: ListBucketsRequest): ListBucketsRequestAmino;
    fromAminoMsg(object: ListBucketsRequestAminoMsg): ListBucketsRequest;
    fromProtoMsg(message: ListBucketsRequestProtoMsg): ListBucketsRequest;
    toProto(message: ListBucketsRequest): Uint8Array;
    toProtoMsg(message: ListBucketsRequest): ListBucketsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListBucketsResponse: {
    typeUrl: string;
    is(o: any): o is ListBucketsResponse;
    isSDK(o: any): o is ListBucketsResponseSDKType;
    isAmino(o: any): o is ListBucketsResponseAmino;
    encode(message: ListBucketsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListBucketsResponse;
    fromJSON(object: any): ListBucketsResponse;
    toJSON(message: ListBucketsResponse): JsonSafe<ListBucketsResponse>;
    fromPartial(object: DeepPartial<ListBucketsResponse>): ListBucketsResponse;
    fromSDK(object: ListBucketsResponseSDKType): ListBucketsResponse;
    fromSDKJSON(object: any): ListBucketsResponseSDKType;
    toSDK(message: ListBucketsResponse): ListBucketsResponseSDKType;
    fromAmino(object: ListBucketsResponseAmino): ListBucketsResponse;
    toAmino(message: ListBucketsResponse): ListBucketsResponseAmino;
    fromAminoMsg(object: ListBucketsResponseAminoMsg): ListBucketsResponse;
    fromProtoMsg(message: ListBucketsResponseProtoMsg): ListBucketsResponse;
    toProto(message: ListBucketsResponse): Uint8Array;
    toProtoMsg(message: ListBucketsResponse): ListBucketsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const CreateBucketRequest: {
    typeUrl: string;
    is(o: any): o is CreateBucketRequest;
    isSDK(o: any): o is CreateBucketRequestSDKType;
    isAmino(o: any): o is CreateBucketRequestAmino;
    encode(message: CreateBucketRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CreateBucketRequest;
    fromJSON(object: any): CreateBucketRequest;
    toJSON(message: CreateBucketRequest): JsonSafe<CreateBucketRequest>;
    fromPartial(object: DeepPartial<CreateBucketRequest>): CreateBucketRequest;
    fromSDK(object: CreateBucketRequestSDKType): CreateBucketRequest;
    fromSDKJSON(object: any): CreateBucketRequestSDKType;
    toSDK(message: CreateBucketRequest): CreateBucketRequestSDKType;
    fromAmino(object: CreateBucketRequestAmino): CreateBucketRequest;
    toAmino(message: CreateBucketRequest): CreateBucketRequestAmino;
    fromAminoMsg(object: CreateBucketRequestAminoMsg): CreateBucketRequest;
    fromProtoMsg(message: CreateBucketRequestProtoMsg): CreateBucketRequest;
    toProto(message: CreateBucketRequest): Uint8Array;
    toProtoMsg(message: CreateBucketRequest): CreateBucketRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateBucketRequest: {
    typeUrl: string;
    is(o: any): o is UpdateBucketRequest;
    isSDK(o: any): o is UpdateBucketRequestSDKType;
    isAmino(o: any): o is UpdateBucketRequestAmino;
    encode(message: UpdateBucketRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateBucketRequest;
    fromJSON(object: any): UpdateBucketRequest;
    toJSON(message: UpdateBucketRequest): JsonSafe<UpdateBucketRequest>;
    fromPartial(object: DeepPartial<UpdateBucketRequest>): UpdateBucketRequest;
    fromSDK(object: UpdateBucketRequestSDKType): UpdateBucketRequest;
    fromSDKJSON(object: any): UpdateBucketRequestSDKType;
    toSDK(message: UpdateBucketRequest): UpdateBucketRequestSDKType;
    fromAmino(object: UpdateBucketRequestAmino): UpdateBucketRequest;
    toAmino(message: UpdateBucketRequest): UpdateBucketRequestAmino;
    fromAminoMsg(object: UpdateBucketRequestAminoMsg): UpdateBucketRequest;
    fromProtoMsg(message: UpdateBucketRequestProtoMsg): UpdateBucketRequest;
    toProto(message: UpdateBucketRequest): Uint8Array;
    toProtoMsg(message: UpdateBucketRequest): UpdateBucketRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetBucketRequest: {
    typeUrl: string;
    is(o: any): o is GetBucketRequest;
    isSDK(o: any): o is GetBucketRequestSDKType;
    isAmino(o: any): o is GetBucketRequestAmino;
    encode(message: GetBucketRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetBucketRequest;
    fromJSON(object: any): GetBucketRequest;
    toJSON(message: GetBucketRequest): JsonSafe<GetBucketRequest>;
    fromPartial(object: DeepPartial<GetBucketRequest>): GetBucketRequest;
    fromSDK(object: GetBucketRequestSDKType): GetBucketRequest;
    fromSDKJSON(object: any): GetBucketRequestSDKType;
    toSDK(message: GetBucketRequest): GetBucketRequestSDKType;
    fromAmino(object: GetBucketRequestAmino): GetBucketRequest;
    toAmino(message: GetBucketRequest): GetBucketRequestAmino;
    fromAminoMsg(object: GetBucketRequestAminoMsg): GetBucketRequest;
    fromProtoMsg(message: GetBucketRequestProtoMsg): GetBucketRequest;
    toProto(message: GetBucketRequest): Uint8Array;
    toProtoMsg(message: GetBucketRequest): GetBucketRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteBucketRequest: {
    typeUrl: string;
    is(o: any): o is DeleteBucketRequest;
    isSDK(o: any): o is DeleteBucketRequestSDKType;
    isAmino(o: any): o is DeleteBucketRequestAmino;
    encode(message: DeleteBucketRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteBucketRequest;
    fromJSON(object: any): DeleteBucketRequest;
    toJSON(message: DeleteBucketRequest): JsonSafe<DeleteBucketRequest>;
    fromPartial(object: DeepPartial<DeleteBucketRequest>): DeleteBucketRequest;
    fromSDK(object: DeleteBucketRequestSDKType): DeleteBucketRequest;
    fromSDKJSON(object: any): DeleteBucketRequestSDKType;
    toSDK(message: DeleteBucketRequest): DeleteBucketRequestSDKType;
    fromAmino(object: DeleteBucketRequestAmino): DeleteBucketRequest;
    toAmino(message: DeleteBucketRequest): DeleteBucketRequestAmino;
    fromAminoMsg(object: DeleteBucketRequestAminoMsg): DeleteBucketRequest;
    fromProtoMsg(message: DeleteBucketRequestProtoMsg): DeleteBucketRequest;
    toProto(message: DeleteBucketRequest): Uint8Array;
    toProtoMsg(message: DeleteBucketRequest): DeleteBucketRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UndeleteBucketRequest: {
    typeUrl: string;
    is(o: any): o is UndeleteBucketRequest;
    isSDK(o: any): o is UndeleteBucketRequestSDKType;
    isAmino(o: any): o is UndeleteBucketRequestAmino;
    encode(message: UndeleteBucketRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UndeleteBucketRequest;
    fromJSON(object: any): UndeleteBucketRequest;
    toJSON(message: UndeleteBucketRequest): JsonSafe<UndeleteBucketRequest>;
    fromPartial(object: DeepPartial<UndeleteBucketRequest>): UndeleteBucketRequest;
    fromSDK(object: UndeleteBucketRequestSDKType): UndeleteBucketRequest;
    fromSDKJSON(object: any): UndeleteBucketRequestSDKType;
    toSDK(message: UndeleteBucketRequest): UndeleteBucketRequestSDKType;
    fromAmino(object: UndeleteBucketRequestAmino): UndeleteBucketRequest;
    toAmino(message: UndeleteBucketRequest): UndeleteBucketRequestAmino;
    fromAminoMsg(object: UndeleteBucketRequestAminoMsg): UndeleteBucketRequest;
    fromProtoMsg(message: UndeleteBucketRequestProtoMsg): UndeleteBucketRequest;
    toProto(message: UndeleteBucketRequest): Uint8Array;
    toProtoMsg(message: UndeleteBucketRequest): UndeleteBucketRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListViewsRequest: {
    typeUrl: string;
    is(o: any): o is ListViewsRequest;
    isSDK(o: any): o is ListViewsRequestSDKType;
    isAmino(o: any): o is ListViewsRequestAmino;
    encode(message: ListViewsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListViewsRequest;
    fromJSON(object: any): ListViewsRequest;
    toJSON(message: ListViewsRequest): JsonSafe<ListViewsRequest>;
    fromPartial(object: DeepPartial<ListViewsRequest>): ListViewsRequest;
    fromSDK(object: ListViewsRequestSDKType): ListViewsRequest;
    fromSDKJSON(object: any): ListViewsRequestSDKType;
    toSDK(message: ListViewsRequest): ListViewsRequestSDKType;
    fromAmino(object: ListViewsRequestAmino): ListViewsRequest;
    toAmino(message: ListViewsRequest): ListViewsRequestAmino;
    fromAminoMsg(object: ListViewsRequestAminoMsg): ListViewsRequest;
    fromProtoMsg(message: ListViewsRequestProtoMsg): ListViewsRequest;
    toProto(message: ListViewsRequest): Uint8Array;
    toProtoMsg(message: ListViewsRequest): ListViewsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListViewsResponse: {
    typeUrl: string;
    is(o: any): o is ListViewsResponse;
    isSDK(o: any): o is ListViewsResponseSDKType;
    isAmino(o: any): o is ListViewsResponseAmino;
    encode(message: ListViewsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListViewsResponse;
    fromJSON(object: any): ListViewsResponse;
    toJSON(message: ListViewsResponse): JsonSafe<ListViewsResponse>;
    fromPartial(object: DeepPartial<ListViewsResponse>): ListViewsResponse;
    fromSDK(object: ListViewsResponseSDKType): ListViewsResponse;
    fromSDKJSON(object: any): ListViewsResponseSDKType;
    toSDK(message: ListViewsResponse): ListViewsResponseSDKType;
    fromAmino(object: ListViewsResponseAmino): ListViewsResponse;
    toAmino(message: ListViewsResponse): ListViewsResponseAmino;
    fromAminoMsg(object: ListViewsResponseAminoMsg): ListViewsResponse;
    fromProtoMsg(message: ListViewsResponseProtoMsg): ListViewsResponse;
    toProto(message: ListViewsResponse): Uint8Array;
    toProtoMsg(message: ListViewsResponse): ListViewsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const CreateViewRequest: {
    typeUrl: string;
    is(o: any): o is CreateViewRequest;
    isSDK(o: any): o is CreateViewRequestSDKType;
    isAmino(o: any): o is CreateViewRequestAmino;
    encode(message: CreateViewRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CreateViewRequest;
    fromJSON(object: any): CreateViewRequest;
    toJSON(message: CreateViewRequest): JsonSafe<CreateViewRequest>;
    fromPartial(object: DeepPartial<CreateViewRequest>): CreateViewRequest;
    fromSDK(object: CreateViewRequestSDKType): CreateViewRequest;
    fromSDKJSON(object: any): CreateViewRequestSDKType;
    toSDK(message: CreateViewRequest): CreateViewRequestSDKType;
    fromAmino(object: CreateViewRequestAmino): CreateViewRequest;
    toAmino(message: CreateViewRequest): CreateViewRequestAmino;
    fromAminoMsg(object: CreateViewRequestAminoMsg): CreateViewRequest;
    fromProtoMsg(message: CreateViewRequestProtoMsg): CreateViewRequest;
    toProto(message: CreateViewRequest): Uint8Array;
    toProtoMsg(message: CreateViewRequest): CreateViewRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateViewRequest: {
    typeUrl: string;
    is(o: any): o is UpdateViewRequest;
    isSDK(o: any): o is UpdateViewRequestSDKType;
    isAmino(o: any): o is UpdateViewRequestAmino;
    encode(message: UpdateViewRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateViewRequest;
    fromJSON(object: any): UpdateViewRequest;
    toJSON(message: UpdateViewRequest): JsonSafe<UpdateViewRequest>;
    fromPartial(object: DeepPartial<UpdateViewRequest>): UpdateViewRequest;
    fromSDK(object: UpdateViewRequestSDKType): UpdateViewRequest;
    fromSDKJSON(object: any): UpdateViewRequestSDKType;
    toSDK(message: UpdateViewRequest): UpdateViewRequestSDKType;
    fromAmino(object: UpdateViewRequestAmino): UpdateViewRequest;
    toAmino(message: UpdateViewRequest): UpdateViewRequestAmino;
    fromAminoMsg(object: UpdateViewRequestAminoMsg): UpdateViewRequest;
    fromProtoMsg(message: UpdateViewRequestProtoMsg): UpdateViewRequest;
    toProto(message: UpdateViewRequest): Uint8Array;
    toProtoMsg(message: UpdateViewRequest): UpdateViewRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetViewRequest: {
    typeUrl: string;
    is(o: any): o is GetViewRequest;
    isSDK(o: any): o is GetViewRequestSDKType;
    isAmino(o: any): o is GetViewRequestAmino;
    encode(message: GetViewRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetViewRequest;
    fromJSON(object: any): GetViewRequest;
    toJSON(message: GetViewRequest): JsonSafe<GetViewRequest>;
    fromPartial(object: DeepPartial<GetViewRequest>): GetViewRequest;
    fromSDK(object: GetViewRequestSDKType): GetViewRequest;
    fromSDKJSON(object: any): GetViewRequestSDKType;
    toSDK(message: GetViewRequest): GetViewRequestSDKType;
    fromAmino(object: GetViewRequestAmino): GetViewRequest;
    toAmino(message: GetViewRequest): GetViewRequestAmino;
    fromAminoMsg(object: GetViewRequestAminoMsg): GetViewRequest;
    fromProtoMsg(message: GetViewRequestProtoMsg): GetViewRequest;
    toProto(message: GetViewRequest): Uint8Array;
    toProtoMsg(message: GetViewRequest): GetViewRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteViewRequest: {
    typeUrl: string;
    is(o: any): o is DeleteViewRequest;
    isSDK(o: any): o is DeleteViewRequestSDKType;
    isAmino(o: any): o is DeleteViewRequestAmino;
    encode(message: DeleteViewRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteViewRequest;
    fromJSON(object: any): DeleteViewRequest;
    toJSON(message: DeleteViewRequest): JsonSafe<DeleteViewRequest>;
    fromPartial(object: DeepPartial<DeleteViewRequest>): DeleteViewRequest;
    fromSDK(object: DeleteViewRequestSDKType): DeleteViewRequest;
    fromSDKJSON(object: any): DeleteViewRequestSDKType;
    toSDK(message: DeleteViewRequest): DeleteViewRequestSDKType;
    fromAmino(object: DeleteViewRequestAmino): DeleteViewRequest;
    toAmino(message: DeleteViewRequest): DeleteViewRequestAmino;
    fromAminoMsg(object: DeleteViewRequestAminoMsg): DeleteViewRequest;
    fromProtoMsg(message: DeleteViewRequestProtoMsg): DeleteViewRequest;
    toProto(message: DeleteViewRequest): Uint8Array;
    toProtoMsg(message: DeleteViewRequest): DeleteViewRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListSinksRequest: {
    typeUrl: string;
    is(o: any): o is ListSinksRequest;
    isSDK(o: any): o is ListSinksRequestSDKType;
    isAmino(o: any): o is ListSinksRequestAmino;
    encode(message: ListSinksRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListSinksRequest;
    fromJSON(object: any): ListSinksRequest;
    toJSON(message: ListSinksRequest): JsonSafe<ListSinksRequest>;
    fromPartial(object: DeepPartial<ListSinksRequest>): ListSinksRequest;
    fromSDK(object: ListSinksRequestSDKType): ListSinksRequest;
    fromSDKJSON(object: any): ListSinksRequestSDKType;
    toSDK(message: ListSinksRequest): ListSinksRequestSDKType;
    fromAmino(object: ListSinksRequestAmino): ListSinksRequest;
    toAmino(message: ListSinksRequest): ListSinksRequestAmino;
    fromAminoMsg(object: ListSinksRequestAminoMsg): ListSinksRequest;
    fromProtoMsg(message: ListSinksRequestProtoMsg): ListSinksRequest;
    toProto(message: ListSinksRequest): Uint8Array;
    toProtoMsg(message: ListSinksRequest): ListSinksRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListSinksResponse: {
    typeUrl: string;
    is(o: any): o is ListSinksResponse;
    isSDK(o: any): o is ListSinksResponseSDKType;
    isAmino(o: any): o is ListSinksResponseAmino;
    encode(message: ListSinksResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListSinksResponse;
    fromJSON(object: any): ListSinksResponse;
    toJSON(message: ListSinksResponse): JsonSafe<ListSinksResponse>;
    fromPartial(object: DeepPartial<ListSinksResponse>): ListSinksResponse;
    fromSDK(object: ListSinksResponseSDKType): ListSinksResponse;
    fromSDKJSON(object: any): ListSinksResponseSDKType;
    toSDK(message: ListSinksResponse): ListSinksResponseSDKType;
    fromAmino(object: ListSinksResponseAmino): ListSinksResponse;
    toAmino(message: ListSinksResponse): ListSinksResponseAmino;
    fromAminoMsg(object: ListSinksResponseAminoMsg): ListSinksResponse;
    fromProtoMsg(message: ListSinksResponseProtoMsg): ListSinksResponse;
    toProto(message: ListSinksResponse): Uint8Array;
    toProtoMsg(message: ListSinksResponse): ListSinksResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetSinkRequest: {
    typeUrl: string;
    is(o: any): o is GetSinkRequest;
    isSDK(o: any): o is GetSinkRequestSDKType;
    isAmino(o: any): o is GetSinkRequestAmino;
    encode(message: GetSinkRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetSinkRequest;
    fromJSON(object: any): GetSinkRequest;
    toJSON(message: GetSinkRequest): JsonSafe<GetSinkRequest>;
    fromPartial(object: DeepPartial<GetSinkRequest>): GetSinkRequest;
    fromSDK(object: GetSinkRequestSDKType): GetSinkRequest;
    fromSDKJSON(object: any): GetSinkRequestSDKType;
    toSDK(message: GetSinkRequest): GetSinkRequestSDKType;
    fromAmino(object: GetSinkRequestAmino): GetSinkRequest;
    toAmino(message: GetSinkRequest): GetSinkRequestAmino;
    fromAminoMsg(object: GetSinkRequestAminoMsg): GetSinkRequest;
    fromProtoMsg(message: GetSinkRequestProtoMsg): GetSinkRequest;
    toProto(message: GetSinkRequest): Uint8Array;
    toProtoMsg(message: GetSinkRequest): GetSinkRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CreateSinkRequest: {
    typeUrl: string;
    is(o: any): o is CreateSinkRequest;
    isSDK(o: any): o is CreateSinkRequestSDKType;
    isAmino(o: any): o is CreateSinkRequestAmino;
    encode(message: CreateSinkRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CreateSinkRequest;
    fromJSON(object: any): CreateSinkRequest;
    toJSON(message: CreateSinkRequest): JsonSafe<CreateSinkRequest>;
    fromPartial(object: DeepPartial<CreateSinkRequest>): CreateSinkRequest;
    fromSDK(object: CreateSinkRequestSDKType): CreateSinkRequest;
    fromSDKJSON(object: any): CreateSinkRequestSDKType;
    toSDK(message: CreateSinkRequest): CreateSinkRequestSDKType;
    fromAmino(object: CreateSinkRequestAmino): CreateSinkRequest;
    toAmino(message: CreateSinkRequest): CreateSinkRequestAmino;
    fromAminoMsg(object: CreateSinkRequestAminoMsg): CreateSinkRequest;
    fromProtoMsg(message: CreateSinkRequestProtoMsg): CreateSinkRequest;
    toProto(message: CreateSinkRequest): Uint8Array;
    toProtoMsg(message: CreateSinkRequest): CreateSinkRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateSinkRequest: {
    typeUrl: string;
    is(o: any): o is UpdateSinkRequest;
    isSDK(o: any): o is UpdateSinkRequestSDKType;
    isAmino(o: any): o is UpdateSinkRequestAmino;
    encode(message: UpdateSinkRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateSinkRequest;
    fromJSON(object: any): UpdateSinkRequest;
    toJSON(message: UpdateSinkRequest): JsonSafe<UpdateSinkRequest>;
    fromPartial(object: DeepPartial<UpdateSinkRequest>): UpdateSinkRequest;
    fromSDK(object: UpdateSinkRequestSDKType): UpdateSinkRequest;
    fromSDKJSON(object: any): UpdateSinkRequestSDKType;
    toSDK(message: UpdateSinkRequest): UpdateSinkRequestSDKType;
    fromAmino(object: UpdateSinkRequestAmino): UpdateSinkRequest;
    toAmino(message: UpdateSinkRequest): UpdateSinkRequestAmino;
    fromAminoMsg(object: UpdateSinkRequestAminoMsg): UpdateSinkRequest;
    fromProtoMsg(message: UpdateSinkRequestProtoMsg): UpdateSinkRequest;
    toProto(message: UpdateSinkRequest): Uint8Array;
    toProtoMsg(message: UpdateSinkRequest): UpdateSinkRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteSinkRequest: {
    typeUrl: string;
    is(o: any): o is DeleteSinkRequest;
    isSDK(o: any): o is DeleteSinkRequestSDKType;
    isAmino(o: any): o is DeleteSinkRequestAmino;
    encode(message: DeleteSinkRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteSinkRequest;
    fromJSON(object: any): DeleteSinkRequest;
    toJSON(message: DeleteSinkRequest): JsonSafe<DeleteSinkRequest>;
    fromPartial(object: DeepPartial<DeleteSinkRequest>): DeleteSinkRequest;
    fromSDK(object: DeleteSinkRequestSDKType): DeleteSinkRequest;
    fromSDKJSON(object: any): DeleteSinkRequestSDKType;
    toSDK(message: DeleteSinkRequest): DeleteSinkRequestSDKType;
    fromAmino(object: DeleteSinkRequestAmino): DeleteSinkRequest;
    toAmino(message: DeleteSinkRequest): DeleteSinkRequestAmino;
    fromAminoMsg(object: DeleteSinkRequestAminoMsg): DeleteSinkRequest;
    fromProtoMsg(message: DeleteSinkRequestProtoMsg): DeleteSinkRequest;
    toProto(message: DeleteSinkRequest): Uint8Array;
    toProtoMsg(message: DeleteSinkRequest): DeleteSinkRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const LogExclusion: {
    typeUrl: string;
    is(o: any): o is LogExclusion;
    isSDK(o: any): o is LogExclusionSDKType;
    isAmino(o: any): o is LogExclusionAmino;
    encode(message: LogExclusion, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogExclusion;
    fromJSON(object: any): LogExclusion;
    toJSON(message: LogExclusion): JsonSafe<LogExclusion>;
    fromPartial(object: DeepPartial<LogExclusion>): LogExclusion;
    fromSDK(object: LogExclusionSDKType): LogExclusion;
    fromSDKJSON(object: any): LogExclusionSDKType;
    toSDK(message: LogExclusion): LogExclusionSDKType;
    fromAmino(object: LogExclusionAmino): LogExclusion;
    toAmino(message: LogExclusion): LogExclusionAmino;
    fromAminoMsg(object: LogExclusionAminoMsg): LogExclusion;
    fromProtoMsg(message: LogExclusionProtoMsg): LogExclusion;
    toProto(message: LogExclusion): Uint8Array;
    toProtoMsg(message: LogExclusion): LogExclusionProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListExclusionsRequest: {
    typeUrl: string;
    is(o: any): o is ListExclusionsRequest;
    isSDK(o: any): o is ListExclusionsRequestSDKType;
    isAmino(o: any): o is ListExclusionsRequestAmino;
    encode(message: ListExclusionsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListExclusionsRequest;
    fromJSON(object: any): ListExclusionsRequest;
    toJSON(message: ListExclusionsRequest): JsonSafe<ListExclusionsRequest>;
    fromPartial(object: DeepPartial<ListExclusionsRequest>): ListExclusionsRequest;
    fromSDK(object: ListExclusionsRequestSDKType): ListExclusionsRequest;
    fromSDKJSON(object: any): ListExclusionsRequestSDKType;
    toSDK(message: ListExclusionsRequest): ListExclusionsRequestSDKType;
    fromAmino(object: ListExclusionsRequestAmino): ListExclusionsRequest;
    toAmino(message: ListExclusionsRequest): ListExclusionsRequestAmino;
    fromAminoMsg(object: ListExclusionsRequestAminoMsg): ListExclusionsRequest;
    fromProtoMsg(message: ListExclusionsRequestProtoMsg): ListExclusionsRequest;
    toProto(message: ListExclusionsRequest): Uint8Array;
    toProtoMsg(message: ListExclusionsRequest): ListExclusionsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListExclusionsResponse: {
    typeUrl: string;
    is(o: any): o is ListExclusionsResponse;
    isSDK(o: any): o is ListExclusionsResponseSDKType;
    isAmino(o: any): o is ListExclusionsResponseAmino;
    encode(message: ListExclusionsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListExclusionsResponse;
    fromJSON(object: any): ListExclusionsResponse;
    toJSON(message: ListExclusionsResponse): JsonSafe<ListExclusionsResponse>;
    fromPartial(object: DeepPartial<ListExclusionsResponse>): ListExclusionsResponse;
    fromSDK(object: ListExclusionsResponseSDKType): ListExclusionsResponse;
    fromSDKJSON(object: any): ListExclusionsResponseSDKType;
    toSDK(message: ListExclusionsResponse): ListExclusionsResponseSDKType;
    fromAmino(object: ListExclusionsResponseAmino): ListExclusionsResponse;
    toAmino(message: ListExclusionsResponse): ListExclusionsResponseAmino;
    fromAminoMsg(object: ListExclusionsResponseAminoMsg): ListExclusionsResponse;
    fromProtoMsg(message: ListExclusionsResponseProtoMsg): ListExclusionsResponse;
    toProto(message: ListExclusionsResponse): Uint8Array;
    toProtoMsg(message: ListExclusionsResponse): ListExclusionsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetExclusionRequest: {
    typeUrl: string;
    is(o: any): o is GetExclusionRequest;
    isSDK(o: any): o is GetExclusionRequestSDKType;
    isAmino(o: any): o is GetExclusionRequestAmino;
    encode(message: GetExclusionRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetExclusionRequest;
    fromJSON(object: any): GetExclusionRequest;
    toJSON(message: GetExclusionRequest): JsonSafe<GetExclusionRequest>;
    fromPartial(object: DeepPartial<GetExclusionRequest>): GetExclusionRequest;
    fromSDK(object: GetExclusionRequestSDKType): GetExclusionRequest;
    fromSDKJSON(object: any): GetExclusionRequestSDKType;
    toSDK(message: GetExclusionRequest): GetExclusionRequestSDKType;
    fromAmino(object: GetExclusionRequestAmino): GetExclusionRequest;
    toAmino(message: GetExclusionRequest): GetExclusionRequestAmino;
    fromAminoMsg(object: GetExclusionRequestAminoMsg): GetExclusionRequest;
    fromProtoMsg(message: GetExclusionRequestProtoMsg): GetExclusionRequest;
    toProto(message: GetExclusionRequest): Uint8Array;
    toProtoMsg(message: GetExclusionRequest): GetExclusionRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CreateExclusionRequest: {
    typeUrl: string;
    is(o: any): o is CreateExclusionRequest;
    isSDK(o: any): o is CreateExclusionRequestSDKType;
    isAmino(o: any): o is CreateExclusionRequestAmino;
    encode(message: CreateExclusionRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CreateExclusionRequest;
    fromJSON(object: any): CreateExclusionRequest;
    toJSON(message: CreateExclusionRequest): JsonSafe<CreateExclusionRequest>;
    fromPartial(object: DeepPartial<CreateExclusionRequest>): CreateExclusionRequest;
    fromSDK(object: CreateExclusionRequestSDKType): CreateExclusionRequest;
    fromSDKJSON(object: any): CreateExclusionRequestSDKType;
    toSDK(message: CreateExclusionRequest): CreateExclusionRequestSDKType;
    fromAmino(object: CreateExclusionRequestAmino): CreateExclusionRequest;
    toAmino(message: CreateExclusionRequest): CreateExclusionRequestAmino;
    fromAminoMsg(object: CreateExclusionRequestAminoMsg): CreateExclusionRequest;
    fromProtoMsg(message: CreateExclusionRequestProtoMsg): CreateExclusionRequest;
    toProto(message: CreateExclusionRequest): Uint8Array;
    toProtoMsg(message: CreateExclusionRequest): CreateExclusionRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateExclusionRequest: {
    typeUrl: string;
    is(o: any): o is UpdateExclusionRequest;
    isSDK(o: any): o is UpdateExclusionRequestSDKType;
    isAmino(o: any): o is UpdateExclusionRequestAmino;
    encode(message: UpdateExclusionRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateExclusionRequest;
    fromJSON(object: any): UpdateExclusionRequest;
    toJSON(message: UpdateExclusionRequest): JsonSafe<UpdateExclusionRequest>;
    fromPartial(object: DeepPartial<UpdateExclusionRequest>): UpdateExclusionRequest;
    fromSDK(object: UpdateExclusionRequestSDKType): UpdateExclusionRequest;
    fromSDKJSON(object: any): UpdateExclusionRequestSDKType;
    toSDK(message: UpdateExclusionRequest): UpdateExclusionRequestSDKType;
    fromAmino(object: UpdateExclusionRequestAmino): UpdateExclusionRequest;
    toAmino(message: UpdateExclusionRequest): UpdateExclusionRequestAmino;
    fromAminoMsg(object: UpdateExclusionRequestAminoMsg): UpdateExclusionRequest;
    fromProtoMsg(message: UpdateExclusionRequestProtoMsg): UpdateExclusionRequest;
    toProto(message: UpdateExclusionRequest): Uint8Array;
    toProtoMsg(message: UpdateExclusionRequest): UpdateExclusionRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteExclusionRequest: {
    typeUrl: string;
    is(o: any): o is DeleteExclusionRequest;
    isSDK(o: any): o is DeleteExclusionRequestSDKType;
    isAmino(o: any): o is DeleteExclusionRequestAmino;
    encode(message: DeleteExclusionRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteExclusionRequest;
    fromJSON(object: any): DeleteExclusionRequest;
    toJSON(message: DeleteExclusionRequest): JsonSafe<DeleteExclusionRequest>;
    fromPartial(object: DeepPartial<DeleteExclusionRequest>): DeleteExclusionRequest;
    fromSDK(object: DeleteExclusionRequestSDKType): DeleteExclusionRequest;
    fromSDKJSON(object: any): DeleteExclusionRequestSDKType;
    toSDK(message: DeleteExclusionRequest): DeleteExclusionRequestSDKType;
    fromAmino(object: DeleteExclusionRequestAmino): DeleteExclusionRequest;
    toAmino(message: DeleteExclusionRequest): DeleteExclusionRequestAmino;
    fromAminoMsg(object: DeleteExclusionRequestAminoMsg): DeleteExclusionRequest;
    fromProtoMsg(message: DeleteExclusionRequestProtoMsg): DeleteExclusionRequest;
    toProto(message: DeleteExclusionRequest): Uint8Array;
    toProtoMsg(message: DeleteExclusionRequest): DeleteExclusionRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetCmekSettingsRequest: {
    typeUrl: string;
    is(o: any): o is GetCmekSettingsRequest;
    isSDK(o: any): o is GetCmekSettingsRequestSDKType;
    isAmino(o: any): o is GetCmekSettingsRequestAmino;
    encode(message: GetCmekSettingsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetCmekSettingsRequest;
    fromJSON(object: any): GetCmekSettingsRequest;
    toJSON(message: GetCmekSettingsRequest): JsonSafe<GetCmekSettingsRequest>;
    fromPartial(object: DeepPartial<GetCmekSettingsRequest>): GetCmekSettingsRequest;
    fromSDK(object: GetCmekSettingsRequestSDKType): GetCmekSettingsRequest;
    fromSDKJSON(object: any): GetCmekSettingsRequestSDKType;
    toSDK(message: GetCmekSettingsRequest): GetCmekSettingsRequestSDKType;
    fromAmino(object: GetCmekSettingsRequestAmino): GetCmekSettingsRequest;
    toAmino(message: GetCmekSettingsRequest): GetCmekSettingsRequestAmino;
    fromAminoMsg(object: GetCmekSettingsRequestAminoMsg): GetCmekSettingsRequest;
    fromProtoMsg(message: GetCmekSettingsRequestProtoMsg): GetCmekSettingsRequest;
    toProto(message: GetCmekSettingsRequest): Uint8Array;
    toProtoMsg(message: GetCmekSettingsRequest): GetCmekSettingsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateCmekSettingsRequest: {
    typeUrl: string;
    is(o: any): o is UpdateCmekSettingsRequest;
    isSDK(o: any): o is UpdateCmekSettingsRequestSDKType;
    isAmino(o: any): o is UpdateCmekSettingsRequestAmino;
    encode(message: UpdateCmekSettingsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateCmekSettingsRequest;
    fromJSON(object: any): UpdateCmekSettingsRequest;
    toJSON(message: UpdateCmekSettingsRequest): JsonSafe<UpdateCmekSettingsRequest>;
    fromPartial(object: DeepPartial<UpdateCmekSettingsRequest>): UpdateCmekSettingsRequest;
    fromSDK(object: UpdateCmekSettingsRequestSDKType): UpdateCmekSettingsRequest;
    fromSDKJSON(object: any): UpdateCmekSettingsRequestSDKType;
    toSDK(message: UpdateCmekSettingsRequest): UpdateCmekSettingsRequestSDKType;
    fromAmino(object: UpdateCmekSettingsRequestAmino): UpdateCmekSettingsRequest;
    toAmino(message: UpdateCmekSettingsRequest): UpdateCmekSettingsRequestAmino;
    fromAminoMsg(object: UpdateCmekSettingsRequestAminoMsg): UpdateCmekSettingsRequest;
    fromProtoMsg(message: UpdateCmekSettingsRequestProtoMsg): UpdateCmekSettingsRequest;
    toProto(message: UpdateCmekSettingsRequest): Uint8Array;
    toProtoMsg(message: UpdateCmekSettingsRequest): UpdateCmekSettingsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CmekSettings: {
    typeUrl: string;
    is(o: any): o is CmekSettings;
    isSDK(o: any): o is CmekSettingsSDKType;
    isAmino(o: any): o is CmekSettingsAmino;
    encode(message: CmekSettings, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CmekSettings;
    fromJSON(object: any): CmekSettings;
    toJSON(message: CmekSettings): JsonSafe<CmekSettings>;
    fromPartial(object: DeepPartial<CmekSettings>): CmekSettings;
    fromSDK(object: CmekSettingsSDKType): CmekSettings;
    fromSDKJSON(object: any): CmekSettingsSDKType;
    toSDK(message: CmekSettings): CmekSettingsSDKType;
    fromAmino(object: CmekSettingsAmino): CmekSettings;
    toAmino(message: CmekSettings): CmekSettingsAmino;
    fromAminoMsg(object: CmekSettingsAminoMsg): CmekSettings;
    fromProtoMsg(message: CmekSettingsProtoMsg): CmekSettings;
    toProto(message: CmekSettings): Uint8Array;
    toProtoMsg(message: CmekSettings): CmekSettingsProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetSettingsRequest: {
    typeUrl: string;
    is(o: any): o is GetSettingsRequest;
    isSDK(o: any): o is GetSettingsRequestSDKType;
    isAmino(o: any): o is GetSettingsRequestAmino;
    encode(message: GetSettingsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetSettingsRequest;
    fromJSON(object: any): GetSettingsRequest;
    toJSON(message: GetSettingsRequest): JsonSafe<GetSettingsRequest>;
    fromPartial(object: DeepPartial<GetSettingsRequest>): GetSettingsRequest;
    fromSDK(object: GetSettingsRequestSDKType): GetSettingsRequest;
    fromSDKJSON(object: any): GetSettingsRequestSDKType;
    toSDK(message: GetSettingsRequest): GetSettingsRequestSDKType;
    fromAmino(object: GetSettingsRequestAmino): GetSettingsRequest;
    toAmino(message: GetSettingsRequest): GetSettingsRequestAmino;
    fromAminoMsg(object: GetSettingsRequestAminoMsg): GetSettingsRequest;
    fromProtoMsg(message: GetSettingsRequestProtoMsg): GetSettingsRequest;
    toProto(message: GetSettingsRequest): Uint8Array;
    toProtoMsg(message: GetSettingsRequest): GetSettingsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateSettingsRequest: {
    typeUrl: string;
    is(o: any): o is UpdateSettingsRequest;
    isSDK(o: any): o is UpdateSettingsRequestSDKType;
    isAmino(o: any): o is UpdateSettingsRequestAmino;
    encode(message: UpdateSettingsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateSettingsRequest;
    fromJSON(object: any): UpdateSettingsRequest;
    toJSON(message: UpdateSettingsRequest): JsonSafe<UpdateSettingsRequest>;
    fromPartial(object: DeepPartial<UpdateSettingsRequest>): UpdateSettingsRequest;
    fromSDK(object: UpdateSettingsRequestSDKType): UpdateSettingsRequest;
    fromSDKJSON(object: any): UpdateSettingsRequestSDKType;
    toSDK(message: UpdateSettingsRequest): UpdateSettingsRequestSDKType;
    fromAmino(object: UpdateSettingsRequestAmino): UpdateSettingsRequest;
    toAmino(message: UpdateSettingsRequest): UpdateSettingsRequestAmino;
    fromAminoMsg(object: UpdateSettingsRequestAminoMsg): UpdateSettingsRequest;
    fromProtoMsg(message: UpdateSettingsRequestProtoMsg): UpdateSettingsRequest;
    toProto(message: UpdateSettingsRequest): Uint8Array;
    toProtoMsg(message: UpdateSettingsRequest): UpdateSettingsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const Settings: {
    typeUrl: string;
    is(o: any): o is Settings;
    isSDK(o: any): o is SettingsSDKType;
    isAmino(o: any): o is SettingsAmino;
    encode(message: Settings, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Settings;
    fromJSON(object: any): Settings;
    toJSON(message: Settings): JsonSafe<Settings>;
    fromPartial(object: DeepPartial<Settings>): Settings;
    fromSDK(object: SettingsSDKType): Settings;
    fromSDKJSON(object: any): SettingsSDKType;
    toSDK(message: Settings): SettingsSDKType;
    fromAmino(object: SettingsAmino): Settings;
    toAmino(message: Settings): SettingsAmino;
    fromAminoMsg(object: SettingsAminoMsg): Settings;
    fromProtoMsg(message: SettingsProtoMsg): Settings;
    toProto(message: Settings): Uint8Array;
    toProtoMsg(message: Settings): SettingsProtoMsg;
    registerTypeUrl(): void;
};
export declare const CopyLogEntriesRequest: {
    typeUrl: string;
    is(o: any): o is CopyLogEntriesRequest;
    isSDK(o: any): o is CopyLogEntriesRequestSDKType;
    isAmino(o: any): o is CopyLogEntriesRequestAmino;
    encode(message: CopyLogEntriesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CopyLogEntriesRequest;
    fromJSON(object: any): CopyLogEntriesRequest;
    toJSON(message: CopyLogEntriesRequest): JsonSafe<CopyLogEntriesRequest>;
    fromPartial(object: DeepPartial<CopyLogEntriesRequest>): CopyLogEntriesRequest;
    fromSDK(object: CopyLogEntriesRequestSDKType): CopyLogEntriesRequest;
    fromSDKJSON(object: any): CopyLogEntriesRequestSDKType;
    toSDK(message: CopyLogEntriesRequest): CopyLogEntriesRequestSDKType;
    fromAmino(object: CopyLogEntriesRequestAmino): CopyLogEntriesRequest;
    toAmino(message: CopyLogEntriesRequest): CopyLogEntriesRequestAmino;
    fromAminoMsg(object: CopyLogEntriesRequestAminoMsg): CopyLogEntriesRequest;
    fromProtoMsg(message: CopyLogEntriesRequestProtoMsg): CopyLogEntriesRequest;
    toProto(message: CopyLogEntriesRequest): Uint8Array;
    toProtoMsg(message: CopyLogEntriesRequest): CopyLogEntriesRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CopyLogEntriesMetadata: {
    typeUrl: string;
    is(o: any): o is CopyLogEntriesMetadata;
    isSDK(o: any): o is CopyLogEntriesMetadataSDKType;
    isAmino(o: any): o is CopyLogEntriesMetadataAmino;
    encode(message: CopyLogEntriesMetadata, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CopyLogEntriesMetadata;
    fromJSON(object: any): CopyLogEntriesMetadata;
    toJSON(message: CopyLogEntriesMetadata): JsonSafe<CopyLogEntriesMetadata>;
    fromPartial(object: DeepPartial<CopyLogEntriesMetadata>): CopyLogEntriesMetadata;
    fromSDK(object: CopyLogEntriesMetadataSDKType): CopyLogEntriesMetadata;
    fromSDKJSON(object: any): CopyLogEntriesMetadataSDKType;
    toSDK(message: CopyLogEntriesMetadata): CopyLogEntriesMetadataSDKType;
    fromAmino(object: CopyLogEntriesMetadataAmino): CopyLogEntriesMetadata;
    toAmino(message: CopyLogEntriesMetadata): CopyLogEntriesMetadataAmino;
    fromAminoMsg(object: CopyLogEntriesMetadataAminoMsg): CopyLogEntriesMetadata;
    fromProtoMsg(message: CopyLogEntriesMetadataProtoMsg): CopyLogEntriesMetadata;
    toProto(message: CopyLogEntriesMetadata): Uint8Array;
    toProtoMsg(message: CopyLogEntriesMetadata): CopyLogEntriesMetadataProtoMsg;
    registerTypeUrl(): void;
};
export declare const CopyLogEntriesResponse: {
    typeUrl: string;
    is(o: any): o is CopyLogEntriesResponse;
    isSDK(o: any): o is CopyLogEntriesResponseSDKType;
    isAmino(o: any): o is CopyLogEntriesResponseAmino;
    encode(message: CopyLogEntriesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CopyLogEntriesResponse;
    fromJSON(object: any): CopyLogEntriesResponse;
    toJSON(message: CopyLogEntriesResponse): JsonSafe<CopyLogEntriesResponse>;
    fromPartial(object: DeepPartial<CopyLogEntriesResponse>): CopyLogEntriesResponse;
    fromSDK(object: CopyLogEntriesResponseSDKType): CopyLogEntriesResponse;
    fromSDKJSON(object: any): CopyLogEntriesResponseSDKType;
    toSDK(message: CopyLogEntriesResponse): CopyLogEntriesResponseSDKType;
    fromAmino(object: CopyLogEntriesResponseAmino): CopyLogEntriesResponse;
    toAmino(message: CopyLogEntriesResponse): CopyLogEntriesResponseAmino;
    fromAminoMsg(object: CopyLogEntriesResponseAminoMsg): CopyLogEntriesResponse;
    fromProtoMsg(message: CopyLogEntriesResponseProtoMsg): CopyLogEntriesResponse;
    toProto(message: CopyLogEntriesResponse): Uint8Array;
    toProtoMsg(message: CopyLogEntriesResponse): CopyLogEntriesResponseProtoMsg;
    registerTypeUrl(): void;
};
