import { MetricDescriptor, MetricDescriptorAmino, MetricDescriptorSDKType } from "../../api/metric";
import { Distribution_BucketOptions, Distribution_BucketOptionsAmino, Distribution_BucketOptionsSDKType } from "../../api/distribution";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
import { JsonSafe } from "../../../json-safe";
export declare const protobufPackage = "google.logging.v2";
/** Logging API version. */
export declare enum LogMetric_ApiVersion {
    /** V2 - Logging API v2. */
    V2 = 0,
    /** V1 - Logging API v1. */
    V1 = 1,
    UNRECOGNIZED = -1
}
export declare const LogMetric_ApiVersionSDKType: typeof LogMetric_ApiVersion;
export declare const LogMetric_ApiVersionAmino: typeof LogMetric_ApiVersion;
export declare function logMetric_ApiVersionFromJSON(object: any): LogMetric_ApiVersion;
export declare function logMetric_ApiVersionToJSON(object: LogMetric_ApiVersion): string;
export interface LogMetric_LabelExtractorsEntry {
    key: string;
    value: string;
}
export interface LogMetric_LabelExtractorsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface LogMetric_LabelExtractorsEntryAmino {
    key?: string;
    value?: string;
}
export interface LogMetric_LabelExtractorsEntryAminoMsg {
    type: string;
    value: LogMetric_LabelExtractorsEntryAmino;
}
export interface LogMetric_LabelExtractorsEntrySDKType {
    key: string;
    value: string;
}
/**
 * Describes a logs-based metric. The value of the metric is the number of log
 * entries that match a logs filter in a given time interval.
 *
 * Logs-based metrics can also be used to extract values from logs and create a
 * distribution of the values. The distribution records the statistics of the
 * extracted values along with an optional histogram of the values as specified
 * by the bucket options.
 */
export interface LogMetric {
    /**
     * Required. The client-assigned metric identifier.
     * Examples: `"error_count"`, `"nginx/requests"`.
     *
     * Metric identifiers are limited to 100 characters and can include only the
     * following characters: `A-Z`, `a-z`, `0-9`, and the special characters
     * `_-.,+!*',()%/`. The forward-slash character (`/`) denotes a hierarchy of
     * name pieces, and it cannot be the first character of the name.
     *
     * This field is the `[METRIC_ID]` part of a metric resource name in the
     * format "projects/[PROJECT_ID]/metrics/[METRIC_ID]". Example: If the
     * resource name of a metric is
     * `"projects/my-project/metrics/nginx%2Frequests"`, this field's value is
     * `"nginx/requests"`.
     */
    name: string;
    /**
     * Optional. A description of this metric, which is used in documentation.
     * The maximum length of the description is 8000 characters.
     */
    description: string;
    /**
     * Required. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced_filters) which
     * is used to match log entries. Example:
     *
     *     "resource.type=gae_app AND severity>=ERROR"
     *
     * The maximum length of the filter is 20000 characters.
     */
    filter: string;
    /**
     * Optional. If set to True, then this metric is disabled and it does not
     * generate any points.
     */
    disabled: boolean;
    /**
     * Optional. The metric descriptor associated with the logs-based metric.
     * If unspecified, it uses a default metric descriptor with a DELTA metric
     * kind, INT64 value type, with no labels and a unit of "1". Such a metric
     * counts the number of log entries matching the `filter` expression.
     *
     * The `name`, `type`, and `description` fields in the `metric_descriptor`
     * are output only, and is constructed using the `name` and `description`
     * field in the LogMetric.
     *
     * To create a logs-based metric that records a distribution of log values, a
     * DELTA metric kind with a DISTRIBUTION value type must be used along with
     * a `value_extractor` expression in the LogMetric.
     *
     * Each label in the metric descriptor must have a matching label
     * name as the key and an extractor expression as the value in the
     * `label_extractors` map.
     *
     * The `metric_kind` and `value_type` fields in the `metric_descriptor` cannot
     * be updated once initially configured. New labels can be added in the
     * `metric_descriptor`, but existing labels cannot be modified except for
     * their description.
     */
    metricDescriptor?: MetricDescriptor;
    /**
     * Optional. A `value_extractor` is required when using a distribution
     * logs-based metric to extract the values to record from a log entry.
     * Two functions are supported for value extraction: `EXTRACT(field)` or
     * `REGEXP_EXTRACT(field, regex)`. The argument are:
     *   1. field: The name of the log entry field from which the value is to be
     *      extracted.
     *   2. regex: A regular expression using the Google RE2 syntax
     *      (https://github.com/google/re2/wiki/Syntax) with a single capture
     *      group to extract data from the specified log entry field. The value
     *      of the field is converted to a string before applying the regex.
     *      It is an error to specify a regex that does not include exactly one
     *      capture group.
     *
     * The result of the extraction must be convertible to a double type, as the
     * distribution always records double values. If either the extraction or
     * the conversion to double fails, then those values are not recorded in the
     * distribution.
     *
     * Example: `REGEXP_EXTRACT(jsonPayload.request, ".*quantity=(\d+).*")`
     */
    valueExtractor: string;
    /**
     * Optional. A map from a label key string to an extractor expression which is
     * used to extract data from a log entry field and assign as the label value.
     * Each label key specified in the LabelDescriptor must have an associated
     * extractor expression in this map. The syntax of the extractor expression
     * is the same as for the `value_extractor` field.
     *
     * The extracted value is converted to the type defined in the label
     * descriptor. If the either the extraction or the type conversion fails,
     * the label will have a default value. The default value for a string
     * label is an empty string, for an integer label its 0, and for a boolean
     * label its `false`.
     *
     * Note that there are upper bounds on the maximum number of labels and the
     * number of active time series that are allowed in a project.
     */
    labelExtractors: {
        [key: string]: string;
    };
    /**
     * Optional. The `bucket_options` are required when the logs-based metric is
     * using a DISTRIBUTION value type and it describes the bucket boundaries
     * used to create a histogram of the extracted values.
     */
    bucketOptions?: Distribution_BucketOptions;
    /**
     * Output only. The creation timestamp of the metric.
     *
     * This field may not be present for older metrics.
     */
    createTime?: Date;
    /**
     * Output only. The last update timestamp of the metric.
     *
     * This field may not be present for older metrics.
     */
    updateTime?: Date;
    /**
     * Deprecated. The API version that created or updated this metric.
     * The v2 format is used by default and cannot be changed.
     */
    /** @deprecated */
    version: LogMetric_ApiVersion;
}
export interface LogMetricProtoMsg {
    typeUrl: "/google.logging.v2.LogMetric";
    value: Uint8Array;
}
/**
 * Describes a logs-based metric. The value of the metric is the number of log
 * entries that match a logs filter in a given time interval.
 *
 * Logs-based metrics can also be used to extract values from logs and create a
 * distribution of the values. The distribution records the statistics of the
 * extracted values along with an optional histogram of the values as specified
 * by the bucket options.
 */
export interface LogMetricAmino {
    /**
     * Required. The client-assigned metric identifier.
     * Examples: `"error_count"`, `"nginx/requests"`.
     *
     * Metric identifiers are limited to 100 characters and can include only the
     * following characters: `A-Z`, `a-z`, `0-9`, and the special characters
     * `_-.,+!*',()%/`. The forward-slash character (`/`) denotes a hierarchy of
     * name pieces, and it cannot be the first character of the name.
     *
     * This field is the `[METRIC_ID]` part of a metric resource name in the
     * format "projects/[PROJECT_ID]/metrics/[METRIC_ID]". Example: If the
     * resource name of a metric is
     * `"projects/my-project/metrics/nginx%2Frequests"`, this field's value is
     * `"nginx/requests"`.
     */
    name?: string;
    /**
     * Optional. A description of this metric, which is used in documentation.
     * The maximum length of the description is 8000 characters.
     */
    description?: string;
    /**
     * Required. An [advanced logs
     * filter](https://cloud.google.com/logging/docs/view/advanced_filters) which
     * is used to match log entries. Example:
     *
     *     "resource.type=gae_app AND severity>=ERROR"
     *
     * The maximum length of the filter is 20000 characters.
     */
    filter?: string;
    /**
     * Optional. If set to True, then this metric is disabled and it does not
     * generate any points.
     */
    disabled?: boolean;
    /**
     * Optional. The metric descriptor associated with the logs-based metric.
     * If unspecified, it uses a default metric descriptor with a DELTA metric
     * kind, INT64 value type, with no labels and a unit of "1". Such a metric
     * counts the number of log entries matching the `filter` expression.
     *
     * The `name`, `type`, and `description` fields in the `metric_descriptor`
     * are output only, and is constructed using the `name` and `description`
     * field in the LogMetric.
     *
     * To create a logs-based metric that records a distribution of log values, a
     * DELTA metric kind with a DISTRIBUTION value type must be used along with
     * a `value_extractor` expression in the LogMetric.
     *
     * Each label in the metric descriptor must have a matching label
     * name as the key and an extractor expression as the value in the
     * `label_extractors` map.
     *
     * The `metric_kind` and `value_type` fields in the `metric_descriptor` cannot
     * be updated once initially configured. New labels can be added in the
     * `metric_descriptor`, but existing labels cannot be modified except for
     * their description.
     */
    metric_descriptor?: MetricDescriptorAmino;
    /**
     * Optional. A `value_extractor` is required when using a distribution
     * logs-based metric to extract the values to record from a log entry.
     * Two functions are supported for value extraction: `EXTRACT(field)` or
     * `REGEXP_EXTRACT(field, regex)`. The argument are:
     *   1. field: The name of the log entry field from which the value is to be
     *      extracted.
     *   2. regex: A regular expression using the Google RE2 syntax
     *      (https://github.com/google/re2/wiki/Syntax) with a single capture
     *      group to extract data from the specified log entry field. The value
     *      of the field is converted to a string before applying the regex.
     *      It is an error to specify a regex that does not include exactly one
     *      capture group.
     *
     * The result of the extraction must be convertible to a double type, as the
     * distribution always records double values. If either the extraction or
     * the conversion to double fails, then those values are not recorded in the
     * distribution.
     *
     * Example: `REGEXP_EXTRACT(jsonPayload.request, ".*quantity=(\d+).*")`
     */
    value_extractor?: string;
    /**
     * Optional. A map from a label key string to an extractor expression which is
     * used to extract data from a log entry field and assign as the label value.
     * Each label key specified in the LabelDescriptor must have an associated
     * extractor expression in this map. The syntax of the extractor expression
     * is the same as for the `value_extractor` field.
     *
     * The extracted value is converted to the type defined in the label
     * descriptor. If the either the extraction or the type conversion fails,
     * the label will have a default value. The default value for a string
     * label is an empty string, for an integer label its 0, and for a boolean
     * label its `false`.
     *
     * Note that there are upper bounds on the maximum number of labels and the
     * number of active time series that are allowed in a project.
     */
    label_extractors?: {
        [key: string]: string;
    };
    /**
     * Optional. The `bucket_options` are required when the logs-based metric is
     * using a DISTRIBUTION value type and it describes the bucket boundaries
     * used to create a histogram of the extracted values.
     */
    bucket_options?: Distribution_BucketOptionsAmino;
    /**
     * Output only. The creation timestamp of the metric.
     *
     * This field may not be present for older metrics.
     */
    create_time?: string;
    /**
     * Output only. The last update timestamp of the metric.
     *
     * This field may not be present for older metrics.
     */
    update_time?: string;
    /**
     * Deprecated. The API version that created or updated this metric.
     * The v2 format is used by default and cannot be changed.
     */
    /** @deprecated */
    version?: LogMetric_ApiVersion;
}
export interface LogMetricAminoMsg {
    type: "/google.logging.v2.LogMetric";
    value: LogMetricAmino;
}
/**
 * Describes a logs-based metric. The value of the metric is the number of log
 * entries that match a logs filter in a given time interval.
 *
 * Logs-based metrics can also be used to extract values from logs and create a
 * distribution of the values. The distribution records the statistics of the
 * extracted values along with an optional histogram of the values as specified
 * by the bucket options.
 */
export interface LogMetricSDKType {
    name: string;
    description: string;
    filter: string;
    disabled: boolean;
    metric_descriptor?: MetricDescriptorSDKType;
    value_extractor: string;
    label_extractors: {
        [key: string]: string;
    };
    bucket_options?: Distribution_BucketOptionsSDKType;
    create_time?: Date;
    update_time?: Date;
    /** @deprecated */
    version: LogMetric_ApiVersion;
}
/** The parameters to ListLogMetrics. */
export interface ListLogMetricsRequest {
    /**
     * Required. The name of the project containing the metrics:
     *
     *     "projects/[PROJECT_ID]"
     */
    parent: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    pageToken: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    pageSize: number;
}
export interface ListLogMetricsRequestProtoMsg {
    typeUrl: "/google.logging.v2.ListLogMetricsRequest";
    value: Uint8Array;
}
/** The parameters to ListLogMetrics. */
export interface ListLogMetricsRequestAmino {
    /**
     * Required. The name of the project containing the metrics:
     *
     *     "projects/[PROJECT_ID]"
     */
    parent?: string;
    /**
     * Optional. If present, then retrieve the next batch of results from the
     * preceding call to this method. `pageToken` must be the value of
     * `nextPageToken` from the previous response. The values of other method
     * parameters should be identical to those in the previous call.
     */
    page_token?: string;
    /**
     * Optional. The maximum number of results to return from this request.
     * Non-positive values are ignored. The presence of `nextPageToken` in the
     * response indicates that more results might be available.
     */
    page_size?: number;
}
export interface ListLogMetricsRequestAminoMsg {
    type: "/google.logging.v2.ListLogMetricsRequest";
    value: ListLogMetricsRequestAmino;
}
/** The parameters to ListLogMetrics. */
export interface ListLogMetricsRequestSDKType {
    parent: string;
    page_token: string;
    page_size: number;
}
/** Result returned from ListLogMetrics. */
export interface ListLogMetricsResponse {
    /** A list of logs-based metrics. */
    metrics: LogMetric[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    nextPageToken: string;
}
export interface ListLogMetricsResponseProtoMsg {
    typeUrl: "/google.logging.v2.ListLogMetricsResponse";
    value: Uint8Array;
}
/** Result returned from ListLogMetrics. */
export interface ListLogMetricsResponseAmino {
    /** A list of logs-based metrics. */
    metrics?: LogMetricAmino[];
    /**
     * If there might be more results than appear in this response, then
     * `nextPageToken` is included. To get the next set of results, call this
     * method again using the value of `nextPageToken` as `pageToken`.
     */
    next_page_token?: string;
}
export interface ListLogMetricsResponseAminoMsg {
    type: "/google.logging.v2.ListLogMetricsResponse";
    value: ListLogMetricsResponseAmino;
}
/** Result returned from ListLogMetrics. */
export interface ListLogMetricsResponseSDKType {
    metrics: LogMetricSDKType[];
    next_page_token: string;
}
/** The parameters to GetLogMetric. */
export interface GetLogMetricRequest {
    /**
     * Required. The resource name of the desired metric:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     */
    metricName: string;
}
export interface GetLogMetricRequestProtoMsg {
    typeUrl: "/google.logging.v2.GetLogMetricRequest";
    value: Uint8Array;
}
/** The parameters to GetLogMetric. */
export interface GetLogMetricRequestAmino {
    /**
     * Required. The resource name of the desired metric:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     */
    metric_name?: string;
}
export interface GetLogMetricRequestAminoMsg {
    type: "/google.logging.v2.GetLogMetricRequest";
    value: GetLogMetricRequestAmino;
}
/** The parameters to GetLogMetric. */
export interface GetLogMetricRequestSDKType {
    metric_name: string;
}
/** The parameters to CreateLogMetric. */
export interface CreateLogMetricRequest {
    /**
     * Required. The resource name of the project in which to create the metric:
     *
     *     "projects/[PROJECT_ID]"
     *
     * The new metric must be provided in the request.
     */
    parent: string;
    /**
     * Required. The new logs-based metric, which must not have an identifier that
     * already exists.
     */
    metric?: LogMetric;
}
export interface CreateLogMetricRequestProtoMsg {
    typeUrl: "/google.logging.v2.CreateLogMetricRequest";
    value: Uint8Array;
}
/** The parameters to CreateLogMetric. */
export interface CreateLogMetricRequestAmino {
    /**
     * Required. The resource name of the project in which to create the metric:
     *
     *     "projects/[PROJECT_ID]"
     *
     * The new metric must be provided in the request.
     */
    parent?: string;
    /**
     * Required. The new logs-based metric, which must not have an identifier that
     * already exists.
     */
    metric?: LogMetricAmino;
}
export interface CreateLogMetricRequestAminoMsg {
    type: "/google.logging.v2.CreateLogMetricRequest";
    value: CreateLogMetricRequestAmino;
}
/** The parameters to CreateLogMetric. */
export interface CreateLogMetricRequestSDKType {
    parent: string;
    metric?: LogMetricSDKType;
}
/** The parameters to UpdateLogMetric. */
export interface UpdateLogMetricRequest {
    /**
     * Required. The resource name of the metric to update:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     *
     * The updated metric must be provided in the request and it's
     * `name` field must be the same as `[METRIC_ID]` If the metric
     * does not exist in `[PROJECT_ID]`, then a new metric is created.
     */
    metricName: string;
    /** Required. The updated metric. */
    metric?: LogMetric;
}
export interface UpdateLogMetricRequestProtoMsg {
    typeUrl: "/google.logging.v2.UpdateLogMetricRequest";
    value: Uint8Array;
}
/** The parameters to UpdateLogMetric. */
export interface UpdateLogMetricRequestAmino {
    /**
     * Required. The resource name of the metric to update:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     *
     * The updated metric must be provided in the request and it's
     * `name` field must be the same as `[METRIC_ID]` If the metric
     * does not exist in `[PROJECT_ID]`, then a new metric is created.
     */
    metric_name?: string;
    /** Required. The updated metric. */
    metric?: LogMetricAmino;
}
export interface UpdateLogMetricRequestAminoMsg {
    type: "/google.logging.v2.UpdateLogMetricRequest";
    value: UpdateLogMetricRequestAmino;
}
/** The parameters to UpdateLogMetric. */
export interface UpdateLogMetricRequestSDKType {
    metric_name: string;
    metric?: LogMetricSDKType;
}
/** The parameters to DeleteLogMetric. */
export interface DeleteLogMetricRequest {
    /**
     * Required. The resource name of the metric to delete:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     */
    metricName: string;
}
export interface DeleteLogMetricRequestProtoMsg {
    typeUrl: "/google.logging.v2.DeleteLogMetricRequest";
    value: Uint8Array;
}
/** The parameters to DeleteLogMetric. */
export interface DeleteLogMetricRequestAmino {
    /**
     * Required. The resource name of the metric to delete:
     *
     *     "projects/[PROJECT_ID]/metrics/[METRIC_ID]"
     */
    metric_name?: string;
}
export interface DeleteLogMetricRequestAminoMsg {
    type: "/google.logging.v2.DeleteLogMetricRequest";
    value: DeleteLogMetricRequestAmino;
}
/** The parameters to DeleteLogMetric. */
export interface DeleteLogMetricRequestSDKType {
    metric_name: string;
}
export declare const LogMetric_LabelExtractorsEntry: {
    encode(message: LogMetric_LabelExtractorsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogMetric_LabelExtractorsEntry;
    fromJSON(object: any): LogMetric_LabelExtractorsEntry;
    toJSON(message: LogMetric_LabelExtractorsEntry): JsonSafe<LogMetric_LabelExtractorsEntry>;
    fromPartial(object: DeepPartial<LogMetric_LabelExtractorsEntry>): LogMetric_LabelExtractorsEntry;
    fromSDK(object: LogMetric_LabelExtractorsEntrySDKType): LogMetric_LabelExtractorsEntry;
    fromSDKJSON(object: any): LogMetric_LabelExtractorsEntrySDKType;
    toSDK(message: LogMetric_LabelExtractorsEntry): LogMetric_LabelExtractorsEntrySDKType;
    fromAmino(object: LogMetric_LabelExtractorsEntryAmino): LogMetric_LabelExtractorsEntry;
    toAmino(message: LogMetric_LabelExtractorsEntry): LogMetric_LabelExtractorsEntryAmino;
    fromAminoMsg(object: LogMetric_LabelExtractorsEntryAminoMsg): LogMetric_LabelExtractorsEntry;
    fromProtoMsg(message: LogMetric_LabelExtractorsEntryProtoMsg): LogMetric_LabelExtractorsEntry;
    toProto(message: LogMetric_LabelExtractorsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const LogMetric: {
    typeUrl: string;
    is(o: any): o is LogMetric;
    isSDK(o: any): o is LogMetricSDKType;
    isAmino(o: any): o is LogMetricAmino;
    encode(message: LogMetric, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LogMetric;
    fromJSON(object: any): LogMetric;
    toJSON(message: LogMetric): JsonSafe<LogMetric>;
    fromPartial(object: DeepPartial<LogMetric>): LogMetric;
    fromSDK(object: LogMetricSDKType): LogMetric;
    fromSDKJSON(object: any): LogMetricSDKType;
    toSDK(message: LogMetric): LogMetricSDKType;
    fromAmino(object: LogMetricAmino): LogMetric;
    toAmino(message: LogMetric): LogMetricAmino;
    fromAminoMsg(object: LogMetricAminoMsg): LogMetric;
    fromProtoMsg(message: LogMetricProtoMsg): LogMetric;
    toProto(message: LogMetric): Uint8Array;
    toProtoMsg(message: LogMetric): LogMetricProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogMetricsRequest: {
    typeUrl: string;
    is(o: any): o is ListLogMetricsRequest;
    isSDK(o: any): o is ListLogMetricsRequestSDKType;
    isAmino(o: any): o is ListLogMetricsRequestAmino;
    encode(message: ListLogMetricsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogMetricsRequest;
    fromJSON(object: any): ListLogMetricsRequest;
    toJSON(message: ListLogMetricsRequest): JsonSafe<ListLogMetricsRequest>;
    fromPartial(object: DeepPartial<ListLogMetricsRequest>): ListLogMetricsRequest;
    fromSDK(object: ListLogMetricsRequestSDKType): ListLogMetricsRequest;
    fromSDKJSON(object: any): ListLogMetricsRequestSDKType;
    toSDK(message: ListLogMetricsRequest): ListLogMetricsRequestSDKType;
    fromAmino(object: ListLogMetricsRequestAmino): ListLogMetricsRequest;
    toAmino(message: ListLogMetricsRequest): ListLogMetricsRequestAmino;
    fromAminoMsg(object: ListLogMetricsRequestAminoMsg): ListLogMetricsRequest;
    fromProtoMsg(message: ListLogMetricsRequestProtoMsg): ListLogMetricsRequest;
    toProto(message: ListLogMetricsRequest): Uint8Array;
    toProtoMsg(message: ListLogMetricsRequest): ListLogMetricsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListLogMetricsResponse: {
    typeUrl: string;
    is(o: any): o is ListLogMetricsResponse;
    isSDK(o: any): o is ListLogMetricsResponseSDKType;
    isAmino(o: any): o is ListLogMetricsResponseAmino;
    encode(message: ListLogMetricsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListLogMetricsResponse;
    fromJSON(object: any): ListLogMetricsResponse;
    toJSON(message: ListLogMetricsResponse): JsonSafe<ListLogMetricsResponse>;
    fromPartial(object: DeepPartial<ListLogMetricsResponse>): ListLogMetricsResponse;
    fromSDK(object: ListLogMetricsResponseSDKType): ListLogMetricsResponse;
    fromSDKJSON(object: any): ListLogMetricsResponseSDKType;
    toSDK(message: ListLogMetricsResponse): ListLogMetricsResponseSDKType;
    fromAmino(object: ListLogMetricsResponseAmino): ListLogMetricsResponse;
    toAmino(message: ListLogMetricsResponse): ListLogMetricsResponseAmino;
    fromAminoMsg(object: ListLogMetricsResponseAminoMsg): ListLogMetricsResponse;
    fromProtoMsg(message: ListLogMetricsResponseProtoMsg): ListLogMetricsResponse;
    toProto(message: ListLogMetricsResponse): Uint8Array;
    toProtoMsg(message: ListLogMetricsResponse): ListLogMetricsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetLogMetricRequest: {
    typeUrl: string;
    is(o: any): o is GetLogMetricRequest;
    isSDK(o: any): o is GetLogMetricRequestSDKType;
    isAmino(o: any): o is GetLogMetricRequestAmino;
    encode(message: GetLogMetricRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetLogMetricRequest;
    fromJSON(object: any): GetLogMetricRequest;
    toJSON(message: GetLogMetricRequest): JsonSafe<GetLogMetricRequest>;
    fromPartial(object: DeepPartial<GetLogMetricRequest>): GetLogMetricRequest;
    fromSDK(object: GetLogMetricRequestSDKType): GetLogMetricRequest;
    fromSDKJSON(object: any): GetLogMetricRequestSDKType;
    toSDK(message: GetLogMetricRequest): GetLogMetricRequestSDKType;
    fromAmino(object: GetLogMetricRequestAmino): GetLogMetricRequest;
    toAmino(message: GetLogMetricRequest): GetLogMetricRequestAmino;
    fromAminoMsg(object: GetLogMetricRequestAminoMsg): GetLogMetricRequest;
    fromProtoMsg(message: GetLogMetricRequestProtoMsg): GetLogMetricRequest;
    toProto(message: GetLogMetricRequest): Uint8Array;
    toProtoMsg(message: GetLogMetricRequest): GetLogMetricRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const CreateLogMetricRequest: {
    typeUrl: string;
    is(o: any): o is CreateLogMetricRequest;
    isSDK(o: any): o is CreateLogMetricRequestSDKType;
    isAmino(o: any): o is CreateLogMetricRequestAmino;
    encode(message: CreateLogMetricRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CreateLogMetricRequest;
    fromJSON(object: any): CreateLogMetricRequest;
    toJSON(message: CreateLogMetricRequest): JsonSafe<CreateLogMetricRequest>;
    fromPartial(object: DeepPartial<CreateLogMetricRequest>): CreateLogMetricRequest;
    fromSDK(object: CreateLogMetricRequestSDKType): CreateLogMetricRequest;
    fromSDKJSON(object: any): CreateLogMetricRequestSDKType;
    toSDK(message: CreateLogMetricRequest): CreateLogMetricRequestSDKType;
    fromAmino(object: CreateLogMetricRequestAmino): CreateLogMetricRequest;
    toAmino(message: CreateLogMetricRequest): CreateLogMetricRequestAmino;
    fromAminoMsg(object: CreateLogMetricRequestAminoMsg): CreateLogMetricRequest;
    fromProtoMsg(message: CreateLogMetricRequestProtoMsg): CreateLogMetricRequest;
    toProto(message: CreateLogMetricRequest): Uint8Array;
    toProtoMsg(message: CreateLogMetricRequest): CreateLogMetricRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const UpdateLogMetricRequest: {
    typeUrl: string;
    is(o: any): o is UpdateLogMetricRequest;
    isSDK(o: any): o is UpdateLogMetricRequestSDKType;
    isAmino(o: any): o is UpdateLogMetricRequestAmino;
    encode(message: UpdateLogMetricRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): UpdateLogMetricRequest;
    fromJSON(object: any): UpdateLogMetricRequest;
    toJSON(message: UpdateLogMetricRequest): JsonSafe<UpdateLogMetricRequest>;
    fromPartial(object: DeepPartial<UpdateLogMetricRequest>): UpdateLogMetricRequest;
    fromSDK(object: UpdateLogMetricRequestSDKType): UpdateLogMetricRequest;
    fromSDKJSON(object: any): UpdateLogMetricRequestSDKType;
    toSDK(message: UpdateLogMetricRequest): UpdateLogMetricRequestSDKType;
    fromAmino(object: UpdateLogMetricRequestAmino): UpdateLogMetricRequest;
    toAmino(message: UpdateLogMetricRequest): UpdateLogMetricRequestAmino;
    fromAminoMsg(object: UpdateLogMetricRequestAminoMsg): UpdateLogMetricRequest;
    fromProtoMsg(message: UpdateLogMetricRequestProtoMsg): UpdateLogMetricRequest;
    toProto(message: UpdateLogMetricRequest): Uint8Array;
    toProtoMsg(message: UpdateLogMetricRequest): UpdateLogMetricRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteLogMetricRequest: {
    typeUrl: string;
    is(o: any): o is DeleteLogMetricRequest;
    isSDK(o: any): o is DeleteLogMetricRequestSDKType;
    isAmino(o: any): o is DeleteLogMetricRequestAmino;
    encode(message: DeleteLogMetricRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteLogMetricRequest;
    fromJSON(object: any): DeleteLogMetricRequest;
    toJSON(message: DeleteLogMetricRequest): JsonSafe<DeleteLogMetricRequest>;
    fromPartial(object: DeepPartial<DeleteLogMetricRequest>): DeleteLogMetricRequest;
    fromSDK(object: DeleteLogMetricRequestSDKType): DeleteLogMetricRequest;
    fromSDKJSON(object: any): DeleteLogMetricRequestSDKType;
    toSDK(message: DeleteLogMetricRequest): DeleteLogMetricRequestSDKType;
    fromAmino(object: DeleteLogMetricRequestAmino): DeleteLogMetricRequest;
    toAmino(message: DeleteLogMetricRequest): DeleteLogMetricRequestAmino;
    fromAminoMsg(object: DeleteLogMetricRequestAminoMsg): DeleteLogMetricRequest;
    fromProtoMsg(message: DeleteLogMetricRequestProtoMsg): DeleteLogMetricRequest;
    toProto(message: DeleteLogMetricRequest): Uint8Array;
    toProtoMsg(message: DeleteLogMetricRequest): DeleteLogMetricRequestProtoMsg;
    registerTypeUrl(): void;
};
