import { Duration, DurationAmino, DurationSDKType } from "../protobuf/duration";
import { Any, AnyAmino, AnySDKType } from "../protobuf/any";
import { Status, StatusAmino, StatusSDKType } from "../rpc/status";
import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.longrunning";
/**
 * This resource represents a long-running operation that is the result of a
 * network API call.
 */
export interface Operation {
    /**
     * The server-assigned name, which is only unique within the same service that
     * originally returns it. If you use the default HTTP mapping, the
     * `name` should be a resource name ending with `operations/{unique_id}`.
     */
    name: string;
    /**
     * Service-specific metadata associated with the operation.  It typically
     * contains progress information and common metadata such as create time.
     * Some services might not provide such metadata.  Any method that returns a
     * long-running operation should document the metadata type, if any.
     */
    metadata?: Any;
    /**
     * If the value is `false`, it means the operation is still in progress.
     * If `true`, the operation is completed, and either `error` or `response` is
     * available.
     */
    done: boolean;
    /** The error result of the operation in case of failure or cancellation. */
    error?: Status;
    /**
     * The normal response of the operation in case of success.  If the original
     * method returns no data on success, such as `Delete`, the response is
     * `google.protobuf.Empty`.  If the original method is standard
     * `Get`/`Create`/`Update`, the response should be the resource.  For other
     * methods, the response should have the type `XxxResponse`, where `Xxx`
     * is the original method name.  For example, if the original method name
     * is `TakeSnapshot()`, the inferred response type is
     * `TakeSnapshotResponse`.
     */
    response?: Any;
}
export interface OperationProtoMsg {
    typeUrl: "/google.longrunning.Operation";
    value: Uint8Array;
}
/**
 * This resource represents a long-running operation that is the result of a
 * network API call.
 */
export interface OperationAmino {
    /**
     * The server-assigned name, which is only unique within the same service that
     * originally returns it. If you use the default HTTP mapping, the
     * `name` should be a resource name ending with `operations/{unique_id}`.
     */
    name?: string;
    /**
     * Service-specific metadata associated with the operation.  It typically
     * contains progress information and common metadata such as create time.
     * Some services might not provide such metadata.  Any method that returns a
     * long-running operation should document the metadata type, if any.
     */
    metadata?: AnyAmino;
    /**
     * If the value is `false`, it means the operation is still in progress.
     * If `true`, the operation is completed, and either `error` or `response` is
     * available.
     */
    done?: boolean;
    /** The error result of the operation in case of failure or cancellation. */
    error?: StatusAmino;
    /**
     * The normal response of the operation in case of success.  If the original
     * method returns no data on success, such as `Delete`, the response is
     * `google.protobuf.Empty`.  If the original method is standard
     * `Get`/`Create`/`Update`, the response should be the resource.  For other
     * methods, the response should have the type `XxxResponse`, where `Xxx`
     * is the original method name.  For example, if the original method name
     * is `TakeSnapshot()`, the inferred response type is
     * `TakeSnapshotResponse`.
     */
    response?: AnyAmino;
}
export interface OperationAminoMsg {
    type: "/google.longrunning.Operation";
    value: OperationAmino;
}
/**
 * This resource represents a long-running operation that is the result of a
 * network API call.
 */
export interface OperationSDKType {
    name: string;
    metadata?: AnySDKType;
    done: boolean;
    error?: StatusSDKType;
    response?: AnySDKType;
}
/** The request message for [Operations.GetOperation][google.longrunning.Operations.GetOperation]. */
export interface GetOperationRequest {
    /** The name of the operation resource. */
    name: string;
}
export interface GetOperationRequestProtoMsg {
    typeUrl: "/google.longrunning.GetOperationRequest";
    value: Uint8Array;
}
/** The request message for [Operations.GetOperation][google.longrunning.Operations.GetOperation]. */
export interface GetOperationRequestAmino {
    /** The name of the operation resource. */
    name?: string;
}
export interface GetOperationRequestAminoMsg {
    type: "/google.longrunning.GetOperationRequest";
    value: GetOperationRequestAmino;
}
/** The request message for [Operations.GetOperation][google.longrunning.Operations.GetOperation]. */
export interface GetOperationRequestSDKType {
    name: string;
}
/** The request message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsRequest {
    /** The name of the operation's parent resource. */
    name: string;
    /** The standard list filter. */
    filter: string;
    /** The standard list page size. */
    pageSize: number;
    /** The standard list page token. */
    pageToken: string;
}
export interface ListOperationsRequestProtoMsg {
    typeUrl: "/google.longrunning.ListOperationsRequest";
    value: Uint8Array;
}
/** The request message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsRequestAmino {
    /** The name of the operation's parent resource. */
    name?: string;
    /** The standard list filter. */
    filter?: string;
    /** The standard list page size. */
    page_size?: number;
    /** The standard list page token. */
    page_token?: string;
}
export interface ListOperationsRequestAminoMsg {
    type: "/google.longrunning.ListOperationsRequest";
    value: ListOperationsRequestAmino;
}
/** The request message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsRequestSDKType {
    name: string;
    filter: string;
    page_size: number;
    page_token: string;
}
/** The response message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsResponse {
    /** A list of operations that matches the specified filter in the request. */
    operations: Operation[];
    /** The standard List next-page token. */
    nextPageToken: string;
}
export interface ListOperationsResponseProtoMsg {
    typeUrl: "/google.longrunning.ListOperationsResponse";
    value: Uint8Array;
}
/** The response message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsResponseAmino {
    /** A list of operations that matches the specified filter in the request. */
    operations?: OperationAmino[];
    /** The standard List next-page token. */
    next_page_token?: string;
}
export interface ListOperationsResponseAminoMsg {
    type: "/google.longrunning.ListOperationsResponse";
    value: ListOperationsResponseAmino;
}
/** The response message for [Operations.ListOperations][google.longrunning.Operations.ListOperations]. */
export interface ListOperationsResponseSDKType {
    operations: OperationSDKType[];
    next_page_token: string;
}
/** The request message for [Operations.CancelOperation][google.longrunning.Operations.CancelOperation]. */
export interface CancelOperationRequest {
    /** The name of the operation resource to be cancelled. */
    name: string;
}
export interface CancelOperationRequestProtoMsg {
    typeUrl: "/google.longrunning.CancelOperationRequest";
    value: Uint8Array;
}
/** The request message for [Operations.CancelOperation][google.longrunning.Operations.CancelOperation]. */
export interface CancelOperationRequestAmino {
    /** The name of the operation resource to be cancelled. */
    name?: string;
}
export interface CancelOperationRequestAminoMsg {
    type: "/google.longrunning.CancelOperationRequest";
    value: CancelOperationRequestAmino;
}
/** The request message for [Operations.CancelOperation][google.longrunning.Operations.CancelOperation]. */
export interface CancelOperationRequestSDKType {
    name: string;
}
/** The request message for [Operations.DeleteOperation][google.longrunning.Operations.DeleteOperation]. */
export interface DeleteOperationRequest {
    /** The name of the operation resource to be deleted. */
    name: string;
}
export interface DeleteOperationRequestProtoMsg {
    typeUrl: "/google.longrunning.DeleteOperationRequest";
    value: Uint8Array;
}
/** The request message for [Operations.DeleteOperation][google.longrunning.Operations.DeleteOperation]. */
export interface DeleteOperationRequestAmino {
    /** The name of the operation resource to be deleted. */
    name?: string;
}
export interface DeleteOperationRequestAminoMsg {
    type: "/google.longrunning.DeleteOperationRequest";
    value: DeleteOperationRequestAmino;
}
/** The request message for [Operations.DeleteOperation][google.longrunning.Operations.DeleteOperation]. */
export interface DeleteOperationRequestSDKType {
    name: string;
}
/** The request message for [Operations.WaitOperation][google.longrunning.Operations.WaitOperation]. */
export interface WaitOperationRequest {
    /** The name of the operation resource to wait on. */
    name: string;
    /**
     * The maximum duration to wait before timing out. If left blank, the wait
     * will be at most the time permitted by the underlying HTTP/RPC protocol.
     * If RPC context deadline is also specified, the shorter one will be used.
     */
    timeout?: Duration;
}
export interface WaitOperationRequestProtoMsg {
    typeUrl: "/google.longrunning.WaitOperationRequest";
    value: Uint8Array;
}
/** The request message for [Operations.WaitOperation][google.longrunning.Operations.WaitOperation]. */
export interface WaitOperationRequestAmino {
    /** The name of the operation resource to wait on. */
    name?: string;
    /**
     * The maximum duration to wait before timing out. If left blank, the wait
     * will be at most the time permitted by the underlying HTTP/RPC protocol.
     * If RPC context deadline is also specified, the shorter one will be used.
     */
    timeout?: DurationAmino;
}
export interface WaitOperationRequestAminoMsg {
    type: "/google.longrunning.WaitOperationRequest";
    value: WaitOperationRequestAmino;
}
/** The request message for [Operations.WaitOperation][google.longrunning.Operations.WaitOperation]. */
export interface WaitOperationRequestSDKType {
    name: string;
    timeout?: DurationSDKType;
}
/**
 * A message representing the message types used by a long-running operation.
 *
 * Example:
 *
 *   rpc LongRunningRecognize(LongRunningRecognizeRequest)
 *       returns (google.longrunning.Operation) {
 *     option (google.longrunning.operation_info) = {
 *       response_type: "LongRunningRecognizeResponse"
 *       metadata_type: "LongRunningRecognizeMetadata"
 *     };
 *   }
 */
export interface OperationInfo {
    /**
     * Required. The message name of the primary return type for this
     * long-running operation.
     * This type will be used to deserialize the LRO's response.
     *
     * If the response is in a different package from the rpc, a fully-qualified
     * message name must be used (e.g. `google.protobuf.Struct`).
     *
     * Note: Altering this value constitutes a breaking change.
     */
    responseType: string;
    /**
     * Required. The message name of the metadata type for this long-running
     * operation.
     *
     * If the response is in a different package from the rpc, a fully-qualified
     * message name must be used (e.g. `google.protobuf.Struct`).
     *
     * Note: Altering this value constitutes a breaking change.
     */
    metadataType: string;
}
export interface OperationInfoProtoMsg {
    typeUrl: "/google.longrunning.OperationInfo";
    value: Uint8Array;
}
/**
 * A message representing the message types used by a long-running operation.
 *
 * Example:
 *
 *   rpc LongRunningRecognize(LongRunningRecognizeRequest)
 *       returns (google.longrunning.Operation) {
 *     option (google.longrunning.operation_info) = {
 *       response_type: "LongRunningRecognizeResponse"
 *       metadata_type: "LongRunningRecognizeMetadata"
 *     };
 *   }
 */
export interface OperationInfoAmino {
    /**
     * Required. The message name of the primary return type for this
     * long-running operation.
     * This type will be used to deserialize the LRO's response.
     *
     * If the response is in a different package from the rpc, a fully-qualified
     * message name must be used (e.g. `google.protobuf.Struct`).
     *
     * Note: Altering this value constitutes a breaking change.
     */
    response_type?: string;
    /**
     * Required. The message name of the metadata type for this long-running
     * operation.
     *
     * If the response is in a different package from the rpc, a fully-qualified
     * message name must be used (e.g. `google.protobuf.Struct`).
     *
     * Note: Altering this value constitutes a breaking change.
     */
    metadata_type?: string;
}
export interface OperationInfoAminoMsg {
    type: "/google.longrunning.OperationInfo";
    value: OperationInfoAmino;
}
/**
 * A message representing the message types used by a long-running operation.
 *
 * Example:
 *
 *   rpc LongRunningRecognize(LongRunningRecognizeRequest)
 *       returns (google.longrunning.Operation) {
 *     option (google.longrunning.operation_info) = {
 *       response_type: "LongRunningRecognizeResponse"
 *       metadata_type: "LongRunningRecognizeMetadata"
 *     };
 *   }
 */
export interface OperationInfoSDKType {
    response_type: string;
    metadata_type: string;
}
export declare const Operation: {
    typeUrl: string;
    is(o: any): o is Operation;
    isSDK(o: any): o is OperationSDKType;
    isAmino(o: any): o is OperationAmino;
    encode(message: Operation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Operation;
    fromJSON(object: any): Operation;
    toJSON(message: Operation): JsonSafe<Operation>;
    fromPartial(object: DeepPartial<Operation>): Operation;
    fromSDK(object: OperationSDKType): Operation;
    fromSDKJSON(object: any): OperationSDKType;
    toSDK(message: Operation): OperationSDKType;
    fromAmino(object: OperationAmino): Operation;
    toAmino(message: Operation): OperationAmino;
    fromAminoMsg(object: OperationAminoMsg): Operation;
    fromProtoMsg(message: OperationProtoMsg): Operation;
    toProto(message: Operation): Uint8Array;
    toProtoMsg(message: Operation): OperationProtoMsg;
    registerTypeUrl(): void;
};
export declare const GetOperationRequest: {
    typeUrl: string;
    is(o: any): o is GetOperationRequest;
    isSDK(o: any): o is GetOperationRequestSDKType;
    isAmino(o: any): o is GetOperationRequestAmino;
    encode(message: GetOperationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GetOperationRequest;
    fromJSON(object: any): GetOperationRequest;
    toJSON(message: GetOperationRequest): JsonSafe<GetOperationRequest>;
    fromPartial(object: DeepPartial<GetOperationRequest>): GetOperationRequest;
    fromSDK(object: GetOperationRequestSDKType): GetOperationRequest;
    fromSDKJSON(object: any): GetOperationRequestSDKType;
    toSDK(message: GetOperationRequest): GetOperationRequestSDKType;
    fromAmino(object: GetOperationRequestAmino): GetOperationRequest;
    toAmino(message: GetOperationRequest): GetOperationRequestAmino;
    fromAminoMsg(object: GetOperationRequestAminoMsg): GetOperationRequest;
    fromProtoMsg(message: GetOperationRequestProtoMsg): GetOperationRequest;
    toProto(message: GetOperationRequest): Uint8Array;
    toProtoMsg(message: GetOperationRequest): GetOperationRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListOperationsRequest: {
    typeUrl: string;
    is(o: any): o is ListOperationsRequest;
    isSDK(o: any): o is ListOperationsRequestSDKType;
    isAmino(o: any): o is ListOperationsRequestAmino;
    encode(message: ListOperationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListOperationsRequest;
    fromJSON(object: any): ListOperationsRequest;
    toJSON(message: ListOperationsRequest): JsonSafe<ListOperationsRequest>;
    fromPartial(object: DeepPartial<ListOperationsRequest>): ListOperationsRequest;
    fromSDK(object: ListOperationsRequestSDKType): ListOperationsRequest;
    fromSDKJSON(object: any): ListOperationsRequestSDKType;
    toSDK(message: ListOperationsRequest): ListOperationsRequestSDKType;
    fromAmino(object: ListOperationsRequestAmino): ListOperationsRequest;
    toAmino(message: ListOperationsRequest): ListOperationsRequestAmino;
    fromAminoMsg(object: ListOperationsRequestAminoMsg): ListOperationsRequest;
    fromProtoMsg(message: ListOperationsRequestProtoMsg): ListOperationsRequest;
    toProto(message: ListOperationsRequest): Uint8Array;
    toProtoMsg(message: ListOperationsRequest): ListOperationsRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListOperationsResponse: {
    typeUrl: string;
    is(o: any): o is ListOperationsResponse;
    isSDK(o: any): o is ListOperationsResponseSDKType;
    isAmino(o: any): o is ListOperationsResponseAmino;
    encode(message: ListOperationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListOperationsResponse;
    fromJSON(object: any): ListOperationsResponse;
    toJSON(message: ListOperationsResponse): JsonSafe<ListOperationsResponse>;
    fromPartial(object: DeepPartial<ListOperationsResponse>): ListOperationsResponse;
    fromSDK(object: ListOperationsResponseSDKType): ListOperationsResponse;
    fromSDKJSON(object: any): ListOperationsResponseSDKType;
    toSDK(message: ListOperationsResponse): ListOperationsResponseSDKType;
    fromAmino(object: ListOperationsResponseAmino): ListOperationsResponse;
    toAmino(message: ListOperationsResponse): ListOperationsResponseAmino;
    fromAminoMsg(object: ListOperationsResponseAminoMsg): ListOperationsResponse;
    fromProtoMsg(message: ListOperationsResponseProtoMsg): ListOperationsResponse;
    toProto(message: ListOperationsResponse): Uint8Array;
    toProtoMsg(message: ListOperationsResponse): ListOperationsResponseProtoMsg;
    registerTypeUrl(): void;
};
export declare const CancelOperationRequest: {
    typeUrl: string;
    is(o: any): o is CancelOperationRequest;
    isSDK(o: any): o is CancelOperationRequestSDKType;
    isAmino(o: any): o is CancelOperationRequestAmino;
    encode(message: CancelOperationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): CancelOperationRequest;
    fromJSON(object: any): CancelOperationRequest;
    toJSON(message: CancelOperationRequest): JsonSafe<CancelOperationRequest>;
    fromPartial(object: DeepPartial<CancelOperationRequest>): CancelOperationRequest;
    fromSDK(object: CancelOperationRequestSDKType): CancelOperationRequest;
    fromSDKJSON(object: any): CancelOperationRequestSDKType;
    toSDK(message: CancelOperationRequest): CancelOperationRequestSDKType;
    fromAmino(object: CancelOperationRequestAmino): CancelOperationRequest;
    toAmino(message: CancelOperationRequest): CancelOperationRequestAmino;
    fromAminoMsg(object: CancelOperationRequestAminoMsg): CancelOperationRequest;
    fromProtoMsg(message: CancelOperationRequestProtoMsg): CancelOperationRequest;
    toProto(message: CancelOperationRequest): Uint8Array;
    toProtoMsg(message: CancelOperationRequest): CancelOperationRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const DeleteOperationRequest: {
    typeUrl: string;
    is(o: any): o is DeleteOperationRequest;
    isSDK(o: any): o is DeleteOperationRequestSDKType;
    isAmino(o: any): o is DeleteOperationRequestAmino;
    encode(message: DeleteOperationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DeleteOperationRequest;
    fromJSON(object: any): DeleteOperationRequest;
    toJSON(message: DeleteOperationRequest): JsonSafe<DeleteOperationRequest>;
    fromPartial(object: DeepPartial<DeleteOperationRequest>): DeleteOperationRequest;
    fromSDK(object: DeleteOperationRequestSDKType): DeleteOperationRequest;
    fromSDKJSON(object: any): DeleteOperationRequestSDKType;
    toSDK(message: DeleteOperationRequest): DeleteOperationRequestSDKType;
    fromAmino(object: DeleteOperationRequestAmino): DeleteOperationRequest;
    toAmino(message: DeleteOperationRequest): DeleteOperationRequestAmino;
    fromAminoMsg(object: DeleteOperationRequestAminoMsg): DeleteOperationRequest;
    fromProtoMsg(message: DeleteOperationRequestProtoMsg): DeleteOperationRequest;
    toProto(message: DeleteOperationRequest): Uint8Array;
    toProtoMsg(message: DeleteOperationRequest): DeleteOperationRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const WaitOperationRequest: {
    typeUrl: string;
    is(o: any): o is WaitOperationRequest;
    isSDK(o: any): o is WaitOperationRequestSDKType;
    isAmino(o: any): o is WaitOperationRequestAmino;
    encode(message: WaitOperationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WaitOperationRequest;
    fromJSON(object: any): WaitOperationRequest;
    toJSON(message: WaitOperationRequest): JsonSafe<WaitOperationRequest>;
    fromPartial(object: DeepPartial<WaitOperationRequest>): WaitOperationRequest;
    fromSDK(object: WaitOperationRequestSDKType): WaitOperationRequest;
    fromSDKJSON(object: any): WaitOperationRequestSDKType;
    toSDK(message: WaitOperationRequest): WaitOperationRequestSDKType;
    fromAmino(object: WaitOperationRequestAmino): WaitOperationRequest;
    toAmino(message: WaitOperationRequest): WaitOperationRequestAmino;
    fromAminoMsg(object: WaitOperationRequestAminoMsg): WaitOperationRequest;
    fromProtoMsg(message: WaitOperationRequestProtoMsg): WaitOperationRequest;
    toProto(message: WaitOperationRequest): Uint8Array;
    toProtoMsg(message: WaitOperationRequest): WaitOperationRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const OperationInfo: {
    typeUrl: string;
    is(o: any): o is OperationInfo;
    isSDK(o: any): o is OperationInfoSDKType;
    isAmino(o: any): o is OperationInfoAmino;
    encode(message: OperationInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): OperationInfo;
    fromJSON(object: any): OperationInfo;
    toJSON(message: OperationInfo): JsonSafe<OperationInfo>;
    fromPartial(object: DeepPartial<OperationInfo>): OperationInfo;
    fromSDK(object: OperationInfoSDKType): OperationInfo;
    fromSDKJSON(object: any): OperationInfoSDKType;
    toSDK(message: OperationInfo): OperationInfoSDKType;
    fromAmino(object: OperationInfoAmino): OperationInfo;
    toAmino(message: OperationInfo): OperationInfoAmino;
    fromAminoMsg(object: OperationInfoAminoMsg): OperationInfo;
    fromProtoMsg(message: OperationInfoProtoMsg): OperationInfo;
    toProto(message: OperationInfo): Uint8Array;
    toProtoMsg(message: OperationInfo): OperationInfoProtoMsg;
    registerTypeUrl(): void;
};
