import { Option, OptionAmino, OptionSDKType, Syntax } from "./type";
import { SourceContext, SourceContextAmino, SourceContextSDKType } from "./source_context";
import { DeepPartial } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.protobuf";
/**
 * Api is a light-weight descriptor for an API Interface.
 *
 * Interfaces are also described as "protocol buffer services" in some contexts,
 * such as by the "service" keyword in a .proto file, but they are different
 * from API Services, which represent a concrete implementation of an interface
 * as opposed to simply a description of methods and bindings. They are also
 * sometimes simply referred to as "APIs" in other contexts, such as the name of
 * this message itself. See https://cloud.google.com/apis/design/glossary for
 * detailed terminology.
 */
export interface Api {
    /**
     * The fully qualified name of this interface, including package name
     * followed by the interface's simple name.
     */
    name: string;
    /** The methods of this interface, in unspecified order. */
    methods: Method[];
    /** Any metadata attached to the interface. */
    options: Option[];
    /**
     * A version string for this interface. If specified, must have the form
     * `major-version.minor-version`, as in `1.10`. If the minor version is
     * omitted, it defaults to zero. If the entire version field is empty, the
     * major version is derived from the package name, as outlined below. If the
     * field is not empty, the version in the package name will be verified to be
     * consistent with what is provided here.
     *
     * The versioning schema uses [semantic
     * versioning](http://semver.org) where the major version number
     * indicates a breaking change and the minor version an additive,
     * non-breaking change. Both version numbers are signals to users
     * what to expect from different versions, and should be carefully
     * chosen based on the product plan.
     *
     * The major version is also reflected in the package name of the
     * interface, which must end in `v<major-version>`, as in
     * `google.feature.v1`. For major versions 0 and 1, the suffix can
     * be omitted. Zero major versions must only be used for
     * experimental, non-GA interfaces.
     */
    version: string;
    /**
     * Source context for the protocol buffer service represented by this
     * message.
     */
    sourceContext?: SourceContext;
    /** Included interfaces. See [Mixin][]. */
    mixins: Mixin[];
    /** The source syntax of the service. */
    syntax: Syntax;
}
export interface ApiProtoMsg {
    typeUrl: "/google.protobuf.Api";
    value: Uint8Array;
}
/**
 * Api is a light-weight descriptor for an API Interface.
 *
 * Interfaces are also described as "protocol buffer services" in some contexts,
 * such as by the "service" keyword in a .proto file, but they are different
 * from API Services, which represent a concrete implementation of an interface
 * as opposed to simply a description of methods and bindings. They are also
 * sometimes simply referred to as "APIs" in other contexts, such as the name of
 * this message itself. See https://cloud.google.com/apis/design/glossary for
 * detailed terminology.
 */
export interface ApiAmino {
    /**
     * The fully qualified name of this interface, including package name
     * followed by the interface's simple name.
     */
    name?: string;
    /** The methods of this interface, in unspecified order. */
    methods?: MethodAmino[];
    /** Any metadata attached to the interface. */
    options?: OptionAmino[];
    /**
     * A version string for this interface. If specified, must have the form
     * `major-version.minor-version`, as in `1.10`. If the minor version is
     * omitted, it defaults to zero. If the entire version field is empty, the
     * major version is derived from the package name, as outlined below. If the
     * field is not empty, the version in the package name will be verified to be
     * consistent with what is provided here.
     *
     * The versioning schema uses [semantic
     * versioning](http://semver.org) where the major version number
     * indicates a breaking change and the minor version an additive,
     * non-breaking change. Both version numbers are signals to users
     * what to expect from different versions, and should be carefully
     * chosen based on the product plan.
     *
     * The major version is also reflected in the package name of the
     * interface, which must end in `v<major-version>`, as in
     * `google.feature.v1`. For major versions 0 and 1, the suffix can
     * be omitted. Zero major versions must only be used for
     * experimental, non-GA interfaces.
     */
    version?: string;
    /**
     * Source context for the protocol buffer service represented by this
     * message.
     */
    source_context?: SourceContextAmino;
    /** Included interfaces. See [Mixin][]. */
    mixins?: MixinAmino[];
    /** The source syntax of the service. */
    syntax?: Syntax;
}
export interface ApiAminoMsg {
    type: "/google.protobuf.Api";
    value: ApiAmino;
}
/**
 * Api is a light-weight descriptor for an API Interface.
 *
 * Interfaces are also described as "protocol buffer services" in some contexts,
 * such as by the "service" keyword in a .proto file, but they are different
 * from API Services, which represent a concrete implementation of an interface
 * as opposed to simply a description of methods and bindings. They are also
 * sometimes simply referred to as "APIs" in other contexts, such as the name of
 * this message itself. See https://cloud.google.com/apis/design/glossary for
 * detailed terminology.
 */
export interface ApiSDKType {
    name: string;
    methods: MethodSDKType[];
    options: OptionSDKType[];
    version: string;
    source_context?: SourceContextSDKType;
    mixins: MixinSDKType[];
    syntax: Syntax;
}
/** Method represents a method of an API interface. */
export interface Method {
    /** The simple name of this method. */
    name: string;
    /** A URL of the input message type. */
    requestTypeUrl: string;
    /** If true, the request is streamed. */
    requestStreaming: boolean;
    /** The URL of the output message type. */
    responseTypeUrl: string;
    /** If true, the response is streamed. */
    responseStreaming: boolean;
    /** Any metadata attached to the method. */
    options: Option[];
    /** The source syntax of this method. */
    syntax: Syntax;
}
export interface MethodProtoMsg {
    typeUrl: "/google.protobuf.Method";
    value: Uint8Array;
}
/** Method represents a method of an API interface. */
export interface MethodAmino {
    /** The simple name of this method. */
    name?: string;
    /** A URL of the input message type. */
    request_type_url?: string;
    /** If true, the request is streamed. */
    request_streaming?: boolean;
    /** The URL of the output message type. */
    response_type_url?: string;
    /** If true, the response is streamed. */
    response_streaming?: boolean;
    /** Any metadata attached to the method. */
    options?: OptionAmino[];
    /** The source syntax of this method. */
    syntax?: Syntax;
}
export interface MethodAminoMsg {
    type: "/google.protobuf.Method";
    value: MethodAmino;
}
/** Method represents a method of an API interface. */
export interface MethodSDKType {
    name: string;
    request_type_url: string;
    request_streaming: boolean;
    response_type_url: string;
    response_streaming: boolean;
    options: OptionSDKType[];
    syntax: Syntax;
}
/**
 * Declares an API Interface to be included in this interface. The including
 * interface must redeclare all the methods from the included interface, but
 * documentation and options are inherited as follows:
 *
 * - If after comment and whitespace stripping, the documentation
 *   string of the redeclared method is empty, it will be inherited
 *   from the original method.
 *
 * - Each annotation belonging to the service config (http,
 *   visibility) which is not set in the redeclared method will be
 *   inherited.
 *
 * - If an http annotation is inherited, the path pattern will be
 *   modified as follows. Any version prefix will be replaced by the
 *   version of the including interface plus the [root][] path if
 *   specified.
 *
 * Example of a simple mixin:
 *
 *     package google.acl.v1;
 *     service AccessControl {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v1/{resource=**}:getAcl";
 *       }
 *     }
 *
 *     package google.storage.v2;
 *     service Storage {
 *       rpc GetAcl(GetAclRequest) returns (Acl);
 *
 *       // Get a data record.
 *       rpc GetData(GetDataRequest) returns (Data) {
 *         option (google.api.http).get = "/v2/{resource=**}";
 *       }
 *     }
 *
 * Example of a mixin configuration:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *
 * The mixin construct implies that all methods in `AccessControl` are
 * also declared with same name and request/response types in
 * `Storage`. A documentation generator or annotation processor will
 * see the effective `Storage.GetAcl` method after inherting
 * documentation and annotations as follows:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 *
 * Note how the version in the path pattern changed from `v1` to `v2`.
 *
 * If the `root` field in the mixin is specified, it should be a
 * relative path under which inherited HTTP paths are placed. Example:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *         root: acls
 *
 * This implies the following inherited HTTP annotation:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/acls/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 */
export interface Mixin {
    /** The fully qualified name of the interface which is included. */
    name: string;
    /**
     * If non-empty specifies a path under which inherited HTTP paths
     * are rooted.
     */
    root: string;
}
export interface MixinProtoMsg {
    typeUrl: "/google.protobuf.Mixin";
    value: Uint8Array;
}
/**
 * Declares an API Interface to be included in this interface. The including
 * interface must redeclare all the methods from the included interface, but
 * documentation and options are inherited as follows:
 *
 * - If after comment and whitespace stripping, the documentation
 *   string of the redeclared method is empty, it will be inherited
 *   from the original method.
 *
 * - Each annotation belonging to the service config (http,
 *   visibility) which is not set in the redeclared method will be
 *   inherited.
 *
 * - If an http annotation is inherited, the path pattern will be
 *   modified as follows. Any version prefix will be replaced by the
 *   version of the including interface plus the [root][] path if
 *   specified.
 *
 * Example of a simple mixin:
 *
 *     package google.acl.v1;
 *     service AccessControl {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v1/{resource=**}:getAcl";
 *       }
 *     }
 *
 *     package google.storage.v2;
 *     service Storage {
 *       rpc GetAcl(GetAclRequest) returns (Acl);
 *
 *       // Get a data record.
 *       rpc GetData(GetDataRequest) returns (Data) {
 *         option (google.api.http).get = "/v2/{resource=**}";
 *       }
 *     }
 *
 * Example of a mixin configuration:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *
 * The mixin construct implies that all methods in `AccessControl` are
 * also declared with same name and request/response types in
 * `Storage`. A documentation generator or annotation processor will
 * see the effective `Storage.GetAcl` method after inherting
 * documentation and annotations as follows:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 *
 * Note how the version in the path pattern changed from `v1` to `v2`.
 *
 * If the `root` field in the mixin is specified, it should be a
 * relative path under which inherited HTTP paths are placed. Example:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *         root: acls
 *
 * This implies the following inherited HTTP annotation:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/acls/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 */
export interface MixinAmino {
    /** The fully qualified name of the interface which is included. */
    name?: string;
    /**
     * If non-empty specifies a path under which inherited HTTP paths
     * are rooted.
     */
    root?: string;
}
export interface MixinAminoMsg {
    type: "/google.protobuf.Mixin";
    value: MixinAmino;
}
/**
 * Declares an API Interface to be included in this interface. The including
 * interface must redeclare all the methods from the included interface, but
 * documentation and options are inherited as follows:
 *
 * - If after comment and whitespace stripping, the documentation
 *   string of the redeclared method is empty, it will be inherited
 *   from the original method.
 *
 * - Each annotation belonging to the service config (http,
 *   visibility) which is not set in the redeclared method will be
 *   inherited.
 *
 * - If an http annotation is inherited, the path pattern will be
 *   modified as follows. Any version prefix will be replaced by the
 *   version of the including interface plus the [root][] path if
 *   specified.
 *
 * Example of a simple mixin:
 *
 *     package google.acl.v1;
 *     service AccessControl {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v1/{resource=**}:getAcl";
 *       }
 *     }
 *
 *     package google.storage.v2;
 *     service Storage {
 *       rpc GetAcl(GetAclRequest) returns (Acl);
 *
 *       // Get a data record.
 *       rpc GetData(GetDataRequest) returns (Data) {
 *         option (google.api.http).get = "/v2/{resource=**}";
 *       }
 *     }
 *
 * Example of a mixin configuration:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *
 * The mixin construct implies that all methods in `AccessControl` are
 * also declared with same name and request/response types in
 * `Storage`. A documentation generator or annotation processor will
 * see the effective `Storage.GetAcl` method after inherting
 * documentation and annotations as follows:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 *
 * Note how the version in the path pattern changed from `v1` to `v2`.
 *
 * If the `root` field in the mixin is specified, it should be a
 * relative path under which inherited HTTP paths are placed. Example:
 *
 *     apis:
 *     - name: google.storage.v2.Storage
 *       mixins:
 *       - name: google.acl.v1.AccessControl
 *         root: acls
 *
 * This implies the following inherited HTTP annotation:
 *
 *     service Storage {
 *       // Get the underlying ACL object.
 *       rpc GetAcl(GetAclRequest) returns (Acl) {
 *         option (google.api.http).get = "/v2/acls/{resource=**}:getAcl";
 *       }
 *       ...
 *     }
 */
export interface MixinSDKType {
    name: string;
    root: string;
}
export declare const Api: {
    typeUrl: string;
    is(o: any): o is Api;
    isSDK(o: any): o is ApiSDKType;
    isAmino(o: any): o is ApiAmino;
    encode(message: Api, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Api;
    fromJSON(object: any): Api;
    toJSON(message: Api): JsonSafe<Api>;
    fromPartial(object: DeepPartial<Api>): Api;
    fromSDK(object: ApiSDKType): Api;
    fromSDKJSON(object: any): ApiSDKType;
    toSDK(message: Api): ApiSDKType;
    fromAmino(object: ApiAmino): Api;
    toAmino(message: Api): ApiAmino;
    fromAminoMsg(object: ApiAminoMsg): Api;
    fromProtoMsg(message: ApiProtoMsg): Api;
    toProto(message: Api): Uint8Array;
    toProtoMsg(message: Api): ApiProtoMsg;
    registerTypeUrl(): void;
};
export declare const Method: {
    typeUrl: string;
    is(o: any): o is Method;
    isSDK(o: any): o is MethodSDKType;
    isAmino(o: any): o is MethodAmino;
    encode(message: Method, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Method;
    fromJSON(object: any): Method;
    toJSON(message: Method): JsonSafe<Method>;
    fromPartial(object: DeepPartial<Method>): Method;
    fromSDK(object: MethodSDKType): Method;
    fromSDKJSON(object: any): MethodSDKType;
    toSDK(message: Method): MethodSDKType;
    fromAmino(object: MethodAmino): Method;
    toAmino(message: Method): MethodAmino;
    fromAminoMsg(object: MethodAminoMsg): Method;
    fromProtoMsg(message: MethodProtoMsg): Method;
    toProto(message: Method): Uint8Array;
    toProtoMsg(message: Method): MethodProtoMsg;
    registerTypeUrl(): void;
};
export declare const Mixin: {
    typeUrl: string;
    is(o: any): o is Mixin;
    isSDK(o: any): o is MixinSDKType;
    isAmino(o: any): o is MixinAmino;
    encode(message: Mixin, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Mixin;
    fromJSON(object: any): Mixin;
    toJSON(message: Mixin): JsonSafe<Mixin>;
    fromPartial(object: DeepPartial<Mixin>): Mixin;
    fromSDK(object: MixinSDKType): Mixin;
    fromSDKJSON(object: any): MixinSDKType;
    toSDK(message: Mixin): MixinSDKType;
    fromAmino(object: MixinAmino): Mixin;
    toAmino(message: Mixin): MixinAmino;
    fromAminoMsg(object: MixinAminoMsg): Mixin;
    fromProtoMsg(message: MixinProtoMsg): Mixin;
    toProto(message: Mixin): Uint8Array;
    toProtoMsg(message: Mixin): MixinProtoMsg;
    registerTypeUrl(): void;
};
