import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.protobuf";
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 *  The JSON representation for `NullValue` is JSON `null`.
 */
export declare enum NullValue {
    /** NULL_VALUE - Null value. */
    NULL_VALUE = 0,
    UNRECOGNIZED = -1
}
export declare const NullValueSDKType: typeof NullValue;
export declare const NullValueAmino: typeof NullValue;
export declare function nullValueFromJSON(object: any): NullValue;
export declare function nullValueToJSON(object: NullValue): string;
export interface Struct_FieldsEntry {
    key: string;
    value?: Value;
}
export interface Struct_FieldsEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface Struct_FieldsEntryAmino {
    key?: string;
    value?: ValueAmino;
}
export interface Struct_FieldsEntryAminoMsg {
    type: string;
    value: Struct_FieldsEntryAmino;
}
export interface Struct_FieldsEntrySDKType {
    key: string;
    value?: ValueSDKType;
}
/**
 * `Struct` represents a structured data value, consisting of fields
 * which map to dynamically typed values. In some languages, `Struct`
 * might be supported by a native representation. For example, in
 * scripting languages like JS a struct is represented as an
 * object. The details of that representation are described together
 * with the proto support for the language.
 *
 * The JSON representation for `Struct` is JSON object.
 */
export interface Struct {
    /** Unordered map of dynamically typed values. */
    fields: {
        [key: string]: Value;
    };
}
export interface StructProtoMsg {
    typeUrl: "/google.protobuf.Struct";
    value: Uint8Array;
}
/**
 * `Struct` represents a structured data value, consisting of fields
 * which map to dynamically typed values. In some languages, `Struct`
 * might be supported by a native representation. For example, in
 * scripting languages like JS a struct is represented as an
 * object. The details of that representation are described together
 * with the proto support for the language.
 *
 * The JSON representation for `Struct` is JSON object.
 */
export interface StructAmino {
    /** Unordered map of dynamically typed values. */
    fields?: {
        [key: string]: ValueAmino;
    };
}
export interface StructAminoMsg {
    type: "/google.protobuf.Struct";
    value: StructAmino;
}
/**
 * `Struct` represents a structured data value, consisting of fields
 * which map to dynamically typed values. In some languages, `Struct`
 * might be supported by a native representation. For example, in
 * scripting languages like JS a struct is represented as an
 * object. The details of that representation are described together
 * with the proto support for the language.
 *
 * The JSON representation for `Struct` is JSON object.
 */
export interface StructSDKType {
    fields: {
        [key: string]: ValueSDKType;
    };
}
/**
 * `Value` represents a dynamically typed value which can be either
 * null, a number, a string, a boolean, a recursive struct value, or a
 * list of values. A producer of value is expected to set one of that
 * variants, absence of any variant indicates an error.
 *
 * The JSON representation for `Value` is JSON value.
 */
export interface Value {
    /** Represents a null value. */
    nullValue?: NullValue;
    /** Represents a double value. */
    numberValue?: number;
    /** Represents a string value. */
    stringValue?: string;
    /** Represents a boolean value. */
    boolValue?: boolean;
    /** Represents a structured value. */
    structValue?: Struct;
    /** Represents a repeated `Value`. */
    listValue?: ListValue;
}
export interface ValueProtoMsg {
    typeUrl: "/google.protobuf.Value";
    value: Uint8Array;
}
/**
 * `Value` represents a dynamically typed value which can be either
 * null, a number, a string, a boolean, a recursive struct value, or a
 * list of values. A producer of value is expected to set one of that
 * variants, absence of any variant indicates an error.
 *
 * The JSON representation for `Value` is JSON value.
 */
export interface ValueAmino {
    /** Represents a null value. */
    null_value?: NullValue;
    /** Represents a double value. */
    number_value?: number;
    /** Represents a string value. */
    string_value?: string;
    /** Represents a boolean value. */
    bool_value?: boolean;
    /** Represents a structured value. */
    struct_value?: StructAmino;
    /** Represents a repeated `Value`. */
    list_value?: ListValueAmino;
}
export interface ValueAminoMsg {
    type: "/google.protobuf.Value";
    value: ValueAmino;
}
/**
 * `Value` represents a dynamically typed value which can be either
 * null, a number, a string, a boolean, a recursive struct value, or a
 * list of values. A producer of value is expected to set one of that
 * variants, absence of any variant indicates an error.
 *
 * The JSON representation for `Value` is JSON value.
 */
export interface ValueSDKType {
    null_value?: NullValue;
    number_value?: number;
    string_value?: string;
    bool_value?: boolean;
    struct_value?: StructSDKType;
    list_value?: ListValueSDKType;
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
export interface ListValue {
    /** Repeated field of dynamically typed values. */
    values: Value[];
}
export interface ListValueProtoMsg {
    typeUrl: "/google.protobuf.ListValue";
    value: Uint8Array;
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
export interface ListValueAmino {
    /** Repeated field of dynamically typed values. */
    values?: ValueAmino[];
}
export interface ListValueAminoMsg {
    type: "/google.protobuf.ListValue";
    value: ListValueAmino;
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
export interface ListValueSDKType {
    values: ValueSDKType[];
}
export declare const Struct_FieldsEntry: {
    encode(message: Struct_FieldsEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Struct_FieldsEntry;
    fromJSON(object: any): Struct_FieldsEntry;
    toJSON(message: Struct_FieldsEntry): JsonSafe<Struct_FieldsEntry>;
    fromPartial(object: DeepPartial<Struct_FieldsEntry>): Struct_FieldsEntry;
    fromSDK(object: Struct_FieldsEntrySDKType): Struct_FieldsEntry;
    fromSDKJSON(object: any): Struct_FieldsEntrySDKType;
    toSDK(message: Struct_FieldsEntry): Struct_FieldsEntrySDKType;
    fromAmino(object: Struct_FieldsEntryAmino): Struct_FieldsEntry;
    toAmino(message: Struct_FieldsEntry): Struct_FieldsEntryAmino;
    fromAminoMsg(object: Struct_FieldsEntryAminoMsg): Struct_FieldsEntry;
    fromProtoMsg(message: Struct_FieldsEntryProtoMsg): Struct_FieldsEntry;
    toProto(message: Struct_FieldsEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const Struct: {
    typeUrl: string;
    is(o: any): o is Struct;
    isSDK(o: any): o is StructSDKType;
    isAmino(o: any): o is StructAmino;
    encode(message: Struct, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Struct;
    fromJSON(object: any): Struct;
    toJSON(message: Struct): JsonSafe<Struct>;
    fromPartial(object: DeepPartial<Struct>): Struct;
    fromSDK(object: StructSDKType): Struct;
    fromSDKJSON(object: any): StructSDKType;
    toSDK(message: Struct): StructSDKType;
    fromAmino(object: StructAmino): Struct;
    toAmino(message: Struct): StructAmino;
    fromAminoMsg(object: StructAminoMsg): Struct;
    fromProtoMsg(message: StructProtoMsg): Struct;
    toProto(message: Struct): Uint8Array;
    toProtoMsg(message: Struct): StructProtoMsg;
    registerTypeUrl(): void;
};
export declare const Value: {
    typeUrl: string;
    is(o: any): o is Value;
    isSDK(o: any): o is ValueSDKType;
    isAmino(o: any): o is ValueAmino;
    encode(message: Value, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Value;
    fromJSON(object: any): Value;
    toJSON(message: Value): JsonSafe<Value>;
    fromPartial(object: DeepPartial<Value>): Value;
    fromSDK(object: ValueSDKType): Value;
    fromSDKJSON(object: any): ValueSDKType;
    toSDK(message: Value): ValueSDKType;
    fromAmino(object: ValueAmino): Value;
    toAmino(message: Value): ValueAmino;
    fromAminoMsg(object: ValueAminoMsg): Value;
    fromProtoMsg(message: ValueProtoMsg): Value;
    toProto(message: Value): Uint8Array;
    toProtoMsg(message: Value): ValueProtoMsg;
    registerTypeUrl(): void;
};
export declare const ListValue: {
    typeUrl: string;
    is(o: any): o is ListValue;
    isSDK(o: any): o is ListValueSDKType;
    isAmino(o: any): o is ListValueAmino;
    encode(message: ListValue, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ListValue;
    fromJSON(object: any): ListValue;
    toJSON(message: ListValue): JsonSafe<ListValue>;
    fromPartial(object: DeepPartial<ListValue>): ListValue;
    fromSDK(object: ListValueSDKType): ListValue;
    fromSDKJSON(object: any): ListValueSDKType;
    toSDK(message: ListValue): ListValueSDKType;
    fromAmino(object: ListValueAmino): ListValue;
    toAmino(message: ListValue): ListValueAmino;
    fromAminoMsg(object: ListValueAminoMsg): ListValue;
    fromProtoMsg(message: ListValueProtoMsg): ListValue;
    toProto(message: ListValue): Uint8Array;
    toProtoMsg(message: ListValue): ListValueProtoMsg;
    registerTypeUrl(): void;
};
