import { Duration, DurationAmino, DurationSDKType } from "../protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.rpc";
/**
 * Describes when the clients can retry a failed request. Clients could ignore
 * the recommendation here or retry when this information is missing from error
 * responses.
 *
 * It's always recommended that clients should use exponential backoff when
 * retrying.
 *
 * Clients should wait until `retry_delay` amount of time has passed since
 * receiving the error response before retrying.  If retrying requests also
 * fail, clients should use an exponential backoff scheme to gradually increase
 * the delay between retries based on `retry_delay`, until either a maximum
 * number of retries have been reached or a maximum retry delay cap has been
 * reached.
 */
export interface RetryInfo {
    /** Clients should wait at least this long between retrying the same request. */
    retryDelay?: Duration;
}
export interface RetryInfoProtoMsg {
    typeUrl: "/google.rpc.RetryInfo";
    value: Uint8Array;
}
/**
 * Describes when the clients can retry a failed request. Clients could ignore
 * the recommendation here or retry when this information is missing from error
 * responses.
 *
 * It's always recommended that clients should use exponential backoff when
 * retrying.
 *
 * Clients should wait until `retry_delay` amount of time has passed since
 * receiving the error response before retrying.  If retrying requests also
 * fail, clients should use an exponential backoff scheme to gradually increase
 * the delay between retries based on `retry_delay`, until either a maximum
 * number of retries have been reached or a maximum retry delay cap has been
 * reached.
 */
export interface RetryInfoAmino {
    /** Clients should wait at least this long between retrying the same request. */
    retry_delay?: DurationAmino;
}
export interface RetryInfoAminoMsg {
    type: "/google.rpc.RetryInfo";
    value: RetryInfoAmino;
}
/**
 * Describes when the clients can retry a failed request. Clients could ignore
 * the recommendation here or retry when this information is missing from error
 * responses.
 *
 * It's always recommended that clients should use exponential backoff when
 * retrying.
 *
 * Clients should wait until `retry_delay` amount of time has passed since
 * receiving the error response before retrying.  If retrying requests also
 * fail, clients should use an exponential backoff scheme to gradually increase
 * the delay between retries based on `retry_delay`, until either a maximum
 * number of retries have been reached or a maximum retry delay cap has been
 * reached.
 */
export interface RetryInfoSDKType {
    retry_delay?: DurationSDKType;
}
/** Describes additional debugging info. */
export interface DebugInfo {
    /** The stack trace entries indicating where the error occurred. */
    stackEntries: string[];
    /** Additional debugging information provided by the server. */
    detail: string;
}
export interface DebugInfoProtoMsg {
    typeUrl: "/google.rpc.DebugInfo";
    value: Uint8Array;
}
/** Describes additional debugging info. */
export interface DebugInfoAmino {
    /** The stack trace entries indicating where the error occurred. */
    stack_entries?: string[];
    /** Additional debugging information provided by the server. */
    detail?: string;
}
export interface DebugInfoAminoMsg {
    type: "/google.rpc.DebugInfo";
    value: DebugInfoAmino;
}
/** Describes additional debugging info. */
export interface DebugInfoSDKType {
    stack_entries: string[];
    detail: string;
}
/**
 * Describes how a quota check failed.
 *
 * For example if a daily limit was exceeded for the calling project,
 * a service could respond with a QuotaFailure detail containing the project
 * id and the description of the quota limit that was exceeded.  If the
 * calling project hasn't enabled the service in the developer console, then
 * a service could respond with the project id and set `service_disabled`
 * to true.
 *
 * Also see RetryInfo and Help types for other details about handling a
 * quota failure.
 */
export interface QuotaFailure {
    /** Describes all quota violations. */
    violations: QuotaFailure_Violation[];
}
export interface QuotaFailureProtoMsg {
    typeUrl: "/google.rpc.QuotaFailure";
    value: Uint8Array;
}
/**
 * Describes how a quota check failed.
 *
 * For example if a daily limit was exceeded for the calling project,
 * a service could respond with a QuotaFailure detail containing the project
 * id and the description of the quota limit that was exceeded.  If the
 * calling project hasn't enabled the service in the developer console, then
 * a service could respond with the project id and set `service_disabled`
 * to true.
 *
 * Also see RetryInfo and Help types for other details about handling a
 * quota failure.
 */
export interface QuotaFailureAmino {
    /** Describes all quota violations. */
    violations?: QuotaFailure_ViolationAmino[];
}
export interface QuotaFailureAminoMsg {
    type: "/google.rpc.QuotaFailure";
    value: QuotaFailureAmino;
}
/**
 * Describes how a quota check failed.
 *
 * For example if a daily limit was exceeded for the calling project,
 * a service could respond with a QuotaFailure detail containing the project
 * id and the description of the quota limit that was exceeded.  If the
 * calling project hasn't enabled the service in the developer console, then
 * a service could respond with the project id and set `service_disabled`
 * to true.
 *
 * Also see RetryInfo and Help types for other details about handling a
 * quota failure.
 */
export interface QuotaFailureSDKType {
    violations: QuotaFailure_ViolationSDKType[];
}
/**
 * A message type used to describe a single quota violation.  For example, a
 * daily quota or a custom quota that was exceeded.
 */
export interface QuotaFailure_Violation {
    /**
     * The subject on which the quota check failed.
     * For example, "clientip:<ip address of client>" or "project:<Google
     * developer project id>".
     */
    subject: string;
    /**
     * A description of how the quota check failed. Clients can use this
     * description to find more about the quota configuration in the service's
     * public documentation, or find the relevant quota limit to adjust through
     * developer console.
     *
     * For example: "Service disabled" or "Daily Limit for read operations
     * exceeded".
     */
    description: string;
}
export interface QuotaFailure_ViolationProtoMsg {
    typeUrl: "/google.rpc.Violation";
    value: Uint8Array;
}
/**
 * A message type used to describe a single quota violation.  For example, a
 * daily quota or a custom quota that was exceeded.
 */
export interface QuotaFailure_ViolationAmino {
    /**
     * The subject on which the quota check failed.
     * For example, "clientip:<ip address of client>" or "project:<Google
     * developer project id>".
     */
    subject?: string;
    /**
     * A description of how the quota check failed. Clients can use this
     * description to find more about the quota configuration in the service's
     * public documentation, or find the relevant quota limit to adjust through
     * developer console.
     *
     * For example: "Service disabled" or "Daily Limit for read operations
     * exceeded".
     */
    description?: string;
}
export interface QuotaFailure_ViolationAminoMsg {
    type: "/google.rpc.Violation";
    value: QuotaFailure_ViolationAmino;
}
/**
 * A message type used to describe a single quota violation.  For example, a
 * daily quota or a custom quota that was exceeded.
 */
export interface QuotaFailure_ViolationSDKType {
    subject: string;
    description: string;
}
export interface ErrorInfo_MetadataEntry {
    key: string;
    value: string;
}
export interface ErrorInfo_MetadataEntryProtoMsg {
    typeUrl: string;
    value: Uint8Array;
}
export interface ErrorInfo_MetadataEntryAmino {
    key?: string;
    value?: string;
}
export interface ErrorInfo_MetadataEntryAminoMsg {
    type: string;
    value: ErrorInfo_MetadataEntryAmino;
}
export interface ErrorInfo_MetadataEntrySDKType {
    key: string;
    value: string;
}
/**
 * Describes the cause of the error with structured details.
 *
 * Example of an error when contacting the "pubsub.googleapis.com" API when it
 * is not enabled:
 *
 *     { "reason": "API_DISABLED"
 *       "domain": "googleapis.com"
 *       "metadata": {
 *         "resource": "projects/123",
 *         "service": "pubsub.googleapis.com"
 *       }
 *     }
 *
 * This response indicates that the pubsub.googleapis.com API is not enabled.
 *
 * Example of an error that is returned when attempting to create a Spanner
 * instance in a region that is out of stock:
 *
 *     { "reason": "STOCKOUT"
 *       "domain": "spanner.googleapis.com",
 *       "metadata": {
 *         "availableRegions": "us-central1,us-east2"
 *       }
 *     }
 */
export interface ErrorInfo {
    /**
     * The reason of the error. This is a constant value that identifies the
     * proximate cause of the error. Error reasons are unique within a particular
     * domain of errors. This should be at most 63 characters and match
     * /[A-Z0-9_]+/.
     */
    reason: string;
    /**
     * The logical grouping to which the "reason" belongs. The error domain
     * is typically the registered service name of the tool or product that
     * generates the error. Example: "pubsub.googleapis.com". If the error is
     * generated by some common infrastructure, the error domain must be a
     * globally unique value that identifies the infrastructure. For Google API
     * infrastructure, the error domain is "googleapis.com".
     */
    domain: string;
    /**
     * Additional structured details about this error.
     *
     * Keys should match /[a-zA-Z0-9-_]/ and be limited to 64 characters in
     * length. When identifying the current value of an exceeded limit, the units
     * should be contained in the key, not the value.  For example, rather than
     * {"instanceLimit": "100/request"}, should be returned as,
     * {"instanceLimitPerRequest": "100"}, if the client exceeds the number of
     * instances that can be created in a single (batch) request.
     */
    metadata: {
        [key: string]: string;
    };
}
export interface ErrorInfoProtoMsg {
    typeUrl: "/google.rpc.ErrorInfo";
    value: Uint8Array;
}
/**
 * Describes the cause of the error with structured details.
 *
 * Example of an error when contacting the "pubsub.googleapis.com" API when it
 * is not enabled:
 *
 *     { "reason": "API_DISABLED"
 *       "domain": "googleapis.com"
 *       "metadata": {
 *         "resource": "projects/123",
 *         "service": "pubsub.googleapis.com"
 *       }
 *     }
 *
 * This response indicates that the pubsub.googleapis.com API is not enabled.
 *
 * Example of an error that is returned when attempting to create a Spanner
 * instance in a region that is out of stock:
 *
 *     { "reason": "STOCKOUT"
 *       "domain": "spanner.googleapis.com",
 *       "metadata": {
 *         "availableRegions": "us-central1,us-east2"
 *       }
 *     }
 */
export interface ErrorInfoAmino {
    /**
     * The reason of the error. This is a constant value that identifies the
     * proximate cause of the error. Error reasons are unique within a particular
     * domain of errors. This should be at most 63 characters and match
     * /[A-Z0-9_]+/.
     */
    reason?: string;
    /**
     * The logical grouping to which the "reason" belongs. The error domain
     * is typically the registered service name of the tool or product that
     * generates the error. Example: "pubsub.googleapis.com". If the error is
     * generated by some common infrastructure, the error domain must be a
     * globally unique value that identifies the infrastructure. For Google API
     * infrastructure, the error domain is "googleapis.com".
     */
    domain?: string;
    /**
     * Additional structured details about this error.
     *
     * Keys should match /[a-zA-Z0-9-_]/ and be limited to 64 characters in
     * length. When identifying the current value of an exceeded limit, the units
     * should be contained in the key, not the value.  For example, rather than
     * {"instanceLimit": "100/request"}, should be returned as,
     * {"instanceLimitPerRequest": "100"}, if the client exceeds the number of
     * instances that can be created in a single (batch) request.
     */
    metadata?: {
        [key: string]: string;
    };
}
export interface ErrorInfoAminoMsg {
    type: "/google.rpc.ErrorInfo";
    value: ErrorInfoAmino;
}
/**
 * Describes the cause of the error with structured details.
 *
 * Example of an error when contacting the "pubsub.googleapis.com" API when it
 * is not enabled:
 *
 *     { "reason": "API_DISABLED"
 *       "domain": "googleapis.com"
 *       "metadata": {
 *         "resource": "projects/123",
 *         "service": "pubsub.googleapis.com"
 *       }
 *     }
 *
 * This response indicates that the pubsub.googleapis.com API is not enabled.
 *
 * Example of an error that is returned when attempting to create a Spanner
 * instance in a region that is out of stock:
 *
 *     { "reason": "STOCKOUT"
 *       "domain": "spanner.googleapis.com",
 *       "metadata": {
 *         "availableRegions": "us-central1,us-east2"
 *       }
 *     }
 */
export interface ErrorInfoSDKType {
    reason: string;
    domain: string;
    metadata: {
        [key: string]: string;
    };
}
/**
 * Describes what preconditions have failed.
 *
 * For example, if an RPC failed because it required the Terms of Service to be
 * acknowledged, it could list the terms of service violation in the
 * PreconditionFailure message.
 */
export interface PreconditionFailure {
    /** Describes all precondition violations. */
    violations: PreconditionFailure_Violation[];
}
export interface PreconditionFailureProtoMsg {
    typeUrl: "/google.rpc.PreconditionFailure";
    value: Uint8Array;
}
/**
 * Describes what preconditions have failed.
 *
 * For example, if an RPC failed because it required the Terms of Service to be
 * acknowledged, it could list the terms of service violation in the
 * PreconditionFailure message.
 */
export interface PreconditionFailureAmino {
    /** Describes all precondition violations. */
    violations?: PreconditionFailure_ViolationAmino[];
}
export interface PreconditionFailureAminoMsg {
    type: "/google.rpc.PreconditionFailure";
    value: PreconditionFailureAmino;
}
/**
 * Describes what preconditions have failed.
 *
 * For example, if an RPC failed because it required the Terms of Service to be
 * acknowledged, it could list the terms of service violation in the
 * PreconditionFailure message.
 */
export interface PreconditionFailureSDKType {
    violations: PreconditionFailure_ViolationSDKType[];
}
/** A message type used to describe a single precondition failure. */
export interface PreconditionFailure_Violation {
    /**
     * The type of PreconditionFailure. We recommend using a service-specific
     * enum type to define the supported precondition violation subjects. For
     * example, "TOS" for "Terms of Service violation".
     */
    type: string;
    /**
     * The subject, relative to the type, that failed.
     * For example, "google.com/cloud" relative to the "TOS" type would indicate
     * which terms of service is being referenced.
     */
    subject: string;
    /**
     * A description of how the precondition failed. Developers can use this
     * description to understand how to fix the failure.
     *
     * For example: "Terms of service not accepted".
     */
    description: string;
}
export interface PreconditionFailure_ViolationProtoMsg {
    typeUrl: "/google.rpc.Violation";
    value: Uint8Array;
}
/** A message type used to describe a single precondition failure. */
export interface PreconditionFailure_ViolationAmino {
    /**
     * The type of PreconditionFailure. We recommend using a service-specific
     * enum type to define the supported precondition violation subjects. For
     * example, "TOS" for "Terms of Service violation".
     */
    type?: string;
    /**
     * The subject, relative to the type, that failed.
     * For example, "google.com/cloud" relative to the "TOS" type would indicate
     * which terms of service is being referenced.
     */
    subject?: string;
    /**
     * A description of how the precondition failed. Developers can use this
     * description to understand how to fix the failure.
     *
     * For example: "Terms of service not accepted".
     */
    description?: string;
}
export interface PreconditionFailure_ViolationAminoMsg {
    type: "/google.rpc.Violation";
    value: PreconditionFailure_ViolationAmino;
}
/** A message type used to describe a single precondition failure. */
export interface PreconditionFailure_ViolationSDKType {
    type: string;
    subject: string;
    description: string;
}
/**
 * Describes violations in a client request. This error type focuses on the
 * syntactic aspects of the request.
 */
export interface BadRequest {
    /** Describes all violations in a client request. */
    fieldViolations: BadRequest_FieldViolation[];
}
export interface BadRequestProtoMsg {
    typeUrl: "/google.rpc.BadRequest";
    value: Uint8Array;
}
/**
 * Describes violations in a client request. This error type focuses on the
 * syntactic aspects of the request.
 */
export interface BadRequestAmino {
    /** Describes all violations in a client request. */
    field_violations?: BadRequest_FieldViolationAmino[];
}
export interface BadRequestAminoMsg {
    type: "/google.rpc.BadRequest";
    value: BadRequestAmino;
}
/**
 * Describes violations in a client request. This error type focuses on the
 * syntactic aspects of the request.
 */
export interface BadRequestSDKType {
    field_violations: BadRequest_FieldViolationSDKType[];
}
/** A message type used to describe a single bad request field. */
export interface BadRequest_FieldViolation {
    /**
     * A path leading to a field in the request body. The value will be a
     * sequence of dot-separated identifiers that identify a protocol buffer
     * field. E.g., "field_violations.field" would identify this field.
     */
    field: string;
    /** A description of why the request element is bad. */
    description: string;
}
export interface BadRequest_FieldViolationProtoMsg {
    typeUrl: "/google.rpc.FieldViolation";
    value: Uint8Array;
}
/** A message type used to describe a single bad request field. */
export interface BadRequest_FieldViolationAmino {
    /**
     * A path leading to a field in the request body. The value will be a
     * sequence of dot-separated identifiers that identify a protocol buffer
     * field. E.g., "field_violations.field" would identify this field.
     */
    field?: string;
    /** A description of why the request element is bad. */
    description?: string;
}
export interface BadRequest_FieldViolationAminoMsg {
    type: "/google.rpc.FieldViolation";
    value: BadRequest_FieldViolationAmino;
}
/** A message type used to describe a single bad request field. */
export interface BadRequest_FieldViolationSDKType {
    field: string;
    description: string;
}
/**
 * Contains metadata about the request that clients can attach when filing a bug
 * or providing other forms of feedback.
 */
export interface RequestInfo {
    /**
     * An opaque string that should only be interpreted by the service generating
     * it. For example, it can be used to identify requests in the service's logs.
     */
    requestId: string;
    /**
     * Any data that was used to serve this request. For example, an encrypted
     * stack trace that can be sent back to the service provider for debugging.
     */
    servingData: string;
}
export interface RequestInfoProtoMsg {
    typeUrl: "/google.rpc.RequestInfo";
    value: Uint8Array;
}
/**
 * Contains metadata about the request that clients can attach when filing a bug
 * or providing other forms of feedback.
 */
export interface RequestInfoAmino {
    /**
     * An opaque string that should only be interpreted by the service generating
     * it. For example, it can be used to identify requests in the service's logs.
     */
    request_id?: string;
    /**
     * Any data that was used to serve this request. For example, an encrypted
     * stack trace that can be sent back to the service provider for debugging.
     */
    serving_data?: string;
}
export interface RequestInfoAminoMsg {
    type: "/google.rpc.RequestInfo";
    value: RequestInfoAmino;
}
/**
 * Contains metadata about the request that clients can attach when filing a bug
 * or providing other forms of feedback.
 */
export interface RequestInfoSDKType {
    request_id: string;
    serving_data: string;
}
/** Describes the resource that is being accessed. */
export interface ResourceInfo {
    /**
     * A name for the type of resource being accessed, e.g. "sql table",
     * "cloud storage bucket", "file", "Google calendar"; or the type URL
     * of the resource: e.g. "type.googleapis.com/google.pubsub.v1.Topic".
     */
    resourceType: string;
    /**
     * The name of the resource being accessed.  For example, a shared calendar
     * name: "example.com_4fghdhgsrgh@group.calendar.google.com", if the current
     * error is [google.rpc.Code.PERMISSION_DENIED][google.rpc.Code.PERMISSION_DENIED].
     */
    resourceName: string;
    /**
     * The owner of the resource (optional).
     * For example, "user:<owner email>" or "project:<Google developer project
     * id>".
     */
    owner: string;
    /**
     * Describes what error is encountered when accessing this resource.
     * For example, updating a cloud project may require the `writer` permission
     * on the developer console project.
     */
    description: string;
}
export interface ResourceInfoProtoMsg {
    typeUrl: "/google.rpc.ResourceInfo";
    value: Uint8Array;
}
/** Describes the resource that is being accessed. */
export interface ResourceInfoAmino {
    /**
     * A name for the type of resource being accessed, e.g. "sql table",
     * "cloud storage bucket", "file", "Google calendar"; or the type URL
     * of the resource: e.g. "type.googleapis.com/google.pubsub.v1.Topic".
     */
    resource_type?: string;
    /**
     * The name of the resource being accessed.  For example, a shared calendar
     * name: "example.com_4fghdhgsrgh@group.calendar.google.com", if the current
     * error is [google.rpc.Code.PERMISSION_DENIED][google.rpc.Code.PERMISSION_DENIED].
     */
    resource_name?: string;
    /**
     * The owner of the resource (optional).
     * For example, "user:<owner email>" or "project:<Google developer project
     * id>".
     */
    owner?: string;
    /**
     * Describes what error is encountered when accessing this resource.
     * For example, updating a cloud project may require the `writer` permission
     * on the developer console project.
     */
    description?: string;
}
export interface ResourceInfoAminoMsg {
    type: "/google.rpc.ResourceInfo";
    value: ResourceInfoAmino;
}
/** Describes the resource that is being accessed. */
export interface ResourceInfoSDKType {
    resource_type: string;
    resource_name: string;
    owner: string;
    description: string;
}
/**
 * Provides links to documentation or for performing an out of band action.
 *
 * For example, if a quota check failed with an error indicating the calling
 * project hasn't enabled the accessed service, this can contain a URL pointing
 * directly to the right place in the developer console to flip the bit.
 */
export interface Help {
    /** URL(s) pointing to additional information on handling the current error. */
    links: Help_Link[];
}
export interface HelpProtoMsg {
    typeUrl: "/google.rpc.Help";
    value: Uint8Array;
}
/**
 * Provides links to documentation or for performing an out of band action.
 *
 * For example, if a quota check failed with an error indicating the calling
 * project hasn't enabled the accessed service, this can contain a URL pointing
 * directly to the right place in the developer console to flip the bit.
 */
export interface HelpAmino {
    /** URL(s) pointing to additional information on handling the current error. */
    links?: Help_LinkAmino[];
}
export interface HelpAminoMsg {
    type: "/google.rpc.Help";
    value: HelpAmino;
}
/**
 * Provides links to documentation or for performing an out of band action.
 *
 * For example, if a quota check failed with an error indicating the calling
 * project hasn't enabled the accessed service, this can contain a URL pointing
 * directly to the right place in the developer console to flip the bit.
 */
export interface HelpSDKType {
    links: Help_LinkSDKType[];
}
/** Describes a URL link. */
export interface Help_Link {
    /** Describes what the link offers. */
    description: string;
    /** The URL of the link. */
    url: string;
}
export interface Help_LinkProtoMsg {
    typeUrl: "/google.rpc.Link";
    value: Uint8Array;
}
/** Describes a URL link. */
export interface Help_LinkAmino {
    /** Describes what the link offers. */
    description?: string;
    /** The URL of the link. */
    url?: string;
}
export interface Help_LinkAminoMsg {
    type: "/google.rpc.Link";
    value: Help_LinkAmino;
}
/** Describes a URL link. */
export interface Help_LinkSDKType {
    description: string;
    url: string;
}
/**
 * Provides a localized error message that is safe to return to the user
 * which can be attached to an RPC error.
 */
export interface LocalizedMessage {
    /**
     * The locale used following the specification defined at
     * http://www.rfc-editor.org/rfc/bcp/bcp47.txt.
     * Examples are: "en-US", "fr-CH", "es-MX"
     */
    locale: string;
    /** The localized error message in the above locale. */
    message: string;
}
export interface LocalizedMessageProtoMsg {
    typeUrl: "/google.rpc.LocalizedMessage";
    value: Uint8Array;
}
/**
 * Provides a localized error message that is safe to return to the user
 * which can be attached to an RPC error.
 */
export interface LocalizedMessageAmino {
    /**
     * The locale used following the specification defined at
     * http://www.rfc-editor.org/rfc/bcp/bcp47.txt.
     * Examples are: "en-US", "fr-CH", "es-MX"
     */
    locale?: string;
    /** The localized error message in the above locale. */
    message?: string;
}
export interface LocalizedMessageAminoMsg {
    type: "/google.rpc.LocalizedMessage";
    value: LocalizedMessageAmino;
}
/**
 * Provides a localized error message that is safe to return to the user
 * which can be attached to an RPC error.
 */
export interface LocalizedMessageSDKType {
    locale: string;
    message: string;
}
export declare const RetryInfo: {
    typeUrl: string;
    is(o: any): o is RetryInfo;
    isSDK(o: any): o is RetryInfoSDKType;
    isAmino(o: any): o is RetryInfoAmino;
    encode(message: RetryInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): RetryInfo;
    fromJSON(object: any): RetryInfo;
    toJSON(message: RetryInfo): JsonSafe<RetryInfo>;
    fromPartial(object: DeepPartial<RetryInfo>): RetryInfo;
    fromSDK(object: RetryInfoSDKType): RetryInfo;
    fromSDKJSON(object: any): RetryInfoSDKType;
    toSDK(message: RetryInfo): RetryInfoSDKType;
    fromAmino(object: RetryInfoAmino): RetryInfo;
    toAmino(message: RetryInfo): RetryInfoAmino;
    fromAminoMsg(object: RetryInfoAminoMsg): RetryInfo;
    fromProtoMsg(message: RetryInfoProtoMsg): RetryInfo;
    toProto(message: RetryInfo): Uint8Array;
    toProtoMsg(message: RetryInfo): RetryInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const DebugInfo: {
    typeUrl: string;
    is(o: any): o is DebugInfo;
    isSDK(o: any): o is DebugInfoSDKType;
    isAmino(o: any): o is DebugInfoAmino;
    encode(message: DebugInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DebugInfo;
    fromJSON(object: any): DebugInfo;
    toJSON(message: DebugInfo): JsonSafe<DebugInfo>;
    fromPartial(object: DeepPartial<DebugInfo>): DebugInfo;
    fromSDK(object: DebugInfoSDKType): DebugInfo;
    fromSDKJSON(object: any): DebugInfoSDKType;
    toSDK(message: DebugInfo): DebugInfoSDKType;
    fromAmino(object: DebugInfoAmino): DebugInfo;
    toAmino(message: DebugInfo): DebugInfoAmino;
    fromAminoMsg(object: DebugInfoAminoMsg): DebugInfo;
    fromProtoMsg(message: DebugInfoProtoMsg): DebugInfo;
    toProto(message: DebugInfo): Uint8Array;
    toProtoMsg(message: DebugInfo): DebugInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const QuotaFailure: {
    typeUrl: string;
    is(o: any): o is QuotaFailure;
    isSDK(o: any): o is QuotaFailureSDKType;
    isAmino(o: any): o is QuotaFailureAmino;
    encode(message: QuotaFailure, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaFailure;
    fromJSON(object: any): QuotaFailure;
    toJSON(message: QuotaFailure): JsonSafe<QuotaFailure>;
    fromPartial(object: DeepPartial<QuotaFailure>): QuotaFailure;
    fromSDK(object: QuotaFailureSDKType): QuotaFailure;
    fromSDKJSON(object: any): QuotaFailureSDKType;
    toSDK(message: QuotaFailure): QuotaFailureSDKType;
    fromAmino(object: QuotaFailureAmino): QuotaFailure;
    toAmino(message: QuotaFailure): QuotaFailureAmino;
    fromAminoMsg(object: QuotaFailureAminoMsg): QuotaFailure;
    fromProtoMsg(message: QuotaFailureProtoMsg): QuotaFailure;
    toProto(message: QuotaFailure): Uint8Array;
    toProtoMsg(message: QuotaFailure): QuotaFailureProtoMsg;
    registerTypeUrl(): void;
};
export declare const QuotaFailure_Violation: {
    typeUrl: string;
    is(o: any): o is QuotaFailure_Violation;
    isSDK(o: any): o is QuotaFailure_ViolationSDKType;
    isAmino(o: any): o is QuotaFailure_ViolationAmino;
    encode(message: QuotaFailure_Violation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QuotaFailure_Violation;
    fromJSON(object: any): QuotaFailure_Violation;
    toJSON(message: QuotaFailure_Violation): JsonSafe<QuotaFailure_Violation>;
    fromPartial(object: DeepPartial<QuotaFailure_Violation>): QuotaFailure_Violation;
    fromSDK(object: QuotaFailure_ViolationSDKType): QuotaFailure_Violation;
    fromSDKJSON(object: any): QuotaFailure_ViolationSDKType;
    toSDK(message: QuotaFailure_Violation): QuotaFailure_ViolationSDKType;
    fromAmino(object: QuotaFailure_ViolationAmino): QuotaFailure_Violation;
    toAmino(message: QuotaFailure_Violation): QuotaFailure_ViolationAmino;
    fromAminoMsg(object: QuotaFailure_ViolationAminoMsg): QuotaFailure_Violation;
    fromProtoMsg(message: QuotaFailure_ViolationProtoMsg): QuotaFailure_Violation;
    toProto(message: QuotaFailure_Violation): Uint8Array;
    toProtoMsg(message: QuotaFailure_Violation): QuotaFailure_ViolationProtoMsg;
    registerTypeUrl(): void;
};
export declare const ErrorInfo_MetadataEntry: {
    encode(message: ErrorInfo_MetadataEntry, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ErrorInfo_MetadataEntry;
    fromJSON(object: any): ErrorInfo_MetadataEntry;
    toJSON(message: ErrorInfo_MetadataEntry): JsonSafe<ErrorInfo_MetadataEntry>;
    fromPartial(object: DeepPartial<ErrorInfo_MetadataEntry>): ErrorInfo_MetadataEntry;
    fromSDK(object: ErrorInfo_MetadataEntrySDKType): ErrorInfo_MetadataEntry;
    fromSDKJSON(object: any): ErrorInfo_MetadataEntrySDKType;
    toSDK(message: ErrorInfo_MetadataEntry): ErrorInfo_MetadataEntrySDKType;
    fromAmino(object: ErrorInfo_MetadataEntryAmino): ErrorInfo_MetadataEntry;
    toAmino(message: ErrorInfo_MetadataEntry): ErrorInfo_MetadataEntryAmino;
    fromAminoMsg(object: ErrorInfo_MetadataEntryAminoMsg): ErrorInfo_MetadataEntry;
    fromProtoMsg(message: ErrorInfo_MetadataEntryProtoMsg): ErrorInfo_MetadataEntry;
    toProto(message: ErrorInfo_MetadataEntry): Uint8Array;
    registerTypeUrl(): void;
};
export declare const ErrorInfo: {
    typeUrl: string;
    is(o: any): o is ErrorInfo;
    isSDK(o: any): o is ErrorInfoSDKType;
    isAmino(o: any): o is ErrorInfoAmino;
    encode(message: ErrorInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ErrorInfo;
    fromJSON(object: any): ErrorInfo;
    toJSON(message: ErrorInfo): JsonSafe<ErrorInfo>;
    fromPartial(object: DeepPartial<ErrorInfo>): ErrorInfo;
    fromSDK(object: ErrorInfoSDKType): ErrorInfo;
    fromSDKJSON(object: any): ErrorInfoSDKType;
    toSDK(message: ErrorInfo): ErrorInfoSDKType;
    fromAmino(object: ErrorInfoAmino): ErrorInfo;
    toAmino(message: ErrorInfo): ErrorInfoAmino;
    fromAminoMsg(object: ErrorInfoAminoMsg): ErrorInfo;
    fromProtoMsg(message: ErrorInfoProtoMsg): ErrorInfo;
    toProto(message: ErrorInfo): Uint8Array;
    toProtoMsg(message: ErrorInfo): ErrorInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const PreconditionFailure: {
    typeUrl: string;
    is(o: any): o is PreconditionFailure;
    isSDK(o: any): o is PreconditionFailureSDKType;
    isAmino(o: any): o is PreconditionFailureAmino;
    encode(message: PreconditionFailure, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): PreconditionFailure;
    fromJSON(object: any): PreconditionFailure;
    toJSON(message: PreconditionFailure): JsonSafe<PreconditionFailure>;
    fromPartial(object: DeepPartial<PreconditionFailure>): PreconditionFailure;
    fromSDK(object: PreconditionFailureSDKType): PreconditionFailure;
    fromSDKJSON(object: any): PreconditionFailureSDKType;
    toSDK(message: PreconditionFailure): PreconditionFailureSDKType;
    fromAmino(object: PreconditionFailureAmino): PreconditionFailure;
    toAmino(message: PreconditionFailure): PreconditionFailureAmino;
    fromAminoMsg(object: PreconditionFailureAminoMsg): PreconditionFailure;
    fromProtoMsg(message: PreconditionFailureProtoMsg): PreconditionFailure;
    toProto(message: PreconditionFailure): Uint8Array;
    toProtoMsg(message: PreconditionFailure): PreconditionFailureProtoMsg;
    registerTypeUrl(): void;
};
export declare const PreconditionFailure_Violation: {
    typeUrl: string;
    is(o: any): o is PreconditionFailure_Violation;
    isSDK(o: any): o is PreconditionFailure_ViolationSDKType;
    isAmino(o: any): o is PreconditionFailure_ViolationAmino;
    encode(message: PreconditionFailure_Violation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): PreconditionFailure_Violation;
    fromJSON(object: any): PreconditionFailure_Violation;
    toJSON(message: PreconditionFailure_Violation): JsonSafe<PreconditionFailure_Violation>;
    fromPartial(object: DeepPartial<PreconditionFailure_Violation>): PreconditionFailure_Violation;
    fromSDK(object: PreconditionFailure_ViolationSDKType): PreconditionFailure_Violation;
    fromSDKJSON(object: any): PreconditionFailure_ViolationSDKType;
    toSDK(message: PreconditionFailure_Violation): PreconditionFailure_ViolationSDKType;
    fromAmino(object: PreconditionFailure_ViolationAmino): PreconditionFailure_Violation;
    toAmino(message: PreconditionFailure_Violation): PreconditionFailure_ViolationAmino;
    fromAminoMsg(object: PreconditionFailure_ViolationAminoMsg): PreconditionFailure_Violation;
    fromProtoMsg(message: PreconditionFailure_ViolationProtoMsg): PreconditionFailure_Violation;
    toProto(message: PreconditionFailure_Violation): Uint8Array;
    toProtoMsg(message: PreconditionFailure_Violation): PreconditionFailure_ViolationProtoMsg;
    registerTypeUrl(): void;
};
export declare const BadRequest: {
    typeUrl: string;
    is(o: any): o is BadRequest;
    isSDK(o: any): o is BadRequestSDKType;
    isAmino(o: any): o is BadRequestAmino;
    encode(message: BadRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BadRequest;
    fromJSON(object: any): BadRequest;
    toJSON(message: BadRequest): JsonSafe<BadRequest>;
    fromPartial(object: DeepPartial<BadRequest>): BadRequest;
    fromSDK(object: BadRequestSDKType): BadRequest;
    fromSDKJSON(object: any): BadRequestSDKType;
    toSDK(message: BadRequest): BadRequestSDKType;
    fromAmino(object: BadRequestAmino): BadRequest;
    toAmino(message: BadRequest): BadRequestAmino;
    fromAminoMsg(object: BadRequestAminoMsg): BadRequest;
    fromProtoMsg(message: BadRequestProtoMsg): BadRequest;
    toProto(message: BadRequest): Uint8Array;
    toProtoMsg(message: BadRequest): BadRequestProtoMsg;
    registerTypeUrl(): void;
};
export declare const BadRequest_FieldViolation: {
    typeUrl: string;
    is(o: any): o is BadRequest_FieldViolation;
    isSDK(o: any): o is BadRequest_FieldViolationSDKType;
    isAmino(o: any): o is BadRequest_FieldViolationAmino;
    encode(message: BadRequest_FieldViolation, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BadRequest_FieldViolation;
    fromJSON(object: any): BadRequest_FieldViolation;
    toJSON(message: BadRequest_FieldViolation): JsonSafe<BadRequest_FieldViolation>;
    fromPartial(object: DeepPartial<BadRequest_FieldViolation>): BadRequest_FieldViolation;
    fromSDK(object: BadRequest_FieldViolationSDKType): BadRequest_FieldViolation;
    fromSDKJSON(object: any): BadRequest_FieldViolationSDKType;
    toSDK(message: BadRequest_FieldViolation): BadRequest_FieldViolationSDKType;
    fromAmino(object: BadRequest_FieldViolationAmino): BadRequest_FieldViolation;
    toAmino(message: BadRequest_FieldViolation): BadRequest_FieldViolationAmino;
    fromAminoMsg(object: BadRequest_FieldViolationAminoMsg): BadRequest_FieldViolation;
    fromProtoMsg(message: BadRequest_FieldViolationProtoMsg): BadRequest_FieldViolation;
    toProto(message: BadRequest_FieldViolation): Uint8Array;
    toProtoMsg(message: BadRequest_FieldViolation): BadRequest_FieldViolationProtoMsg;
    registerTypeUrl(): void;
};
export declare const RequestInfo: {
    typeUrl: string;
    is(o: any): o is RequestInfo;
    isSDK(o: any): o is RequestInfoSDKType;
    isAmino(o: any): o is RequestInfoAmino;
    encode(message: RequestInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): RequestInfo;
    fromJSON(object: any): RequestInfo;
    toJSON(message: RequestInfo): JsonSafe<RequestInfo>;
    fromPartial(object: DeepPartial<RequestInfo>): RequestInfo;
    fromSDK(object: RequestInfoSDKType): RequestInfo;
    fromSDKJSON(object: any): RequestInfoSDKType;
    toSDK(message: RequestInfo): RequestInfoSDKType;
    fromAmino(object: RequestInfoAmino): RequestInfo;
    toAmino(message: RequestInfo): RequestInfoAmino;
    fromAminoMsg(object: RequestInfoAminoMsg): RequestInfo;
    fromProtoMsg(message: RequestInfoProtoMsg): RequestInfo;
    toProto(message: RequestInfo): Uint8Array;
    toProtoMsg(message: RequestInfo): RequestInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const ResourceInfo: {
    typeUrl: string;
    is(o: any): o is ResourceInfo;
    isSDK(o: any): o is ResourceInfoSDKType;
    isAmino(o: any): o is ResourceInfoAmino;
    encode(message: ResourceInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ResourceInfo;
    fromJSON(object: any): ResourceInfo;
    toJSON(message: ResourceInfo): JsonSafe<ResourceInfo>;
    fromPartial(object: DeepPartial<ResourceInfo>): ResourceInfo;
    fromSDK(object: ResourceInfoSDKType): ResourceInfo;
    fromSDKJSON(object: any): ResourceInfoSDKType;
    toSDK(message: ResourceInfo): ResourceInfoSDKType;
    fromAmino(object: ResourceInfoAmino): ResourceInfo;
    toAmino(message: ResourceInfo): ResourceInfoAmino;
    fromAminoMsg(object: ResourceInfoAminoMsg): ResourceInfo;
    fromProtoMsg(message: ResourceInfoProtoMsg): ResourceInfo;
    toProto(message: ResourceInfo): Uint8Array;
    toProtoMsg(message: ResourceInfo): ResourceInfoProtoMsg;
    registerTypeUrl(): void;
};
export declare const Help: {
    typeUrl: string;
    is(o: any): o is Help;
    isSDK(o: any): o is HelpSDKType;
    isAmino(o: any): o is HelpAmino;
    encode(message: Help, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Help;
    fromJSON(object: any): Help;
    toJSON(message: Help): JsonSafe<Help>;
    fromPartial(object: DeepPartial<Help>): Help;
    fromSDK(object: HelpSDKType): Help;
    fromSDKJSON(object: any): HelpSDKType;
    toSDK(message: Help): HelpSDKType;
    fromAmino(object: HelpAmino): Help;
    toAmino(message: Help): HelpAmino;
    fromAminoMsg(object: HelpAminoMsg): Help;
    fromProtoMsg(message: HelpProtoMsg): Help;
    toProto(message: Help): Uint8Array;
    toProtoMsg(message: Help): HelpProtoMsg;
    registerTypeUrl(): void;
};
export declare const Help_Link: {
    typeUrl: string;
    is(o: any): o is Help_Link;
    isSDK(o: any): o is Help_LinkSDKType;
    isAmino(o: any): o is Help_LinkAmino;
    encode(message: Help_Link, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Help_Link;
    fromJSON(object: any): Help_Link;
    toJSON(message: Help_Link): JsonSafe<Help_Link>;
    fromPartial(object: DeepPartial<Help_Link>): Help_Link;
    fromSDK(object: Help_LinkSDKType): Help_Link;
    fromSDKJSON(object: any): Help_LinkSDKType;
    toSDK(message: Help_Link): Help_LinkSDKType;
    fromAmino(object: Help_LinkAmino): Help_Link;
    toAmino(message: Help_Link): Help_LinkAmino;
    fromAminoMsg(object: Help_LinkAminoMsg): Help_Link;
    fromProtoMsg(message: Help_LinkProtoMsg): Help_Link;
    toProto(message: Help_Link): Uint8Array;
    toProtoMsg(message: Help_Link): Help_LinkProtoMsg;
    registerTypeUrl(): void;
};
export declare const LocalizedMessage: {
    typeUrl: string;
    is(o: any): o is LocalizedMessage;
    isSDK(o: any): o is LocalizedMessageSDKType;
    isAmino(o: any): o is LocalizedMessageAmino;
    encode(message: LocalizedMessage, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): LocalizedMessage;
    fromJSON(object: any): LocalizedMessage;
    toJSON(message: LocalizedMessage): JsonSafe<LocalizedMessage>;
    fromPartial(object: DeepPartial<LocalizedMessage>): LocalizedMessage;
    fromSDK(object: LocalizedMessageSDKType): LocalizedMessage;
    fromSDKJSON(object: any): LocalizedMessageSDKType;
    toSDK(message: LocalizedMessage): LocalizedMessageSDKType;
    fromAmino(object: LocalizedMessageAmino): LocalizedMessage;
    toAmino(message: LocalizedMessage): LocalizedMessageAmino;
    fromAminoMsg(object: LocalizedMessageAminoMsg): LocalizedMessage;
    fromProtoMsg(message: LocalizedMessageProtoMsg): LocalizedMessage;
    toProto(message: LocalizedMessage): Uint8Array;
    toProtoMsg(message: LocalizedMessage): LocalizedMessageProtoMsg;
    registerTypeUrl(): void;
};
