import { Duration } from "../protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../binary";
import { isSet, isObject } from "../../helpers";
export const protobufPackage = "google.rpc";
function createBaseRetryInfo() {
    return {
        retryDelay: undefined
    };
}
export const RetryInfo = {
    typeUrl: "/google.rpc.RetryInfo",
    is(o) {
        return o && o.$typeUrl === RetryInfo.typeUrl;
    },
    isSDK(o) {
        return o && o.$typeUrl === RetryInfo.typeUrl;
    },
    isAmino(o) {
        return o && o.$typeUrl === RetryInfo.typeUrl;
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.retryDelay !== undefined) {
            Duration.encode(message.retryDelay, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseRetryInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.retryDelay = Duration.decode(reader, reader.uint32());
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseRetryInfo();
        if (isSet(object.retryDelay))
            obj.retryDelay = Duration.fromJSON(object.retryDelay);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.retryDelay !== undefined && (obj.retryDelay = message.retryDelay ? Duration.toJSON(message.retryDelay) : undefined);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseRetryInfo();
        if (object.retryDelay !== undefined && object.retryDelay !== null) {
            message.retryDelay = Duration.fromPartial(object.retryDelay);
        }
        return message;
    },
    fromSDK(object) {
        return {
            retryDelay: object.retry_delay ? Duration.fromSDK(object.retry_delay) : undefined
        };
    },
    fromSDKJSON(object) {
        return {
            retry_delay: isSet(object.retry_delay) ? Duration.fromSDKJSON(object.retry_delay) : undefined
        };
    },
    toSDK(message) {
        const obj = {};
        message.retryDelay !== undefined && (obj.retry_delay = message.retryDelay ? Duration.toSDK(message.retryDelay) : undefined);
        return obj;
    },
    fromAmino(object) {
        const message = createBaseRetryInfo();
        if (object.retry_delay !== undefined && object.retry_delay !== null) {
            message.retryDelay = Duration.fromAmino(object.retry_delay);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.retry_delay = message.retryDelay ? Duration.toAmino(message.retryDelay) : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return RetryInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return RetryInfo.decode(message.value);
    },
    toProto(message) {
        return RetryInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.RetryInfo",
            value: RetryInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseDebugInfo() {
    return {
        stackEntries: [],
        detail: ""
    };
}
export const DebugInfo = {
    typeUrl: "/google.rpc.DebugInfo",
    is(o) {
        return o && (o.$typeUrl === DebugInfo.typeUrl || Array.isArray(o.stackEntries) && (!o.stackEntries.length || typeof o.stackEntries[0] === "string") && typeof o.detail === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === DebugInfo.typeUrl || Array.isArray(o.stack_entries) && (!o.stack_entries.length || typeof o.stack_entries[0] === "string") && typeof o.detail === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === DebugInfo.typeUrl || Array.isArray(o.stack_entries) && (!o.stack_entries.length || typeof o.stack_entries[0] === "string") && typeof o.detail === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.stackEntries) {
            writer.uint32(10).string(v);
        }
        if (message.detail !== undefined) {
            writer.uint32(18).string(message.detail);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseDebugInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.stackEntries.push(reader.string());
                    break;
                case 2:
                    message.detail = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseDebugInfo();
        if (Array.isArray(object?.stackEntries))
            obj.stackEntries = object.stackEntries.map((e) => String(e));
        if (isSet(object.detail))
            obj.detail = String(object.detail);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.stackEntries) {
            obj.stackEntries = message.stackEntries.map(e => e);
        }
        else {
            obj.stackEntries = [];
        }
        message.detail !== undefined && (obj.detail = message.detail);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseDebugInfo();
        message.stackEntries = object.stackEntries?.map(e => e) || [];
        message.detail = object.detail ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            stackEntries: Array.isArray(object?.stack_entries) ? object.stack_entries.map((e) => e) : [],
            detail: object?.detail
        };
    },
    fromSDKJSON(object) {
        return {
            stack_entries: Array.isArray(object?.stack_entries) ? object.stack_entries.map((e) => String(e)) : [],
            detail: isSet(object.detail) ? String(object.detail) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.stackEntries) {
            obj.stack_entries = message.stackEntries.map(e => e);
        }
        else {
            obj.stack_entries = [];
        }
        obj.detail = message.detail;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseDebugInfo();
        message.stackEntries = object.stack_entries?.map(e => e) || [];
        if (object.detail !== undefined && object.detail !== null) {
            message.detail = object.detail;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.stackEntries) {
            obj.stack_entries = message.stackEntries.map(e => e);
        }
        else {
            obj.stack_entries = message.stackEntries;
        }
        obj.detail = message.detail === "" ? undefined : message.detail;
        return obj;
    },
    fromAminoMsg(object) {
        return DebugInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return DebugInfo.decode(message.value);
    },
    toProto(message) {
        return DebugInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.DebugInfo",
            value: DebugInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseQuotaFailure() {
    return {
        violations: []
    };
}
export const QuotaFailure = {
    typeUrl: "/google.rpc.QuotaFailure",
    is(o) {
        return o && (o.$typeUrl === QuotaFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || QuotaFailure_Violation.is(o.violations[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || QuotaFailure_Violation.isSDK(o.violations[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || QuotaFailure_Violation.isAmino(o.violations[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.violations) {
            QuotaFailure_Violation.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaFailure();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.violations.push(QuotaFailure_Violation.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaFailure();
        if (Array.isArray(object?.violations))
            obj.violations = object.violations.map((e) => QuotaFailure_Violation.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? QuotaFailure_Violation.toJSON(e) : undefined);
        }
        else {
            obj.violations = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaFailure();
        message.violations = object.violations?.map(e => QuotaFailure_Violation.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            violations: Array.isArray(object?.violations) ? object.violations.map((e) => QuotaFailure_Violation.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            violations: Array.isArray(object?.violations) ? object.violations.map((e) => QuotaFailure_Violation.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? QuotaFailure_Violation.toSDK(e) : undefined);
        }
        else {
            obj.violations = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaFailure();
        message.violations = object.violations?.map(e => QuotaFailure_Violation.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? QuotaFailure_Violation.toAmino(e) : undefined);
        }
        else {
            obj.violations = message.violations;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaFailure.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaFailure.decode(message.value);
    },
    toProto(message) {
        return QuotaFailure.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.QuotaFailure",
            value: QuotaFailure.encode(message).finish()
        };
    },
    registerTypeUrl() {
        QuotaFailure_Violation.registerTypeUrl();
    }
};
function createBaseQuotaFailure_Violation() {
    return {
        subject: "",
        description: ""
    };
}
export const QuotaFailure_Violation = {
    typeUrl: "/google.rpc.Violation",
    is(o) {
        return o && (o.$typeUrl === QuotaFailure_Violation.typeUrl || typeof o.subject === "string" && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === QuotaFailure_Violation.typeUrl || typeof o.subject === "string" && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === QuotaFailure_Violation.typeUrl || typeof o.subject === "string" && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.subject !== undefined) {
            writer.uint32(10).string(message.subject);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseQuotaFailure_Violation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.subject = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseQuotaFailure_Violation();
        if (isSet(object.subject))
            obj.subject = String(object.subject);
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.subject !== undefined && (obj.subject = message.subject);
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseQuotaFailure_Violation();
        message.subject = object.subject ?? "";
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            subject: object?.subject,
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            subject: isSet(object.subject) ? String(object.subject) : "",
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.subject = message.subject;
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseQuotaFailure_Violation();
        if (object.subject !== undefined && object.subject !== null) {
            message.subject = object.subject;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.subject = message.subject === "" ? undefined : message.subject;
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return QuotaFailure_Violation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return QuotaFailure_Violation.decode(message.value);
    },
    toProto(message) {
        return QuotaFailure_Violation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.Violation",
            value: QuotaFailure_Violation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseErrorInfo_MetadataEntry() {
    return {
        key: "",
        value: ""
    };
}
export const ErrorInfo_MetadataEntry = {
    encode(message, writer = BinaryWriter.create()) {
        if (message.key !== undefined) {
            writer.uint32(10).string(message.key);
        }
        if (message.value !== undefined) {
            writer.uint32(18).string(message.value);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseErrorInfo_MetadataEntry();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.key = reader.string();
                    break;
                case 2:
                    message.value = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseErrorInfo_MetadataEntry();
        if (isSet(object.key))
            obj.key = String(object.key);
        if (isSet(object.value))
            obj.value = String(object.value);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.key !== undefined && (obj.key = message.key);
        message.value !== undefined && (obj.value = message.value);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseErrorInfo_MetadataEntry();
        message.key = object.key ?? "";
        message.value = object.value ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            key: object?.key,
            value: object?.value
        };
    },
    fromSDKJSON(object) {
        return {
            key: isSet(object.key) ? String(object.key) : "",
            value: isSet(object.value) ? String(object.value) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.key = message.key;
        obj.value = message.value;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseErrorInfo_MetadataEntry();
        if (object.key !== undefined && object.key !== null) {
            message.key = object.key;
        }
        if (object.value !== undefined && object.value !== null) {
            message.value = object.value;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.key = message.key === "" ? undefined : message.key;
        obj.value = message.value === "" ? undefined : message.value;
        return obj;
    },
    fromAminoMsg(object) {
        return ErrorInfo_MetadataEntry.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ErrorInfo_MetadataEntry.decode(message.value);
    },
    toProto(message) {
        return ErrorInfo_MetadataEntry.encode(message).finish();
    },
    registerTypeUrl() { }
};
function createBaseErrorInfo() {
    return {
        reason: "",
        domain: "",
        metadata: {}
    };
}
export const ErrorInfo = {
    typeUrl: "/google.rpc.ErrorInfo",
    is(o) {
        return o && (o.$typeUrl === ErrorInfo.typeUrl || typeof o.reason === "string" && typeof o.domain === "string" && isSet(o.metadata));
    },
    isSDK(o) {
        return o && (o.$typeUrl === ErrorInfo.typeUrl || typeof o.reason === "string" && typeof o.domain === "string" && isSet(o.metadata));
    },
    isAmino(o) {
        return o && (o.$typeUrl === ErrorInfo.typeUrl || typeof o.reason === "string" && typeof o.domain === "string" && isSet(o.metadata));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.reason !== undefined) {
            writer.uint32(10).string(message.reason);
        }
        if (message.domain !== undefined) {
            writer.uint32(18).string(message.domain);
        }
        Object.entries(message.metadata).forEach(([key, value]) => {
            ErrorInfo_MetadataEntry.encode({
                key: key,
                value
            }, writer.uint32(26).fork()).ldelim();
        });
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseErrorInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.reason = reader.string();
                    break;
                case 2:
                    message.domain = reader.string();
                    break;
                case 3:
                    const entry3 = ErrorInfo_MetadataEntry.decode(reader, reader.uint32());
                    if (entry3.value !== undefined) {
                        message.metadata[entry3.key] = entry3.value;
                    }
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseErrorInfo();
        if (isSet(object.reason))
            obj.reason = String(object.reason);
        if (isSet(object.domain))
            obj.domain = String(object.domain);
        if (isObject(object.metadata))
            obj.metadata = Object.entries(object.metadata).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {});
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.reason !== undefined && (obj.reason = message.reason);
        message.domain !== undefined && (obj.domain = message.domain);
        obj.metadata = {};
        if (message.metadata) {
            Object.entries(message.metadata).forEach(([k, v]) => {
                obj.metadata[k] = v;
            });
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseErrorInfo();
        message.reason = object.reason ?? "";
        message.domain = object.domain ?? "";
        message.metadata = Object.entries(object.metadata ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        return message;
    },
    fromSDK(object) {
        return {
            reason: object?.reason,
            domain: object?.domain,
            metadata: isObject(object.metadata) ? Object.entries(object.metadata).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {}
        };
    },
    fromSDKJSON(object) {
        return {
            reason: isSet(object.reason) ? String(object.reason) : "",
            domain: isSet(object.domain) ? String(object.domain) : "",
            metadata: isObject(object.metadata) ? Object.entries(object.metadata).reduce((acc, [key, value]) => {
                acc[key] = String(value);
                return acc;
            }, {}) : {}
        };
    },
    toSDK(message) {
        const obj = {};
        obj.reason = message.reason;
        obj.domain = message.domain;
        obj.metadata = {};
        if (message.metadata) {
            Object.entries(message.metadata).forEach(([k, v]) => {
                obj.metadata[k] = v;
            });
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseErrorInfo();
        if (object.reason !== undefined && object.reason !== null) {
            message.reason = object.reason;
        }
        if (object.domain !== undefined && object.domain !== null) {
            message.domain = object.domain;
        }
        message.metadata = Object.entries(object.metadata ?? {}).reduce((acc, [key, value]) => {
            if (value !== undefined) {
                acc[key] = String(value);
            }
            return acc;
        }, {});
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.reason = message.reason === "" ? undefined : message.reason;
        obj.domain = message.domain === "" ? undefined : message.domain;
        obj.metadata = {};
        if (message.metadata) {
            Object.entries(message.metadata).forEach(([k, v]) => {
                obj.metadata[k] = v;
            });
        }
        return obj;
    },
    fromAminoMsg(object) {
        return ErrorInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ErrorInfo.decode(message.value);
    },
    toProto(message) {
        return ErrorInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.ErrorInfo",
            value: ErrorInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBasePreconditionFailure() {
    return {
        violations: []
    };
}
export const PreconditionFailure = {
    typeUrl: "/google.rpc.PreconditionFailure",
    is(o) {
        return o && (o.$typeUrl === PreconditionFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || PreconditionFailure_Violation.is(o.violations[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === PreconditionFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || PreconditionFailure_Violation.isSDK(o.violations[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === PreconditionFailure.typeUrl || Array.isArray(o.violations) && (!o.violations.length || PreconditionFailure_Violation.isAmino(o.violations[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.violations) {
            PreconditionFailure_Violation.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBasePreconditionFailure();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.violations.push(PreconditionFailure_Violation.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBasePreconditionFailure();
        if (Array.isArray(object?.violations))
            obj.violations = object.violations.map((e) => PreconditionFailure_Violation.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? PreconditionFailure_Violation.toJSON(e) : undefined);
        }
        else {
            obj.violations = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBasePreconditionFailure();
        message.violations = object.violations?.map(e => PreconditionFailure_Violation.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            violations: Array.isArray(object?.violations) ? object.violations.map((e) => PreconditionFailure_Violation.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            violations: Array.isArray(object?.violations) ? object.violations.map((e) => PreconditionFailure_Violation.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? PreconditionFailure_Violation.toSDK(e) : undefined);
        }
        else {
            obj.violations = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBasePreconditionFailure();
        message.violations = object.violations?.map(e => PreconditionFailure_Violation.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.violations) {
            obj.violations = message.violations.map(e => e ? PreconditionFailure_Violation.toAmino(e) : undefined);
        }
        else {
            obj.violations = message.violations;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return PreconditionFailure.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return PreconditionFailure.decode(message.value);
    },
    toProto(message) {
        return PreconditionFailure.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.PreconditionFailure",
            value: PreconditionFailure.encode(message).finish()
        };
    },
    registerTypeUrl() {
        PreconditionFailure_Violation.registerTypeUrl();
    }
};
function createBasePreconditionFailure_Violation() {
    return {
        type: "",
        subject: "",
        description: ""
    };
}
export const PreconditionFailure_Violation = {
    typeUrl: "/google.rpc.Violation",
    is(o) {
        return o && (o.$typeUrl === PreconditionFailure_Violation.typeUrl || typeof o.type === "string" && typeof o.subject === "string" && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === PreconditionFailure_Violation.typeUrl || typeof o.type === "string" && typeof o.subject === "string" && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === PreconditionFailure_Violation.typeUrl || typeof o.type === "string" && typeof o.subject === "string" && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.type !== undefined) {
            writer.uint32(10).string(message.type);
        }
        if (message.subject !== undefined) {
            writer.uint32(18).string(message.subject);
        }
        if (message.description !== undefined) {
            writer.uint32(26).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBasePreconditionFailure_Violation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.type = reader.string();
                    break;
                case 2:
                    message.subject = reader.string();
                    break;
                case 3:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBasePreconditionFailure_Violation();
        if (isSet(object.type))
            obj.type = String(object.type);
        if (isSet(object.subject))
            obj.subject = String(object.subject);
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.type !== undefined && (obj.type = message.type);
        message.subject !== undefined && (obj.subject = message.subject);
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBasePreconditionFailure_Violation();
        message.type = object.type ?? "";
        message.subject = object.subject ?? "";
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            type: object?.type,
            subject: object?.subject,
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            type: isSet(object.type) ? String(object.type) : "",
            subject: isSet(object.subject) ? String(object.subject) : "",
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.type = message.type;
        obj.subject = message.subject;
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBasePreconditionFailure_Violation();
        if (object.type !== undefined && object.type !== null) {
            message.type = object.type;
        }
        if (object.subject !== undefined && object.subject !== null) {
            message.subject = object.subject;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.type = message.type === "" ? undefined : message.type;
        obj.subject = message.subject === "" ? undefined : message.subject;
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return PreconditionFailure_Violation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return PreconditionFailure_Violation.decode(message.value);
    },
    toProto(message) {
        return PreconditionFailure_Violation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.Violation",
            value: PreconditionFailure_Violation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseBadRequest() {
    return {
        fieldViolations: []
    };
}
export const BadRequest = {
    typeUrl: "/google.rpc.BadRequest",
    is(o) {
        return o && (o.$typeUrl === BadRequest.typeUrl || Array.isArray(o.fieldViolations) && (!o.fieldViolations.length || BadRequest_FieldViolation.is(o.fieldViolations[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === BadRequest.typeUrl || Array.isArray(o.field_violations) && (!o.field_violations.length || BadRequest_FieldViolation.isSDK(o.field_violations[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === BadRequest.typeUrl || Array.isArray(o.field_violations) && (!o.field_violations.length || BadRequest_FieldViolation.isAmino(o.field_violations[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.fieldViolations) {
            BadRequest_FieldViolation.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBadRequest();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.fieldViolations.push(BadRequest_FieldViolation.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBadRequest();
        if (Array.isArray(object?.fieldViolations))
            obj.fieldViolations = object.fieldViolations.map((e) => BadRequest_FieldViolation.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.fieldViolations) {
            obj.fieldViolations = message.fieldViolations.map(e => e ? BadRequest_FieldViolation.toJSON(e) : undefined);
        }
        else {
            obj.fieldViolations = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBadRequest();
        message.fieldViolations = object.fieldViolations?.map(e => BadRequest_FieldViolation.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            fieldViolations: Array.isArray(object?.field_violations) ? object.field_violations.map((e) => BadRequest_FieldViolation.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            field_violations: Array.isArray(object?.field_violations) ? object.field_violations.map((e) => BadRequest_FieldViolation.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.fieldViolations) {
            obj.field_violations = message.fieldViolations.map(e => e ? BadRequest_FieldViolation.toSDK(e) : undefined);
        }
        else {
            obj.field_violations = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBadRequest();
        message.fieldViolations = object.field_violations?.map(e => BadRequest_FieldViolation.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.fieldViolations) {
            obj.field_violations = message.fieldViolations.map(e => e ? BadRequest_FieldViolation.toAmino(e) : undefined);
        }
        else {
            obj.field_violations = message.fieldViolations;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return BadRequest.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BadRequest.decode(message.value);
    },
    toProto(message) {
        return BadRequest.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.BadRequest",
            value: BadRequest.encode(message).finish()
        };
    },
    registerTypeUrl() {
        BadRequest_FieldViolation.registerTypeUrl();
    }
};
function createBaseBadRequest_FieldViolation() {
    return {
        field: "",
        description: ""
    };
}
export const BadRequest_FieldViolation = {
    typeUrl: "/google.rpc.FieldViolation",
    is(o) {
        return o && (o.$typeUrl === BadRequest_FieldViolation.typeUrl || typeof o.field === "string" && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === BadRequest_FieldViolation.typeUrl || typeof o.field === "string" && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === BadRequest_FieldViolation.typeUrl || typeof o.field === "string" && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.field !== undefined) {
            writer.uint32(10).string(message.field);
        }
        if (message.description !== undefined) {
            writer.uint32(18).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseBadRequest_FieldViolation();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.field = reader.string();
                    break;
                case 2:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseBadRequest_FieldViolation();
        if (isSet(object.field))
            obj.field = String(object.field);
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.field !== undefined && (obj.field = message.field);
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseBadRequest_FieldViolation();
        message.field = object.field ?? "";
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            field: object?.field,
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            field: isSet(object.field) ? String(object.field) : "",
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.field = message.field;
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseBadRequest_FieldViolation();
        if (object.field !== undefined && object.field !== null) {
            message.field = object.field;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.field = message.field === "" ? undefined : message.field;
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return BadRequest_FieldViolation.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return BadRequest_FieldViolation.decode(message.value);
    },
    toProto(message) {
        return BadRequest_FieldViolation.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.FieldViolation",
            value: BadRequest_FieldViolation.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseRequestInfo() {
    return {
        requestId: "",
        servingData: ""
    };
}
export const RequestInfo = {
    typeUrl: "/google.rpc.RequestInfo",
    is(o) {
        return o && (o.$typeUrl === RequestInfo.typeUrl || typeof o.requestId === "string" && typeof o.servingData === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === RequestInfo.typeUrl || typeof o.request_id === "string" && typeof o.serving_data === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === RequestInfo.typeUrl || typeof o.request_id === "string" && typeof o.serving_data === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.requestId !== undefined) {
            writer.uint32(10).string(message.requestId);
        }
        if (message.servingData !== undefined) {
            writer.uint32(18).string(message.servingData);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseRequestInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.requestId = reader.string();
                    break;
                case 2:
                    message.servingData = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseRequestInfo();
        if (isSet(object.requestId))
            obj.requestId = String(object.requestId);
        if (isSet(object.servingData))
            obj.servingData = String(object.servingData);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.requestId !== undefined && (obj.requestId = message.requestId);
        message.servingData !== undefined && (obj.servingData = message.servingData);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseRequestInfo();
        message.requestId = object.requestId ?? "";
        message.servingData = object.servingData ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            requestId: object?.request_id,
            servingData: object?.serving_data
        };
    },
    fromSDKJSON(object) {
        return {
            request_id: isSet(object.request_id) ? String(object.request_id) : "",
            serving_data: isSet(object.serving_data) ? String(object.serving_data) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.request_id = message.requestId;
        obj.serving_data = message.servingData;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseRequestInfo();
        if (object.request_id !== undefined && object.request_id !== null) {
            message.requestId = object.request_id;
        }
        if (object.serving_data !== undefined && object.serving_data !== null) {
            message.servingData = object.serving_data;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.request_id = message.requestId === "" ? undefined : message.requestId;
        obj.serving_data = message.servingData === "" ? undefined : message.servingData;
        return obj;
    },
    fromAminoMsg(object) {
        return RequestInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return RequestInfo.decode(message.value);
    },
    toProto(message) {
        return RequestInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.RequestInfo",
            value: RequestInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseResourceInfo() {
    return {
        resourceType: "",
        resourceName: "",
        owner: "",
        description: ""
    };
}
export const ResourceInfo = {
    typeUrl: "/google.rpc.ResourceInfo",
    is(o) {
        return o && (o.$typeUrl === ResourceInfo.typeUrl || typeof o.resourceType === "string" && typeof o.resourceName === "string" && typeof o.owner === "string" && typeof o.description === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === ResourceInfo.typeUrl || typeof o.resource_type === "string" && typeof o.resource_name === "string" && typeof o.owner === "string" && typeof o.description === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === ResourceInfo.typeUrl || typeof o.resource_type === "string" && typeof o.resource_name === "string" && typeof o.owner === "string" && typeof o.description === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.resourceType !== undefined) {
            writer.uint32(10).string(message.resourceType);
        }
        if (message.resourceName !== undefined) {
            writer.uint32(18).string(message.resourceName);
        }
        if (message.owner !== undefined) {
            writer.uint32(26).string(message.owner);
        }
        if (message.description !== undefined) {
            writer.uint32(34).string(message.description);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseResourceInfo();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.resourceType = reader.string();
                    break;
                case 2:
                    message.resourceName = reader.string();
                    break;
                case 3:
                    message.owner = reader.string();
                    break;
                case 4:
                    message.description = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseResourceInfo();
        if (isSet(object.resourceType))
            obj.resourceType = String(object.resourceType);
        if (isSet(object.resourceName))
            obj.resourceName = String(object.resourceName);
        if (isSet(object.owner))
            obj.owner = String(object.owner);
        if (isSet(object.description))
            obj.description = String(object.description);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.resourceType !== undefined && (obj.resourceType = message.resourceType);
        message.resourceName !== undefined && (obj.resourceName = message.resourceName);
        message.owner !== undefined && (obj.owner = message.owner);
        message.description !== undefined && (obj.description = message.description);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseResourceInfo();
        message.resourceType = object.resourceType ?? "";
        message.resourceName = object.resourceName ?? "";
        message.owner = object.owner ?? "";
        message.description = object.description ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            resourceType: object?.resource_type,
            resourceName: object?.resource_name,
            owner: object?.owner,
            description: object?.description
        };
    },
    fromSDKJSON(object) {
        return {
            resource_type: isSet(object.resource_type) ? String(object.resource_type) : "",
            resource_name: isSet(object.resource_name) ? String(object.resource_name) : "",
            owner: isSet(object.owner) ? String(object.owner) : "",
            description: isSet(object.description) ? String(object.description) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.resource_type = message.resourceType;
        obj.resource_name = message.resourceName;
        obj.owner = message.owner;
        obj.description = message.description;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseResourceInfo();
        if (object.resource_type !== undefined && object.resource_type !== null) {
            message.resourceType = object.resource_type;
        }
        if (object.resource_name !== undefined && object.resource_name !== null) {
            message.resourceName = object.resource_name;
        }
        if (object.owner !== undefined && object.owner !== null) {
            message.owner = object.owner;
        }
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.resource_type = message.resourceType === "" ? undefined : message.resourceType;
        obj.resource_name = message.resourceName === "" ? undefined : message.resourceName;
        obj.owner = message.owner === "" ? undefined : message.owner;
        obj.description = message.description === "" ? undefined : message.description;
        return obj;
    },
    fromAminoMsg(object) {
        return ResourceInfo.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return ResourceInfo.decode(message.value);
    },
    toProto(message) {
        return ResourceInfo.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.ResourceInfo",
            value: ResourceInfo.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseHelp() {
    return {
        links: []
    };
}
export const Help = {
    typeUrl: "/google.rpc.Help",
    is(o) {
        return o && (o.$typeUrl === Help.typeUrl || Array.isArray(o.links) && (!o.links.length || Help_Link.is(o.links[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === Help.typeUrl || Array.isArray(o.links) && (!o.links.length || Help_Link.isSDK(o.links[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === Help.typeUrl || Array.isArray(o.links) && (!o.links.length || Help_Link.isAmino(o.links[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        for (const v of message.links) {
            Help_Link.encode(v, writer.uint32(10).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseHelp();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.links.push(Help_Link.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseHelp();
        if (Array.isArray(object?.links))
            obj.links = object.links.map((e) => Help_Link.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        if (message.links) {
            obj.links = message.links.map(e => e ? Help_Link.toJSON(e) : undefined);
        }
        else {
            obj.links = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseHelp();
        message.links = object.links?.map(e => Help_Link.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            links: Array.isArray(object?.links) ? object.links.map((e) => Help_Link.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            links: Array.isArray(object?.links) ? object.links.map((e) => Help_Link.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        if (message.links) {
            obj.links = message.links.map(e => e ? Help_Link.toSDK(e) : undefined);
        }
        else {
            obj.links = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseHelp();
        message.links = object.links?.map(e => Help_Link.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        if (message.links) {
            obj.links = message.links.map(e => e ? Help_Link.toAmino(e) : undefined);
        }
        else {
            obj.links = message.links;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return Help.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Help.decode(message.value);
    },
    toProto(message) {
        return Help.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.Help",
            value: Help.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Help_Link.registerTypeUrl();
    }
};
function createBaseHelp_Link() {
    return {
        description: "",
        url: ""
    };
}
export const Help_Link = {
    typeUrl: "/google.rpc.Link",
    is(o) {
        return o && (o.$typeUrl === Help_Link.typeUrl || typeof o.description === "string" && typeof o.url === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Help_Link.typeUrl || typeof o.description === "string" && typeof o.url === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Help_Link.typeUrl || typeof o.description === "string" && typeof o.url === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.description !== undefined) {
            writer.uint32(10).string(message.description);
        }
        if (message.url !== undefined) {
            writer.uint32(18).string(message.url);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseHelp_Link();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.description = reader.string();
                    break;
                case 2:
                    message.url = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseHelp_Link();
        if (isSet(object.description))
            obj.description = String(object.description);
        if (isSet(object.url))
            obj.url = String(object.url);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.description !== undefined && (obj.description = message.description);
        message.url !== undefined && (obj.url = message.url);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseHelp_Link();
        message.description = object.description ?? "";
        message.url = object.url ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            description: object?.description,
            url: object?.url
        };
    },
    fromSDKJSON(object) {
        return {
            description: isSet(object.description) ? String(object.description) : "",
            url: isSet(object.url) ? String(object.url) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.description = message.description;
        obj.url = message.url;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseHelp_Link();
        if (object.description !== undefined && object.description !== null) {
            message.description = object.description;
        }
        if (object.url !== undefined && object.url !== null) {
            message.url = object.url;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.description = message.description === "" ? undefined : message.description;
        obj.url = message.url === "" ? undefined : message.url;
        return obj;
    },
    fromAminoMsg(object) {
        return Help_Link.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return Help_Link.decode(message.value);
    },
    toProto(message) {
        return Help_Link.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.Link",
            value: Help_Link.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
function createBaseLocalizedMessage() {
    return {
        locale: "",
        message: ""
    };
}
export const LocalizedMessage = {
    typeUrl: "/google.rpc.LocalizedMessage",
    is(o) {
        return o && (o.$typeUrl === LocalizedMessage.typeUrl || typeof o.locale === "string" && typeof o.message === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === LocalizedMessage.typeUrl || typeof o.locale === "string" && typeof o.message === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === LocalizedMessage.typeUrl || typeof o.locale === "string" && typeof o.message === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.locale !== undefined) {
            writer.uint32(10).string(message.locale);
        }
        if (message.message !== undefined) {
            writer.uint32(18).string(message.message);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseLocalizedMessage();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.locale = reader.string();
                    break;
                case 2:
                    message.message = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseLocalizedMessage();
        if (isSet(object.locale))
            obj.locale = String(object.locale);
        if (isSet(object.message))
            obj.message = String(object.message);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.locale !== undefined && (obj.locale = message.locale);
        message.message !== undefined && (obj.message = message.message);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseLocalizedMessage();
        message.locale = object.locale ?? "";
        message.message = object.message ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            locale: object?.locale,
            message: object?.message
        };
    },
    fromSDKJSON(object) {
        return {
            locale: isSet(object.locale) ? String(object.locale) : "",
            message: isSet(object.message) ? String(object.message) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.locale = message.locale;
        obj.message = message.message;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseLocalizedMessage();
        if (object.locale !== undefined && object.locale !== null) {
            message.locale = object.locale;
        }
        if (object.message !== undefined && object.message !== null) {
            message.message = object.message;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.locale = message.locale === "" ? undefined : message.locale;
        obj.message = message.message === "" ? undefined : message.message;
        return obj;
    },
    fromAminoMsg(object) {
        return LocalizedMessage.fromAmino(object.value);
    },
    fromProtoMsg(message) {
        return LocalizedMessage.decode(message.value);
    },
    toProto(message) {
        return LocalizedMessage.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/google.rpc.LocalizedMessage",
            value: LocalizedMessage.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
