import { ProtobufRpcClient } from "@cosmjs/stargate";
import * as _AkashCertV1beta2Queryrpc from "./akash/cert/v1beta2/query.rpc.Query";
import * as _CosmosAuthV1beta1Queryrpc from "./cosmos/auth/v1beta1/query.rpc.Query";
import * as _CosmosBankV1beta1Queryrpc from "./cosmos/bank/v1beta1/query.rpc.Query";
import * as _CosmosNftV1beta1Queryrpc from "./cosmos/nft/v1beta1/query.rpc.Query";
import * as _CosmosStakingV1beta1Queryrpc from "./cosmos/staking/v1beta1/query.rpc.Query";
import * as _OsmosisGammV1beta1Queryrpc from "./osmosis/gamm/v1beta1/query.rpc.Query";
import * as _OsmosisGammV2Queryrpc from "./osmosis/gamm/v2/query.rpc.Query";
export declare const createRpcQueryHooks: ({ rpc }: {
    rpc: ProtobufRpcClient | undefined;
}) => {
    akash: {
        cert: {
            v1beta2: {
                useCertificates: <TData = import("./akash/cert/v1beta2/query").QueryCertificatesResponse>({ request, options }: _AkashCertV1beta2Queryrpc.UseCertificatesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
    };
    cosmos: {
        auth: {
            v1beta1: {
                useAccounts: <TData = import("./cosmos/auth/v1beta1/query").QueryAccountsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAccountsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useAccount: <TData = import("./cosmos/auth/v1beta1/query").QueryAccountResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAccountQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useParams: <TData = import("./cosmos/auth/v1beta1/query").QueryParamsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useModuleAccounts: <TData = import("./cosmos/auth/v1beta1/query").QueryModuleAccountsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseModuleAccountsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useBech32Prefix: <TData = import("./cosmos/auth/v1beta1/query").Bech32PrefixResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseBech32PrefixQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useAddressBytesToString: <TData = import("./cosmos/auth/v1beta1/query").AddressBytesToStringResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAddressBytesToStringQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useAddressStringToBytes: <TData = import("./cosmos/auth/v1beta1/query").AddressStringToBytesResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAddressStringToBytesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
        bank: {
            v1beta1: {
                useBalance: <TData = import("./cosmos/bank/v1beta1/query").QueryBalanceResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseBalanceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useAllBalances: <TData = import("./cosmos/bank/v1beta1/query").QueryAllBalancesResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseAllBalancesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useSpendableBalances: <TData = import("./cosmos/bank/v1beta1/query").QuerySpendableBalancesResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseSpendableBalancesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useTotalSupply: <TData = import("./cosmos/bank/v1beta1/query").QueryTotalSupplyResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseTotalSupplyQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useSupplyOf: <TData = import("./cosmos/bank/v1beta1/query").QuerySupplyOfResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseSupplyOfQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useParams: <TData = import("./cosmos/bank/v1beta1/query").QueryParamsResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDenomMetadata: <TData = import("./cosmos/bank/v1beta1/query").QueryDenomMetadataResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseDenomMetadataQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDenomsMetadata: <TData = import("./cosmos/bank/v1beta1/query").QueryDenomsMetadataResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseDenomsMetadataQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDenomOwners: <TData = import("./cosmos/bank/v1beta1/query").QueryDenomOwnersResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseDenomOwnersQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
        nft: {
            v1beta1: {
                useBalance: <TData = import("./cosmos/nft/v1beta1/query").QueryBalanceResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseBalanceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useOwner: <TData = import("./cosmos/nft/v1beta1/query").QueryOwnerResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseOwnerQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useSupply: <TData = import("./cosmos/nft/v1beta1/query").QuerySupplyResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseSupplyQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useNFTs: <TData = import("./cosmos/nft/v1beta1/query").QueryNFTsResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseNFTsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useNFT: <TData = import("./cosmos/nft/v1beta1/query").QueryNFTResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseNFTQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useClass: <TData = import("./cosmos/nft/v1beta1/query").QueryClassResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseClassQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useClasses: <TData = import("./cosmos/nft/v1beta1/query").QueryClassesResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseClassesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
        staking: {
            v1beta1: {
                useValidators: <TData = import("./cosmos/staking/v1beta1/query").QueryValidatorsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseValidatorsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useValidator: <TData = import("./cosmos/staking/v1beta1/query").QueryValidatorResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseValidatorQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useValidatorDelegations: <TData = import("./cosmos/staking/v1beta1/query").QueryValidatorDelegationsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseValidatorDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useValidatorUnbondingDelegations: <TData = import("./cosmos/staking/v1beta1/query").QueryValidatorUnbondingDelegationsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseValidatorUnbondingDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDelegation: <TData = import("./cosmos/staking/v1beta1/query").QueryDelegationResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseDelegationQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useUnbondingDelegation: <TData = import("./cosmos/staking/v1beta1/query").QueryUnbondingDelegationResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseUnbondingDelegationQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDelegatorDelegations: <TData = import("./cosmos/staking/v1beta1/query").QueryDelegatorDelegationsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseDelegatorDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDelegatorUnbondingDelegations: <TData = import("./cosmos/staking/v1beta1/query").QueryDelegatorUnbondingDelegationsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseDelegatorUnbondingDelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useRedelegations: <TData = import("./cosmos/staking/v1beta1/query").QueryRedelegationsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseRedelegationsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDelegatorValidators: <TData = import("./cosmos/staking/v1beta1/query").QueryDelegatorValidatorsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseDelegatorValidatorsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useDelegatorValidator: <TData = import("./cosmos/staking/v1beta1/query").QueryDelegatorValidatorResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseDelegatorValidatorQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useHistoricalInfo: <TData = import("./cosmos/staking/v1beta1/query").QueryHistoricalInfoResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseHistoricalInfoQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                usePool: <TData = import("./cosmos/staking/v1beta1/query").QueryPoolResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UsePoolQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useParams: <TData = import("./cosmos/staking/v1beta1/query").QueryParamsResponse>({ request, options }: _CosmosStakingV1beta1Queryrpc.UseParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
    };
    osmosis: {
        gamm: {
            v1beta1: {
                usePools: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useNumPools: <TData = import("./osmosis/gamm/v1beta1/query").QueryNumPoolsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseNumPoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useTotalLiquidity: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalLiquidityResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                usePoolsWithFilter: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolsWithFilterResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolsWithFilterQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                usePool: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                usePoolType: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolTypeResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolTypeQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useCalcJoinPoolNoSwapShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcJoinPoolNoSwapSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcJoinPoolNoSwapSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useCalcJoinPoolShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcJoinPoolSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcJoinPoolSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useCalcExitPoolCoinsFromShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcExitPoolCoinsFromSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcExitPoolCoinsFromSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                usePoolParams: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolParamsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useTotalPoolLiquidity: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalPoolLiquidityResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalPoolLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useTotalShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useSpotPrice: <TData = import("./osmosis/gamm/v1beta1/query").QuerySpotPriceResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseSpotPriceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useEstimateSwapExactAmountIn: <TData = import("./osmosis/gamm/v1beta1/query").QuerySwapExactAmountInResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseEstimateSwapExactAmountInQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
                useEstimateSwapExactAmountOut: <TData = import("./osmosis/gamm/v1beta1/query").QuerySwapExactAmountOutResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseEstimateSwapExactAmountOutQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
            v2: {
                useSpotPrice: <TData = import("./osmosis/gamm/v2/query").QuerySpotPriceResponse>({ request, options }: _OsmosisGammV2Queryrpc.UseSpotPriceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
            };
        };
    };
    /**
     * akash.cert.v1beta2.useCertificates
     * Certificates queries certificates
     */
    useCertificates: <TData = import("./akash/cert/v1beta2/query").QueryCertificatesResponse>({ request, options }: _AkashCertV1beta2Queryrpc.UseCertificatesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useAccounts
     * Accounts returns all the existing accounts
     *
     * Since: cosmos-sdk 0.43
     */
    useAccounts: <TData = import("./cosmos/auth/v1beta1/query").QueryAccountsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAccountsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useAccount
     * Account returns account details based on address.
     */
    useAccount: <TData = import("./cosmos/auth/v1beta1/query").QueryAccountResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAccountQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useParams
     * Params queries all parameters.
     */
    useParams: <TData = import("./cosmos/auth/v1beta1/query").QueryParamsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useModuleAccounts
     * ModuleAccounts returns all the existing module accounts.
     */
    useAuthModuleAccounts: <TData = import("./cosmos/auth/v1beta1/query").QueryModuleAccountsResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseModuleAccountsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useBech32Prefix
     * Bech32 queries bech32Prefix
     */
    useBech32Prefix: <TData = import("./cosmos/auth/v1beta1/query").Bech32PrefixResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseBech32PrefixQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useAddressBytesToString
     * AddressBytesToString converts Account Address bytes to string
     */
    useAddressBytesToString: <TData = import("./cosmos/auth/v1beta1/query").AddressBytesToStringResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAddressBytesToStringQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.auth.v1beta1.useAddressStringToBytes
     * AddressStringToBytes converts Address string to bytes
     */
    useAddressStringToBytes: <TData = import("./cosmos/auth/v1beta1/query").AddressStringToBytesResponse>({ request, options }: _CosmosAuthV1beta1Queryrpc.UseAddressStringToBytesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.bank.v1beta1.useBalance
     * Balance queries the balance of a single coin for a single account.
     */
    useBankBalance: <TData = import("./cosmos/bank/v1beta1/query").QueryBalanceResponse>({ request, options }: _CosmosBankV1beta1Queryrpc.UseBalanceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * cosmos.nft.v1beta1.useBalance
     * Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721
     */
    useNftBalance: <TData = import("./cosmos/nft/v1beta1/query").QueryBalanceResponse>({ request, options }: _CosmosNftV1beta1Queryrpc.UseBalanceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.usePools
     * Pools
     */
    usePools: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useNumPools
     * NumPools
     */
    useNumPools: <TData = import("./osmosis/gamm/v1beta1/query").QueryNumPoolsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseNumPoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useTotalLiquidity
     * TotalLiquidity
     */
    useTotalLiquidity: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalLiquidityResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.usePoolsWithFilter
     * PoolsWithFilter allows you to query specific pools with requested
     * parameters
     */
    usePoolsWithFilter: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolsWithFilterResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolsWithFilterQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.usePool
     * Per Pool gRPC Endpoints
     */
    usePool: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.usePoolType
     * PoolType returns the type of the pool.
     * Returns "Balancer" as a string literal when the pool is a balancer pool.
     * Errors if the pool is failed to be type caseted.
     */
    usePoolType: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolTypeResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolTypeQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useCalcJoinPoolNoSwapShares
     * Simulates joining pool without a swap. Returns the amount of shares you'd
     * get and tokens needed to provide
     */
    useCalcJoinPoolNoSwapShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcJoinPoolNoSwapSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcJoinPoolNoSwapSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useCalcJoinPoolShares
     * CalcJoinPoolShares
     */
    useCalcJoinPoolShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcJoinPoolSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcJoinPoolSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useCalcExitPoolCoinsFromShares
     * CalcExitPoolCoinsFromShares
     */
    useCalcExitPoolCoinsFromShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryCalcExitPoolCoinsFromSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseCalcExitPoolCoinsFromSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.usePoolParams
     * PoolParams
     */
    usePoolParams: <TData = import("./osmosis/gamm/v1beta1/query").QueryPoolParamsResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UsePoolParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useTotalPoolLiquidity
     * TotalPoolLiquidity
     */
    useTotalPoolLiquidity: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalPoolLiquidityResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalPoolLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useTotalShares
     * TotalShares
     */
    useTotalShares: <TData = import("./osmosis/gamm/v1beta1/query").QueryTotalSharesResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseTotalSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useSpotPrice
     * SpotPrice defines a gRPC query handler that returns the spot price given
     * a base denomination and a quote denomination.
     */
    useSpotPrice: <TData = import("./osmosis/gamm/v1beta1/query").QuerySpotPriceResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseSpotPriceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useEstimateSwapExactAmountIn
     * Estimate the swap.
     */
    useEstimateSwapExactAmountIn: <TData = import("./osmosis/gamm/v1beta1/query").QuerySwapExactAmountInResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseEstimateSwapExactAmountInQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v1beta1.useEstimateSwapExactAmountOut
     * EstimateSwapExactAmountOut
     */
    useEstimateSwapExactAmountOut: <TData = import("./osmosis/gamm/v1beta1/query").QuerySwapExactAmountOutResponse>({ request, options }: _OsmosisGammV1beta1Queryrpc.UseEstimateSwapExactAmountOutQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * osmosis.gamm.v2.useSpotPrice
     * SpotPrice defines a gRPC query handler that returns the spot price given
     * a base denomination and a quote denomination.
     */
    useOsmosisGammV2SpotPrice: <TData = import("./osmosis/gamm/v2/query").QuerySpotPriceResponse>({ request, options }: _OsmosisGammV2Queryrpc.UseSpotPriceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
};
