import { MsgChannelOpenInit, MsgChannelOpenTry, MsgChannelOpenAck, MsgChannelOpenConfirm, MsgChannelCloseInit, MsgChannelCloseConfirm, MsgRecvPacket, MsgTimeout, MsgTimeoutOnClose, MsgAcknowledgement } from "./tx";
export class MsgClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* ChannelOpenInit defines a rpc handler method for MsgChannelOpenInit. */
    channelOpenInit = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelOpenInit.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ChannelOpenTry defines a rpc handler method for MsgChannelOpenTry. */
    channelOpenTry = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelOpenTry.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ChannelOpenAck defines a rpc handler method for MsgChannelOpenAck. */
    channelOpenAck = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelOpenAck.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ChannelOpenConfirm defines a rpc handler method for MsgChannelOpenConfirm. */
    channelOpenConfirm = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelOpenConfirm.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ChannelCloseInit defines a rpc handler method for MsgChannelCloseInit. */
    channelCloseInit = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelCloseInit.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* ChannelCloseConfirm defines a rpc handler method for
     MsgChannelCloseConfirm. */
    channelCloseConfirm = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgChannelCloseConfirm.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* RecvPacket defines a rpc handler method for MsgRecvPacket. */
    recvPacket = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgRecvPacket.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Timeout defines a rpc handler method for MsgTimeout. */
    timeout = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgTimeout.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* TimeoutOnClose defines a rpc handler method for MsgTimeoutOnClose. */
    timeoutOnClose = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgTimeoutOnClose.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
    /* Acknowledgement defines a rpc handler method for MsgAcknowledgement. */
    acknowledgement = async (signerAddress, message, fee = "auto", memo = "") => {
        const data = [{
                typeUrl: MsgAcknowledgement.typeUrl,
                value: message
            }];
        return this.rpc.signAndBroadcast(signerAddress, data, fee, memo);
    };
}
export const createClientImpl = (rpc) => {
    return new MsgClientImpl(rpc);
};
