import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { Params } from "./params";
import { ClaimRecord } from "./claim";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "osmosis.claim.v1beta1";
function createBaseGenesisState() {
    return {
        moduleAccountBalance: Coin.fromPartial({}),
        params: Params.fromPartial({}),
        claimRecords: []
    };
}
export const GenesisState = {
    typeUrl: "/osmosis.claim.v1beta1.GenesisState",
    aminoType: "osmosis/claim/genesis-state",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Coin.is(o.moduleAccountBalance) && Params.is(o.params) && Array.isArray(o.claimRecords) && (!o.claimRecords.length || ClaimRecord.is(o.claimRecords[0])));
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Coin.isSDK(o.module_account_balance) && Params.isSDK(o.params) && Array.isArray(o.claim_records) && (!o.claim_records.length || ClaimRecord.isSDK(o.claim_records[0])));
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Coin.isAmino(o.module_account_balance) && Params.isAmino(o.params) && Array.isArray(o.claim_records) && (!o.claim_records.length || ClaimRecord.isAmino(o.claim_records[0])));
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.moduleAccountBalance !== undefined) {
            Coin.encode(message.moduleAccountBalance, writer.uint32(10).fork()).ldelim();
        }
        if (message.params !== undefined) {
            Params.encode(message.params, writer.uint32(18).fork()).ldelim();
        }
        for (const v of message.claimRecords) {
            ClaimRecord.encode(v, writer.uint32(26).fork()).ldelim();
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.moduleAccountBalance = Coin.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.params = Params.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.claimRecords.push(ClaimRecord.decode(reader, reader.uint32()));
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (isSet(object.moduleAccountBalance))
            obj.moduleAccountBalance = Coin.fromJSON(object.moduleAccountBalance);
        if (isSet(object.params))
            obj.params = Params.fromJSON(object.params);
        if (Array.isArray(object?.claimRecords))
            obj.claimRecords = object.claimRecords.map((e) => ClaimRecord.fromJSON(e));
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.moduleAccountBalance !== undefined && (obj.moduleAccountBalance = message.moduleAccountBalance ? Coin.toJSON(message.moduleAccountBalance) : undefined);
        message.params !== undefined && (obj.params = message.params ? Params.toJSON(message.params) : undefined);
        if (message.claimRecords) {
            obj.claimRecords = message.claimRecords.map(e => e ? ClaimRecord.toJSON(e) : undefined);
        }
        else {
            obj.claimRecords = [];
        }
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        if (object.moduleAccountBalance !== undefined && object.moduleAccountBalance !== null) {
            message.moduleAccountBalance = Coin.fromPartial(object.moduleAccountBalance);
        }
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromPartial(object.params);
        }
        message.claimRecords = object.claimRecords?.map(e => ClaimRecord.fromPartial(e)) || [];
        return message;
    },
    fromSDK(object) {
        return {
            moduleAccountBalance: object.module_account_balance ? Coin.fromSDK(object.module_account_balance) : undefined,
            params: object.params ? Params.fromSDK(object.params) : undefined,
            claimRecords: Array.isArray(object?.claim_records) ? object.claim_records.map((e) => ClaimRecord.fromSDK(e)) : []
        };
    },
    fromSDKJSON(object) {
        return {
            module_account_balance: isSet(object.module_account_balance) ? Coin.fromSDKJSON(object.module_account_balance) : undefined,
            params: isSet(object.params) ? Params.fromSDKJSON(object.params) : undefined,
            claim_records: Array.isArray(object?.claim_records) ? object.claim_records.map((e) => ClaimRecord.fromSDKJSON(e)) : []
        };
    },
    toSDK(message) {
        const obj = {};
        message.moduleAccountBalance !== undefined && (obj.module_account_balance = message.moduleAccountBalance ? Coin.toSDK(message.moduleAccountBalance) : undefined);
        message.params !== undefined && (obj.params = message.params ? Params.toSDK(message.params) : undefined);
        if (message.claimRecords) {
            obj.claim_records = message.claimRecords.map(e => e ? ClaimRecord.toSDK(e) : undefined);
        }
        else {
            obj.claim_records = [];
        }
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        if (object.module_account_balance !== undefined && object.module_account_balance !== null) {
            message.moduleAccountBalance = Coin.fromAmino(object.module_account_balance);
        }
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromAmino(object.params);
        }
        message.claimRecords = object.claim_records?.map(e => ClaimRecord.fromAmino(e)) || [];
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.module_account_balance = message.moduleAccountBalance ? Coin.toAmino(message.moduleAccountBalance) : undefined;
        obj.params = message.params ? Params.toAmino(message.params) : undefined;
        if (message.claimRecords) {
            obj.claim_records = message.claimRecords.map(e => e ? ClaimRecord.toAmino(e) : undefined);
        }
        else {
            obj.claim_records = message.claimRecords;
        }
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/claim/genesis-state",
            value: GenesisState.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.claim.v1beta1.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Coin.registerTypeUrl();
        Params.registerTypeUrl();
        ClaimRecord.registerTypeUrl();
    }
};
