import { Timestamp } from "../../../google/protobuf/timestamp";
import { Duration } from "../../../google/protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { toTimestamp, fromTimestamp, isSet } from "../../../helpers";
export const protobufPackage = "osmosis.claim.v1beta1";
function createBaseParams() {
    return {
        airdropStartTime: new Date(),
        durationUntilDecay: Duration.fromPartial({}),
        durationOfDecay: Duration.fromPartial({}),
        claimDenom: ""
    };
}
export const Params = {
    typeUrl: "/osmosis.claim.v1beta1.Params",
    aminoType: "osmosis/claim/params",
    is(o) {
        return o && (o.$typeUrl === Params.typeUrl || Timestamp.is(o.airdropStartTime) && Duration.is(o.durationUntilDecay) && Duration.is(o.durationOfDecay) && typeof o.claimDenom === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Params.typeUrl || Timestamp.isSDK(o.airdrop_start_time) && Duration.isSDK(o.duration_until_decay) && Duration.isSDK(o.duration_of_decay) && typeof o.claim_denom === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Params.typeUrl || Timestamp.isAmino(o.airdrop_start_time) && Duration.isAmino(o.duration_until_decay) && Duration.isAmino(o.duration_of_decay) && typeof o.claim_denom === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.airdropStartTime !== undefined) {
            Timestamp.encode(toTimestamp(message.airdropStartTime), writer.uint32(10).fork()).ldelim();
        }
        if (message.durationUntilDecay !== undefined) {
            Duration.encode(message.durationUntilDecay, writer.uint32(18).fork()).ldelim();
        }
        if (message.durationOfDecay !== undefined) {
            Duration.encode(message.durationOfDecay, writer.uint32(26).fork()).ldelim();
        }
        if (message.claimDenom !== undefined) {
            writer.uint32(34).string(message.claimDenom);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseParams();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.airdropStartTime = fromTimestamp(Timestamp.decode(reader, reader.uint32()));
                    break;
                case 2:
                    message.durationUntilDecay = Duration.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.durationOfDecay = Duration.decode(reader, reader.uint32());
                    break;
                case 4:
                    message.claimDenom = reader.string();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseParams();
        if (isSet(object.airdropStartTime))
            obj.airdropStartTime = new Date(object.airdropStartTime);
        if (isSet(object.durationUntilDecay))
            obj.durationUntilDecay = Duration.fromJSON(object.durationUntilDecay);
        if (isSet(object.durationOfDecay))
            obj.durationOfDecay = Duration.fromJSON(object.durationOfDecay);
        if (isSet(object.claimDenom))
            obj.claimDenom = String(object.claimDenom);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.airdropStartTime !== undefined && (obj.airdropStartTime = message.airdropStartTime.toISOString());
        message.durationUntilDecay !== undefined && (obj.durationUntilDecay = message.durationUntilDecay ? Duration.toJSON(message.durationUntilDecay) : undefined);
        message.durationOfDecay !== undefined && (obj.durationOfDecay = message.durationOfDecay ? Duration.toJSON(message.durationOfDecay) : undefined);
        message.claimDenom !== undefined && (obj.claimDenom = message.claimDenom);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseParams();
        message.airdropStartTime = object.airdropStartTime ?? undefined;
        if (object.durationUntilDecay !== undefined && object.durationUntilDecay !== null) {
            message.durationUntilDecay = Duration.fromPartial(object.durationUntilDecay);
        }
        if (object.durationOfDecay !== undefined && object.durationOfDecay !== null) {
            message.durationOfDecay = Duration.fromPartial(object.durationOfDecay);
        }
        message.claimDenom = object.claimDenom ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            airdropStartTime: object.airdrop_start_time ?? undefined,
            durationUntilDecay: object.duration_until_decay ? Duration.fromSDK(object.duration_until_decay) : undefined,
            durationOfDecay: object.duration_of_decay ? Duration.fromSDK(object.duration_of_decay) : undefined,
            claimDenom: object?.claim_denom
        };
    },
    fromSDKJSON(object) {
        return {
            airdrop_start_time: isSet(object.airdrop_start_time) ? new Date(object.airdrop_start_time) : undefined,
            duration_until_decay: isSet(object.duration_until_decay) ? Duration.fromSDKJSON(object.duration_until_decay) : undefined,
            duration_of_decay: isSet(object.duration_of_decay) ? Duration.fromSDKJSON(object.duration_of_decay) : undefined,
            claim_denom: isSet(object.claim_denom) ? String(object.claim_denom) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        message.airdropStartTime !== undefined && (obj.airdrop_start_time = message.airdropStartTime ?? undefined);
        message.durationUntilDecay !== undefined && (obj.duration_until_decay = message.durationUntilDecay ? Duration.toSDK(message.durationUntilDecay) : undefined);
        message.durationOfDecay !== undefined && (obj.duration_of_decay = message.durationOfDecay ? Duration.toSDK(message.durationOfDecay) : undefined);
        obj.claim_denom = message.claimDenom;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseParams();
        if (object.airdrop_start_time !== undefined && object.airdrop_start_time !== null) {
            message.airdropStartTime = fromTimestamp(Timestamp.fromAmino(object.airdrop_start_time));
        }
        if (object.duration_until_decay !== undefined && object.duration_until_decay !== null) {
            message.durationUntilDecay = Duration.fromAmino(object.duration_until_decay);
        }
        if (object.duration_of_decay !== undefined && object.duration_of_decay !== null) {
            message.durationOfDecay = Duration.fromAmino(object.duration_of_decay);
        }
        if (object.claim_denom !== undefined && object.claim_denom !== null) {
            message.claimDenom = object.claim_denom;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.airdrop_start_time = message.airdropStartTime ? Timestamp.toAmino(toTimestamp(message.airdropStartTime)) : undefined;
        obj.duration_until_decay = message.durationUntilDecay ? Duration.toAmino(message.durationUntilDecay) : undefined;
        obj.duration_of_decay = message.durationOfDecay ? Duration.toAmino(message.durationOfDecay) : undefined;
        obj.claim_denom = message.claimDenom === "" ? undefined : message.claimDenom;
        return obj;
    },
    fromAminoMsg(object) {
        return Params.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/claim/params",
            value: Params.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Params.decode(message.value);
    },
    toProto(message) {
        return Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.claim.v1beta1.Params",
            value: Params.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
