import { TxRpc } from "../../../types";
import { ReactQueryParams } from "../../../react-query";
import { ProtobufRpcClient } from "@cosmjs/stargate";
import { QueryPoolsRequest, QueryPoolsResponse, QueryNumPoolsRequest, QueryNumPoolsResponse, QueryTotalLiquidityRequest, QueryTotalLiquidityResponse, QueryPoolsWithFilterRequest, QueryPoolsWithFilterResponse, QueryPoolRequest, QueryPoolResponse, QueryPoolTypeRequest, QueryPoolTypeResponse, QueryCalcJoinPoolNoSwapSharesRequest, QueryCalcJoinPoolNoSwapSharesResponse, QueryCalcJoinPoolSharesRequest, QueryCalcJoinPoolSharesResponse, QueryCalcExitPoolCoinsFromSharesRequest, QueryCalcExitPoolCoinsFromSharesResponse, QueryPoolParamsRequest, QueryPoolParamsResponse, QueryTotalPoolLiquidityRequest, QueryTotalPoolLiquidityResponse, QueryTotalSharesRequest, QueryTotalSharesResponse, QuerySpotPriceRequest, QuerySpotPriceResponse, QuerySwapExactAmountInRequest, QuerySwapExactAmountInResponse, QuerySwapExactAmountOutRequest, QuerySwapExactAmountOutResponse } from "./query";
export interface Query {
    pools(request?: QueryPoolsRequest): Promise<QueryPoolsResponse>;
    numPools(request?: QueryNumPoolsRequest): Promise<QueryNumPoolsResponse>;
    totalLiquidity(request?: QueryTotalLiquidityRequest): Promise<QueryTotalLiquidityResponse>;
    /**
     * PoolsWithFilter allows you to query specific pools with requested
     * parameters
     */
    poolsWithFilter(request: QueryPoolsWithFilterRequest): Promise<QueryPoolsWithFilterResponse>;
    /** Per Pool gRPC Endpoints */
    pool(request: QueryPoolRequest): Promise<QueryPoolResponse>;
    /**
     * PoolType returns the type of the pool.
     * Returns "Balancer" as a string literal when the pool is a balancer pool.
     * Errors if the pool is failed to be type caseted.
     */
    poolType(request: QueryPoolTypeRequest): Promise<QueryPoolTypeResponse>;
    /**
     * Simulates joining pool without a swap. Returns the amount of shares you'd
     * get and tokens needed to provide
     */
    calcJoinPoolNoSwapShares(request: QueryCalcJoinPoolNoSwapSharesRequest): Promise<QueryCalcJoinPoolNoSwapSharesResponse>;
    calcJoinPoolShares(request: QueryCalcJoinPoolSharesRequest): Promise<QueryCalcJoinPoolSharesResponse>;
    calcExitPoolCoinsFromShares(request: QueryCalcExitPoolCoinsFromSharesRequest): Promise<QueryCalcExitPoolCoinsFromSharesResponse>;
    poolParams(request: QueryPoolParamsRequest): Promise<QueryPoolParamsResponse>;
    totalPoolLiquidity(request: QueryTotalPoolLiquidityRequest): Promise<QueryTotalPoolLiquidityResponse>;
    totalShares(request: QueryTotalSharesRequest): Promise<QueryTotalSharesResponse>;
    /**
     * SpotPrice defines a gRPC query handler that returns the spot price given
     * a base denomination and a quote denomination.
     */
    spotPrice(request: QuerySpotPriceRequest): Promise<QuerySpotPriceResponse>;
    /** Estimate the swap. */
    estimateSwapExactAmountIn(request: QuerySwapExactAmountInRequest): Promise<QuerySwapExactAmountInResponse>;
    estimateSwapExactAmountOut(request: QuerySwapExactAmountOutRequest): Promise<QuerySwapExactAmountOutResponse>;
}
export declare class QueryClientImpl implements Query {
    private readonly rpc;
    constructor(rpc: TxRpc);
    pools: (request?: QueryPoolsRequest) => Promise<QueryPoolsResponse>;
    numPools: (request?: QueryNumPoolsRequest) => Promise<QueryNumPoolsResponse>;
    totalLiquidity: (request?: QueryTotalLiquidityRequest) => Promise<QueryTotalLiquidityResponse>;
    poolsWithFilter: (request: QueryPoolsWithFilterRequest) => Promise<QueryPoolsWithFilterResponse>;
    pool: (request: QueryPoolRequest) => Promise<QueryPoolResponse>;
    poolType: (request: QueryPoolTypeRequest) => Promise<QueryPoolTypeResponse>;
    calcJoinPoolNoSwapShares: (request: QueryCalcJoinPoolNoSwapSharesRequest) => Promise<QueryCalcJoinPoolNoSwapSharesResponse>;
    calcJoinPoolShares: (request: QueryCalcJoinPoolSharesRequest) => Promise<QueryCalcJoinPoolSharesResponse>;
    calcExitPoolCoinsFromShares: (request: QueryCalcExitPoolCoinsFromSharesRequest) => Promise<QueryCalcExitPoolCoinsFromSharesResponse>;
    poolParams: (request: QueryPoolParamsRequest) => Promise<QueryPoolParamsResponse>;
    totalPoolLiquidity: (request: QueryTotalPoolLiquidityRequest) => Promise<QueryTotalPoolLiquidityResponse>;
    totalShares: (request: QueryTotalSharesRequest) => Promise<QueryTotalSharesResponse>;
    spotPrice: (request: QuerySpotPriceRequest) => Promise<QuerySpotPriceResponse>;
    estimateSwapExactAmountIn: (request: QuerySwapExactAmountInRequest) => Promise<QuerySwapExactAmountInResponse>;
    estimateSwapExactAmountOut: (request: QuerySwapExactAmountOutRequest) => Promise<QuerySwapExactAmountOutResponse>;
}
export declare const createClientImpl: (rpc: TxRpc) => QueryClientImpl;
export interface UsePoolsQuery<TData> extends ReactQueryParams<QueryPoolsResponse, TData> {
    request?: QueryPoolsRequest;
}
export interface UseNumPoolsQuery<TData> extends ReactQueryParams<QueryNumPoolsResponse, TData> {
    request?: QueryNumPoolsRequest;
}
export interface UseTotalLiquidityQuery<TData> extends ReactQueryParams<QueryTotalLiquidityResponse, TData> {
    request?: QueryTotalLiquidityRequest;
}
export interface UsePoolsWithFilterQuery<TData> extends ReactQueryParams<QueryPoolsWithFilterResponse, TData> {
    request: QueryPoolsWithFilterRequest;
}
export interface UsePoolQuery<TData> extends ReactQueryParams<QueryPoolResponse, TData> {
    request: QueryPoolRequest;
}
export interface UsePoolTypeQuery<TData> extends ReactQueryParams<QueryPoolTypeResponse, TData> {
    request: QueryPoolTypeRequest;
}
export interface UseCalcJoinPoolNoSwapSharesQuery<TData> extends ReactQueryParams<QueryCalcJoinPoolNoSwapSharesResponse, TData> {
    request: QueryCalcJoinPoolNoSwapSharesRequest;
}
export interface UseCalcJoinPoolSharesQuery<TData> extends ReactQueryParams<QueryCalcJoinPoolSharesResponse, TData> {
    request: QueryCalcJoinPoolSharesRequest;
}
export interface UseCalcExitPoolCoinsFromSharesQuery<TData> extends ReactQueryParams<QueryCalcExitPoolCoinsFromSharesResponse, TData> {
    request: QueryCalcExitPoolCoinsFromSharesRequest;
}
export interface UsePoolParamsQuery<TData> extends ReactQueryParams<QueryPoolParamsResponse, TData> {
    request: QueryPoolParamsRequest;
}
export interface UseTotalPoolLiquidityQuery<TData> extends ReactQueryParams<QueryTotalPoolLiquidityResponse, TData> {
    request: QueryTotalPoolLiquidityRequest;
}
export interface UseTotalSharesQuery<TData> extends ReactQueryParams<QueryTotalSharesResponse, TData> {
    request: QueryTotalSharesRequest;
}
export interface UseSpotPriceQuery<TData> extends ReactQueryParams<QuerySpotPriceResponse, TData> {
    request: QuerySpotPriceRequest;
}
export interface UseEstimateSwapExactAmountInQuery<TData> extends ReactQueryParams<QuerySwapExactAmountInResponse, TData> {
    request: QuerySwapExactAmountInRequest;
}
export interface UseEstimateSwapExactAmountOutQuery<TData> extends ReactQueryParams<QuerySwapExactAmountOutResponse, TData> {
    request: QuerySwapExactAmountOutRequest;
}
export declare const createRpcQueryHooks: (rpc: ProtobufRpcClient | undefined) => {
    usePools: <TData = QueryPoolsResponse>({ request, options }: UsePoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useNumPools: <TData = QueryNumPoolsResponse>({ request, options }: UseNumPoolsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useTotalLiquidity: <TData = QueryTotalLiquidityResponse>({ request, options }: UseTotalLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * PoolsWithFilter allows you to query specific pools with requested
     * parameters
     */
    usePoolsWithFilter: <TData = QueryPoolsWithFilterResponse>({ request, options }: UsePoolsWithFilterQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Per Pool gRPC Endpoints */ usePool: <TData = QueryPoolResponse>({ request, options }: UsePoolQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * PoolType returns the type of the pool.
     * Returns "Balancer" as a string literal when the pool is a balancer pool.
     * Errors if the pool is failed to be type caseted.
     */
    usePoolType: <TData = QueryPoolTypeResponse>({ request, options }: UsePoolTypeQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * Simulates joining pool without a swap. Returns the amount of shares you'd
     * get and tokens needed to provide
     */
    useCalcJoinPoolNoSwapShares: <TData = QueryCalcJoinPoolNoSwapSharesResponse>({ request, options }: UseCalcJoinPoolNoSwapSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useCalcJoinPoolShares: <TData = QueryCalcJoinPoolSharesResponse>({ request, options }: UseCalcJoinPoolSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useCalcExitPoolCoinsFromShares: <TData = QueryCalcExitPoolCoinsFromSharesResponse>({ request, options }: UseCalcExitPoolCoinsFromSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    usePoolParams: <TData = QueryPoolParamsResponse>({ request, options }: UsePoolParamsQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useTotalPoolLiquidity: <TData = QueryTotalPoolLiquidityResponse>({ request, options }: UseTotalPoolLiquidityQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useTotalShares: <TData = QueryTotalSharesResponse>({ request, options }: UseTotalSharesQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /**
     * SpotPrice defines a gRPC query handler that returns the spot price given
     * a base denomination and a quote denomination.
     */
    useSpotPrice: <TData = QuerySpotPriceResponse>({ request, options }: UseSpotPriceQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    /** Estimate the swap. */ useEstimateSwapExactAmountIn: <TData = QuerySwapExactAmountInResponse>({ request, options }: UseEstimateSwapExactAmountInQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
    useEstimateSwapExactAmountOut: <TData = QuerySwapExactAmountOutResponse>({ request, options }: UseEstimateSwapExactAmountOutQuery<TData>) => import("@tanstack/react-query").UseQueryResult<TData, Error>;
};
