import { PageRequest } from "../../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryPoolsRequest, QueryPoolsResponse, QueryNumPoolsRequest, QueryNumPoolsResponse, QueryTotalLiquidityRequest, QueryTotalLiquidityResponse, QueryPoolsWithFilterRequest, QueryPoolsWithFilterResponse, QueryPoolRequest, QueryPoolResponse, QueryPoolTypeRequest, QueryPoolTypeResponse, QueryCalcJoinPoolNoSwapSharesRequest, QueryCalcJoinPoolNoSwapSharesResponse, QueryCalcJoinPoolSharesRequest, QueryCalcJoinPoolSharesResponse, QueryCalcExitPoolCoinsFromSharesRequest, QueryCalcExitPoolCoinsFromSharesResponse, QueryPoolParamsRequest, QueryPoolParamsResponse, QueryTotalPoolLiquidityRequest, QueryTotalPoolLiquidityResponse, QueryTotalSharesRequest, QueryTotalSharesResponse, QuerySpotPriceRequest, QuerySpotPriceResponse, QuerySwapExactAmountInRequest, QuerySwapExactAmountInResponse, QuerySwapExactAmountOutRequest, QuerySwapExactAmountOutResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Pools */
    pools = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryPoolsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "Pools", data);
        return promise.then(data => QueryPoolsResponse.decode(new BinaryReader(data)));
    };
    /* NumPools */
    numPools = async (request = {}) => {
        const data = QueryNumPoolsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "NumPools", data);
        return promise.then(data => QueryNumPoolsResponse.decode(new BinaryReader(data)));
    };
    /* TotalLiquidity */
    totalLiquidity = async (request = {}) => {
        const data = QueryTotalLiquidityRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "TotalLiquidity", data);
        return promise.then(data => QueryTotalLiquidityResponse.decode(new BinaryReader(data)));
    };
    /* PoolsWithFilter allows you to query specific pools with requested
     parameters */
    poolsWithFilter = async (request) => {
        const data = QueryPoolsWithFilterRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "PoolsWithFilter", data);
        return promise.then(data => QueryPoolsWithFilterResponse.decode(new BinaryReader(data)));
    };
    /* Per Pool gRPC Endpoints */
    pool = async (request) => {
        const data = QueryPoolRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "Pool", data);
        return promise.then(data => QueryPoolResponse.decode(new BinaryReader(data)));
    };
    /* PoolType returns the type of the pool.
     Returns "Balancer" as a string literal when the pool is a balancer pool.
     Errors if the pool is failed to be type caseted. */
    poolType = async (request) => {
        const data = QueryPoolTypeRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "PoolType", data);
        return promise.then(data => QueryPoolTypeResponse.decode(new BinaryReader(data)));
    };
    /* Simulates joining pool without a swap. Returns the amount of shares you'd
     get and tokens needed to provide */
    calcJoinPoolNoSwapShares = async (request) => {
        const data = QueryCalcJoinPoolNoSwapSharesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "CalcJoinPoolNoSwapShares", data);
        return promise.then(data => QueryCalcJoinPoolNoSwapSharesResponse.decode(new BinaryReader(data)));
    };
    /* CalcJoinPoolShares */
    calcJoinPoolShares = async (request) => {
        const data = QueryCalcJoinPoolSharesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "CalcJoinPoolShares", data);
        return promise.then(data => QueryCalcJoinPoolSharesResponse.decode(new BinaryReader(data)));
    };
    /* CalcExitPoolCoinsFromShares */
    calcExitPoolCoinsFromShares = async (request) => {
        const data = QueryCalcExitPoolCoinsFromSharesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "CalcExitPoolCoinsFromShares", data);
        return promise.then(data => QueryCalcExitPoolCoinsFromSharesResponse.decode(new BinaryReader(data)));
    };
    /* PoolParams */
    poolParams = async (request) => {
        const data = QueryPoolParamsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "PoolParams", data);
        return promise.then(data => QueryPoolParamsResponse.decode(new BinaryReader(data)));
    };
    /* TotalPoolLiquidity */
    totalPoolLiquidity = async (request) => {
        const data = QueryTotalPoolLiquidityRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "TotalPoolLiquidity", data);
        return promise.then(data => QueryTotalPoolLiquidityResponse.decode(new BinaryReader(data)));
    };
    /* TotalShares */
    totalShares = async (request) => {
        const data = QueryTotalSharesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "TotalShares", data);
        return promise.then(data => QueryTotalSharesResponse.decode(new BinaryReader(data)));
    };
    /* SpotPrice defines a gRPC query handler that returns the spot price given
     a base denomination and a quote denomination. */
    spotPrice = async (request) => {
        const data = QuerySpotPriceRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "SpotPrice", data);
        return promise.then(data => QuerySpotPriceResponse.decode(new BinaryReader(data)));
    };
    /* Estimate the swap. */
    estimateSwapExactAmountIn = async (request) => {
        const data = QuerySwapExactAmountInRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "EstimateSwapExactAmountIn", data);
        return promise.then(data => QuerySwapExactAmountInResponse.decode(new BinaryReader(data)));
    };
    /* EstimateSwapExactAmountOut */
    estimateSwapExactAmountOut = async (request) => {
        const data = QuerySwapExactAmountOutRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.gamm.v1beta1.Query", "EstimateSwapExactAmountOut", data);
        return promise.then(data => QuerySwapExactAmountOutResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const usePools = ({ request, options }) => {
        return useQuery(["poolsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.pools(request);
        }, options);
    };
    const useNumPools = ({ request, options }) => {
        return useQuery(["numPoolsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.numPools(request);
        }, options);
    };
    const useTotalLiquidity = ({ request, options }) => {
        return useQuery(["totalLiquidityQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.totalLiquidity(request);
        }, options);
    };
    const usePoolsWithFilter = ({ request, options }) => {
        return useQuery(["poolsWithFilterQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.poolsWithFilter(request);
        }, options);
    };
    const usePool = ({ request, options }) => {
        return useQuery(["poolQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.pool(request);
        }, options);
    };
    const usePoolType = ({ request, options }) => {
        return useQuery(["poolTypeQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.poolType(request);
        }, options);
    };
    const useCalcJoinPoolNoSwapShares = ({ request, options }) => {
        return useQuery(["calcJoinPoolNoSwapSharesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.calcJoinPoolNoSwapShares(request);
        }, options);
    };
    const useCalcJoinPoolShares = ({ request, options }) => {
        return useQuery(["calcJoinPoolSharesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.calcJoinPoolShares(request);
        }, options);
    };
    const useCalcExitPoolCoinsFromShares = ({ request, options }) => {
        return useQuery(["calcExitPoolCoinsFromSharesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.calcExitPoolCoinsFromShares(request);
        }, options);
    };
    const usePoolParams = ({ request, options }) => {
        return useQuery(["poolParamsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.poolParams(request);
        }, options);
    };
    const useTotalPoolLiquidity = ({ request, options }) => {
        return useQuery(["totalPoolLiquidityQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.totalPoolLiquidity(request);
        }, options);
    };
    const useTotalShares = ({ request, options }) => {
        return useQuery(["totalSharesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.totalShares(request);
        }, options);
    };
    const useSpotPrice = ({ request, options }) => {
        return useQuery(["spotPriceQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.spotPrice(request);
        }, options);
    };
    const useEstimateSwapExactAmountIn = ({ request, options }) => {
        return useQuery(["estimateSwapExactAmountInQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.estimateSwapExactAmountIn(request);
        }, options);
    };
    const useEstimateSwapExactAmountOut = ({ request, options }) => {
        return useQuery(["estimateSwapExactAmountOutQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.estimateSwapExactAmountOut(request);
        }, options);
    };
    return {
        usePools,
        useNumPools,
        useTotalLiquidity,
        /**
         * PoolsWithFilter allows you to query specific pools with requested
         * parameters
         */
        usePoolsWithFilter,
        /** Per Pool gRPC Endpoints */ usePool,
        /**
         * PoolType returns the type of the pool.
         * Returns "Balancer" as a string literal when the pool is a balancer pool.
         * Errors if the pool is failed to be type caseted.
         */
        usePoolType,
        /**
         * Simulates joining pool without a swap. Returns the amount of shares you'd
         * get and tokens needed to provide
         */
        useCalcJoinPoolNoSwapShares,
        useCalcJoinPoolShares,
        useCalcExitPoolCoinsFromShares,
        usePoolParams,
        useTotalPoolLiquidity,
        useTotalShares,
        /**
         * SpotPrice defines a gRPC query handler that returns the spot price given
         * a base denomination and a quote denomination.
         */
        useSpotPrice,
        /** Estimate the swap. */ useEstimateSwapExactAmountIn,
        useEstimateSwapExactAmountOut
    };
};
