import { TelescopeGeneratedType } from "../../../types";
import { Registry } from "@cosmjs/proto-signing";
import { MsgJoinPool, MsgExitPool, MsgSwapExactAmountIn, MsgSwapExactAmountOut, MsgJoinSwapExternAmountIn, MsgJoinSwapShareAmountOut, MsgExitSwapExternAmountOut, MsgExitSwapShareAmountIn } from "./tx";
export declare const registry: ReadonlyArray<[string, TelescopeGeneratedType<any, any, any>]>;
export declare const load: (protoRegistry: Registry) => void;
export declare const MessageComposer: {
    encoded: {
        joinPool(value: MsgJoinPool): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        exitPool(value: MsgExitPool): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        swapExactAmountIn(value: MsgSwapExactAmountIn): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        swapExactAmountOut(value: MsgSwapExactAmountOut): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        joinSwapExternAmountIn(value: MsgJoinSwapExternAmountIn): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        joinSwapShareAmountOut(value: MsgJoinSwapShareAmountOut): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        exitSwapExternAmountOut(value: MsgExitSwapExternAmountOut): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
        exitSwapShareAmountIn(value: MsgExitSwapShareAmountIn): {
            typeUrl: string;
            value: Uint8Array<ArrayBufferLike>;
        };
    };
    withTypeUrl: {
        joinPool(value: MsgJoinPool): {
            typeUrl: string;
            value: MsgJoinPool;
        };
        exitPool(value: MsgExitPool): {
            typeUrl: string;
            value: MsgExitPool;
        };
        swapExactAmountIn(value: MsgSwapExactAmountIn): {
            typeUrl: string;
            value: MsgSwapExactAmountIn;
        };
        swapExactAmountOut(value: MsgSwapExactAmountOut): {
            typeUrl: string;
            value: MsgSwapExactAmountOut;
        };
        joinSwapExternAmountIn(value: MsgJoinSwapExternAmountIn): {
            typeUrl: string;
            value: MsgJoinSwapExternAmountIn;
        };
        joinSwapShareAmountOut(value: MsgJoinSwapShareAmountOut): {
            typeUrl: string;
            value: MsgJoinSwapShareAmountOut;
        };
        exitSwapExternAmountOut(value: MsgExitSwapExternAmountOut): {
            typeUrl: string;
            value: MsgExitSwapExternAmountOut;
        };
        exitSwapShareAmountIn(value: MsgExitSwapShareAmountIn): {
            typeUrl: string;
            value: MsgExitSwapShareAmountIn;
        };
    };
    toJSON: {
        joinPool(value: MsgJoinPool): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                shareOutAmount: string;
                tokenInMaxs: {
                    denom: string;
                    amount: string;
                }[];
            };
        };
        exitPool(value: MsgExitPool): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                shareInAmount: string;
                tokenOutMins: {
                    denom: string;
                    amount: string;
                }[];
            };
        };
        swapExactAmountIn(value: MsgSwapExactAmountIn): {
            typeUrl: string;
            value: {
                sender: string;
                routes: {
                    poolId: string;
                    tokenOutDenom: string;
                }[];
                tokenIn: {
                    denom: string;
                    amount: string;
                };
                tokenOutMinAmount: string;
            };
        };
        swapExactAmountOut(value: MsgSwapExactAmountOut): {
            typeUrl: string;
            value: {
                sender: string;
                routes: {
                    poolId: string;
                    tokenInDenom: string;
                }[];
                tokenInMaxAmount: string;
                tokenOut: {
                    denom: string;
                    amount: string;
                };
            };
        };
        joinSwapExternAmountIn(value: MsgJoinSwapExternAmountIn): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                tokenIn: {
                    denom: string;
                    amount: string;
                };
                shareOutMinAmount: string;
            };
        };
        joinSwapShareAmountOut(value: MsgJoinSwapShareAmountOut): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                tokenInDenom: string;
                shareOutAmount: string;
                tokenInMaxAmount: string;
            };
        };
        exitSwapExternAmountOut(value: MsgExitSwapExternAmountOut): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                tokenOut: {
                    denom: string;
                    amount: string;
                };
                shareInMaxAmount: string;
            };
        };
        exitSwapShareAmountIn(value: MsgExitSwapShareAmountIn): {
            typeUrl: string;
            value: {
                sender: string;
                poolId: string;
                tokenOutDenom: string;
                shareInAmount: string;
                tokenOutMinAmount: string;
            };
        };
    };
    fromJSON: {
        joinPool(value: any): {
            typeUrl: string;
            value: MsgJoinPool;
        };
        exitPool(value: any): {
            typeUrl: string;
            value: MsgExitPool;
        };
        swapExactAmountIn(value: any): {
            typeUrl: string;
            value: MsgSwapExactAmountIn;
        };
        swapExactAmountOut(value: any): {
            typeUrl: string;
            value: MsgSwapExactAmountOut;
        };
        joinSwapExternAmountIn(value: any): {
            typeUrl: string;
            value: MsgJoinSwapExternAmountIn;
        };
        joinSwapShareAmountOut(value: any): {
            typeUrl: string;
            value: MsgJoinSwapShareAmountOut;
        };
        exitSwapExternAmountOut(value: any): {
            typeUrl: string;
            value: MsgExitSwapExternAmountOut;
        };
        exitSwapShareAmountIn(value: any): {
            typeUrl: string;
            value: MsgExitSwapShareAmountIn;
        };
    };
    fromPartial: {
        joinPool(value: MsgJoinPool): {
            typeUrl: string;
            value: MsgJoinPool;
        };
        exitPool(value: MsgExitPool): {
            typeUrl: string;
            value: MsgExitPool;
        };
        swapExactAmountIn(value: MsgSwapExactAmountIn): {
            typeUrl: string;
            value: MsgSwapExactAmountIn;
        };
        swapExactAmountOut(value: MsgSwapExactAmountOut): {
            typeUrl: string;
            value: MsgSwapExactAmountOut;
        };
        joinSwapExternAmountIn(value: MsgJoinSwapExternAmountIn): {
            typeUrl: string;
            value: MsgJoinSwapExternAmountIn;
        };
        joinSwapShareAmountOut(value: MsgJoinSwapShareAmountOut): {
            typeUrl: string;
            value: MsgJoinSwapShareAmountOut;
        };
        exitSwapExternAmountOut(value: MsgExitSwapExternAmountOut): {
            typeUrl: string;
            value: MsgExitSwapExternAmountOut;
        };
        exitSwapShareAmountIn(value: MsgExitSwapShareAmountIn): {
            typeUrl: string;
            value: MsgExitSwapShareAmountIn;
        };
    };
};
