import { PageRequest } from "../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../helpers";
import { ModuleToDistributeCoinsResponse, GaugeByIDResponse, GaugesResponse, ActiveGaugesResponse, ActiveGaugesPerDenomResponse, UpcomingGaugesResponse, UpcomingGaugesPerDenomResponse, RewardsEstResponse, QueryLockableDurationsResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* ModuleToDistributeCoins returns coins that are going to be distributed */
    moduleToDistributeCoins = async (_params = {}) => {
        const endpoint = `osmosis/incentives/v1beta1/module_to_distribute_coins`;
        return ModuleToDistributeCoinsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* GaugeByID returns gauges by their respective ID */
    gaugeByID = async (params) => {
        const endpoint = `osmosis/incentives/v1beta1/gauge_by_id/${params.id}`;
        return GaugeByIDResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Gauges returns both upcoming and active gauges */
    gauges = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/incentives/v1beta1/gauges`;
        return GaugesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ActiveGauges returns active gauges */
    activeGauges = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/incentives/v1beta1/active_gauges`;
        return ActiveGaugesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* ActiveGaugesPerDenom returns active gauges by denom */
    activeGaugesPerDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/incentives/v1beta1/active_gauges_per_denom`;
        return ActiveGaugesPerDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns scheduled gauges that have not yet occured */
    upcomingGauges = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/incentives/v1beta1/upcoming_gauges`;
        return UpcomingGaugesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* UpcomingGaugesPerDenom returns scheduled gauges that have not yet occured
     by denom */
    upcomingGaugesPerDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/incentives/v1beta1/upcoming_gauges_per_denom`;
        return UpcomingGaugesPerDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* RewardsEst returns an estimate of the rewards from now until a specified
     time in the future The querier either provides an address or a set of locks
     for which they want to find the associated rewards */
    rewardsEst = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.lockIds !== "undefined") {
            options.params.lock_ids = params.lockIds;
        }
        if (typeof params?.endEpoch !== "undefined") {
            options.params.end_epoch = params.endEpoch;
        }
        const endpoint = `osmosis/incentives/v1beta1/rewards_est/${params.owner}`;
        return RewardsEstResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* LockableDurations returns lockable durations that are valid to distribute
     incentives for */
    lockableDurations = async (_params = {}) => {
        const endpoint = `osmosis/incentives/v1beta1/lockable_durations`;
        return QueryLockableDurationsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
