import { PageRequest } from "../../cosmos/base/query/v1beta1/pagination";
import { BinaryReader } from "../../binary";
import { ModuleToDistributeCoinsRequest, ModuleToDistributeCoinsResponse, GaugeByIDRequest, GaugeByIDResponse, GaugesRequest, GaugesResponse, ActiveGaugesRequest, ActiveGaugesResponse, ActiveGaugesPerDenomRequest, ActiveGaugesPerDenomResponse, UpcomingGaugesRequest, UpcomingGaugesResponse, UpcomingGaugesPerDenomRequest, UpcomingGaugesPerDenomResponse, RewardsEstRequest, RewardsEstResponse, QueryLockableDurationsRequest, QueryLockableDurationsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* ModuleToDistributeCoins returns coins that are going to be distributed */
    moduleToDistributeCoins = async (request = {}) => {
        const data = ModuleToDistributeCoinsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "ModuleToDistributeCoins", data);
        return promise.then(data => ModuleToDistributeCoinsResponse.decode(new BinaryReader(data)));
    };
    /* GaugeByID returns gauges by their respective ID */
    gaugeByID = async (request) => {
        const data = GaugeByIDRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "GaugeByID", data);
        return promise.then(data => GaugeByIDResponse.decode(new BinaryReader(data)));
    };
    /* Gauges returns both upcoming and active gauges */
    gauges = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = GaugesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "Gauges", data);
        return promise.then(data => GaugesResponse.decode(new BinaryReader(data)));
    };
    /* ActiveGauges returns active gauges */
    activeGauges = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = ActiveGaugesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "ActiveGauges", data);
        return promise.then(data => ActiveGaugesResponse.decode(new BinaryReader(data)));
    };
    /* ActiveGaugesPerDenom returns active gauges by denom */
    activeGaugesPerDenom = async (request) => {
        const data = ActiveGaugesPerDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "ActiveGaugesPerDenom", data);
        return promise.then(data => ActiveGaugesPerDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns scheduled gauges that have not yet occured */
    upcomingGauges = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = UpcomingGaugesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "UpcomingGauges", data);
        return promise.then(data => UpcomingGaugesResponse.decode(new BinaryReader(data)));
    };
    /* UpcomingGaugesPerDenom returns scheduled gauges that have not yet occured
     by denom */
    upcomingGaugesPerDenom = async (request) => {
        const data = UpcomingGaugesPerDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "UpcomingGaugesPerDenom", data);
        return promise.then(data => UpcomingGaugesPerDenomResponse.decode(new BinaryReader(data)));
    };
    /* RewardsEst returns an estimate of the rewards from now until a specified
     time in the future The querier either provides an address or a set of locks
     for which they want to find the associated rewards */
    rewardsEst = async (request) => {
        const data = RewardsEstRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "RewardsEst", data);
        return promise.then(data => RewardsEstResponse.decode(new BinaryReader(data)));
    };
    /* LockableDurations returns lockable durations that are valid to distribute
     incentives for */
    lockableDurations = async (request = {}) => {
        const data = QueryLockableDurationsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.incentives.Query", "LockableDurations", data);
        return promise.then(data => QueryLockableDurationsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
