import { ModuleBalanceResponse, ModuleLockedAmountResponse, AccountUnlockableCoinsResponse, AccountUnlockingCoinsResponse, AccountLockedCoinsResponse, AccountLockedPastTimeResponse, AccountLockedPastTimeNotUnlockingOnlyResponse, AccountUnlockedBeforeTimeResponse, AccountLockedPastTimeDenomResponse, LockedDenomResponse, LockedResponse, SyntheticLockupsByLockupIDResponse, AccountLockedLongerDurationResponse, AccountLockedDurationResponse, AccountLockedLongerDurationNotUnlockingOnlyResponse, AccountLockedLongerDurationDenomResponse, QueryParamsResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Return full balance of the module */
    moduleBalance = async (_params = {}) => {
        const endpoint = `osmosis/lockup/v1beta1/module_balance`;
        return ModuleBalanceResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Return locked balance of the module */
    moduleLockedAmount = async (_params = {}) => {
        const endpoint = `osmosis/lockup/v1beta1/module_locked_amount`;
        return ModuleLockedAmountResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns unlockable coins which are not withdrawn yet */
    accountUnlockableCoins = async (params) => {
        const endpoint = `osmosis/lockup/v1beta1/account_unlockable_coins/${params.owner}`;
        return AccountUnlockableCoinsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns unlocking coins */
    accountUnlockingCoins = async (params) => {
        const endpoint = `osmosis/lockup/v1beta1/account_unlocking_coins/${params.owner}`;
        return AccountUnlockingCoinsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Return a locked coins that can't be withdrawn */
    accountLockedCoins = async (params) => {
        const endpoint = `osmosis/lockup/v1beta1/account_locked_coins/${params.owner}`;
        return AccountLockedCoinsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns locked records of an account with unlock time beyond timestamp */
    accountLockedPastTime = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.timestamp !== "undefined") {
            options.params.timestamp = params.timestamp;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_pasttime/${params.owner}`;
        return AccountLockedPastTimeResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns locked records of an account with unlock time beyond timestamp
     excluding tokens started unlocking */
    accountLockedPastTimeNotUnlockingOnly = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.timestamp !== "undefined") {
            options.params.timestamp = params.timestamp;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_pasttime_not_unlocking_only/${params.owner}`;
        return AccountLockedPastTimeNotUnlockingOnlyResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns unlocked records with unlock time before timestamp */
    accountUnlockedBeforeTime = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.timestamp !== "undefined") {
            options.params.timestamp = params.timestamp;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_unlocked_before_time/${params.owner}`;
        return AccountUnlockedBeforeTimeResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns lock records by address, timestamp, denom */
    accountLockedPastTimeDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.timestamp !== "undefined") {
            options.params.timestamp = params.timestamp;
        }
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_pasttime_denom/${params.owner}`;
        return AccountLockedPastTimeDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns total locked per denom with longer past given time */
    lockedDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        if (typeof params?.duration !== "undefined") {
            options.params.duration = params.duration;
        }
        const endpoint = `osmosis/lockup/v1beta1/locked_denom`;
        return LockedDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns lock record by id */
    lockedByID = async (params) => {
        const endpoint = `osmosis/lockup/v1beta1/locked_by_id/${params.lockId}`;
        return LockedResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns synthetic lockups by native lockup id */
    syntheticLockupsByLockupID = async (params) => {
        const endpoint = `osmosis/lockup/v1beta1/synthetic_lockups_by_lock_id/${params.lockId}`;
        return SyntheticLockupsByLockupIDResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns account locked records with longer duration */
    accountLockedLongerDuration = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.duration !== "undefined") {
            options.params.duration = params.duration;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_longer_duration/${params.owner}`;
        return AccountLockedLongerDurationResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns account locked records with a specific duration */
    accountLockedDuration = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.duration !== "undefined") {
            options.params.duration = params.duration;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_duration/${params.owner}`;
        return AccountLockedDurationResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns account locked records with longer duration excluding tokens
     started unlocking */
    accountLockedLongerDurationNotUnlockingOnly = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.duration !== "undefined") {
            options.params.duration = params.duration;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_longer_duration_not_unlocking_only/${params.owner}`;
        return AccountLockedLongerDurationNotUnlockingOnlyResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns account's locked records for a denom with longer duration */
    accountLockedLongerDurationDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.duration !== "undefined") {
            options.params.duration = params.duration;
        }
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/lockup/v1beta1/account_locked_longer_duration_denom/${params.owner}`;
        return AccountLockedLongerDurationDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Params returns lockup params. */
    params = async (_params = {}) => {
        const endpoint = `osmosis/lockup/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
