import { BinaryReader } from "../../binary";
import { ModuleBalanceRequest, ModuleBalanceResponse, ModuleLockedAmountRequest, ModuleLockedAmountResponse, AccountUnlockableCoinsRequest, AccountUnlockableCoinsResponse, AccountUnlockingCoinsRequest, AccountUnlockingCoinsResponse, AccountLockedCoinsRequest, AccountLockedCoinsResponse, AccountLockedPastTimeRequest, AccountLockedPastTimeResponse, AccountLockedPastTimeNotUnlockingOnlyRequest, AccountLockedPastTimeNotUnlockingOnlyResponse, AccountUnlockedBeforeTimeRequest, AccountUnlockedBeforeTimeResponse, AccountLockedPastTimeDenomRequest, AccountLockedPastTimeDenomResponse, LockedDenomRequest, LockedDenomResponse, LockedRequest, LockedResponse, SyntheticLockupsByLockupIDRequest, SyntheticLockupsByLockupIDResponse, AccountLockedLongerDurationRequest, AccountLockedLongerDurationResponse, AccountLockedDurationRequest, AccountLockedDurationResponse, AccountLockedLongerDurationNotUnlockingOnlyRequest, AccountLockedLongerDurationNotUnlockingOnlyResponse, AccountLockedLongerDurationDenomRequest, AccountLockedLongerDurationDenomResponse, QueryParamsRequest, QueryParamsResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Return full balance of the module */
    moduleBalance = async (request = {}) => {
        const data = ModuleBalanceRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "ModuleBalance", data);
        return promise.then(data => ModuleBalanceResponse.decode(new BinaryReader(data)));
    };
    /* Return locked balance of the module */
    moduleLockedAmount = async (request = {}) => {
        const data = ModuleLockedAmountRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "ModuleLockedAmount", data);
        return promise.then(data => ModuleLockedAmountResponse.decode(new BinaryReader(data)));
    };
    /* Returns unlockable coins which are not withdrawn yet */
    accountUnlockableCoins = async (request) => {
        const data = AccountUnlockableCoinsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountUnlockableCoins", data);
        return promise.then(data => AccountUnlockableCoinsResponse.decode(new BinaryReader(data)));
    };
    /* Returns unlocking coins */
    accountUnlockingCoins = async (request) => {
        const data = AccountUnlockingCoinsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountUnlockingCoins", data);
        return promise.then(data => AccountUnlockingCoinsResponse.decode(new BinaryReader(data)));
    };
    /* Return a locked coins that can't be withdrawn */
    accountLockedCoins = async (request) => {
        const data = AccountLockedCoinsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedCoins", data);
        return promise.then(data => AccountLockedCoinsResponse.decode(new BinaryReader(data)));
    };
    /* Returns locked records of an account with unlock time beyond timestamp */
    accountLockedPastTime = async (request) => {
        const data = AccountLockedPastTimeRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedPastTime", data);
        return promise.then(data => AccountLockedPastTimeResponse.decode(new BinaryReader(data)));
    };
    /* Returns locked records of an account with unlock time beyond timestamp
     excluding tokens started unlocking */
    accountLockedPastTimeNotUnlockingOnly = async (request) => {
        const data = AccountLockedPastTimeNotUnlockingOnlyRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedPastTimeNotUnlockingOnly", data);
        return promise.then(data => AccountLockedPastTimeNotUnlockingOnlyResponse.decode(new BinaryReader(data)));
    };
    /* Returns unlocked records with unlock time before timestamp */
    accountUnlockedBeforeTime = async (request) => {
        const data = AccountUnlockedBeforeTimeRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountUnlockedBeforeTime", data);
        return promise.then(data => AccountUnlockedBeforeTimeResponse.decode(new BinaryReader(data)));
    };
    /* Returns lock records by address, timestamp, denom */
    accountLockedPastTimeDenom = async (request) => {
        const data = AccountLockedPastTimeDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedPastTimeDenom", data);
        return promise.then(data => AccountLockedPastTimeDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns total locked per denom with longer past given time */
    lockedDenom = async (request) => {
        const data = LockedDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "LockedDenom", data);
        return promise.then(data => LockedDenomResponse.decode(new BinaryReader(data)));
    };
    /* Returns lock record by id */
    lockedByID = async (request) => {
        const data = LockedRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "LockedByID", data);
        return promise.then(data => LockedResponse.decode(new BinaryReader(data)));
    };
    /* Returns synthetic lockups by native lockup id */
    syntheticLockupsByLockupID = async (request) => {
        const data = SyntheticLockupsByLockupIDRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "SyntheticLockupsByLockupID", data);
        return promise.then(data => SyntheticLockupsByLockupIDResponse.decode(new BinaryReader(data)));
    };
    /* Returns account locked records with longer duration */
    accountLockedLongerDuration = async (request) => {
        const data = AccountLockedLongerDurationRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedLongerDuration", data);
        return promise.then(data => AccountLockedLongerDurationResponse.decode(new BinaryReader(data)));
    };
    /* Returns account locked records with a specific duration */
    accountLockedDuration = async (request) => {
        const data = AccountLockedDurationRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedDuration", data);
        return promise.then(data => AccountLockedDurationResponse.decode(new BinaryReader(data)));
    };
    /* Returns account locked records with longer duration excluding tokens
     started unlocking */
    accountLockedLongerDurationNotUnlockingOnly = async (request) => {
        const data = AccountLockedLongerDurationNotUnlockingOnlyRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedLongerDurationNotUnlockingOnly", data);
        return promise.then(data => AccountLockedLongerDurationNotUnlockingOnlyResponse.decode(new BinaryReader(data)));
    };
    /* Returns account's locked records for a denom with longer duration */
    accountLockedLongerDurationDenom = async (request) => {
        const data = AccountLockedLongerDurationDenomRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "AccountLockedLongerDurationDenom", data);
        return promise.then(data => AccountLockedLongerDurationDenomResponse.decode(new BinaryReader(data)));
    };
    /* Params returns lockup params. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.lockup.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
