import { Minter, Params } from "./mint";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { isSet } from "../../../helpers";
export const protobufPackage = "osmosis.mint.v1beta1";
function createBaseGenesisState() {
    return {
        minter: Minter.fromPartial({}),
        params: Params.fromPartial({}),
        reductionStartedEpoch: BigInt(0)
    };
}
export const GenesisState = {
    typeUrl: "/osmosis.mint.v1beta1.GenesisState",
    aminoType: "osmosis/mint/genesis-state",
    is(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Minter.is(o.minter) && Params.is(o.params) && typeof o.reductionStartedEpoch === "bigint");
    },
    isSDK(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Minter.isSDK(o.minter) && Params.isSDK(o.params) && typeof o.reduction_started_epoch === "bigint");
    },
    isAmino(o) {
        return o && (o.$typeUrl === GenesisState.typeUrl || Minter.isAmino(o.minter) && Params.isAmino(o.params) && typeof o.reduction_started_epoch === "bigint");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.minter !== undefined) {
            Minter.encode(message.minter, writer.uint32(10).fork()).ldelim();
        }
        if (message.params !== undefined) {
            Params.encode(message.params, writer.uint32(18).fork()).ldelim();
        }
        if (message.reductionStartedEpoch !== undefined) {
            writer.uint32(24).int64(message.reductionStartedEpoch);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseGenesisState();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.minter = Minter.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.params = Params.decode(reader, reader.uint32());
                    break;
                case 3:
                    message.reductionStartedEpoch = reader.int64();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseGenesisState();
        if (isSet(object.minter))
            obj.minter = Minter.fromJSON(object.minter);
        if (isSet(object.params))
            obj.params = Params.fromJSON(object.params);
        if (isSet(object.reductionStartedEpoch))
            obj.reductionStartedEpoch = BigInt(object.reductionStartedEpoch.toString());
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.minter !== undefined && (obj.minter = message.minter ? Minter.toJSON(message.minter) : undefined);
        message.params !== undefined && (obj.params = message.params ? Params.toJSON(message.params) : undefined);
        message.reductionStartedEpoch !== undefined && (obj.reductionStartedEpoch = (message.reductionStartedEpoch || BigInt(0)).toString());
        return obj;
    },
    fromPartial(object) {
        const message = createBaseGenesisState();
        if (object.minter !== undefined && object.minter !== null) {
            message.minter = Minter.fromPartial(object.minter);
        }
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromPartial(object.params);
        }
        if (object.reductionStartedEpoch !== undefined && object.reductionStartedEpoch !== null) {
            message.reductionStartedEpoch = BigInt(object.reductionStartedEpoch.toString());
        }
        return message;
    },
    fromSDK(object) {
        return {
            minter: object.minter ? Minter.fromSDK(object.minter) : undefined,
            params: object.params ? Params.fromSDK(object.params) : undefined,
            reductionStartedEpoch: object?.reduction_started_epoch
        };
    },
    fromSDKJSON(object) {
        return {
            minter: isSet(object.minter) ? Minter.fromSDKJSON(object.minter) : undefined,
            params: isSet(object.params) ? Params.fromSDKJSON(object.params) : undefined,
            reduction_started_epoch: isSet(object.reduction_started_epoch) ? BigInt(object.reduction_started_epoch.toString()) : BigInt(0)
        };
    },
    toSDK(message) {
        const obj = {};
        message.minter !== undefined && (obj.minter = message.minter ? Minter.toSDK(message.minter) : undefined);
        message.params !== undefined && (obj.params = message.params ? Params.toSDK(message.params) : undefined);
        obj.reduction_started_epoch = message.reductionStartedEpoch;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseGenesisState();
        if (object.minter !== undefined && object.minter !== null) {
            message.minter = Minter.fromAmino(object.minter);
        }
        if (object.params !== undefined && object.params !== null) {
            message.params = Params.fromAmino(object.params);
        }
        if (object.reduction_started_epoch !== undefined && object.reduction_started_epoch !== null) {
            message.reductionStartedEpoch = BigInt(object.reduction_started_epoch);
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.minter = message.minter ? Minter.toAmino(message.minter) : undefined;
        obj.params = message.params ? Params.toAmino(message.params) : undefined;
        obj.reduction_started_epoch = message.reductionStartedEpoch !== BigInt(0) ? message.reductionStartedEpoch?.toString() : undefined;
        return obj;
    },
    fromAminoMsg(object) {
        return GenesisState.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/mint/genesis-state",
            value: GenesisState.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return GenesisState.decode(message.value);
    },
    toProto(message) {
        return GenesisState.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.mint.v1beta1.GenesisState",
            value: GenesisState.encode(message).finish()
        };
    },
    registerTypeUrl() {
        Minter.registerTypeUrl();
        Params.registerTypeUrl();
    }
};
