import { BinaryReader } from "../../../binary";
import { QueryGaugeIdsRequest, QueryGaugeIdsResponse, QueryDistrInfoRequest, QueryDistrInfoResponse, QueryParamsRequest, QueryParamsResponse, QueryLockableDurationsRequest, QueryLockableDurationsResponse, QueryIncentivizedPoolsRequest, QueryIncentivizedPoolsResponse, QueryExternalIncentiveGaugesRequest, QueryExternalIncentiveGaugesResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* GaugeIds takes the pool id and returns the matching gauge ids and durations */
    gaugeIds = async (request) => {
        const data = QueryGaugeIdsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "GaugeIds", data);
        return promise.then(data => QueryGaugeIdsResponse.decode(new BinaryReader(data)));
    };
    /* DistrInfo returns the pool's matching gauge ids and weights. */
    distrInfo = async (request = {}) => {
        const data = QueryDistrInfoRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "DistrInfo", data);
        return promise.then(data => QueryDistrInfoResponse.decode(new BinaryReader(data)));
    };
    /* Params returns pool incentives params. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* LockableDurations returns lock durations for pools. */
    lockableDurations = async (request = {}) => {
        const data = QueryLockableDurationsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "LockableDurations", data);
        return promise.then(data => QueryLockableDurationsResponse.decode(new BinaryReader(data)));
    };
    /* IncentivizedPools returns currently incentivized pools */
    incentivizedPools = async (request = {}) => {
        const data = QueryIncentivizedPoolsRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "IncentivizedPools", data);
        return promise.then(data => QueryIncentivizedPoolsResponse.decode(new BinaryReader(data)));
    };
    /* ExternalIncentiveGauges returns external incentive gauges. */
    externalIncentiveGauges = async (request = {}) => {
        const data = QueryExternalIncentiveGaugesRequest.encode(request).finish();
        const promise = this.rpc.request("osmosis.poolincentives.v1beta1.Query", "ExternalIncentiveGauges", data);
        return promise.then(data => QueryExternalIncentiveGaugesResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
