import { BinaryReader, BinaryWriter } from "../../binary";
import { Decimal } from "@cosmjs/math";
import { isSet } from "../../helpers";
export const protobufPackage = "osmosis.superfluid";
function createBaseParams() {
    return {
        minimumRiskFactor: ""
    };
}
export const Params = {
    typeUrl: "/osmosis.superfluid.Params",
    aminoType: "osmosis/params",
    is(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.minimumRiskFactor === "string");
    },
    isSDK(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.minimum_risk_factor === "string");
    },
    isAmino(o) {
        return o && (o.$typeUrl === Params.typeUrl || typeof o.minimum_risk_factor === "string");
    },
    encode(message, writer = BinaryWriter.create()) {
        if (message.minimumRiskFactor !== undefined) {
            writer.uint32(10).string(Decimal.fromUserInput(message.minimumRiskFactor, 18).atomics);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof BinaryReader ? input : new BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseParams();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.minimumRiskFactor = Decimal.fromAtomics(reader.string(), 18).toString();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromJSON(object) {
        const obj = createBaseParams();
        if (isSet(object.minimumRiskFactor))
            obj.minimumRiskFactor = String(object.minimumRiskFactor);
        return obj;
    },
    toJSON(message) {
        const obj = {};
        message.minimumRiskFactor !== undefined && (obj.minimumRiskFactor = message.minimumRiskFactor);
        return obj;
    },
    fromPartial(object) {
        const message = createBaseParams();
        message.minimumRiskFactor = object.minimumRiskFactor ?? "";
        return message;
    },
    fromSDK(object) {
        return {
            minimumRiskFactor: object?.minimum_risk_factor
        };
    },
    fromSDKJSON(object) {
        return {
            minimum_risk_factor: isSet(object.minimum_risk_factor) ? String(object.minimum_risk_factor) : ""
        };
    },
    toSDK(message) {
        const obj = {};
        obj.minimum_risk_factor = message.minimumRiskFactor;
        return obj;
    },
    fromAmino(object) {
        const message = createBaseParams();
        if (object.minimum_risk_factor !== undefined && object.minimum_risk_factor !== null) {
            message.minimumRiskFactor = object.minimum_risk_factor;
        }
        return message;
    },
    toAmino(message) {
        const obj = {};
        obj.minimum_risk_factor = message.minimumRiskFactor === "" ? undefined : message.minimumRiskFactor;
        return obj;
    },
    fromAminoMsg(object) {
        return Params.fromAmino(object.value);
    },
    toAminoMsg(message) {
        return {
            type: "osmosis/params",
            value: Params.toAmino(message)
        };
    },
    fromProtoMsg(message) {
        return Params.decode(message.value);
    },
    toProto(message) {
        return Params.encode(message).finish();
    },
    toProtoMsg(message) {
        return {
            typeUrl: "/osmosis.superfluid.Params",
            value: Params.encode(message).finish()
        };
    },
    registerTypeUrl() { }
};
